/*
 Copyright 2009-2020 Rumma & Ko Ltd
 License: BSD (see file COPYING for details)
*/

// lino.js --- generated Fri Mar 26 01:39:31 2021 by Lino Amici 20.12.0 for 900 (Verwalter).
Ext.BLANK_IMAGE_URL = '/static/ext-3.3.1/resources/images/default/s.gif';
LANGUAGE_CHOICES = [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ];
MEDIA_URL = "/media/";
GEN_TIMESTAMP = 1616722555.1958566;

// hack to add a toCamel function, inspired by
// http://jamesroberts.name/blog/2010/02/22/string-functions-for-javascript-trim-to-camel-case-to-dashed-and-to-underscore/
String.prototype.toCamel = function(){
  //~ return this.replace(/(\-[a-z])/g, function($1){return $1.toUpperCase().replace('-','');});
  //~ return this;
  return this.replace(/([A-Z])([A-Z]+)/g, function(match,p1,p2,offset,string){
      //~ console.log("20131005 got ",arguments);
      return p1 + p2.toLowerCase();});
};

if (!Array.prototype.last) {
    Array.prototype.last = function () {
        return this[this.length - 1];
    }
}


// 20151126 hack to modify Ext.EventObjectImpl.isSpecialKey() which
// returned false for Ctrl-S when called from a keyup handler (namely
// ComboBox.onLoad)

Ext.EventObjectImpl.prototype.isSpecialKey = function(){
    // same as original except for one line
    var k = this.normalizeKey(this.keyCode);
    // return (this.type == 'keypress' && this.ctrlKey) ||
    return (this.ctrlKey) ||
        this.isNavKeyPress() ||
        (k == this.BACKSPACE) ||
        (k >= 16 && k <= 20) ||
        (k >= 44 && k <= 46);
};





/* MonthPickerPlugin: thanks to keypoint @ sencha forum
   http://www.sencha.com/forum/showthread.php?74002-3.x-Ext.ux.MonthMenu&p=356860#post356860
*/
Ext.namespace('Ext.ux');

Ext.ux.MonthPickerPlugin = function() {
    var picker;
    var oldDateDefaults;

    this.init = function(pk) {
        picker = pk;
        picker.onTriggerClick = picker.onTriggerClick.createSequence(onClick);
        picker.getValue = picker.getValue.createInterceptor(setDefaultMonthDay).createSequence(restoreDefaultMonthDay);
        picker.beforeBlur = picker.beforeBlur.createInterceptor(setDefaultMonthDay).createSequence(restoreDefaultMonthDay);
    };

    function setDefaultMonthDay() {
        oldDateDefaults = Date.defaults.d;
        Date.defaults.d = 1;
        return true;
    }

    function restoreDefaultMonthDay(ret) {
        Date.defaults.d = oldDateDefaults;
        return ret;
    }

    function onClick(e, el, opt) {
        var p = picker.menu.picker;
        p.activeDate = p.activeDate.getFirstDateOfMonth();
        if (p.value) {
            p.value = p.value.getFirstDateOfMonth();
        }

        p.showMonthPicker();

        if (!p.disabled) {
            p.monthPicker.stopFx();
            p.monthPicker.show();

            p.mun(p.monthPicker, 'click', p.onMonthClick, p);
            p.mun(p.monthPicker, 'dblclick', p.onMonthDblClick, p);
            p.onMonthClick = p.onMonthClick.createSequence(pickerClick);
            p.onMonthDblClick = p.onMonthDblClick.createSequence(pickerDblclick);
            p.mon(p.monthPicker, 'click', p.onMonthClick, p);
            p.mon(p.monthPicker, 'dblclick', p.onMonthDblClick, p);
        }
    }

    function pickerClick(e, t) {
        var el = new Ext.Element(t);
        if (el.is('button.x-date-mp-cancel')) {
            picker.menu.hide();
        } else if(el.is('button.x-date-mp-ok')) {
            var p = picker.menu.picker;
            p.setValue(p.activeDate);
            p.fireEvent('select', p, p.value);
        }
    }

    function pickerDblclick(e, t) {
        var el = new Ext.Element(t);
        if (el.parent()
            && (el.parent().is('td.x-date-mp-month')
            || el.parent().is('td.x-date-mp-year'))) {

            var p = picker.menu.picker;
            p.setValue(p.activeDate);
            p.fireEvent('select', p, p.value);
        }
    }
};

Ext.preg('monthPickerPlugin', Ext.ux.MonthPickerPlugin);

// Override this function to put the listeners always on the keydown event regardless of the browser.See #2887
Ext.EventManager.getKeyEvent = function() {
  return 'keydown';
};

/**
JC Watsons solution (adapted to ExtJS 3.3.1 by LS) is elegant and simple:
`A "fix" for unchecked checkbox submission  behaviour
<http://www.sencha.com/forum/showthread.php?28449>`_

Added special handling for checkbox inputs.
ExtJS defines disabled checkboxes `readonly`, not `disabled` as for other inputs.

*/
Ext.lib.Ajax.serializeForm = function(form) {
    // console.log('20170731 linolib.js serializeForm', form);
    var fElements = form.elements || (document.forms[form] || Ext.getDom(form)).elements,
        hasSubmit = false,
        encoder = encodeURIComponent,
        name,
        data = '',
        type,
        hasValue;

    Ext.each(fElements, function(element){
        name = element.name;
        type = element.type;

        if (!element.disabled && name && !(type == 'checkbox' && element.readonly)) {
            if (/select-(one|multiple)/i.test(type)) {
                Ext.each(element.options, function(opt){
                    if (opt.selected) {
                        hasValue = opt.hasAttribute ? opt.hasAttribute('value') : opt.getAttributeNode('value').specified;
                        data += String.format("{0}={1}&", encoder(name), encoder(hasValue ? opt.value : opt.text));
                    }
                });
            } else if (!(/file|undefined|reset|button/i.test(type))) {
                //~ if (!(/radio|checkbox/i.test(type) && !element.checked) && !(type == 'submit' && hasSubmit)) {
                if (!(type == 'submit' && hasSubmit)) {
                    if (type == 'checkbox') {
                        //~ console.log('20111001',element,'data += ',encoder(name) + '=' + (element.checked ? 'on' : 'off') + '&');
                        data += encoder(name) + '=' + (element.checked ? 'on' : 'off') + '&';
                    } else {
                        //~ console.log('20111001',element,'data += ',encoder(name) + '=' + encoder(element.value) + '&');
                        data += encoder(name) + '=' + encoder(element.value) + '&';
                    }
                    hasSubmit = /submit/i.test(type);
                }
            }
        //~ } else {
            //~ console.log(name,type,element.readonly);
        }
    });
    return data.substr(0, data.length - 1);
};



/*
Set a long timeout of fifteen minutes.
See /blog/2012/0307
*/
Ext.Ajax.timeout = 15 * 60 * 1000;

/*
 * Thanks to
 * `huuze <http://stackoverflow.com/users/10040/huuuze>`_ for the question
 * and to
 * `chrisv <http://stackoverflow.com/users/683808/chrisv>`_
 * for the answer on
 * http://stackoverflow.com/questions/3764589/how-do-i-include-django-1-2s-csrf-token-in-a-javascript-generated-html-form/5485616#5485616
 *
 * */

Ext.Ajax.on('beforerequest', function (conn, options) {
   if (!(/^http:.*/.test(options.url) || /^https:.*/.test(options.url))) {
     if (typeof(options.headers) == "undefined") {
       options.headers = {'X-CSRFToken': Ext.util.Cookies.get('csrftoken')};
     } else {
       options.headers['X-CSRFToken'] = Ext.util.Cookies.get('csrftoken');
     }
   }
}, this);

// Ext.apply(Ext.EventManager, function(){
//     return{
//         getKeyEvent : function(){
//                //return useKeydown ? 'keydown' : 'keypress';
//            return 'keydown';
//            },
// }});

/* This probably worked, but was not used in real world.
My fix for the "Cannot set QuickTips dismissDelay to 0" bug,
see http://www.sencha.com/forum/showthread.php?183515

*/
// Ext.override(Ext.QuickTip,{
//   showAt : function(xy){
//         var t = this.activeTarget;
//         // console.log("20171024 QuickTip.showAt",this.title,this.dismissDelay,t.dismissDelay);
//         if(t){
//             if(!this.rendered){
//                 this.render(Ext.getBody());
//                 this.activeTarget = t;
//             }
//             if(t.width){
//                 this.setWidth(t.width);
//                 this.body.setWidth(this.adjustBodyWidth(t.width - this.getFrameWidth()));
//                 this.measureWidth = false;
//             } else{
//                 this.measureWidth = true;
//             }
//             this.setTitle(t.title || '');
//             this.body.update(t.text);
//             this.autoHide = t.autoHide;
//             // bugfix by Luc 20120226
//             if (t.dismissDelay != undefined) this.dismissDelay = t.dismissDelay;
//             //~ this.dismissDelay = t.dismissDelay || this.dismissDelay;
//             if(this.lastCls){
//                 this.el.removeClass(this.lastCls);
//                 delete this.lastCls;
//             }
//             if(t.cls){
//                 this.el.addClass(t.cls);
//                 this.lastCls = t.cls;
//             }
//             if(this.anchor){
//                 this.constrainPosition = false;
//             }else if(t.align){
//                 xy = this.el.getAlignToXY(t.el, t.align);
//                 this.constrainPosition = false;
//             }else{
//                 this.constrainPosition = true;
//             }
//         }
//         Ext.QuickTip.superclass.showAt.call(this, xy);
//     }
// });

/*
Another hack. See /docs/blog/2012/0228
*/
Ext.Element.addMethods(
    function() {
        var VISIBILITY      = "visibility",
            DISPLAY         = "display",
            HIDDEN          = "hidden",
            NONE            = "none",
            XMASKED         = "x-masked",
            XMASKEDRELATIVE = "x-masked-relative",
            data            = Ext.Element.data;

        return {

            mask : function(msg, msgCls) {
                var me  = this,
                    dom = me.dom,
                    dh  = Ext.DomHelper,
                    EXTELMASKMSG = "ext-el-mask-msg",
                    el,
                    mask;
                // removed the following lines. See /docs/blog/2012/0228
                //~ if (!(/^body/i.test(dom.tagName) && me.getStyle('position') == 'static')) {
                    //~ console.log(20120228,dom.tagName,me);
                    //~ me.addClass(XMASKEDRELATIVE);
                //~ }
                if (el = data(dom, 'maskMsg')) {
                    el.remove();
                }
                if (el = data(dom, 'mask')) {
                    el.remove();
                }

                mask = dh.append(dom, {cls : "ext-el-mask"}, true);
                data(dom, 'mask', mask);

                me.addClass(XMASKED);
                mask.setDisplayed(true);

                if (typeof msg == 'string') {
                    var mm = dh.append(dom, {cls : EXTELMASKMSG, cn:{tag:'div'}}, true);
                    data(dom, 'maskMsg', mm);
                    mm.dom.className = msgCls ? EXTELMASKMSG + " " + msgCls : EXTELMASKMSG;
                    mm.dom.firstChild.innerHTML = msg;
                    mm.setDisplayed(true);
                    mm.center(me);
                }


                if (Ext.isIE && !(Ext.isIE7 && Ext.isStrict) && me.getStyle('height') == 'auto') {
                    mask.setSize(undefined, me.getHeight());
                }

                return mask;
            }


        };
    }()
);



Ext.namespace('Lino');

Lino.insert_linoweb_version = function(p){
    p.lv = GEN_TIMESTAMP;
};


//~ Lino.subst_user_field = new Ext.form.ComboBox({});
//~ Lino.subst_user = null;
Lino.insert_subst_user = function(p){
    Lino.insert_linoweb_version(p);
    //~ console.log('20120714 insert_subst_user',Lino.subst_user,p);
    if (!p.ul)
      if (Lino.user_language)
        p.ul = Lino.user_language;

    if (p.su) return;
    if (Lino.subst_user) {
        //~ p.su = Lino.subst_user_field.getValue();
        p.su = Lino.subst_user;
    //~ } else {
        //~ delete p.su;
    }
    //~ console.log('20120714 insert_subst_user -->',Lino.subst_user,p);
}

// Lino.login_window = null;



Lino.set_subst_user = function(id, name) {
    //~ console.log(20130723,'Lino.set_subst_user',id,name,Lino.current_window,Lino.viewport);
    Lino.subst_user = id;
    if (Lino.current_window)
        Lino.current_window.main_item.set_base_param("su",id);
    if (Lino.viewport)
        Lino.permalink_handler(Lino.current_window)();
}

Lino.set_user_language = function(lang) {
    Lino.user_language = lang;
    if (Lino.current_window)
        Lino.current_window.main_item.set_base_param("ul", lang);
    if (Lino.viewport)
        Lino.permalink_handler(Lino.current_window)();
}

Lino.goto_record_id = function(pk) {

    if (Lino.current_window)
        Lino.current_window.main_item.goto_record_id(pk);
}


//~ Lino.select_subst_user = function(cmp,rec,value){
    //~ Lino.subst_user=value;
    //~ console.log(20120713,rec);
//~ }

Lino.current_window = null;
Lino.window_history = Array();

Lino.chars2width = function(cols) {  return cols * 9; }
Lino.rows2height = function(cols) {  return cols * 20; }
Lino.perc2width = function(perc) {
    // var w = Math.max(document.documentElement.clientWidth, window.innerWidth);
    // console.log("20151226", document, window, w);
    var w = Lino.viewport.getWidth();
    return w * perc / 100;
}



Lino.MainPanel = {
  is_home_page: false
  ,auto_apply_params: true
  ,setting_param_values : false
  ,config_containing_window : function(wincfg) { }
  ,init_containing_window : function(win) { }
  ,is_loading : function() {
      if (!this.rendered) return true;
      //~ return (Ext.select('.x-loading-msg').elements.length > 0);
      return true;
    }
  ,do_when_clean : function(auto_save,todo) { todo() }
  ,get_master_params : function() {
    var p = {}
    p['mt'] = this.content_type;
    rec = this.get_current_record()
    if (rec) {
      if (rec.phantom) {
          p['mk'] = undefined;
      }else{
          p['mk'] = rec.id;
      }
    } else {
      p['mk'] = undefined;
    }
    //~ console.log('get_master_params returns',p,'using record',rec);
    return p;
  }
  ,get_permalink : function() {
    var p = Ext.apply({}, this.get_base_params());
    delete p.fmt;
    delete p.lv;
    Ext.apply(p, this.get_permalink_params());

    if (this.toggle_params_panel_btn) {
        p.sp = this.toggle_params_panel_btn.pressed;
        //~ if (this.toggle_params_panel_btn.pressed == this.params_panel_hidden) {
          //~ p.sp = true;
        //~ }
    }

    //~ Lino.insert_subst_user(p);
     //~ p.fmt = 'html';
    //~ console.log('get_permalink',p,this.get_permalink_params());
    if (this.is_home_page)
        //~ var url = '';
        var url = '/';
    else
        var url = this.get_permalink_url();
    if (p.su == null)
        delete p.su;
    if (Ext.urlEncode(p)) url = url + "?" + Ext.urlEncode(p);
    return url;
  }
  ,get_record_url : function(record_id) {
      var url = '/api' + this.ls_url
      //~ var url = this.containing_window.config.url_data; // ls_url;
      url += '/' + (record_id === undefined ? this.default_record_id : String(record_id));
      //~ if (record_id !== undefined) url += '/' + String(record_id);
      //~ url += '/' + String(record_id);
      return url;
  }
  ,get_permalink_url : function() {
      return '/api' + this.ls_url;
  }
  ,get_permalink_params : function() {
      //~ return {an:'grid'};
      var p = {};
      if (this.action_name)
          p.an = this.action_name;
      this.add_param_values(p,false)
      return p;
  }
  /*

  Lino.MainPanel.set_status() : the status can have the following keys:

  - param_values : values of parameter fields
  - field_values : values of action parameter fields
  - base_params
  - record_id
  - active_tab
  - data_record
  - show_params_panel
  - current_page

   */
  ,set_status : function(status, requesting_panel) {}
  ,get_status : function() { return {}}
  ,refresh : function() {}
  ,get_base_params : function() {  // Lino.MainPanel
    var p = {};
    Lino.insert_subst_user(p);
    Lino.insert_linoweb_version(p);
    return p;
  }
  ,add_params_panel : function (tbar) {
      if (this.params_panel) {
        //~  20130923b
        //~ this.params_panel.autoHeight = true; // 20130924
        var t = this;
        var update = function() {
            var p = t.params_panel;
            //~ console.log("update", p.getSize().height,p.forceLayout,p.autoHeight);
            var w = t.get_containing_window();
            Lino.do_when_visible(w, function() {
                //~ p.doLayout(true); // doLayout(shallow, force)
                w.doLayout(true); // doLayout(shallow, force)
                //~ t.params_panel.on('afterlayout',update,t,{single:true});
            });
        };
        Lino.do_when_visible(this.params_panel, update);
        this.params_panel.on('show',update);
        this.params_panel.on('hide',update);
        //~ this.params_panel.on('bodyresize',update);
        this.params_panel.on('afterlayout',update);
        //~ this.params_panel.on('afterlayout',update,this,{single:true});
        //~ this.params_panel.on('bodyresize',update,this,{single:true});
        //~ this.params_panel.on('resize',update,this,{single:true});
        //~ this.params_panel.on('render',update,this,{single:true});

        // this.params_panel.on('render',
        //~ this.params_panel.on('afterlayout',update,this,{single:true,delay:200});
        //~ this.params_panel.on('bodyresize',update,this,{single:true,delay:200});
        this.toggle_params_panel_btn = new Ext.Button({ scope:this,
          //~ text: "$_("[parameters]")", // gear
          iconCls: 'x-tbar-database_gear',
          tooltip:"Parameter-Panel ein- bzw. ausblenden",
          enableToggle: true,
          //~ pressed: ! this.params_panel.hidden,
          pressed: ! this.params_panel_hidden,
          toggleHandler: function(btn,state) {
            //~ console.log("20120210 add_params_panel",state,this.params_panel);
            if (state) {
                this.params_panel.show();
            } else {
                this.params_panel.hide();
            }
            //~ this.params_panel.on('afterlayout',update,this,{single:true});
            //~ t.get_containing_window().doLayout();
            //~ this.params_panel.on('afterlayout',function() {
                //~ console.log("20130918 afterlayout");
                //~ t.get_containing_window().doLayout(); // doLayout(shallow, force)
            //~ },this,{single:true});
          }
        });
        tbar = tbar.concat([this.toggle_params_panel_btn]);

        if (this.auto_apply_params) {
            var refresh = function() {
                if (!t.setting_param_values) {
                    t._force_dirty = true;
                    t.refresh();
                }
            }
            Ext.each(this.params_panel.fields,function(f) {
              //~ f.on('valid',function() {t.refresh()});
              if (f instanceof Ext.form.Checkbox) {
                  f.on('check',refresh);
//              } else if (f instanceof Ext.DatePicker) {
//                  f.on('select',refresh);
//                  console.log('Ext.DatePicker');
              } else if (f instanceof Ext.form.DateField) {
                  f.on('change',refresh);
              } else if (f instanceof Ext.form.TriggerField) {
                  f.on('select',refresh);
                  //~ f.on('change',refresh);
                  //~ f.on('valid',refresh);
              } else {
                  if (! f.on)
                      console.log("20121010 no method 'on'",f);
                  else
                      f.on('change',refresh);
                }
              });
        }
      }
      return tbar;
  }
  ,add_param_values : function (p,force_dirty) {
    if (this.params_panel) {
      /*
      * 20120918 add param_values to the request string
      * *only if the params_form is dirty*.
      * Otherwise Actor.default_params() would never be used.
      *
      * 20121023 But IntegClients.params_default has non-empty default values.
      * Users must have the possibility to make them empty.
      *
      * 20130605 : added `force_dirty` parameter because Checkbox fields don't
      * mark their form as dirty when check is fired.
      *
      * 20130721 : `force_dirty` not as a parameter but as
      * `this._force_dirty` because
      *
      * 20130915 : both _force_dirty and force_dirty parameter are needed.
      *
      */
      if (force_dirty || this._force_dirty || this.params_panel.form.isDirty()) {
      //~ if (this._force_dirty || this.params_panel.form.isDirty()) {
        p.pv = this.get_param_values();
        //~ console.log("20130923 form is dirty (",force_dirty,this._force_dirty,this.params_panel.form.isDirty(),")");
        //~ console.log("20130923 form is dirty",p);
      }else{
        //~ console.log("20130923 form not dirty:",this.params_panel.form);
        if (this.status_param_values)
          p.pv = Lino.fields2array(
            this.params_panel.fields,this.status_param_values);
      }
      //~ if (!this.params_panel.form.isDirty()) return;
      //~ p.pv = this.get_param_values();
      //~ console.log("20120203 add_param_values added pv",p.pv,"to",p);
    }
    else if(this.use_detail_params_value){
      p.pv = Lino.fields2array(this.ownerCt.ownerCt.ownerCt.params_panel.fields);
      }
  },
  get_param_values : function() { // similar to get_field_values()
      return Lino.fields2array(this.params_panel.fields);
  },
  set_param_values : function(pv) {
    if (this.params_panel) {
      //~ console.log('20120203 MainPanel.set_param_values', pv);
      this.status_param_values = pv;
      //~ this.params_panel.form.suspendEvents(false);
      this.setting_param_values = true;
      if (pv) {
          this.params_panel.form.my_loadRecord(pv);
      } else {
        this.params_panel.form.reset();
      }
      this.setting_param_values = false;
      this._force_dirty = false;
      //~ this.params_panel.form.resumeEvents();
    }
  }
};




Lino.Viewport = Ext.extend(Ext.Viewport, Lino.MainPanel);
Lino.Viewport = Ext.extend(Lino.Viewport, {
  layout : "fit"
  ,is_home_page : true
  ,initComponent : function(){
    Lino.Viewport.superclass.initComponent.call(this);
    this.on('render',function(){
      this.loadMask = new Ext.LoadMask(this.el,{msg:"Bitte warten..."});
      //~ console.log("20121118 Lino.viewport.loadMask",this.loadMask);
    },this);
  }
  ,refresh : function() {
      var caller = this;
      // console.log("20140829 Lino.Viewport.refresh()");
      if (caller.loadMask) caller.loadMask.show();
      var success = function(response) {
        if (caller.loadMask) caller.loadMask.hide();
        if (response.responseText) {
          var result = Ext.decode(response.responseText);
          //~ console.log('Lino.do_action()',action.name,'result is',result);
          if (result.html) {
              var cmp = Ext.getCmp('dashboard');
              // cmp.removeAll(true);  // 20140829
              cmp.update(result.html, true);
          }

        if (result.message) {
            //~ if (result.alert && ! gridmode) {
            if (result.alert) { // 20120628b
                //~ Ext.MessageBox.alert('Alert',result.alert_msg);
                if (result.alert === true) result.alert = "Alarm";
                Ext.MessageBox.alert(result.alert, result.message, function(){eval(result.alert_eval_js)});
            } else {
                Lino.notify(result.message);
            }
        }
          if (result.notify_msg) Lino.notify(result.notify_msg);
          if (result.js_code) {
            var jsr = result.js_code(caller);
            //~ console.log('Lino.do_action()',action,'returned from js_code in',result);
          };
        }
      };
      var p = {}
      Lino.insert_linoweb_version(p);
      var action = {
        url : '/api/main_html',
        waitMsg: "Bitte warten...",
        failure: Lino.ajax_error_handler(caller),
        success: success,
        method: 'GET',
        params: {}
      };
      Lino.insert_subst_user(action.params);
      Ext.Ajax.request(action);

  }
});




Lino.open_window = function(win, st, requesting_panel) {
  // console.log("20140831 Lino.open_window()", win, win.el.getBox());
  var cw = Lino.current_window;
  if (cw) {
    // console.log("20140829 Lino.open_window() save current status",
    //             cw.main_item.get_status());
    Lino.window_history.push({
      window:cw,
      status:cw.main_item.get_status()
    });
  }
  Lino.current_window = win;
  //~ if (st.su)
      //~ Lino.subst_user_field.setValue(st.su);
  win.main_item.set_status(st, requesting_panel);
  // win.toFront();
  win.show();
};

Lino.load_url = function(url) {
    //~ foo.bar.baz = 2;
    //~ console.log("20121120 Lino.load_url()");
    //~ Lino.body_loadMask.show();
    Lino.viewport.loadMask.show();
    //~ location.replace(url);
    document.location = url;
}

Lino.close_window = function(status_update, norestore) {
  // norestore is true when called by handle_action_result() who
  // will call set_status() itself later
  var cw = Lino.current_window;
  var ww = Lino.window_history.pop();
  var retval = cw.main_item.requesting_panel;
  // console.log(
  //     "20150514 Lino.close_window() going to close", cw.title,
  //     "previous is", ww,
  //     "norestore is", norestore,
  //     "retval is", retval);
  if (ww) {
    //~ if (status_update) Ext.apply(ww.status,status_update);
    if(!norestore) {
        if (status_update) status_update(ww);
        // 20180725 ww.window.main_item.set_status(ww.status , cw.id);
        ww.window.main_item.set_status(ww.status , retval);
    }
    Lino.current_window = ww.window;
  } else {
      Lino.current_window = null;
      // new since 20140829:
      if(!norestore) { Lino.viewport.refresh(); }
  }
  if (cw) cw.hide_really();
  return retval;
};

Lino.kill_current_window = function() {
  // console.log("20140418 Lino.kill_current_window()");
  var cw = Lino.current_window;
  Lino.current_window = null;
  if (cw) cw.hide_really();
};

Lino.reload = function() {
    // First close all windows to ensure all changes are saved
    Lino.close_all_windows();

    // Then reload current view
    var url =  "/"

    var p = {};
    Lino.insert_subst_user(p)
    if (Ext.urlEncode(p))
        url = url + "?" + Ext.urlEncode(p);

    Lino.load_url(url);
}

Lino.handle_home_button = function() {
  if (Lino.window_history.length == 0)
      Lino.reload();
  else
      Lino.close_all_windows();
}

Lino.close_all_windows = function() {
    while (Lino.window_history.length > 0) {
        Lino.close_window();
    }
}

Lino.calling_window = function() {
    if (Lino.window_history.length)
        return Lino.window_history[Lino.window_history.length-1];
}

//~ Lino.WindowAction = function(mainItemClass,windowConfig,mainConfig,ppf) {
Lino.WindowAction = function(windowConfig,main_item_fn) {
    //~ if(!mainConfig) mainConfig = {};
    //~ mainConfig.is_main_window = true;
    this.windowConfig = windowConfig;
    this.main_item_fn = main_item_fn;
    //~ if (ppf) mainConfig.params_panel.fields = ppf;
    //~ this.mainConfig = mainConfig;
    //~ this.mainItemClass = mainItemClass;
};

Lino.WindowAction = Ext.extend(Lino.WindowAction,{
    window : null,
    //~ mainItemClass: null,
    get_window : function() {
      //~ if(mainConfig) Ext.apply(this.mainConfig,mainConfig);
      // if (this.window == null || this.window.isDestroyed)  { // 20140829
      // if (this.window == null || this.window.getBox().width == 0)  { // 20140829
      if (this.window == null)  {
      // if (true)  {
          //~ this.windowConfig.main_item = new this.mainItemClass(this.mainConfig);
          this.windowConfig.main_item = this.main_item_fn();
          this.window = new Lino.Window(this.windowConfig);
      }
      return this.window;
    },
    run : function(requesting_panel, status) {
      // console.log('20140829 window_action.run()', this)
      Lino.open_window(this.get_window(), status, requesting_panel);
    }

});


Lino.PanelMixin = {
  get_containing_window : function (){
      if (this.containing_window) return this.containing_window;
      return this.containing_panel.get_containing_window();
  }
  ,set_window_title : function(title) {
    //~ this.setTitle(title);
    var cw = this.get_containing_window();

    //~ if (cw) {
    //~ if (cw && cw.closable) {
    if (cw && !cw.main_item.hide_window_title) {
      //~ console.log('20111202 set_window_title(',title,') for',this.containing_window);
      //~ if (! this.containing_window.rendered) console.log("WARNING: not rendered!");
      cw.setTitle(title);
    //~ } else {
      //~ document.title = title;
    }
    //~ else console.log('20111202 not set_window_title(',title,') for',this);
  }

};


// Lino.status_bar = new Ext.ux.StatusBar({defaultText:'Lino version 21.3.1.'});






/*
  Originally copied from Ext JS Library 3.3.1
  Modifications by Luc Saffre :
  - rendering of phantom records
  - fire afteredit event
  - react on dblclcik, not on single click

 */
Lino.CheckColumn = Ext.extend(Ext.grid.Column, {

    processEvent : function(name, e, grid, rowIndex, colIndex){
        //~ console.log('20110713 Lino.CheckColumn.processEvent',name)
        if (name == 'click') {
        //~ if (name == 'mousedown') {
        //~ if (name == 'dblclick') {
            return this.toggleValue(grid, rowIndex, colIndex);
        } else {
            return Ext.grid.ActionColumn.superclass.processEvent.apply(this, arguments);
        }
    },

    toggleValue : function (grid,rowIndex,colIndex) {
        var record = grid.store.getAt(rowIndex);
        var dataIndex = grid.colModel.getDataIndex(colIndex);
        // 20120514
        //~ if(record.data.disabled_fields && record.data.disabled_fields[dataIndex]) {
          //~ Lino.notify("Dieses Feld ist deaktiviert");
          //~ return false;
        //~ }

        //~ if (dataIndex in record.data['disabled_fields']) {
            //~ Lino.notify("This field is disabled.");
            //~ return false;
        //~ }
        var startValue = record.data[dataIndex];
        var value = !startValue;
        //~ record.set(this.dataIndex, value);
        var e = {
            grid: grid,
            record: record,
            field: dataIndex,
            originalValue: startValue,
            value: value,
            row: rowIndex,
            column: colIndex,
            cancel: false
        };
        if(grid.fireEvent("beforeedit", e) !== false && !e.cancel){
        //~ if(grid.fireEvent("validateedit", e) !== false && !e.cancel){
            record.set(dataIndex, value);
            delete e.cancel;
            grid.fireEvent("afteredit", e);
        }
        return false; // Cancel event propagation
    },

    renderer : function(v, p, record){
        if (record.phantom) return '';
        p.css += ' x-grid3-check-col-td';
        return String.format('<div class="x-grid3-check-col{0}">&#160;</div>', v ? '-on' : '');
    }

    // Deprecate use as a plugin. Remove in 4.0
    // init: Ext.emptyFn
});

// register ptype. Deprecate. Remove in 4.0
// Ext.preg('checkcolumn', Lino.CheckColumn);

// backwards compat. Remove in 4.0
// Ext.grid.CheckColumn = Lino.CheckColumn;

// register Column xtype
Ext.grid.Column.types.checkcolumn = Lino.CheckColumn;


/* 20110725 :
Lino.on_tab_activate is necessary
in contacts.Person.2.dtl
(but don't ask me why...)
*/
Lino.on_tab_activate = function(item) {
  //~ console.log('activate',item);
  if (item.rendered && item.doLayout) item.doLayout();
  //~ if (item.rendered) item.doLayout();
}

Lino.TimeField = Ext.extend(Ext.form.TimeField,{
  format: 'H:i',
  altFormats: 'g:ia|g:iA|g:i a|g:i A|h:i|g:i|H:i|ga|ha|gA|h a|g a|g A|gi|hi|gia|hia|g|H|gi a|hi a|giA|hiA|gi A|hi A|Hi|g.ia|g.iA|g.i a|g.i A|h.i|g.i|H.i',
  increment: 15
  });
Lino.DateField = Ext.extend(Ext.form.DateField,{
  //~ boxMinWidth: Lino.chars2width(15), // 20131005 changed from 11 to 15
  format: 'd.m.Y',
  altFormats: 'd/m/Y|Y-m-d'
  });
Lino.DatePickerField = Ext.extend(Ext.DatePicker,{
  //~ boxMinWidth: Lino.chars2width(11),
  format: 'd.m.Y',
  //~ altFormats: 'd/m/Y|Y-m-d'
  formatDate : function(date){
      //~ console.log("20121203 formatDate",this.name,date);
      return Ext.isDate(date) ? date.dateFormat(this.format) : date;
  }
  });
Lino.DateTimeField = Ext.extend(Ext.ux.form.DateTime,{
  dateFormat: 'd.m.Y',
  timeFormat: 'H:i'
  //~ ,hiddenFormat: 'd.m.Y H:i'
  });
Lino.URLField = Ext.extend(Ext.form.TriggerField,{
  triggerClass : 'x-form-search-trigger',
  //~ triggerClass : 'x-form-world-trigger',
  vtype: 'url',
  onTriggerClick : function() {
    //~ console.log('Lino.URLField.onTriggerClick',this.value)
    //~ document.location = this.value;
    window.open(this.getValue(),'_blank');
  }
});
Lino.IncompleteDateField = Ext.extend(Ext.form.TextField,{
  //~ regex: /^-?\d+-[01]\d-[0123]\d$/,
  //~ regex: /^[0123]\d\.[01]\d\.-?\d+$/,
  maxLength: 10,
  boxMinWidth: Lino.chars2width(10),
  regex: /^[0123]?\d\.[01]?\d\.-?\d+$/,
  regexText: 'Datum im Format JJJJ-MM-TT eingeben (Nullen für unbekannte Teile)'
  });


//~ Lino.make_dropzone = function(cmp) {
    //~ cmp.on('render', function(ct, position){
      //~ ct.el.on({
        //~ dragenter:function(event){
          //~ event.browserEvent.dataTransfer.dropEffect = 'move';
          //~ return true;
        //~ }
        //~ ,dragover:function(event){
          //~ event.browserEvent.dataTransfer.dropEffect = 'move';
          //~ event.stopEvent();
          //~ return true;
        //~ }
        //~ ,drop:{
          //~ scope:this
          //~ ,fn:function(event){
            //~ event.stopEvent();
            //~ console.log(20110516);
            //~ var files = event.browserEvent.dataTransfer.files;
            //~ if(files === undefined){
              //~ return true;
            //~ }
            //~ var len = files.length;
            //~ while(--len >= 0){
              //~ console.log(files[len]);
              //~ // this.processDragAndDropFileUpload(files[len]);
            //~ }
          //~ }
        //~ }
      //~ });
    //~ });
//~ };

//~ Lino.FileUploadField = Ext.ux.form.FileUploadField;

Lino.FileUploadField = Ext.extend(Ext.ux.form.FileUploadField,{
    ctCls :"field-margin",
    unused_onRender : function(ct, position){
      Lino.FileUploadField.superclass.onRender.call(this, ct, position);
      this.el.on({
        dragenter:function(event){
          event.browserEvent.dataTransfer.dropEffect = 'move';
          return true;
        }
        ,dragover:function(event){
          event.browserEvent.dataTransfer.dropEffect = 'move';
          event.stopEvent();
          return true;
        }
        ,drop:{
          scope:this
          ,fn:function(event){
            event.stopEvent();
            //~ console.log(20110516);
            var files = event.browserEvent.dataTransfer.files;
            if(files === undefined){
              return true;
            }
            var len = files.length;
            while(--len >= 0){
              console.log(files[len]);
              //~ this.processDragAndDropFileUpload(files[len]);
            }
          }
        }
      });
    }
});

Lino.FileField = Ext.extend(Ext.form.TriggerField,{
  triggerClass : 'x-form-search-trigger',
  editable: false,
  onTriggerClick : function() {
    //~ console.log('Lino.URLField.onTriggerClick',this.value)
    //~ document.location = this.value;
    if (this.getValue()) window.open(MEDIA_URL + '/'+this.getValue(),'_blank');
  }
});

Lino.file_field_handler = function(panel,config) {
  if (panel.action_name == 'insert') {
      panel.has_file_upload = true;


      // config.value = '<br/><br/>';

      var f = new Lino.FileUploadField(config);
      //~ Lino.make_dropzone(f);
      return f;
      //~ return new Ext.ux.form.FileUploadField(config);
      //~ return new Lino.FileField(config);

  } else {
      //~ return new Lino.URLField(config);
      return new Lino.FileField(config);
  }
}

Lino.VBorderPanel = Ext.extend(Ext.Panel,{
    constructor : function(config) {
      config.layout = 'border';
      delete config.layoutConfig;
      Lino.VBorderPanel.superclass.constructor.call(this,config);
      for(var i=0; i < this.items.length;i++) {
        var item = this.items.get(i);
        if (this.isVertical(item) && item.collapsible) {
          item.on('collapse',this.onBodyResize,this);
          item.on('expand',this.onBodyResize,this);
        }
      }
    },
    isVertical : function(item) {
       return (item.region == 'north' || item.region == 'south' || item.region == 'center');
    },
    onBodyResize: function(w, h){
        //~ console.log('VBorderPanel.onBodyResize',this.title)
      if (this.isVisible()) { // to avoid "Uncaught TypeError: Cannot call method 'getHeight' of undefined."
        var sumflex = 0;
        var availableHeight = this.getInnerHeight();
        var me = this;
        this.items.each(function(item){
          if (me.isVertical(item)) {
              if (item.collapsed || item.flex == 0 || item.flex === undefined) {
                  if (item.rendered) availableHeight -= item.getHeight();
              } else {
                  sumflex += item.flex;
              }
          }

        });
        //~ for(var i=0; i < this.items.length;i++) {
          //~ var item = this.items.get(i);
          //~ // if (this.isVertical(item) && item.getResizeEl()) {
          //~ if (this.isVertical(item)) {
              //~ if (item.collapsed || item.flex == 0 || item.flex === undefined) {
                  //~ // item.syncSize()
                  //~ // item.doLayout()
                  //~ // if (item.region == "north") console.log('region north',item.getHeight(),item.id, item);
                  //~ // if (item.getHeight() == 0) console.log(20100921,'both flex and getHeight() are 0!');
                  //~ availableHeight -= item.getHeight();
              //~ } else {
                  //~ sumflex += item.flex;
                  //~ // console.log(item.flex);
              //~ }
          //~ }
          //~ // else console.log('non-vertical item in VBoderPanel:',item)
        //~ }
        var hunit = availableHeight / sumflex;
        //~ console.log('sumflex=',sumflex,'hunit=',hunit, 'availableHeight=',availableHeight);
        for(var i=0; i < this.items.length;i++) {
          var item = this.items.get(i);
          if (this.isVertical(item)) {
              if (item.flex != 0 && ! item.collapsed) {
                  item.setHeight(hunit * item.flex);
                  //~ console.log(item.region,' : height set to',item.getHeight());
              }
          }
          //~ else console.log('non-vertical item in VBoderPanel:',item)
        }
      }
      Lino.VBorderPanel.superclass.onBodyResize.call(this, w, h);
    }
});


/*
  modifications to the standard behaviour of a CellSelectionModel:

*/
Ext.override(Ext.grid.CellSelectionModel, {
//~ var dummy = {

    getRowFrompx : function(px){
        g = this.grid;
        rows = g.getView().getRows();
        total_height = 0,
        searched_row = 0;
        for (row in rows){
            if (total_height < px){
                searched_row += 1;
                total_height += rows[row].clientHeight;
                }
            else{
                return searched_row;
            }
        }

    },
    handleKeyDown : function(e){
        /* removed because F2 wouldn't pass
        if(!e.isNavKeyPress()){
            return;
        }
        */
        //~ console.log('handleKeyDown',e)
        var k = e.getKey(),
            g = this.grid,
            s = this.selection,
            sm = this,
            walk = function(row, col, step){
                return g.walkCells(
                    row,
                    col,
                    step,
                    g.isEditor && g.editing ? sm.acceptsNav : sm.isSelectable,
                    sm
                );
            },
            cell, newCell, r, c, ae;
            t = g.getTopToolbar();
            if (t != undefined){
                d = t.getPageData();
            }
            else{
                d = undefined;
            }

        switch(k){
            case e.ESC:
                break;
            default:
                // e.stopEvent(); // removed because Browser keys like Alt-Home, Ctrl-R wouldn't work
                break;
        }

        if(!s){
            cell = walk(0, 0, 1);
            if(cell){
                this.select(cell[0], cell[1]);
            }
            return;
        }

        cell = s.cell;
        r = cell[0];
        c = cell[1];

        switch(k){
            case e.TAB:
                if(e.shiftKey){
                    newCell = walk(r, c - 1, -1);
                    // prev + [-1 -1]
                }else{
                    newCell = walk(r, c + 1, 1);
                }
                e.stopEvent(); // Don't allow tab to cause grid to loose focus
                if(!newCell && d != undefined){
                    var self = this;
                    var new_page = e.shiftKey? Math.max(1, d.activePage -1) : Math.min(d.pages, d.activePage +1) ;
                    if (d.activePage !== new_page) {
                        t.on('change', function (tb, pageData) {
                            if (e.shiftKey) {
                                self.select(
                                    Math.min(r, g.store.getCount() - 1),
                                    g.getColumnModel().getColumnsBy(function (col) {return !col.hidden}).last().colIndex
                                );
                            }else {
                                self.select(0,0);
                            }
                            //~ console.log('change',r,c);
                        }, this, {single: true});

                        if (e.shiftKey) {
                            t.movePrevious();
                        } else {
                            t.moveNext();
                        }
                        return;}
                }
                break;
            case e.HOME:
                if (!(g.isEditor && g.editing)) {
                    if (!e.hasModifier()) {
                        newCell = [r, 0];
                        //~ console.log('home',newCell);
                        break;
                    } else {
                        var activePage = Math.ceil((t.cursor + t.pageSize) / t.pageSize);
                        if (e.ctrlKey && activePage > 1) {
                            e.stopEvent();
                            var self = this;
                            t.on('change', function (tb, pageData) {
                                self.select(0, c);
                                //~ console.log('change',r,c);
                            }, this, {single: true});

                            t.moveFirst();
                            return;
                        }
                        newCell = [0, c];
                        break;
                    }
                }
            case e.END:
                if (!(g.isEditor && g.editing)) {
                    if (!e.hasModifier()) {
                        newCell = [r, g.getColumnModel().getColumnsBy(function (col) {
                            return !col.hidden
                        }).last().colIndex];
                        //~ console.log('end',newCell);
                        break;
                    } else if (d != undefined){
                        if (e.ctrlKey && d.activePage < d.pages) {
                            e.stopEvent();
                            var self = this;
                            t.on('change', function (tb, pageData) {
                                var r = g.store.getCount() - 1;
                                self.select(r, c);
                                //~ console.log('change',r,c);
                            }, this, {single: true});
                            t.moveLast();
                            return;
                        } else {
                            newCell = [g.store.getCount() - 1, c];
                            //~ console.log('ctrl-end',newCell);
                            break;
                        }
                    }
                }
            case e.PAGE_UP:
            case e.PAGE_DOWN:
                e.stopEvent();
                var self = this;
                var scroller = g.getView().scroller;
                var box = scroller.getBox();
                //console.log('box',box);
                var viewSize = scroller.getSize(); // EXP {width: 547, height: 500}
//                console.log('viewSize',viewSize);
                var scrollPosition = scroller.getScroll(); // EXP {left: 0, top: 135}
//                console.log('scrollPosition',scrollPosition);
//                if (box.height < box.bottom){
                var direction  = e.PAGE_DOWN === k ? 'b' : 'u';
                scroller.scroll(direction, box.y,false);
//                }
                var new_scrollPosition = scroller.getScroll(); // EXP {left: 0, top: 135}
//                console.log('new_scrollPosition',new_scrollPosition);
                if (new_scrollPosition.top != scrollPosition.top){
                    newcellpx = e.PAGE_DOWN === k ? box.height : new_scrollPosition.top;
                    var newx = this.getRowFrompx(newcellpx);
//                    console.log('newx',newx);
                    newCell = walk(newx,c,1)
                    break;
                }
//                g.getView().scroller.scroll('b', 99999,true);
//                g.getView().scroller.isScrollable();
                if (d != undefined){
                    var new_page = e.PAGE_DOWN === k ? Math.min(d.pages, d.activePage +1) : Math.max(1, d.activePage -1);
                    if (d.activePage !== new_page) {
                        t.on('change', function (tb, pageData) {
                            self.select(Math.min(r, g.store.getCount() - 1), c);
                            //~ console.log('change',r,c);
                        }, this, {single: true});
                        if(k === e.PAGE_DOWN){
                            t.moveNext();
                        }else{
                            t.movePrevious();
    //                        Go to the bottom of the new page
                            var scroller = g.getView().scroller;
                            var newbox = scroller.getBox();
                            scroller.scroll('b', newbox.bottom,false);
                        }
                    }
                    return;
                }else{ // same page, goto top / bottom row, keep c same
                    r = e.PAGE_DOWN === k ? g.store.getCount() - 1 : 0;
                    newCell = [r, c]
                }
                break;
            case e.DOWN:
                newCell = walk(r + 1, c, 1);
                break;
            case e.UP:
                newCell = walk(r - 1, c, -1);
                break;
            case e.RIGHT:
                newCell = walk(r, c + 1, 1);
                break;
            case e.LEFT:
                newCell = walk(r, c - 1, -1);
                break;
            case e.F2:
                if (!e.hasModifier()) {
                    if (g.isEditor && !g.editing) {
                        g.startEditing(r, c);
                        e.stopEvent();
                        return;
                    }
                    break;
                }
            case e.INSERT:
                if (!e.hasModifier()) {
                    if (g.ls_insert_handler && !g.editing) {
                        e.stopEvent();
                        Lino.show_insert(g);
                        return;
                    }
                    break;
                }
            case e.DELETE:
                if (!e.hasModifier()) {
                    if (!g.editing) {
                        e.stopEvent();
                        // Lino.delete_selected(g);
                        Lino.row_action_handler('delete_selected','GET',null)(g);
                        return;
                    }
                    break;
                }

            case e.ENTER:
                e.stopEvent();
                g.onCellDblClick(g,r,c);
                break;

            default:
                g.handle_key_event(e);

        }


        if(newCell){
          e.stopEvent();
          r = newCell[0];
          c = newCell[1];
          this.select(r, c);
          if(g.isEditor && g.editing){
            ae = g.activeEditor;
            if(ae && ae.field.triggerBlur){
                ae.field.triggerBlur();
            }
            g.startEditing(r, c);
          }
        //~ } else if (g.isEditor && !g.editing && e.charCode) {
        //~ // } else if (!e.isSpecialKey() && g.isEditor && !g.editing) {
            //~ g.set_start_value(String.fromCharCode(e.charCode));
            //~ // g.set_start_value(String.fromCharCode(k));
            //~ // g.set_start_value(e.charCode);
            //~ g.startEditing(r, c);
            //~ // e.stopEvent();
            //~ return;
        // } else {
          // console.log('20120513',e,g);
        }

    }


//~ };
});



function PseudoConsole() {
    this.log = function() {};
};
if (typeof(console) == 'undefined') console = new PseudoConsole();

Lino.notify = function(msg) {
  if (msg == undefined) msg = ''; else console.log(msg);
  
    if (msg == undefined) return;
    // Lino.alert(msg);
  
};

Lino.alert = function(msg) {
  Ext.MessageBox.alert('Notify',msg);
};


//~ Lino.show_about = function() {
  //~ new Ext.Window({
    //~ width: 400, height: 400,
    //~ title: "About",
    //~ html: '<a href="http://www.extjs.com" target="_blank">ExtJS</a> version ' + Ext.version
  //~ }).show();
//~ };

function obj2str(o) {
  if (typeof o != 'object') return String(o);
  var s = '';
  for (var p in o) {
    s += p + ': ' + obj2str(o[p]) + '\n';
  }
  return s;
}

Lino.on_store_exception = function (store,type,action,options,response,arg) {
  //~ throw response;
  console.log("on_store_exception: store=",store,
    "type=",type,
    "action=",action,
    "options=",options,
    "response=",response,
    "arg=",arg);
    if (arg != undefined && arg) { console.log(arg.stack)};
    var msg = "Problem mit der Verbindung zur Datenbank";
    if (response.responseText)
        msg += '<br/>' + response.responseText
    msg += '<br/>' + "Falls der Fehler sich wiederholt, laden Sie die Seite im Browser neu ([SHIFT+CTRL+R] in Firefox)."
    Ext.Msg.alert("Datenbank-Problem", msg );

};

//~ Lino.on_submit_success = function(form, action) {
   //~ Lino.notify(action.result.message);
   //~ this.close();
//~ };

Lino.on_submit_failure = function(form, action) {
    //~ Lino.notify();
  // action may be undefined
    switch (action.failureType) {
        case Ext.form.Action.CLIENT_INVALID:
            Ext.Msg.alert("Client-side failure", "Bitte überprüfe alle Felder im Formular vor dem Speichern");
            break;
        case Ext.form.Action.CONNECT_FAILURE:
            Ext.Msg.alert("Connection failure", "Ajax communication failed");
            break;
        case Ext.form.Action.SERVER_INVALID:
            Ext.Msg.alert("Server-side failure", action.result.message);
   }
};



/*
Lino.save_wc_handler = function(ww) {
  return function(event,toolEl,panel,tc) {
    var pos = panel.getPosition();
    var size = panel.getSize();
    wc = ww.get_window_config();
    Ext.applyIf(wc,{
      x:pos[0],y:pos[1],height:size.height,width:size.width,
      maximized:panel.maximized});
    Lino.do_action(ww,{url:'/window_configs/'+ww.config.permalink_name,params:wc,method:'POST'});
  }
};

*/

Lino.show_in_own_window_button = function(handler) {
  return {
    qtip: "Dieses Panel in eigenem Fenster öffnen",
    id: "up",
    handler: function(event,toolEl,panel, tc) {
      //~ console.log('20111206 report_window_button',panel,handler);
      handler.run(null,{base_params:panel.containing_panel.get_master_params()});
    }
  }
}

Lino.action_handler = function (panel, on_success, on_confirm) {
  return function (response) {
      if (!panel) {
          if (Lino.current_window)
              panel = Lino.current_window.main_item;
          else panel = Lino.viewport;
      }

    if (panel.loadMask) panel.loadMask.hide(); // 20120211
    if (!response.responseText) return ;
    var result = Ext.decode(response.responseText);
    Lino.handle_action_result(panel, result, on_success, on_confirm);
  }
};

Lino.handle_action_result = function (panel, result, on_success, on_confirm) {

    // console.log('20150514 Lino.handle_action_result()', result);

    // if (panel instanceof Lino.GridPanel) {
    //     gridmode = true;
    // } else {
    //     gridmode = false;
    // }

    //~ if (result.goto_record) {
        //~ var js = "Lino." + result.goto_record[0] + '.detail.run';
        //~ var h = eval(js);
        //~ h(panel,{record_id:result.goto_record[1]});
    //~ }

    if (result.goto_url) {
        document.location = result.goto_url;
        if (result.close_window) Lino.close_window();
        return;
    }

    if (result.xcallback) {
        //~ var config = {title:"Bestätigung"};
        var config = {cls:"l-confirmation", title:result.xcallback.title};
        //~ config.buttons = Ext.MessageBox.YESNOCANCEL;
        //~ config.buttons = Ext.MessageBox.YESNO;
        var p = {};
        Lino.insert_subst_user(p);
        config.buttons = {};
        result.xcallback.buttons.forEach((button) => config.buttons[button[0]] = button[1]);
        config.msg = result.message;
        config.fn = function(buttonId, text, opt) {
          eval(result.xcallback[buttonId + "_resendEvalJs"])
        }
        Ext.MessageBox.show(config);
        return;
    }

    // `record_id` and/or `data_record` both mean "display the detail
    // of this record".

    if(result.detail_handler_name) {
        // TODO: make sure that result.detail_handler_name is secure
        var detail_handler = eval("Lino." + result.detail_handler_name);
    }
    var ns = {};  // new status
    if (result.close_window) {

        // Subsequent processing expects that `panel` is "the current
        // panel". But if we close the window, `panel` must point
        // to the previous window. Note the case of an insert window
        // that has been invoked by double-clicking on the phantom row
        // of a slave table in a detail window. In that case we want
        // `panel` to become the grid panel of the slave table who
        // called the insert window, not the master's detail form
        // panel.  When the insert window has been called by an action
        // link (e.g. generated using ar.insert_button), then
        // Lino.close_window can return `undefined`.

        if(result.record_id || result.data_record) {
            var ww = Lino.calling_window();
            if (ww && ww.window.main_item instanceof Lino.FormPanel) {
                if (ww.window.main_item.ls_detail_handler == detail_handler) {
                    ns.record_id = result.record_id;
                    ns.data_record = result.data_record;
                    // console.log("20150514 use new status.");
                }
            }
        }

        panel = Lino.close_window(
            function(ww) { Ext.apply(ww.status, ns) });
        if (!panel)
            // console.log("20150514 close_window returned no panel.");
            if (Lino.current_window)
                panel = Lino.current_window.main_item;

    }

    if(result.record_id || result.data_record) {
        if (! (ns.record_id || ns.data_record)) {
          // no close_window, so we must update record data in current
          // panel (if it is the detail_handler for this record) or
          // open the detail handler.
          var st = {
              record_id: result.record_id,
              data_record: result.data_record
          };
          if (result.active_tab) st.active_tab = result.active_tab;
          if (panel instanceof Lino.FormPanel
              && panel.ls_detail_handler == detail_handler)
            {
              // console.log("20210106 use panel.set_status().");
              st.base_params = panel.get_base_params();
              panel.set_status(st);
          } else {
              // console.log("20210106 run detail_handler.");
              if (panel !== undefined && panel.ls_detail_handler == detail_handler){
                st.base_params = panel.get_base_params();}
              detail_handler.run(null, st);
          }

          // if (panel instanceof Lino.FormPanel
          //     && panel.ls_url == result.actor_url) {
          //     // console.log("20140506 case 2 it's a FormPanel:", panel);
          //     panel.set_status({
          //         record_id: result.record_id,
          //         data_record: result.data_record});
          // } else if (panel.ls_detail_handler
          //            && panel.ls_url == result.actor_url) {
          //     // console.log("20140506 case 4");
          //     panel.ls_detail_handler.run(null, {
          //         record_id: result.record_id,
          //         data_record: result.data_record,
          //         base_params: panel.get_base_params()});
          // } else {
          //     result.refresh_all = true;
          //     console.log("20140604 case 6", result.actor_url);
          // }
        }
    }

    // `eval_js` must get handled after `close_window` because it
    // might ask to open a new window (and we don't want to close that
    // new window).  It must execute *before* any MessageBox,
    // otherwise the box would get hidden by a window that opens
    // afterwards.

    if (result.eval_js) {
        //~ console.log(20120618,result.eval_js);
        eval(result.eval_js);
    }

    if (on_success && result.success) {
        // console.log("20140430 handle_action_result calls on_success",
        //             on_success);
        on_success(result);
    }

    if (result.info_message) {
        console.log(result.info_message);
    }

    if (result.warning_message) {
        if (!result.alert) result.alert = "Warnung";
        Ext.MessageBox.alert(result.alert, result.warning_message);
    }

    if (result.message) {
        //~ if (result.alert && ! gridmode) {
        if (result.alert) { // 20120628b
            //~ Ext.MessageBox.alert('Alert',result.alert_msg);
            if (result.alert === true) result.alert = "Alarm";
            Ext.MessageBox.alert(result.alert, result.message, function(){eval(result.alert_eval_js)});
        } else {
            Lino.notify(result.message);
        }
    }

    if(result.record_deleted && panel.ls_detail_handler == detail_handler) {
        panel.after_delete();
        return;  // added 20200717 to fix #3715
    }

    if (result.refresh_all) {
        var cw = Lino.current_window;
        // var cw = panel.get_containing_window();
        if (cw) {
            // console.log("20140917 refresh_all calls refresh on", cw.main_item);
            cw.main_item.refresh();
        } else { Lino.viewport.refresh(); }
        // else console.log("20140917 cannot refresh_all because ",
        //                  "there is no current_window");
    } else {
        if (result.refresh) {
            // console.log("20140917 Gonna call panel.refresh()", panel);
            panel.refresh();
            panel.focus();
        }
    }if (result.open_url) {
        //~ console.log(20111126,result.open_url);
        //~ if (!result.message)
            //~ Lino.notify('Open new window <a href="'+result.open_url+'" target="_blank">'+result.open_url+'</a>');
        window.open(result.open_url,'foo',"");
        //~ document.location = result.open_url;
    }
};

// obsolete but still used for deleting records.
Lino.do_action = function(caller,action) {
  action.success = function(response) {
    if (caller.loadMask) caller.loadMask.hide();
    //~ console.log('Lino.do_action()',action,'action success',response);
    if (action.after_success) {
        //~ console.log('Lino.do_action() calling after_success');
        action.after_success();
    }
    if (response.responseText) {
      var result = Ext.decode(response.responseText);
      //~ console.log('Lino.do_action()',action.name,'result is',result);
      if (result.message) {
          if (result.alert) {
              //~ Ext.MessageBox.alert('Alert',result.alert_msg);
              Ext.MessageBox.alert('Alert',result.message);
          } else {
              Lino.notify(result.message);
          }
      }

      //~ if (result.alert_msg) Ext.MessageBox.alert('Alert',result.alert_msg);
      //~ if (result.message) Lino.notify(result.message);
      if (result.notify_msg) Lino.notify(result.notify_msg);
      if (result.js_code) {
        //~ console.log('Lino.do_action()',action,'gonna call js_code in',result);
        var jsr = result.js_code(caller);
        //~ console.log('Lino.do_action()',action,'returned from js_code in',result);
        if (action.after_js_code) {
          //~ console.log('Lino.do_action()',action,'gonna call after_js_code');
          action.after_js_code(jsr);
          //~ console.log('Lino.do_action()',action,'returned from after_js_code');
        //~ } else {
          //~ console.log('Lino.do_action()',action,' : after_js_code is false');
        }
      };
    }
  };
  Ext.applyIf(action,{
    waitMsg: "Bitte warten...",
    failure: Lino.ajax_error_handler(caller),
    params: {}
  });
  //~ action.params.su = Lino.subst_user;
  Lino.insert_subst_user(action.params);

  Ext.Ajax.request(action);
};

//~ Lino.gup = function( name )
//~ {
  //~ // Thanks to http://www.netlobo.com/url_query_string_javascript.html
  //~ name = name.replace(/[\[]/,"\\\[").replace(/[\]]/,"\\\]");
  //~ var regexS = "[\\?&]"+name+"=([^&#]*)";
  //~ var regex = new RegExp( regexS );
  //~ var results = regex.exec( window.location.href );
  //~ if( results == null )
    //~ return "";
  //~ else
    //~ return results[1];
//~ };

//~ Lino.refresh_handler = function (ww) {
  //~ return function() {
      //~ console.log('refresh',ww);
      //~ ww.main_item.doLayout(false,true);
      //~ ww.main_item.syncSize();
  //~ }
//~ };

//~ Lino.tools_close_handler = function (ww) {
  //~ return function() {
      //~ ww.close();
  //~ }
//~ };
Lino.permalink_handler = function (ww) {
  return function() {
    //~ document.location = ww.main_item.get_permalink();
    //~ console.log('20130723 Lino.permalink_handler',ww);

    /* Uncaught TypeError: Cannot read property 'main_item' of null  */
    if (ww) {
        var url = ww.main_item.get_permalink();
    } else {
        var url = Lino.viewport.get_permalink();
    }
    Lino.load_url(url);
  }
};
//~ Lino.run_permalink = function() {
  //~ var plink = Lino.gup('permalink');
  //~ if(plink) { eval('Lino.'+plink); }
//~ }

Lino.close_and_save_handler =  function (ww){
    return function(){
    if (ww) {
        ww.main_item.do_when_clean(true,function() {
        Lino.close_window(); });
        }
    }
};

Lino.ajax_error_handler = function(panel) {
  return function(response,options) {
    console.log('Ajax failure:', response, options);
    if (panel.loadMask) panel.loadMask.hide();
    if (response.responseText) {
      var lines = response.responseText.split('\n');
      if (lines.length > 10) {
          line = lines.splice(5, lines.length-10, "(...)");
      }
      //~ console.log(20131005, response.statusText.toCamel());
      Ext.MessageBox.alert(
        response.statusText.toCamel(),
        lines.join('<br/>')
        //~ response.responseText.replace(/\n/g,'<br/>'))
      )
    } else {
      Ext.MessageBox.alert('Action failed',
        'Lino server did not respond to Ajax request');
    }
  }
}
// Ext.Ajax.on('requestexception',Lino.ajax_error_handler)



Ext.QuickTips.init();

/* setting QuickTips dismissDelay to 0 */
// Apply a set of config properties to the singleton
//~ Ext.apply(Ext.QuickTips.getQuickTip(), {
//~ Ext.apply(Ext.ToolTip, {
    //~ dismissDelay: 0
    //~ autoHide: false,
    //~ closable: true,
    //~ maxWidth: 200,
    //~ minWidth: 100,
    //~ showDelay: 50      // Show 50ms after entering target
    //~ ,trackMouse: true
//~ });


// Ext.apply(Ext.QuickTips.getQuickTip(), {
//     dismissDelay: 500,
//     showDelay: 20      // Show 10ms after entering target
// });

Lino.quicktip_renderer = function(title, body) {
  return function(c) {
    //~ if (c instanceof Ext.Panel) var t = c.bwrap; else // 20130129
      if (c instanceof Ext.Panel) {
          var t = c.header;
      } else if (c instanceof Ext.Button) {
          var t = c.btnEl;
      } else  {
          var t = c.getEl();
      }
    // console.log(20171024, c, t, body);
    //~ t.dismissDelay = 0;
    Ext.QuickTips.register({
      target: t,
      //~ cls: 'lino-quicktip-classical',
      dismissDelay: 10000,
      //~ autoHide: false,
      showDelay: 30,      // Show X ms after entering target
      //~ title: title,
      text: body
    });
  }
};



Lino.help_text_editor = function() {
  //~ var bp = {
      //~ mk:this.content_type,
      //~ mt:1
    //~ };
    //~ console.log(20120202,bp);
  //~ Lino.lino.ContentTypes.detail({},{base_params:bp});
  //~ Lino.lino.ContentTypes.detail.run(null,{record_id:this.content_type});
  Lino.lino.ContentTypes.detail.run(null,{record_id:this.content_type});
}

// Path to the blank image should point to a valid location on your server
//~ Ext.BLANK_IMAGE_URL = MEDIA_URL + '/extjs/resources/images/default/s.gif';


// used as Ext.grid.Column.renderer for id columns in order to hide the special id value -99999
Lino.id_renderer = function(value, metaData, record, rowIndex, colIndex, store) {
  //~ if (record.phantom) return '';
  return value;
}

Lino.raw_renderer = function(value, metaData, record, rowIndex, colIndex, store) {
  return value;
}

Lino.text_renderer = function(value, metaData, record, rowIndex, colIndex, store) {
  //~ return "not implemented";
  return value;
}

Lino.NullNumberColumn = Ext.extend(Ext.grid.Column, {
    align : 'right',
    format : '0,000.00/i',
    renderer : function(value, metaData, record, rowIndex, colIndex, store) {
        // if( colIndex == 3)
        //     console.log(20130128,"NullNumberColumn.renderer",value);
        if (value === null) return '';
        return Ext.util.Format.number(value, this.format);
    }
});


Lino.link_button = function(url) {
    // return '<a href="' + url + '"><img src="/media/lino/extjs/images/xsite/link.png" alt="link_button"></a>'
    return '<a href="' + url + '" style="text-decoration:none;">&#10138;</a>'
}

Lino.fk_renderer = function(fkname,handlername) {
  //~ console.log('Lino.fk_renderer handler=',handler);
  return function(value, metaData, record, rowIndex, colIndex, store) {
    //~ console.log('Lino.fk_renderer',fkname,rowIndex,colIndex,record,metaData,store);
    //~ if (record.phantom) return '';
    if (value) {
        return Lino.link_button('javascript:'+handlername + '.run(null,{record_id:\'' + String(record.data[fkname]) + '\'})")') + value;
        // until 20140822 (clickable foreign keys):
        // var s = '<a href="javascript:' ;
        // s += handlername + '.run(null,{record_id:\'' + String(record.data[fkname]) + '\'})">';
        // s += value + '</a>';
        // return s
    }
    return '';
  }
};

Lino.lfk_renderer = function(panel,fkname) {
  //~ console.log('Lino.fk_renderer handler=',handler);
  var handlername = 'console.log';
  return function(value, metaData, record, rowIndex, colIndex, store) {
    //~ console.log('Lino.fk_renderer',fkname,rowIndex,colIndex,record,metaData,store);
    if (record.phantom) return '';
    if (value) {
        var s = '<a href="javascript:' ;
        s += handlername + '({},{record_id:\'' + String(record.data[fkname]) + '\'})">';
        s += value + '</a>';
        //~ console.log('Lino.fk_renderer',value,'-->',s);
        return s
    }
    return '';
  }
};

//~ Lino.gfk_renderer = function() {
  //~ return function(value, metaData, record, rowIndex, colIndex, store) {
    //~ if (record.phantom) return '';
    //~ console.log('Lino.gfk_renderer',value,colIndex,record,metaData,store);
    //~ return value;
  //~ }
//~ };


Lino.build_buttons = function(panel,actions) {
  //~ console.log("20121006 Lino.build_buttons",actions);
  if (actions) {
    var buttons = Array(actions.length);
    var cmenu = Array(actions.length);
    var keyhandlers = [];
    for (var i=0; i < actions.length; i++) {
      var a = actions[i];
      if (a.menu) a.menu = Lino.build_buttons(panel,a.menu).bbar;
      buttons[i] = a;
      cmenu[i] = {
            text : a.menu_item_text,
            iconCls : a.iconCls,
            menu : a.menu,
            itemId : a.itemId
          };
      if (a.panel_btn_handler) {
          var h = a.panel_btn_handler.createCallback(panel);
          if (a.auto_save == true) {
              h = panel.do_when_clean.createDelegate(panel,[true,h]);
          } else if (a.auto_save == null) {
              h = panel.do_when_clean.createDelegate(panel,[false,h]);
          } else if (a.auto_save == false) {
              // h = h;
          } else {
              console.log("20120703 unhandled auto_save value",a)
          }
          buttons[i].handler = h;
          cmenu[i].handler = h;
          if (a.keycode) {
                keyhandlers.push({
                key : a.keycode,
                fn : h});
//              keyhandlers[a.keycode] = h;
          }
          //~ if (buttons[i].xtype == 'splitbutton') {
              //~ cmenu[i].menu = a.menu;
          //~ } else {
              //~ cmenu[i].handler = h;
          //~ }
      } else {
          console.log("action without panel_btn_handler",a)
          // cmenu[i].handler = a.handler;
      }
    }
//    if (keyhandlers.length > 0){
//        var keys = new Ext.KeyMap(panel,keyhandlers);
//    }
    return {
        bbar:buttons,
        cmenu:new Ext.menu.Menu(cmenu),
        keyhandlers: keyhandlers
    };
  }
}

Lino.do_when_visible = function(cmp,todo) {
  //~ if (cmp.el && cmp.el.dom)
  if (cmp.isVisible()) {
    // 'visible' means 'rendered and not hidden'
    //~ console.log(cmp.title,'-> cmp is visible now');
    todo();
  //~ } else {
      //~ cmp.on('resize',todo,cmp,{single:true});
  //~ }
  //~ if (false) { // 20120213
  } else {
    //~ console.log('Lino.do_when_visible() must defer because not isVisible()',todo,cmp);
    if (cmp.rendered) {
      //~ console.log(cmp,'-> cmp is rendered but not visible: and now?');
      //~ console.log(cmp.title,'-> cmp is rendered but not visible: try again in a moment...');
      //~ var fn = function() {Lino.do_when_visible(cmp,todo)};
      //~ fn.defer(100);

      Lino.do_when_visible.defer(50,this,[cmp,todo]);
      //~ Lino.do_when_visible.defer(100,this,[cmp,todo]);

    } else {
      //~ console.log(cmp.title,'-> after render');
      cmp.on('afterrender',todo,cmp,{single:true});
    }
  }

};

/*
*/
Lino.do_on_current_record = function(panel, fn, phantom_fn) {
  // console.log('20140930 do_on_current_record', arguments);
  var rec = panel.get_current_record();
  if (rec == undefined) {
    Lino.notify("There's no selected record.");
    return;
  }
  // 20120307 A VirtualTable with a Detail (lino.Models) has only "phantom" records.
  if (rec.phantom) {
    //~ if (!panel.editable) { console.log("20120312 not editable:",panel)}
    if (phantom_fn) {
      phantom_fn(panel);
    } else {
      Lino.notify("Aktion nicht verfügbar auf dem Phantom-Record.");
    }
    return;
  }
  return fn(rec);
};


Lino.call_ajax_action = function(
    panel, method, url, p, actionName, step, on_confirm, on_success) {
  p.an = actionName;
  if (!panel || !panel.isVisible()) {
  //~ if (true) { // 20131026 : workflow_actions of a newly created record detail executed but did't refresh the screen because their requesting panel was the insert (not the detail) formpanel.
      if (Lino.current_window)
          panel = Lino.current_window.main_item;
      else panel = Lino.viewport;
  }
  // console.log("20150130 a", p.pv);
  // Ext.apply(p, panel.get_base_params());
  // console.log("20150130 b", p.pv);

  if (panel.get_selected && p.sr === undefined) {
      var selected_recs = panel.get_selected();
      //~ console.log("20130831",selected_recs);
      var rs = Array(selected_recs.length);
      for(var i=0; i < selected_recs.length;i++) {
          rs[i] = selected_recs[i].data[panel.ls_id_property];
      };
      p.sr = rs;
  }

  // console.log("20170731 Lino.call_ajax_action", Ext.Ajax, p, actionName, step);

  if (panel.loadMask) panel.loadMask.show();
  Lino.insert_linoweb_version(p)
  // Ext.Ajax.params = {};
  Ext.Ajax.request({
    method: method
    ,url: url
    ,params: p
    ,success: Lino.action_handler(panel, on_success, on_confirm)
    ,failure: Lino.ajax_error_handler(panel)
  });
};




Lino.row_action_handler = function(actionName, hm, pp,rqData,xcallback ) {
  var fn = function(panel, btn, step) {
      var p = {};
      // console.log('20150514 row_action_handler');
      if (pp) { p = pp(panel); if (! p) return; }
      if (rqData) {
          Ext.apply(p, rqData);
      }
      if (xcallback){
          p["xcallback__"+xcallback.xcallback_id] =xcallback.choice;
      }

      if (!panel || panel.get_current_record == undefined) { // AFTER_20130725
        // console.log('20140930 row_action_handler 2', panel);
        panel = Ext.getCmp(panel);
        if (panel == undefined) {
          console.log("20160410 Invalid panel spec.", actionName, hm, pp);
          Lino.notify("Invalid panel spec.");
          return;
        }
      }

      Lino.do_on_current_record(panel, function(rec) {
          //~ console.log(panel);
          panel.add_param_values(p, true);
          Ext.apply(p, panel.get_base_params());
          Lino.call_ajax_action(
              panel, hm, panel.get_record_url(rec.id),
              p, actionName, step, fn);
      });
  };
  return fn;
};

Lino.list_action_handler = function(ls_url,actionName,hm,pp, rqData, xcallback) {
  var url = '/api' + ls_url
  var fn = function(panel,btn,step) {
      var p = {};
      //~ console.log("20121210 Lino.list_action_handler",arguments);
      if (pp) { p = pp(panel);  if (! p) return; }

      if (rqData) {
          Ext.apply(p, rqData);
      }
      if (xcallback){
          p["xcallback__"+xcallback.xcallback_id] =xcallback.choice;
      }

      if (panel) { // may be undefined when called e.g. from quicklink
          panel.add_param_values(p, true);
          Ext.apply(p, panel.get_base_params());
      }
      // Lino.call_ajax_action(panel, hm,url, p, actionName, step, fn);
      var runFn = function () { Lino.call_ajax_action(panel, hm,url, p, actionName, step, fn); };
      setTimeout(runFn, p.timeout ? p.timeout : 0);

  };
  return fn;
};

Lino.param_action_handler = function(window_action) { // 20121012
  var fn = function(panel,btn,step) {
    Lino.do_on_current_record(panel,function(rec) {
      window_action.run(panel.getId(),{});
    });
  };
  return fn;
};



Lino.run_row_action = function(
    requesting_panel, is_on_main_actor, url, meth, pk,
    actionName, params, preprocessor) {
  //~ var panel = action.get_window().main_item;
  // console.log("20140930 Lino.run_row_action", params);
  url = '/api' + url;
  if (Array.isArray(pk) && pk.length) { url += '/' + pk[0]}
  else if (!Array.isArray(pk)) {url += '/' + pk}
  var panel = Ext.getCmp(requesting_panel);
  // var params = {}
  // if (init_params) Ext.apply(params, init_params);
  if (!params) params = {};
  if (preprocessor) {
      var p = preprocessor();
      Ext.apply(params, p);
  }
  if (panel && is_on_main_actor) {
      Ext.apply(params, panel.get_base_params())
  }else {
     params.sr = pk
  }
  Lino.insert_subst_user(params);

  if (params.rqdata) {
      Ext.apply(params, params.rqdata);
      delete(params.rqdata)
  }
  if (params.xcallback){
      params["xcallback__"+params.xcallback.xcallback_id] =params.xcallback.choice;
      delete(params.xcallback)
  }

  var fn = function(panel, btn, step) {
    Lino.call_ajax_action(panel, meth, url, params, actionName, step, fn);
  }
  // fn(panel, null, null);

  var runFn = function () { fn(panel, null, null); };
  setTimeout(runFn, params.timeout ? params.timeout : 0);


}


Lino.show_detail = function(panel, btn) {
  Lino.do_on_current_record(panel,
    function(rec) {
      //~ panel.loadMask.show();
      Lino.run_detail_handler(panel, rec.id);
    },
    Lino.show_insert
  );
};

Lino.run_detail_handler = function(panel,pk) {
  var bp = panel.get_base_params();
  panel.add_param_values(bp); // 20120918
  var status = {
    record_id:pk,
    base_params:bp
  }
  //~ console.log("20120918 Lino.show_detail",status);
  panel.ls_detail_handler.run(null,status);
}

Lino.show_fk_detail = function(combo,detail_action,insert_action) {
    //~ console.log("Lino.show_fk_detail",combo,handler);
    pk = combo.getValue();
    if (pk) {
        detail_action.run(null,{record_id: pk})
      } else {
        insert_action.run(null);
        //~ Lino.notify("Cannot show detail for empty foreign key.");
      }
};

Lino.show_insert = function(panel,btn) {
  var bp = panel.get_base_params();
  //~ console.log('20120125 Lino.show_insert',bp)
  //~ panel.ls_insert_handler.run(null,{record_id:-99999,base_params:bp});
  panel.ls_insert_handler.run(panel.getId(),{base_params:bp});
};



if (Ext.ux.grid !== undefined) {
    Lino.GridFilters = Ext.extend(Ext.ux.grid.GridFilters,{
      encode:true,
      local:false
    });
} else {
    Lino.GridFilters = function() {}; // dummy
    Ext.override(Lino.GridFilters,{
      init : function() {}
    });
};



Lino.FieldBoxMixin = {
  before_init : function(config,params) {
    if (params) Ext.apply(config,params);
    var actions = Lino.build_buttons(this, config.ls_bbar_actions);
    if (actions) config.bbar = actions.bbar;
  },
  //~ constructor : function(ww,config,params){
    //~ this.containing_window = ww;
    //~ if (params) Ext.apply(config,params);
    //~ var actions = Lino.build_buttons(this,config.ls_bbar_actions);
    //~ if (actions) config.bbar = actions.bbar;
    //~ Lino.FieldBoxMixin.superclass.constructor.call(this, config);
  //~ },
  do_when_clean : function(auto_save,todo) { todo() },
  //~ format_data : function(html) { return '<div class="htmlText">' + html + '</div>' },
  format_data : function(html) { return html },
  get_base_params : function() {
    // needed for insert action
    var p = Ext.apply({}, this.base_params);
    Lino.insert_subst_user(p);
    return p;
  },
  set_base_params : function(p) {
    this.base_params = Ext.apply({},p);
    //~ if (p.param_values) this.set_param_values(p.param_values);
  },
  clear_base_params : function() {
      this.base_params = {};
      Lino.insert_subst_user(this.base_params);
  },
  set_base_param : function(k,v) {
    this.base_params[k] = v;
  }
};

Ext.override(Ext.form.HtmlEditor, {
    fixKeys : function(){
        if(Ext.isIE){
            return function(e){
                var k = e.getKey(),
                    doc = this.getDoc(),
                        r;
                if(k == e.TAB){
                    e.stopEvent();
                    r = doc.selection.createRange();
                    if(r){
                        r.collapse(true);
                        r.pasteHTML('&nbsp;&nbsp;&nbsp;&nbsp;');
                        this.deferFocus();
                    }
                }else if(k == e.ENTER){
                    r = doc.selection.createRange();
                    if(r){
                        var target = r.parentElement();
                        if(!target || target.tagName.toLowerCase() != 'li'){
                            e.stopEvent();
                            r.pasteHTML('<br />');
                            r.collapse(false);
                            r.select();
                        }
                    }
                }
            };
        }else if(Ext.isOpera){
            return function(e){
                var k = e.getKey();
                if(k == e.TAB){
                    e.stopEvent();
                    this.win.focus();
                    this.execCmd('InsertHTML','&nbsp;&nbsp;&nbsp;&nbsp;');
                    this.deferFocus();
                }
            };
        }else if(Ext.isWebKit){
            // HKC : this is probably our most used case.
            return function(e){
                var k = e.getKey();
                if(k == e.TAB){
                    e.stopEvent();
                    this.execCmd('InsertText','\t');
                    this.deferFocus();
                }else if(k == e.ENTER){
                    e.stopEvent();
                    this.execCmd('InsertHtml','<br /><br />');
                    this.deferFocus();
                }
             //   HKC
               else if (k == e.S && e.ctrlKey){
                    e.stopEvent();
                    e.preventDefault();
                    //this.getWin.fireEvent('keyup');
                    // this.fireKey(e);
                    console.log('HTMLEditor is saving...');
                }
             };
        }
    }(),
    // bubbleEvents : ['keypress']
    // initComponent : function() {
    //     Ext.form.HtmlEditor.superclass.initComponent.call(this);
    //     this.addEvents('submit');
    // },
    // submit : function (event) {
    //     console.log("rrrrr");
    // },
    // initEditor : function() {
    //     Ext.form.HtmlEditor.superclass.initEditor.call(this);
    //     if (Ext.isGecko) {
    //         Ext.EventManager.on(this, 'keypress', this.fireSubmit, this);
    //     }
    //     if (Ext.isIE || Ext.isWebKit || Ext.isOpera) {
    //         Ext.EventManager.on(this, 'keydown', this.fireSubmit,
    //             this);
    //     }
    // },
    fireSubmit : function(e) {
        console.log("fireSubmit ...");
    }
});

Lino.HtmlBoxPanel = Ext.extend(Ext.Panel, Lino.PanelMixin);
Lino.HtmlBoxPanel = Ext.extend(Lino.HtmlBoxPanel, Lino.FieldBoxMixin);
Lino.HtmlBoxPanel = Ext.extend(Lino.HtmlBoxPanel, {
  disabled_in_insert_window : true,
  constructor : function(config,params) {
    this.before_init(config,params);
    Lino.HtmlBoxPanel.superclass.constructor.call(this, config);
  },
  //~ constructor : function(ww,config,params){
    //~ this.ww = ww;
    //~ if (params) Ext.apply(config,params);
    //~ var actions = Lino.build_buttons(this,config.ls_bbar_actions);
    //~ if (actions) config.bbar = actions.bbar;
    //~ Lino.FieldBoxMixin.constructor.call(this, ww,config,params);
  //~ },
  //~ constructor : function(ww,config,params){
    //~ this.ww = ww;
    //~ if (params) Ext.apply(config,params);
    //~ var actions = Lino.build_buttons(this,config.ls_bbar_actions);
    //~ if (actions) config.bbar = actions.bbar;
    //~ Lino.FieldBoxMixin.superclass.constructor.call(this, config);
  //~ },
  //~ disable : function() { var tb = this.getBottomToolbar(); if(tb) tb.disable()},
  //~ enable : function() { var tb = this.getBottomToolbar(); if(tb) tb.enable()},
  onRender : function(ct, position){
    Lino.HtmlBoxPanel.superclass.onRender.call(this, ct, position);
    Ext.getDoc().addKeyListener(Ext.EventObject.ESC, function(k,e) {
      // this.get_containing_window().close();
      this.get_containing_window().main_item.do_when_clean(false,function() {
        if (Lino.current_window ) {
          Lino.close_window();
        }
      });
    },this);
    //~ console.log(20111125,this.containing_window);
    if (this.containing_panel) {
      this.containing_panel.on('enable',this.enable,this);
      this.containing_panel.on('disable',this.disable,this);
    }
    this.el.on({
      dragenter:function(event){
        event.browserEvent.dataTransfer.dropEffect = 'move';
        return true;
      }
      ,dragover:function(event){
        event.browserEvent.dataTransfer.dropEffect = 'move';
        event.stopEvent();
        return true;
      }
      ,drop:{
        scope:this
        ,fn:function(event){
          event.stopEvent();
          //~ console.log(20110516);
          var files = event.browserEvent.dataTransfer.files;
          if(files === undefined){
            return true;
          }
          var len = files.length;
          while(--len >= 0){
            console.log(files[len]);
            //~ this.processDragAndDropFileUpload(files[len]);
          }
          Lino.show_insert(this);
        }
      }
    });
  },
  refresh : function(unused) {
      // this.containing_panel.refresh();
      this.refresh_with_after();
  },
  /* HtmlBoxPanel */
  refresh_with_after : function(after) {
      // var todo = this.containing_panel.refresh();
      var box = this.items.get(0);
      var todo = function() {
        if (this.disabled) { return; }
        this.set_base_params(this.containing_panel.get_master_params());

        var el = box.getEl();
        if (el) {
            var record = this.containing_panel.get_current_record();
            var newcontent = record ?
                this.format_data(record.data[this.name]) : '';
            // console.log('20140917 HtmlBox.refresh()',
            //             this.name, record.data.LinksByHuman);
            el.update(newcontent, true);
        // } else {
        //     console.log('20140502 cannot HtmlBox.refresh()',this.name);
        }
      };

      Lino.do_when_visible(box, todo.createDelegate(this));
  }
});
//~ Ext.override(Lino.HtmlBoxPanel,Lino.FieldBoxMixin);


Lino.ActionFormPanel = Ext.extend(Ext.form.FormPanel,Lino.MainPanel);
Lino.ActionFormPanel = Ext.extend(Lino.ActionFormPanel, Lino.PanelMixin);
Lino.ActionFormPanel = Ext.extend(Lino.ActionFormPanel, Lino.FieldBoxMixin);
Lino.ActionFormPanel = Ext.extend(Lino.ActionFormPanel, {
  //~ layout:'fit'
  //~ ,autoHeight: true
  //~ ,frame: true
  window_title : "Action Parameters",
  cls : "l-ActionFormPanel",
  constructor : function(config){
    config.buttons = [
        {text: 'OK', handler: this.on_ok, scope: this, cls:"l-ok"},
        {text: 'Cancel', handler: this.on_cancel, scope: this, cls:"l-cancel"}
    ];
    Lino.ActionFormPanel.superclass.constructor.call(this, config);
  }
  ,initComponent : function(){
      this.on('render',function(){
          this.loadMask = new Ext.LoadMask(
              this.bwrap,{msg:"Bitte warten..."});
      },this);
      Lino.ActionFormPanel.superclass.initComponent.call(this);
  }
  ,on_cancel : function() {
    this.get_containing_window().close();
  }
  ,on_ok : function() {
    var panel = this.requesting_panel;
    // var panel = this.get_containing_window().main_item;
    // console.log("20131004 on_ok",this,panel,arguments);
    var actionName = this.action_name;
    var pk = this.record_id || this.default_record_id;
    if (pk == undefined && this.base_params) { pk = this.base_params.mk; }
    if (pk == undefined && panel) {
        pk = panel.get_current_record().id;
    }
    if (pk == undefined) {
        // 20170101 VerifyUser action
        pk = '-99998';
        // Lino.alert("Sorry, dialog action without base_params.mk");
        // return;
    }
    var self = this;
    // self.loadMask.show();  // 20180727
    // function on_success() { self.get_containing_window().close(); };
    // see 20131004 and 20140430
    var url = '/api';

    // 20150119 : The OK button on AgentsByClient.create_visit went to
    // /api/pcsw/Clients/ instead of /api/pcsw/Coachings/
    // if (panel)
    //     url += panel.ls_url;
    // else
    //     url += this.ls_url;

    if (this.ls_url)
        url += this.ls_url;
    else
        url += panel.ls_url;
    url += '/' + pk;
    // wrap into function to prepare possible recursive call
    var fn = function(panel, btn, step) {
      var p = {};
      self.add_field_values(p);
      if (self.xcallback && self.rqdata ) {
          Ext.apply(p, self.rqdata);
          Ext.apply(p, self.xcallback);
      }
      if (panel) Ext.apply(p, panel.get_base_params());
      delete p.pv;
      // console.log("20150130", p.pv);
      Lino.call_ajax_action(
          self, self.http_method || "GET", url, p, actionName, step, fn); //  , on_success);
        // panel, 'GET', url, p, actionName, step, fn); //  , on_success);
        // 20180802 : passing self instead of panel fixes #2474
    }
    fn(panel, null, null);


  }
  /* ActionFormPanel*/
  ,set_status : function(status, rp){
    if (rp) this.requesting_panel = Ext.getCmp(rp);
    //~ console.log('20120918 ActionFormPanel.set_status()',status,rp,this.requesting_panel);
    this.clear_base_params();
    this.set_field_values();
    this.set_base_params({});
    this.record_id = undefined;
    // this.loadMask.hide();  // 20180727
    if (status == undefined) status = {};
    //~ if (status.param_values)
    // 20180725 : do not set field values and record id if status
    // doesn't have them.
    if (status.field_values) this.set_field_values(status.field_values);
    if (status.base_params) this.set_base_params(status.base_params);
    if (status.record_id) this.record_id = status.record_id;
    if (status.xcallback && status.rqdata) {
      this.xcallback = {["xcallback__"+status.xcallback.xcallback_id] : status.xcallback.choice};
      this.rqdata = status.rqdata;
      this.on_ok()
    } else {
        delete this.xcallback // insure no callback data if not in status
        delete this.rqdata
    }
  }

  ,before_row_edit : function(record) {}
  ,add_field_values : function (p) { // similar to add_param_values()
      /* LS 20160517 : Until now Lino tested whether the form is
       dirty, and if not, submitted only the values which had been set
       by set_status. But now status_field_values can be empty because
       Action.keep_user_values is True. In that case we must submit
       the current values even if the form is not dirty.  I don't
       remember why we had this feature of not submitting unmodified
       field values, so I remove this feature for now. */
      p.fv = this.get_field_values();
      // if (this.form.isDirty()) {
      //   p.fv = this.get_field_values();
      // }else{
      //   // console.log("20160517 add_param_values not dirty, status_field_values",
      //   //             this.status_field_values);
      //   if (this.status_field_values)
      //     p.fv = Lino.fields2array(
      //         this.fields, this.status_field_values);
      // }
      //~ console.log("20120203 add_param_values added pv",pv,"to",p);
  }
  ,get_field_values : function() {
      return Lino.fields2array(this.fields);
  }
  ,set_field_values : function(pv) {
      // console.log('20160516 MainPanel.set_param_values', pv);
      // if Action.keep_user_values, we receive an empty dict ({})
      this.status_field_values = pv;
      if (pv) {
          this.form.my_loadRecord(pv);
          var record = { data: pv };
          this.before_row_edit(record);
      } else {
          this.form.reset();
          this.before_row_edit();
      }
  }
  ,config_containing_window : function(wincfg) {
      wincfg.title = this.window_title;
      wincfg.keys = [
        { key: Ext.EventObject.ENTER, fn: this.on_ok, scope: this }
        ,{ key: 's', ctrl: true, fn: this.on_ok, scope: this, stopEvent: true  }
      ];

      if (!wincfg.defaultButton) this.getForm().items.each(function(f){
          if(f.isFormField){
              wincfg.defaultButton = f;
              return false;
          }
      });

  }
});


Lino.fields2array = function(fields, values) {
    // console.log('20160517 fields2array gonna loop on', fields, values);
    var pv = Array(fields.length);
    for(var i=0; i < fields.length;i++) {
        var f = fields[i]
        if (values)
          var v = values[f.name];
        else
          var v = f.getValue();
        if (f.formatDate) {
            pv[i] = f.formatDate(v);
        } else {
            pv[i] = v; // f.getValue();
        }
    }
    // console.log('20160517 fields2array returns', pv);
    return pv;
}


Lino.FormPanel = Ext.extend(Ext.form.FormPanel,Lino.MainPanel);
Lino.FormPanel = Ext.extend(Lino.FormPanel,Lino.PanelMixin);
Lino.FormPanel = Ext.extend(Lino.FormPanel,{
  params_panel_hidden : false,
  save_action_name : null,
  //~ base_params : {},
  //~ trackResetOnLoad : true,
  //~ query_params : {},
  //~ 20110119b quick_search_text : '',
  constructor : function(config,params){
    if (params) Ext.apply(config,params);
    this.base_params = {};
    //~ ww.config.base_params.query = ''; // 20111018
    //~ console.log(config);
    //~ console.log('FormPanel.constructor() 1',config)
    //~ Ext.applyIf(config,{base_params:{}});
    //~ console.log('FormPanel.constructor() 2',config)

    config.trackResetOnLoad = true;

    Lino.FormPanel.superclass.constructor.call(this, config);

    //~ this.set_base_param('$URL_PARAM_FILTER',null); // 20111018
    //~ this.set_base_param('$URL_PARAM_FILTER',''); // 20111018

  },
  initComponent : function(){

    this.containing_panel = this;

    //~ console.log("20111201 containing_window",this.containing_window,this);
    var actions = Lino.build_buttons(this, this.ls_bbar_actions);
    if (actions) {
        this.bbar = actions.bbar;
        // console.log("20160829 tooltip", actions.bbar);
    //~ } else {
        //~ this.bbar = [];
    }
    //~ Ext.apply(config,Lino.build_buttons(this,config.ls_bbar_actions));
    //~ config.bbar = Lino.build_buttons(this,config.ls_bbar_actions);
    //~ var config = this;

    //~ if (this.containing_window instanceof Lino.DetailWrapper) {

    //~ console.log('20120121 initComponent', this.action_name);
    //~ if (this.action_name == 'detail' | this.action_name == 'show') {
    //~ if (this.action_name != 'insert') {
    if (! this.hide_top_toolbar) {
      this.tbar = [];
      // 20111015
      if (! this.hide_navigator) {
        this.record_selector = new Lino.RemoteComboFieldElement({
          store: new Lino.ComplexRemoteComboStore({
            //~ baseParams: this.containing_window.config.base_params,
            baseParams: this.get_base_params(),
            //~ value: this.containing_window.config.base_params.query,
            proxy: new Ext.data.HttpProxy({
              url: '/choices' + this.ls_url,
              method:'GET'
            })
          }),
          pageSize:25,
          listeners: {
            scope:this,
            select:function(combo,record,index) {
                // console.log('20180719 select', combo);
                this.set_base_param('query',
                                    combo.lastQuery);
              this.goto_record_id(record.id);
            }
          },
          emptyText: "Gehe zu Datensatz"
        })
        this.tbar = this.tbar.concat([this.record_selector]);

        this.tbar = this.tbar.concat([
          this.first = new Ext.Toolbar.Button({
              tooltip:"Erster",disabled:true,
              handler:this.moveFirst,scope:this,iconCls:'x-tbar-page-first'}),
          this.prev = new Ext.Toolbar.Button({
              tooltip:"Voriger",disabled:true,
              handler:this.movePrev,scope:this,iconCls:'x-tbar-page-prev'}),
          this.next = new Ext.Toolbar.Button({
              tooltip:"Nächster",disabled:true,
              handler:this.moveNext,scope:this,iconCls:'x-tbar-page-next'}),
          this.last = new Ext.Toolbar.Button({
              tooltip:"Letzter",disabled:true,
              handler:this.moveLast,scope:this,iconCls:'x-tbar-page-last'})
        ]);
      }
      this.tbar = this.add_params_panel(this.tbar);

      this.tbar = this.tbar.concat([
        {
            handler:function(){ this.do_when_clean(
                false, this.refresh.createDelegate(this)) },
          iconCls: 'x-tbar-loading',
          tooltip:"Datensatz neu laden",
          scope:this}
      ]);

      if (this.bbar) { // since 20121016
        if (this.tbar) {
            this.tbar = this.tbar.concat(['-']) ;
        } else {
          this.tbar = [];
        }
        this.tbar = this.tbar.concat(this.bbar) ;
        this.bbar = undefined;
      }

      this.tbar = this.tbar.concat([
          '->',
          this.displayItem = new Ext.Toolbar.TextItem({})
      ]);

    }
    //~ if (this.content_type && this.action_name != 'insert') {
      //~ this.bbar = this.bbar.concat([
        //~ '->',
        //~ { text: "[$_('Help Text Editor')]",
          //~ handler: Lino.help_text_editor,
          //~ qtip: "$_('Edit help texts for fields on this model.')",
          //~ scope: this}
      //~ ])
    //~ }
    //~ this.before_row_edit = config.before_row_edit.createDelegate(this);

    //~ if (this.master_panel) {
        //~ this.set_base_params(this.master_panel.get_master_params());
    //~ }

    Lino.FormPanel.superclass.initComponent.call(this);

    // this.on('show',
    //         function(){ this.init_focus();},
    //         this);

    this.on('render',function(){
      this.loadMask = new Ext.LoadMask(this.bwrap,{msg:"Bitte warten..."});
    },this);


    if (this.action_name == 'insert') {
      this.cascade(function(cmp){
        if (cmp.disabled_in_insert_window) {
            // console.log('20110613 disabled_in_insert_window', cmp);
            //~ cmp.disable();
            cmp.hide();
        }
      });

    }

  },

  unused_init_focus : function(){
    // set focus to the first field
    console.log("20140205 Lino.FormPanel.init_focus");
    // Lino.FormPanel.superclass.focus.call(this);
    this.getForm().items.each(function(f){
        if(f.isFormField && f.rendered){
            f.focus();
            console.log("20140205 focus", f);
            return false;
        }
    });
  },

  /* FormPanel */
  get_status : function(){
      var st = {
        base_params: this.get_base_params(),
        // data_record : this.get_current_record()
      }
      var rec = this.get_current_record();
      if (rec) st.record_id = rec.id;
      // 20140917 : get_status must not store the whole data_record
      // because that would prevent the form to actually reload
      // when set_status is called after a child window closed.

      var tp = this.items.get(0);
      if (tp instanceof Ext.TabPanel) {
        st.active_tab = tp.getActiveTab();
      }
      st.param_values = this.status_param_values;
      return st;
  },

  /* FormPanel */
  set_status : function(status, rp){
    this.requesting_panel = Ext.getCmp(rp);
    // console.log('20140917 FormPanel.set_status()', status);
    this.clear_base_params();
    if (status == undefined) status = {};
    //~ if (status.param_values)
    this.set_param_values(status.param_values);
    if (status.base_params) this.set_base_params(status.base_params);
    var tp = this.items.get(0);
    if (tp instanceof Ext.TabPanel) {
      if (status.active_tab) {
        //~ console.log('20111201 active_tab',this.active_tab,this.items.get(0));
        //~ tp.activeTab = status.active_tab;
        tp.setActiveTab(status.active_tab);
        //~ this.main_item.items.get(0).activate(status.active_tab);
      } else {
        if (! status.data_record) {  // 20141206
            tp.setActiveTab(0);
        }
      }
    }

    if (status.data_record) {
      /* defer because set_window_title() didn't work otherwise */
      // 20140421 removed defer for bughunting to simplify side effects
      // this.set_current_record.createDelegate(
      //     this, [status.data_record]).defer(100);
      this.set_current_record(status.data_record);
      //~ return;
    } else {
        var record_id = status.record_id != undefined ? status.record_id : this.default_record_id;
        if (record_id != undefined) {
          /* possible values include 0 and null, 0 being a valid record id,
          null the equivalent of undefined
          */
          this.load_record_id(record_id);
        } else {
            this.set_current_record(undefined);
        }
    }
    // this.init_focus()
  }
  ,get_base_params : function() {  /* FormPanel */
    // needed for insert_action
    var p = Ext.apply({}, this.base_params);
    Lino.insert_subst_user(p);
    return p;
  }
  ,set_base_params : function(p) {
    //~ this.base_params = Ext.apply({},this.base_params); // make sure it is an instance variable
    delete p['query'] // 20120725
    Ext.apply(this.base_params,p);
    if (this.record_selector) {
        var store = this.record_selector.getStore();
        for (k in p) store.setBaseParam(k,p[k]);
        delete this.record_selector.lastQuery;
        //~ console.log("20120725 record_selector.setBaseParam",p)
    }
  }
  ,clear_base_params : function() {
      this.base_params = {};
      Lino.insert_subst_user(this.base_params);
  }
  ,set_base_param : function(k,v) {
    this.base_params[k] = v;
  }
  ,after_delete : function() {
    console.log("20200717", this.current_record.navinfo);
    if (this.current_record.navinfo.next)
      this.moveNext();
    else if (this.current_record.navinfo.prev)
      this.movePrev();
    else
      this.abandon();
  }
  ,moveFirst : function() {this.goto_record_id(
      this.current_record.navinfo.first)}
  ,movePrev : function() {this.goto_record_id(
      this.current_record.navinfo.prev)}
  ,moveNext : function() {this.goto_record_id(
      this.current_record.navinfo.next)}
  ,moveLast : function() {this.goto_record_id(
      this.current_record.navinfo.last)}

  ,refresh : function(unused) {
      this.refresh_with_after();
  }
  /* FormPanel */
  ,refresh_with_after : function(after) {
    // console.log('20140917 Lino.FormPanel.refresh_with_after()',this);
    if (this.current_record) {
        this.load_record_id(this.current_record.id, after);
    } else {
        this.set_current_record(undefined, after);
    }
  }

  ,do_when_clean : function(auto_save, todo) {
    var this_ = this;
    if (this.form.isDirty()) {
        // console.log('20140421 do_when_clean : form is dirty')
        if (auto_save) {
            this_.save(todo);
        } else {
          //~ console.log('20111217 do_when_clean() form is dirty',this.form);
          var config = {cls:"l-confirmation", title:"Bestätigung"};
          config.buttons = Ext.MessageBox.YESNOCANCEL;
          config.msg = "Änderungen in diesem Datensatz speichern?";
          config.fn = function(buttonId,text,opt) {
            //~ console.log('do_when_clean',buttonId)
            if (buttonId == "yes") {
                //~ Lino.submit_detail(this_,undefined,todo);
                //~ this_.containing_window.save(todo);
                this_.save(todo);
            } else if (buttonId == "no") {
              todo();
            }
          }
          Ext.MessageBox.show(config);
        }
    }else{
      // console.log('20140421 do_when_clean : now!')
      todo();
    }
  }

  ,goto_record_id : function(record_id) {
    // console.log('20140917 Lino.FormPanel.goto_record_id()',record_id);
    //~ var this_ = this;
    //~ this.do_when_clean(function() { this_.load_record_id(record_id) }
    this.do_when_clean(
        true, this.load_record_id.createDelegate(this, [record_id]));
  }

  ,load_record_id : function(record_id, after) {
    var this_ = this;
    var p = Ext.apply({}, this.get_base_params());
    if (this.action_name)
        p.an = this.action_name;
    p.rp = this.getId();
    p.fmt = 'json';
    this.add_param_values(p);
    Lino.insert_linoweb_version(p);
    if (this.loadMask) this.loadMask.show();
    Ext.Ajax.request({
      waitMsg: 'Loading record...',
      method: 'GET',
      params: p,
      scope: this,
      url: this.get_record_url(record_id),
      success: function(response) {
        // todo: convert to Lino.action_handler.... but result
        if (this.loadMask) this.loadMask.hide();
        if (response.responseText) {
          var rec = Ext.decode(response.responseText);
          // console.log('20150905 load_record_id success', rec);
          this.set_param_values(rec.param_values);
          this.set_current_record(rec, after);
          if (rec.message) {
            //~ if (rec.alert && ! gridmode) {
            if (rec.alert) { // 20120628b
                //~ Ext.MessageBox.alert('Alert',rec.alert_msg);
                if (rec.alert === true) rec.alert = "Alarm";
                Ext.MessageBox.alert(rec.alert, rec.message, function(){eval(rec.alert_eval_js)});
            } else {
                Lino.notify(rec.message);
            }
          }
        }
      },
      failure: Lino.ajax_error_handler(this)
    });
  }

  ,abandon : function () {
    Ext.MessageBox.alert('Note',
      "Keine weiteren Datensätze zu sehen. Detail-Fenster wird geschlossen.");
    Lino.close_window();
  }

  ,set_current_record : function(record, after) {
    // console.log('20160825 set_current_record', record);
    if (this.record_selector) {
        this.record_selector.clearValue();
        // e.g. InsertWrapper FormPanel doesn't have a record_selector
    }
    this.current_record = record;
    if (record && record.data) {
      this.enable();
      // After this method focus is moved to the panel.
      this.form.my_loadRecord(record.data);
      this.set_window_title(record.title);
      //~ this.getBottomToolbar().enable();
      var da = record.data.disabled_fields;
      if (da) {
          //~ console.log('20120528 disabled_fields =',da,this.getBottomToolbar());
          //~ 20121016 this.getBottomToolbar().items.each(function(item,index,length){
          if(this.hide_top_toolbar) {
              var tb = this.getBottomToolbar();
          } else {
              var tb = this.getTopToolbar();
          }
          if (tb) tb.items.each(function(item,index,length){
              //~ console.log('20120528 ',item.itemId,'-->',da[item.itemId]);
              // if (da[item.itemId]) item.disable(); else item.enable();
              if (da[item.itemId]) item.hide(); else item.show();
          });
      };
      if (this.disable_editing | record.data.disable_editing) {
          //~ console.log("20120202 disable_editing",record.title);
          this.form.items.each(function(cmp){
            if (!cmp.always_enabled) cmp.disable();
          },this);
      } else {
          this.form.items.each(function(cmp){
            //~ console.log("20120202",cmp);
            if (record.data.disabled_fields[cmp.name]) cmp.disable();
            else cmp.enable();
          },this);

          //~ if (record.data.disabled_fields) {
              //~ for (i = 0; i < record.data.disabled_fields.length; i++) {
                  //~ var flds = this.find('name',record.data.disabled_fields[i]);
                  //~ if (flds.length == 1) {
                    //~ flds[0].disable();
                  //~ }
              //~ }
          //~ }
      };
      if (this.first) {
        if (record.navinfo  && ! this.hide_navigator) {
          this.first.setDisabled(record.navinfo.first == null);
          this.prev.setDisabled(record.navinfo.prev == null);
          this.next.setDisabled(record.navinfo.next == null);
          this.last.setDisabled(record.navinfo.last == null);
          this.displayItem.setText(record.navinfo.message);
        } else {
          this.first.setDisabled(true);
          this.prev.setDisabled(true);
          this.next.setDisabled(true);
          this.last.setDisabled(true);
        }
      }
    } else {
      if (this.form.rendered)
        this.form.reset(); /* FileUploadField would fail when resetting a non-rendered form */
      //~ this.disable();
      //~ this.getBottomToolbar().disable();
      this.form.items.each(function(cmp){
        cmp.disable();
      },this);
      this.set_window_title(this.empty_title);
      //~ this.containing_window.window.setTitle(this.empty_title);
      if (!this.hide_navigator) {
        this.first.disable();
        this.prev.disable();
        this.next.disable();
        this.last.disable();
      }
    }
    // console.log('20140917 gonna call before_row_edit', record);
        var current_focus_fields = false;
        for (var i = 0; i < this.form.items.items.length;i++) {
            if (this.form.items.items[i].hasFocus) current_focus_fields = i;
        }
    this.before_row_edit(record);
        if (current_focus_fields != false){
            this.form.items.items[current_focus_fields].focus();
        }
    // console.log('20140917 gonna call after', after);
    this.containing_window.focus(); // ticket: 2509 regain focus on reload
    if (after) after();
  },

  /* FormPanel */
  before_row_edit : function(record) {},
  search_change : function(field,oldValue,newValue) {
    //~ console.log('search_change',field.getValue(),oldValue,newValue)
    this.set_base_param('query',field.getValue());
    this.refresh();
  },

//  get_selected : function() { return [ this.current_record ] },
  get_current_record : function() {
    //~ console.log(20100714,this.current_record);
    return this.current_record
  },

  get_permalink_url : function() {
      var rec = this.get_current_record();
      if (rec && ! rec.phantom && rec.id != -99998)
          return '/api'
              + this.ls_url + '/' + rec.id;
      return '/api' + this.ls_url;

  },
  add_param_tab : function(p) {
    var main = this.items.get(0);
    if (main.activeTab) {
      var tab = main.items.indexOf(main.activeTab);
      // console.log('20150130 main.activeTab', tab, main.activeTab);
      if (tab) p.tab = tab;
    // } else {
    //   console.log('20150130 no main.activeTab');
    }
  },
  get_permalink_params : function() {
    var p = {};
    //~ var p = {an:'detail'};
    if (this.action_name)
        p.an = this.action_name;
    this.add_param_tab(p)
    this.add_param_values(p)
    return p;
  }

  ,validate_form : function() {  // not used. see actions.ValidateForm
      // var ov = {};
      // this.form.items.each(function(f){
      //     ov[f.name] = f.originalValue
      // });

      // console.log('20140509 FormPanel.validate_form', ov);
      // var after = function() {
      //     this.form.items.each(function(f){
      //         f.originalValue = ov[f.name];
      //     });
      // }
      // this.save2(null, 'validate', after);
      this.save2(null, 'validate');
  }

  /* Lino.FormPanel */
  ,save : function(after) {
    var action_name = this.save_action_name;
    if (!action_name)
        action_name = this.action_name;
    // console.log('20140503 FormPanel.save', action_name);
    this.save2(after, action_name);
  }

  ,save2 : function(after, action_name) {
    var rec = this.get_current_record();
    var p = {};
    var panel = this;

    if (!rec) {
        Lino.notify("Sorry, no current record.");
        return;
    }
    if (this.has_file_upload) {
        p.csrfmiddlewaretoken = Ext.util.Cookies.get('csrftoken');
        document.domain = document.domain;
        p._document_domain = document.domain;
        this.form.fileUpload = true;
    }
    this.loadMask.show();
    Ext.apply(p, this.get_base_params());
    p.rp = this.getId();
    p.an = action_name;
    this.add_param_tab(p)
    // console.log('20150216 FormPanel.save()', rec, this.form);
    var submit_config = {
        params: p,
        scope: this,
        success: function(form, action) {
          this.loadMask.hide();
          Lino.notify(action.result.message);
          Lino.handle_action_result(this, action.result, after);
        },
        failure: function(form,action) {
          this.loadMask.hide();
          Lino.on_submit_failure(form, action);
        },
        clientValidation: true
    };
    if (rec.phantom) {  // it's a new record
      Ext.apply(submit_config, {
        url: '/api' + this.ls_url,
        method: 'POST'
      });
      // panel.refresh();
      // temporarily disabled. See 20151002
    } else {  // submit on existing row
      Ext.apply(submit_config, {
        url: '/api'
              + this.ls_url + '/' + rec.id,
        method: 'PUT'
      })
    }
    this.form.submit(submit_config);
  }

  ,on_cancel : function() {
    this.get_containing_window().close();
  }
  ,on_ok : function() {
      // console.log("20140424");
      // this.save(null, true, this.save_action_name);
      this.save();
  }
  ,run_action_hotkeys : function(k ,e){
    var result = this.actions_hotkeys.filter(obj => {
      return obj.key.toUpperCase() === String.fromCharCode(k).toUpperCase()
    })
    if (result != undefined){
      if (result.length != undefined){
        result = result[0];
      }
      // this.actions_hotkeys[i].ba
      var pk = this.current_record.id || this.default_record_id;
      if (pk == undefined && this.base_params) { pk = this.base_params.mk; }
//          if (pk == undefined && this.containing_panel) {
//             pk = this.containing_panel.get_current_record().id;
//          }
      if (pk == undefined) {
        // 20170101 VerifyUser action
        pk = '-99998';
        // Lino.alert("Sorry, dialog action without base_params.mk");
        // return;
        }
        eval(result.ba)(this.containing_panel,
                                              this.is_main_window,
                                              pk, {});
                                            }
      e.stopEvent();
      e.stopPropagation();

  }
  ,config_containing_window : function(wincfg) {

      // Note that defaultButton means: which component should receive
      // focus when Window is focussed.  If no defaultButton set,
      // specify the first form field.

      if (!wincfg.defaultButton) this.getForm().items.each(function(f){
          if(f.isFormField){
              wincfg.defaultButton = f;
              // console.log("20140205 defaultButton", f);
              return false;
          }
      });

      wincfg.keys = [];

      wincfg.keys.push({
          key: Ext.EventObject.ESCAPE,
          // this is not called sometimes.
          handler: this.on_cancel, scope:this });
      wincfg.keys.push({
          key: 's', ctrl: true,
             stopEvent: true, handler: this.on_ok, scope:this });
      if (this.actions_hotkeys) {
          for (var i = 0; i < this.actions_hotkeys.length;i++) {
            wincfg.keys.push({
              key: this.actions_hotkeys[i].key,
              ctrl: this.actions_hotkeys[i].ctrl,
              shift : this.actions_hotkeys[i].shift,
              stopEvent: true,
              handler:
                function(k, e){
                  this.run_action_hotkeys(k,e);
                },
              scope:this });
          }
      }
  }

});



Lino.getRowClass = function(record, rowIndex, rowParams, store) {
    //~ console.log(20130816,record);
    //~ return 'x-grid3-row-green';
    //~ return record.data.row_class + ' auto-height';
    return record.data.row_class;
  //~ if (true) {
      //~ return 'x-grid3-row-red';
  //~ }
  //~ if (record.phantom) {
    //~ console.log(20101009,record);
    //~ rowParams.bodyStyle = "color:red;background-color:blue";
    //~ return 'lino-phantom-row';
    //~ }
  //~ console.log('20101009 not a phantom:',record);
  //~ return '';
}

//~ FOO = 0;



Lino.GridStore = Ext.extend(Ext.data.ArrayStore,{
  autoLoad: false
  ,load: function(options) {
    //~ foo.bar = baz; // 20120213
    if (!options) options = {};
    if (!options.params) options.params = {};
    options.params.fmt = 'json';
    options.params.rp = this.grid_panel.getId();
    Lino.insert_subst_user(options.params); // since 20121016

    var start = this.grid_panel.start_at_bottom ? -1 : 0;
    if (this.grid_panel.hide_top_toolbar) {
        //~ console.log("20120206 GridStore.load() toolbar is hidden");
        options.params.start = start;
        if (this.grid_panel.preview_limit) {
          options.params.limit = this.grid_panel.preview_limit;
        }
    } else {
        var ps = this.grid_panel.calculatePageSize();
        if (!ps) {
          // console.log("GridStore.load() failed to calculate pagesize");
          return false;
        }
        options.params.limit = ps;

        this.grid_panel.getTopToolbar().pageSize =  ps;
        if (options.params.start == undefined)
            // if (start != -1)
            //     start = this.grid_panel.getTopToolbar().cursor
            options.params.start = start;

        // console.log("20141108 GridStore.load() ", options.params);
    }

    this.grid_panel.add_param_values(options.params);
    //~ Lino.insert_subst_user(options.params);
    //~ console.log("20120814 GridStore.load()",options.params,this.baseParams);
    return Lino.GridStore.superclass.load.call(this, options);
  }
  // ,insert : function(index, records) {
  //   return Ext.data.Store.prototype.insert.call(this, index, records)
    // return Lino.GridStore.superclass.insert.call(this, index, records);
  // }
});

Lino.get_current_grid_config = function(panel) {
    return panel.get_current_grid_config();
}


// Like the default value for GridView.cellTpl but adds a class "lino-auto-height"
Lino.auto_height_cell_template = new Ext.Template(
'<td class="x-grid3-col x-grid3-cell x-grid3-td-{id} {css}" style="{style}" tabIndex="0" {cellAttr}>',
    '<div class="lino-auto-height x-grid3-cell-inner x-grid3-col-{id}" unselectable="on" {attr}>{value}</div>',
'</td>'
);

Lino.GridPanel = Ext.extend(Ext.grid.EditorGridPanel, Lino.MainPanel);
Lino.GridPanel = Ext.extend(Lino.GridPanel, Lino.PanelMixin);
Lino.GridPanel = Ext.extend(Lino.GridPanel, {
  quick_search_text : '',
  start_at_bottom : false,
  is_searching : false,
  disabled_in_insert_window : true,
  clicksToEdit:2,
  enableColLock: false,
  autoHeight: false,
  params_panel_hidden : false,
  preview_limit : undefined,
  // fake_row_content: '<br>',
  row_height: 1,
  //~ loadMask: true,
  //~ viewConfig: {
          //~ getRowClass: Lino.getRowClass,
          //~ emptyText:"$_('No data to display.')"
        //~ },


  loadMask: {msg:"Bitte warten..."},

  constructor : function(config){

    config.plugins = [new Lino.GridFilters()];


    Lino.GridPanel.superclass.constructor.call(this,config);

    //~ if (this.containing_window) {
        //~ console.log("20111206 install refresh");
        //~ this.containing_window.on('show',this.refresh,this);
    //~ }

  },

  // private
  initEvents : function(){
    Ext.grid.GridPanel.superclass.initEvents.call(this);

    // modifed from Ext.grid.GridPanel
    // Override the function to replace the element to be covered by the mask to the body.
    if(this.loadMask){
        this.loadMask = new Ext.LoadMask(this.body,
                Ext.apply({store:this.store}, this.loadMask));
    }

    // unmodified from Ext.grid.EditorGridPanel
    this.getGridEl().on('mousewheel', this.stopEditing.createDelegate(this, [true]), this);
    this.on('columnresize', this.stopEditing, this, [true]);

    if(this.clicksToEdit == 1){
        this.on("cellclick", this.onCellDblClick, this);
    }else {
        var view = this.getView();
        if(this.clicksToEdit == 'auto' && view.mainBody){
            view.mainBody.on('mousedown', this.onAutoEditClick, this);
        }
        this.on('celldblclick', this.onCellDblClick, this);
    }
},

  init_containing_window : function(win) {
    //~ console.log("20111206 install refresh");
    //~ win.on('show',this.refresh,this);
  }

  ,handle_key_event : function(e) {
    // console.log("20140514 handle_key_event", e, this.keyhandlers);
    if (this.keyhandlers){
        var h = this.keyhandlers[e.keyCode];
        }
    else if (this.keys !== undefined){
        var h = this.keys[e.keyCode];
        }
    if (h) {
        h(this);
        e.stopEvent();
    }
  }

  ,initComponent : function(){

    /*
    Problem 20111206:
    When a GridPanel is the main item of the window, then it doesn't
    have it's own header but uses the window's header bar.
    We must do this in initComponent because e.g. in beforerender
    it's already to late: a header element has been created because
    there was a title.
    But Lino.Window adds itself as `this.containing_window`
    only after the GridPanel has been initialized.
    Workaround is to generate a line "params.containing_window = true;"
    in the handler function.
    */
    if (this.is_main_window) {
        //~ console.log(20111206, 'delete title',this.title,'from',this);
        this.tools = undefined;
        this.title = undefined;  /* simply deleting it
          isn't enough because that would only
          unhide the title defined in some base class. */
    }
    //~ else console.log(20111206, 'dont delete title',this.title,'from',this);

    /* e.g. when slave gridwindow called from a permalink */
    //~ if (this.base_params) Ext.apply(bp,this.base_params);

    var proxy = new Ext.data.HttpProxy({
      // 20120814
      url: '/api' + this.ls_url
      ,method: "GET"
      //~ ,url: ADMIN_URL + '/restful' + this.ls_url
      //~ ,restful: true
      ,listeners: {load: function (proxy, req, optps) {
            var result = req.reader.arrayData;
            // Used for lino version validation
            if (result.message) { //
                if (result.alert) { // 20120628b
                    if (result.alert === true) result.alert = "Alarm";
                    Ext.MessageBox.alert(result.alert, result.message, function(){eval(result.alert_eval_js)});
                } else {
                    Lino.notify(result.message);
                }
            }
            } }
      //~ ,listeners: {write:on_proxy_write}
    });
    //~ config.store = new Ext.data.JsonStore({
    //~ this.store = new Ext.data.ArrayStore({
    this.store = new Lino.GridStore({
      grid_panel: this
      ,listeners: { exception: Lino.on_store_exception }
      ,remoteSort: true
      ,totalProperty: "count"
      ,root: "rows"
      //~ ,id: "id"
      ,proxy: proxy
      //~ autoLoad: this.containing_window ? true : false
      ,idIndex: this.pk_index
      //~ ,baseParams: bp
      ,fields: this.ls_store_fields
      ,idProperty: this.ls_id_property
      // 20120814
      //~ ,writer : new Ext.data.JsonWriter({
        //~ writeAllFields: false
        //~ ,listful: true
      //~ })
      //~ ,restful : true
    });

    //~ console.log('config.pk_index',config.pk_index,config.store),
    delete this.ls_store_fields;

    var this_ = this;
    //~ var grid = this;
    this.store.on('load', function() {
        //~ console.log('20120814 GridStore.on(load)',this_.store);
        this_.set_param_values(this_.store.reader.arrayData.param_values);
        //~ this_.set_status(this_.store.reader.arrayData.status);
        //~ 20120918
        this.getView().getRowClass = Lino.getRowClass;

        if (this_.store.reader.arrayData.no_data_text) {
            //~ this.viewConfig.emptyText = this_.store.reader.arrayData.no_data_text;
            this.getView().emptyText = this_.store.reader.arrayData.no_data_text;
            this.getView().refresh();
        }
        if (this_.containing_window)
            this_.set_window_title(this_.store.reader.arrayData.title);
            //~ this_.containing_window.setTitle(this_.store.reader.arrayData.title);
        // 20190704 add open_in_own_window button after title of slave panel
        // else if (! (this_ instanceof Ext.TabPanel)) this_.setTitle(this_.store.reader.arrayData.title);

        if (!this.is_searching) { // disabled 20121025: quick_search_field may not lose focus
          this.is_searching = false;
          if (this_.selModel.getSelectedCell){
              if (this_.getStore().getCount()) // there may be no data
                  this_.selModel.select(0,0);
          } else {
              this_.selModel.selectFirstRow();
              this_.getView().focusEl.focus();
          }
        }
        //~ else console.log("is_searching -> no focussing");
        //~ var t = this.getTopToolbar();
        //~ var activePage = Math.ceil((t.cursor + t.pageSize) / t.pageSize);
        //~ this.quick_search_field.focus(); // 20121024
      }, this
    );
    var actions = Lino.build_buttons(this, this.ls_bbar_actions);
    //~ Ext.apply(config,Lino.build_buttons(this,config.ls_bbar_actions));
    //~ config.bbar, this.cmenu = Lino.build_buttons(this,config.ls_bbar_actions);
    //~ this.cmenu = new Ext.menu.Menu({items: config.bbar});
    delete this.ls_bbar_actions
    if (actions) {
        this.cmenu = actions.cmenu;
//        this.keyhandlers = actions.keyhandlers;
        this.keys = new Ext.KeyMap(this.elements,actions.keyhandlers);
    }

    if (!this.hide_top_toolbar) {
      var tbar = [
        this.quick_search_field = new Ext.form.TextField({
            //~ fieldLabel: "Search"
          emptyText: "Schnellsuche",
          listeners: {
            scope:this_
            //~ ,change:this_.search_change
            
            ,render: Lino.quicktip_renderer("Schnellsuche","Hier Text eingeben für Schnellsuche.")
            
            //~ ,keypress: this.search_keypress
            ,blur: function() { this.is_searching = false}
            ,afterrender: function(field) {
                if (this.focus_on_quick_search){
                    field.focus(false, 1000);
                    }
              }
          }
          ,validator:function(value) { return this_.search_validate(value) }
          //~ ,tooltip: "Enter a quick search text, then press TAB"
          //~ value: text
          //~ scope:this,
          //~ ,enableKeyEvents: true
          //~ listeners: { keypress: this.search_keypress },
          //~ id: "seachString"
      })];
      tbar = this.add_params_panel(tbar);
      var menu = [];
      // var set_gc = function(index) {
      //   return function() {
      //     //~ console.log('set_gc() 20100812');
      //     this.getColumnModel().setConfig(this.ls_columns);
      //   }
      // }
      // for (var i = 0; i < this.ls_grid_configs.length;i++) {
      //   var gc = this.ls_grid_configs[i];
      //   menu.push({text:gc.label,handler:set_gc(i),scope:this})
      // }
      if(menu.length > 1) {
        tbar = tbar.concat([
          { text:"Ansicht",
            menu: menu,
            tooltip:"Andere Ansicht auswählen"
          }
        ]);
      }

      if (actions) {
        tbar = tbar.concat(actions.bbar);
          //~ this.bbar = actions.bbar;
      }

      this.tbar = new Ext.PagingToolbar({
        store: this.store,
        prependButtons: true,
        //~ pageSize: this.page_length,
        pageSize: 1,
        displayInfo: true,
        beforePageText: "Seite",
        afterPageText: "von {0}",
        displayMsg: "Zeilen {0} bis {1} von {2}",
        firstText: "Erste Seite",
        lastText: "Letzte Seite",
        prevText: "Vorige Seite",
        nextText: "Nächste Seite",
        items: tbar
      });
    }

    if (this.cell_edit) {
      this.selModel = new Ext.grid.CellSelectionModel()
      this.get_selected = function() {
        //~ console.log(this.getSelectionModel().selection);
        if (this.selModel.selection)
            return [ this.selModel.selection.record ];
        return [this.store.getAt(0)];
      };
      this.get_current_record = function() {
        if (this.getSelectionModel().selection)
          return this.selModel.selection.record;
        return this.store.getAt(0);
      };
    } else {
      this.selModel = new Ext.grid.RowSelectionModel()
      this.get_selected = function() {
        var sels = this.selModel.getSelections();
        if (sels.length == 0) sels = [this.store.getAt(0)];
        return sels
      };
      this.get_current_record = function() {
        var rec = this.selModel.getSelected();
        if (rec == undefined) rec = this.store.getAt(0);
        return rec
      };
    };
    this.columns  = this.ls_columns;

    Lino.GridPanel.superclass.initComponent.call(this);

    this.on('resize', function(){
      //~ console.log("20120213 resize",arguments)
      this.refresh();
      },this);
    this.on('viewready', function(){
      //~ console.log("20120213 resize",arguments);
      this.view_is_ready = true;
      this.refresh(); // removed 20130911
      },this);
    this.on('afteredit', this.on_afteredit); // 20120814
    this.on('beforeedit', this.on_beforeedit);
    this.on('beforeedit',function(e) { this.before_row_edit(e.record)},this);
    if (this.cell_edit) {
        this.on('cellcontextmenu', Lino.cell_context_menu, this);
    } else {
        this.on('rowcontextmenu', Lino.row_context_menu, this);
    }
    //~ this.on('contextmenu', Lino.grid_context_menu, this);

    delete this.cell_edit;

  },

  //~ onResize : function(){
      //~ console.log("20120206 GridPanel.onResize",arguments);
      //~ Lino.GridPanel.superclass.onResize.apply(this, arguments);
      //~ this.refresh();
  //~ },


  get_status : function(){
    var st = { base_params : this.get_base_params()};
    if (!this.hide_top_toolbar) {
        // #866
        if (this.getStore().lastOptions != undefined && this.getStore().lastOptions.params != undefined){
            st.current_page = Math.round(this.getStore().lastOptions.params.start / this.getStore().lastOptions.params.limit ) + 1 ;
        }
    }
    st.param_values = this.status_param_values;
    //~ console.log("20120213 GridPanel.get_status",st);
    return st;
  },

  /*
  Lino.GridPanel.set_status()
  */
  set_status : function(status, rp){
    this.requesting_panel = Ext.getCmp(rp);
    // console.log("20140527 GridPanel.set_status", status);
    this.clear_base_params();
    if (status == undefined) status = {base_params:{}};
    this.set_param_values(status.param_values);
    if (status.base_params) {
      this.set_base_params(status.base_params);
    }
    if (status.show_params_panel != undefined) {
        if (this.toggle_params_panel_btn) {
            //~ this.toggle_params_panel_btn.toggle(status.show_params_panel=='true');
            this.toggle_params_panel_btn.toggle(status.show_params_panel);
        }
    }
    if (!this.hide_top_toolbar) {
      //~ console.log("20120213 GridPanel.getTopToolbar().changePage",
          //~ status.current_page || 1);
      this.getTopToolbar().changePage(status.current_page || 1);
    }
    //~ this.fireEvent('resize');
    //~ this.refresh.defer(100,this);
    //~ this.onResize.defer(100,this);
    //~ this.refresh();
    //~ this.doLayout();
    //~ this.onResize();
    //~ this.store.load();
  },

  refresh : function(unused) {
    this.refresh_with_after();
  },
  /* GridPanel */
  refresh_with_after : function(after) {
    // console.log('20140504 Lino.GridPanel.refresh '+ this.store.proxy.url);
    //~ var bp = { fmt:'json' }
    if (! this.view_is_ready) return;

    if (this.containing_panel) {
        //~ Ext.apply(p,this.master_panel.get_master_params());
        //~ Ext.apply(options.params,this.containing_panel.get_master_params());
        this.set_base_params(this.containing_panel.get_master_params());
        // 20130911
        if (this.store.baseParams.mk === undefined ) {
            return;
        }
    }

    //~ console.log('20130911 Lino.GridPanel.refresh_with_after',this.containing_panel.get_master_params());

    var options = {};
    if (after) {
        options.callback = function(r,options,success) {if(success) after()}
    }

    //~ if (!this.rendered) {
        //~ console.log("20120206 GridPanel.refresh() must wait until rendered",options);
        //~ this.grid_panel.on('render',this.load.createDelegate(this,options))
        //~ return;
    //~ }
    // Ticket 802
    if (this.store.lastOptions != undefined){
        var params = {};
        params.limit = this.store.lastOptions.params.limit;
        params.start = this.store.lastOptions.params.start;
        options.params = params;
    }
    this.store.load(options);
  },

  /* pageSize depends on grid height (Trying to remove scrollbar)
  Thanks to
  - Christophe Badoit on http://www.sencha.com/forum/showthread.php?82647
  - http://www.sencha.com/forum/archive/index.php/t-37231.html
  */
  calculatePageSize : function(second_attempt) {
    //~ if (!this.rendered) {
    if (!this.view_is_ready) {
      //~ console.log('Cannot calculatePageSize() : not rendered');
      return false; }
    //~ if (!this.isVisible()) {
      //~ console.log('calculatePageSize : not visible');
      //~ return false; }

    //~ console.log('getFrameHeight() is',this.getFrameHeight());
    //~ console.log('getView().scroller.getHeight() is',this.getView().scroller.getHeight());
    //~ console.log('mainBody.getHeight() is',this.getView().mainBody.getHeight());
    //~ console.log('getInnerHeight() is',this.getInnerHeight());
    //~ console.log('getHeight() is',this.getHeight());
    //~ console.log('el.getHeight() is',this.getEl().getHeight());
    //~ console.log('getGridEl().getHeight() is',this.getGridEl().getHeight());
    //~ console.log('getOuterSize().height is',this.getOuterSize().height);
    //~ console.log('getBox().height is',this.getBox().height);
    //~ console.log('getResizeEl.getHeight() is',this.getResizeEl().getHeight());
    //~ console.log('getLayoutTarget().getHeight() is',this.getLayoutTarget().getHeight());

    // var rowHeight = this.row_height * 11; experimental value 11
    // same as in ext_renderer.py that's not enough because it is the
    // height of one text line. But here we need the outer height of a
    // grid row containing that many text lines.

    var row_content = '&nbsp;'
    for (var i = 0; i < this.row_height;i++) {
        row_content += '<br>';
    }

    var Element = Ext.Element;
    var gv = this.view;
    var fakeBody = new Element(Element.fly(gv.scroller).child('div.x-grid3-body'));
    var rowTemplate = gv.templates.row;
    var cellTemplate = gv.templates.cell;
    var tstyle  = 'width:' + gv.getGridInnerWidth() + 'px;';
    // console.log("20160615", this.fake_row_content);
    var cells = cellTemplate.apply({value:row_content});
    var markup = rowTemplate.apply({
            tstyle: tstyle,
            cols  : 1,
            cells : cells,
            alt   : ''
        });
    fakeBody.dom.innerHTML = gv.templates.body.apply({rows: markup});
    var row = fakeBody.dom.childNodes[0];
    var rowHeight = Ext.get(row).getHeight();

    //~ console.log('rowHeight is ',rowHeight,this,caller);
    //~ this.getView().syncScroll();
    //~ this.getView().initTemplates();
    var height = this.getView().scroller.getHeight();

    //~ console.log('getView().scroller.getHeight() is',this.getView().scroller.getHeight());
    //~ console.log('getInnerHeight() - getFrameHeight() is',
      //~ this.getInnerHeight(), '-',
      //~ this.getFrameHeight(), '=',
      //~ this.getInnerHeight() - this.getFrameHeight());
    //~ var height = this.getView().mainBody.getHeight();
    //~ var height = this.getView().mainWrap.getHeight();
    //~ var height = this.getView().resizeMarker.getHeight();
    //~ this.syncSize();
    //~ var height = this.getInnerHeight() - this.getFrameHeight();
    //~ var height = this.getHeight() - this.getFrameHeight();
    height -= Ext.getScrollBarWidth(); // leave room for a possible horizontal scrollbar...
    //~ height -= this.getView().scrollOffset;
    var ps = Math.floor(height / rowHeight);
    //~ console.log('20130816 calculatePageSize():',height,'/',rowHeight,'->',ps);
    ps -= 1; // leave room for a possible phantom row
    //~ return (ps > 1 ? ps : false);
    if (ps > 1) return ps;
    //~ console.log('calculatePageSize() found less than 1 row:',height,'/',rowHeight,'->',ps);
    //~ foo.bar = baz; // 20120213
    return 5; // preview_limit
    //~ if (second_attempt) {
        //~ console.log('calculatePageSize() abandons after second attempt:',
          //~ height,'/',rowHeight,'->',ps);
      //~ return 5;
    //~ }
    //~ return this.calculatePageSize.defer(500,this,[true]);
  },

  onCellDblClick : function(grid, row, col){
      //~ console.log("20120307 onCellDblClick",this,grid, row, col);
      if (this.ls_detail_handler) {
          //~ Lino.notify('show detail');
          Lino.show_detail(this);
          return false;
      }else{
        //~ console.log('startEditing');
        this.startEditing(row,col);
      }
  },
  get_base_params : function() {  /* Lino.GridPanel */
    var p = Ext.apply({}, this.store.baseParams);
    Lino.insert_subst_user(p);
    // if (this.quick_search_field)
    //     if (this.quick_search_field.getValue())
    //         p.query = this.quick_search_field.getValue();
    return p;
  },
  set_base_params : function(p) {
    // console.log('20130911 GridPanel.set_base_params',p)
    for (k in p) this.store.setBaseParam(k,p[k]);
    //~ this.store.baseParams = p;
    if (this.quick_search_field)
      this.quick_search_field.setValue(p.query || "");
    //~ if (p.param_values)
        //~ this.set_param_values(p.param_values);
  },
  clear_base_params : function() {
      this.store.baseParams = {};
      Lino.insert_subst_user(this.store.baseParams);
  },
  set_base_param : function(k,v) {
    this.store.setBaseParam(k,v);
  },

  //~ get_permalink_params : function() {
    //~ var p = {};
    //~ return p;
  //~ },

  before_row_edit : function(record) {},

  //~ search_keypress : function(){
    //~ console.log("2012124 search_keypress",arguments);
  //~ },
  search_validate : function(value) {
      if (value == this.quick_search_text) return true;

      /**
      *  Cancel the previous request when do a new load request.
      *  Prevents Ajax race conditions. Ticket #2136
      **/
      var c = this.store.proxy.getConnection();
      c.abort(c.transId);


    this.is_searching = true;
    //~ console.log('search_validate',value)
    this.quick_search_text = value;
    this.set_base_param('query',value);
    //~ this.getTopToolbar().changePage(1);
    this.getTopToolbar().moveFirst();
    //~ this.refresh();
    return true;
  },

  search_change : function(field,oldValue,newValue) {
    //~ console.log('search_change',field.getValue(),oldValue,newValue)
    this.set_base_param('query',field.getValue());
    this.getTopToolbar().moveFirst();
    //~ this.refresh();
  },

  get_current_grid_config : function () {
    var cm = this.getColumnModel();
    var widths = Array(cm.config.length);
    var hiddens = Array(cm.config.length);
    //~ var hiddens = Array(cm.config.length);
    var columns = Array(cm.config.length);
    //~ var columns = Array(cm.config.length);
    //~ var hidden_cols = [];
    //~ var filters = this.filters.getFilterValues();
    var p = this.filters.buildQuery(this.filters.getFilterData())
    for (var i = 0; i < cm.config.length; i++) {
      var col = cm.config[i];
      columns[i] = col.dataIndex;
      //~ hiddens[i] = col.hidden;
      widths[i] = col.width;
      hiddens[i] = col.hidden;
      //~ if (col.hidden) hidden_cols.push(col.dataIndex);
    }
    //~ p['hidden_cols'] = hidden_cols;
    p.cw = widths;
    p.ch = hiddens;
    p.ci = columns;
    //~ p['widths'] = widths;
    //~ p['hiddens'] = hiddens;
    //~ p['columns'] = columns;
    // p['name'] = this.gc_name;
    //~ var gc = this.ls_grid_configs[this.gc_name];
    //~ if (gc !== undefined)
        //~ p['label'] = gc.label
    //~ console.log('20100810 save_grid_config',p);
    return p;
  },

  on_beforeedit : function(e) {
    //~ console.log('20130128 GridPanel.on_beforeedit()',e,e.record.data.disable_editing);
    if(this.disable_editing | e.record.data.disable_editing) {
      e.cancel = true;
      Lino.notify("Dieser Datensatz ist deaktiviert");
      return;
    }
    if(e.record.data.disabled_fields && e.record.data.disabled_fields[e.field]) {
      e.cancel = true;
      Lino.notify("Dieses Feld ist deaktiviert");
      return;
    }
    //~ if (e.record.data.disabled_fields) {
      //~ for (i in e.record.data.disabled_fields) {
        //~ if(e.record.data.disabled_fields[i] == e.field) {
          //~ e.cancel = true;
          //~ Lino.notify(String.format('Field "{0}" is disabled for this record',e.field));
          //~ return
        //~ }
      //~ }
    //~ }
  },
  save_grid_data : function() {
      //~ console.log("20120814 save_grid_data");
      this.getStore().commitChanges();
  },
  on_afteredit : function(e) {
    /*
    e.grid - The grid that fired the event
    e.record - The record being edited
    e.field - The field name being edited
    e.value - The value being set
    e.originalValue - The original value for the field, before the edit.
    e.row - The grid row index
    e.column - The grid column index
    */
    var p = {};
    // console.log('20140403 afteredit: ',e.record);
    //~ console.log('20101130 value: ',e.value);
    //~ var p = e.record.getChanges();
    //~ console.log('20101130 getChanges: ',e.record.getChanges());
    //~ this.before_row_edit(e.record);

    for(k in e.record.getChanges()) {
        var v = e.record.get(k);
    //~ for(k in e.record.modified) {
        //~ console.log('20101130',k,'=',v);
        //~ var cm = e.grid.getColumnModel();
        //~ var di = cm.getDataIndex(k);
        var f = e.record.fields.get(k);
        //~ console.log('20101130 f = ',f);
        //~ var v = e.record.get(di);
        if (f.type.type == 'date') {
            p[k] = Ext.util.Format.date(v, f.dateFormat);
        }else{
            p[k] = v;
            var v = e.record.get(k+'Hidden');
            if (v !== undefined) {
              p[k+'Hidden'] = v;
            }
        }
    }
    // add value used by ForeignKeyStoreField CHOICES_HIDDEN_SUFFIX
    // not sure whether this is still needed:
    p[e.field+'Hidden'] = e.value;
    //~ p.su = Lino.subst_user;
    Lino.insert_subst_user(p);
    // this one is needed so that this field can serve as choice context:
    e.record.data[e.field+'Hidden'] = e.value;
    // p[pk] = e.record.data[pk];
    // console.log("grid_afteredit:",e.field,'=',e.value);
    Ext.apply(p, this.get_base_params()); // needed for POST, ignored for PUT
    //~ Ext.apply(p,this.containing_window.config.base_params);
    //~ 20121109 p['$constants.URL_PARAM_ACTION_NAME'] = 'grid';
    var self = this;
    var req = {
        params: p,
        waitMsg: 'Saving your data...',
        success: Lino.action_handler(this, function (result) {
            // console.log("20140728 afteredit.success got ", result);
            //~ if (result.data_record) {
            if (result.refresh_all) {
                var cw = self.get_containing_window();
                if (cw) {
                    cw.main_item.refresh();
                }
                else console.log("20120123 cannot refresh_all", self);
            } else if (result.rows) {
                //~ self.getStore().loadData(result,true);
                var r = self.getStore().reader.readRecords(result);
                var cell = e.grid.getSelectionModel().selection.cell; // post insert cord for edit / selection
                if (e.record.phantom) {
                    var was_editing = false;
                    // console.log("20140728 gonna call Store.insert()", self.getStore(), e.row, r.records);
                    if (e.grid.editing && e.grid.activeEditor) {
                        cell = [e.grid.activeEditor.row, e.grid.activeEditor.col];
                        console.log("was editing", cell);
                        e.grid.activeEditor.cancelEdit();
                        was_editing = true;
                    }

                    self.getStore().insert(e.row, r.records);
                    if (was_editing) {
                        e.grid.startEditing(cell[0], cell[1]);
                    }

                } else {
                    // console.log("20140728 afteredit.success doUpdate", r.records[0]);
                    self.getStore().doUpdate(r.records[0]);
                }
                self.getStore().rejectChanges();
                /*
            get rid of the red triangles without saving the record again
            */
                e.grid.getSelectionModel().select(cell[0], cell[1]);

                //~ self.getStore().commitChanges(); // get rid of the red triangles
            } else {
                self.getStore().commitChanges(); // get rid of the red triangles
                self.getStore().reload();        // reload our datastore.
            }
        }),
        scope: this,
        failure: Lino.ajax_error_handler(this)
    };
    if (e.record.phantom) {
      req.params.an = 'grid_post'; // CreateRow.action_name
      Ext.apply(req,{
        method: 'POST',
        url: '/api' + this.ls_url
      });
    } else {
      req.params.an = 'grid_put'; // SaveRow.action_name
      Ext.apply(req,{
        method: 'PUT',
        url: '/api' + this.ls_url + '/' + e.record.id
      });
    }
    //~ console.log('20110406 on_afteredit',req);
    this.loadMask.show(); // 20120211
    Ext.Ajax.request(req);
  },

  afterRender : function() {
    Lino.GridPanel.superclass.afterRender.call(this);
    // this.getView().mainBody.focus();
    // console.log(20100114,this.getView().getRows());
    // if (this.getView().getRows().length > 0) {
    //  this.getView().focusRow(1);
    // }
    //~ this.my_load_mask = new Ext.LoadMask(this.getEl(), {
        //~ msg:'$_("Please wait...")',
        //~ store:this.store});

    var tbar = this.getTopToolbar();
    // tbar.on('change',function() {this.getView().focusRow(1);},this);
    // tbar.on('change',function() {this.getSelectionModel().selectFirstRow();this.getView().mainBody.focus();},this);
    // tbar.on('change',function() {this.getView().mainBody.focus();},this);
    // tbar.on('change',function() {this.getView().focusRow(1);},this);
    this.nav = new Ext.KeyNav(this.getEl(),{
      pageUp: function() {tbar.movePrevious(); },
      pageDown: function() {tbar.moveNext(); },
      home: function() {tbar.moveFirst(); },
      end: function() {tbar.moveLast(); },
      scope: this
    });

  },
  after_delete : function() {
    //~ console.log('Lino.GridPanel.after_delete');
    this.refresh();
  },
  add_row_listener : function(fn,scope) {
    this.getSelectionModel().addListener('rowselect',fn,scope);
  },
  postEditValue : function(value, originalValue, r, field){
    value = Lino.GridPanel.superclass.postEditValue.call(this,value,originalValue,r,field);
    //~ console.log('GridPanel.postEdit()',value, originalValue, r, field);
    return value;
  },

  set_start_value : function(v) {
      this.start_value = v;
  },
  preEditValue : function(r, field){
      if (this.start_value) {
        var v = this.start_value;
        delete this.start_value;
        this.activeEditor.selectOnFocus = false;
        return v;
      }
      var value = r.data[field];
      return this.autoEncode && Ext.isString(value) ? Ext.util.Format.htmlDecode(value) : value;
  },

  on_master_changed : function() {
    //~ if (! this.enabled) return;
    //~ cmp = this;
    //~ console.log('20130911 Lino.GridPanel.on_master_changed()',this.title,this.rendered);
    if (! this.rendered) return; // 20120213
    var todo = function() {
      if (this.disabled) return;
      //~ if (this.disabled) return;
      //~ if (this.enabled) {
          //~ var src = caller.config.url_data + "/" + record.id + ".jpg"
          //~ console.log(20111125, this.containing_window);
          //~ for (k in p) this.getStore().setBaseParam(k,p[k]);
          //~ console.log('Lino.GridPanel.on_master_changed()',this.title,p);
          this.refresh();
          //~ this.set_base_params(this.master_panel.get_master_params());
          //~ this.getStore().load();
      //~ }
    };
    Lino.do_when_visible(this,todo.createDelegate(this));
  },
  load_record_id : function(record_id,after) {
      Lino.run_detail_handler(this,record_id)
  }

});


//~ Lino.MainPanelMixin = {
  //~ tbar_items : function() {
      //~ return ;
  //~ }
//~ };

//~ Ext.override(Lino.GridPanel,Lino.MainPanelMixin);
//~ Ext.override(Lino.FormPanel,Lino.MainPanelMixin);

//~ Lino.grid_context_menu = function(e) {
  //~ console.log('contextmenu',arguments);
//~ }

Lino.row_context_menu = function(grid,row,col,e) {
  console.log('20130927 rowcontextmenu',grid,row,col,e,grid.store.reader.arrayData.rows[row]);
}

Lino.cell_context_menu = function(grid,row,col,e) {
  //~ console.log('20120531 cellcontextmenu',grid,row,col,e,grid.store.reader.arrayData.rows[row]);
  e.stopEvent();
  //~ grid.getView().focusCell(row,col);
  grid.getSelectionModel().select(row,col);
  //~ console.log(grid.store.getAt(row));
  //~ grid.getView().focusRow(row);
  //~ return;
  if(!grid.cmenu.el){grid.cmenu.render(); }
  //~ if(e.record.data.disabled_fields) {

  if (grid.disabled_fields_index) {
      var da = grid.store.reader.arrayData.rows[row][grid.disabled_fields_index];
      if (da) {
          this.cmenu.cascade(function(item){
            //~ console.log(20120531, item.itemId, da[item.itemId]);
            if (da[item.itemId]) item.disable(); else item.enable();
          });
      }
  };

  var xy = e.getXY();
  xy[1] -= grid.cmenu.el.getHeight();
  grid.cmenu.showAt(xy);
}


Lino.chooser_handler = function(combo,name) {
  return function(cmp, newValue, oldValue) {
    //~ console.log('Lino.chooser_handler()',cmp,oldValue,newValue);
    combo.setContextValue(name, newValue);
  }
};



Lino.ComboBox = Ext.extend(Ext.form.ComboBox,{
  forceSelection: "yes but select on tab",
  // forceSelection: true,
  triggerAction: 'all',
  minListWidth:280, // 20131022
  autoSelect: true,
//  lazyRender:true,
//  lazyInit:false,
//  validationDelay :0,
//  typeAhead : true,
//  typeAheadDelay :false,
  selectOnFocus: true, // select any existing text in the field immediately on focus.
  submitValue: true,
  queryDelay:0,
  minChars: 0,
  displayField: 'text', // 'text',
  valueField: 'value', // 'value',

  //~ initComponent : Ext.form.ComboBox.prototype.initComponent.createSequence(function() {
  initComponent : function(){
      this.contextParams = {};
      this.on('expand',function(){
        // console.log("expand",this.store.getRange());
        if (this.store.getRange().length > 1){
            // Auto selection the first choices in the dropdown list.
            this.select(this.store.getRange()[0].id);
        }
      },this);
      //~ Ext.form.ComboBox.initComponent(this);
      Lino.ComboBox.superclass.initComponent.call(this);
      this.queryDelay = 0;
  },
  //Override this to accept DELETE key as not a specialkey and show choices.
  onKeyUp : function(e){
    var k = e.getKey();
    if(this.editable !== false && this.readOnly !== true && (k == e.BACKSPACE || k == e.DELETE || !e.isSpecialKey())){

        this.lastKey = k;
        this.dqTask.delay(this.queryDelay);
    }
    Ext.form.ComboBox.superclass.onKeyUp.call(this, e);
    },
  setValue : function(v, record_data){
      /*
      Based on feature request developed in http://extjs.net/forum/showthread.php?t=75751
      */
      /* `record_data` is used to get the text corresponding to this value */
      //~ if(this.name == 'city')
      //~ console.log('20120203', this.name,'.setValue(', v ,') this=', this,'record_data=',record_data);
      var text = v;
      if(this.valueField){
        if(v == null || v == '') {
            //~ if (this.name == 'birth_country')
                //~ console.log(this.name,'.setValue',v,'no lookup needed, value is empty');
            //~ v = undefined;
            v = '';
            //~ text = '';
        } else if (Ext.isDefined(record_data)) {
          text = record_data[this.name];
          //~ if (this.name == 'birth_country')
          this.original_record_data = record_data;
            //~ console.log(this.name,'.setValue',v,'got text ',text,' from record ',record);
        } else if (Ext.isDefined(this.original_record_data) && this.original_record_data[this.hiddenName] === v) {
            // Fix for ticket #2628
            text = this.original_record_data[this.name];
        } else {
          // if(this.mode == 'remote' && !Ext.isDefined(this.store.totalLength)){
          if(this.mode == 'remote' && ( this.lastQuery === null || (!Ext.isDefined(this.store.totalLength)))){
              //~ if (this.name == 'birth_country') console.log(this.name,'.setValue',v,'store not yet loaded');
              this.store.on('load', this.setValue.createDelegate(this, arguments), null, {single: true});
              if(this.store.lastOptions === null || this.lastQuery === null){
                  var params;
                  if(this.valueParam){
                      params = {};
                      params[this.valueParam] = v;
                  }else{
                      var q = this.allQuery;
                      this.lastQuery = q;
                      this.store.setBaseParam(this.queryParam, q);
                      params = this.getParams(q);
                  }
                  //~ if (this.name == 'birth_country')
                    //~ console.log(this.name,'.setValue',v,' : call load() with params ',params);
                  this.store.load({params: params});
              //~ }else{
                  //~ if (this.name == 'birth_country')
                    //~ console.log(this.name,'.setValue',v,' : but store is loading',this.store.lastOptions);
              }
              return;
          //~ }else{
              //~ if (this.name == 'birth_country')
                //~ console.log(this.name,'.setValue',v,' : store is loaded, lastQuery is "',this.lastQuery,'"');
          }
          var r = this.findRecord(this.valueField, v);
          if(r){
              text = r.data[this.displayField];
          }else if(this.valueNotFoundText !== undefined){
              text = this.valueNotFoundText;
          }
        }
      }
      this.lastSelectionText = text;
      //~ this.lastSelectionText = v;
      if(this.hiddenField){
          //~ this.hiddenField.originalValue = v;
          this.hiddenField.value = v;
      }
      Ext.form.ComboBox.superclass.setValue.call(this, text);
      this.value = v; // needed for grid.afteredit
  },

  getParams : function(q){
    // p = Ext.form.ComboBox.superclass.getParams.call(this, q);
    // causes "Ext.form.ComboBox.superclass.getParams is undefined"
    var p = {};
    if(this.pageSize){
        p['start'] = 0;
        p['limit'] = this.pageSize;
    }
    // now my code:
    if(this.contextParams) Ext.apply(p, this.contextParams);
    return p;
  },
  setContextValue : function(name,value) {
    //~ console.log('setContextValue',this,this.name,':',name,'=',value);
    //~ if (this.contextValues === undefined) {
        //~ this.contextValues = Array(); // this.contextParams.length);
    //~ }
    if ((this.contextParams[name] != value) || (this.contextParams[name] == undefined)) {
      //~ console.log('setContextValue 1',this.contextParams);
      this.contextParams[name] = value;
      this.lastQuery = null;
      //~ console.log('setContextValue 2',this.contextParams);
    }
  }
});

Lino.ChoicesFieldElement = Ext.extend(Lino.ComboBox,{
  mode: 'local'
});


Lino.SimpleRemoteComboStore = Ext.extend(Ext.data.JsonStore,{
  // forceSelection: true,  20140206 why was this here?
  constructor: function(config){
      Lino.SimpleRemoteComboStore.superclass.constructor.call(this, Ext.apply(config, {
          totalProperty: 'count',
          root: 'rows',
          id: 'value', // 'value'
          fields: ['value' ],
          listeners: { exception: Lino.on_store_exception }
      }));
  }
});

Lino.ComplexRemoteComboStore = Ext.extend(Ext.data.JsonStore,{
  constructor: function(config){
      Lino.ComplexRemoteComboStore.superclass.constructor.call(this, Ext.apply(config, {
          totalProperty: 'count',
          root: 'rows',
          id: 'value', // constants.CHOICES_VALUE_FIELD
          fields: ['value','text'], // constants.CHOICES_VALUE_FIELD, // constants.CHOICES_TEXT_FIELD
          listeners: { exception: Lino.on_store_exception }
      }));
  }
});

Lino.RemoteComboFieldElement = Ext.extend(Lino.ComboBox,{
  mode: 'remote',
  //~ forceSelection:false,
  minChars: 0, // default 4 is too much
//  queryDelay: 300, // default 500 is maybe slow
  queryParam: 'query',
  //~ typeAhead: true,
  //~ selectOnFocus: true, // select any existing text in the field immediately on focus.
  resizable: true
  ,initList : function() {
      Lino.RemoteComboFieldElement.superclass.initList.call(this);
      if (this.pageTb) {

          var me = this;
          this.pageTb.on("beforechange", function(toolbar, o){
              if(me.contextParams)
                  Ext.apply(o, me.contextParams);
          });

          //~
          //~ var btn = ls_buttons
          //~ this.pageTb.items = this.pageTb.items.concat([btn]);
          //~ console.log("20131022 pageTb.items is", this.pageTb.items)
      }
  }
});

/*
Thanks to Animal for posting the basic idea:
http://www.sencha.com/forum/showthread.php?15842-2.0-SOLVED-Combobox-twintrigger-clear&p=76130&viewfull=1#post76130

*/
Lino.TwinCombo = Ext.extend(Lino.RemoteComboFieldElement,{
    trigger2Class : 'x-form-search-trigger',
    //~ trigger2Class : 'x-tbar-detail',
    initComponent : function() {
        //~ Lino.TwinCombo.superclass.initComponent.call(this);
        Lino.ComboBox.prototype.initComponent.call(this);
        Ext.form.TwinTriggerField.prototype.initComponent.call(this);
    },
    onTrigger2Click : function() {
        //~ console.log('onTrigger2Click',this,arguments);
    }
  });
//~ Lino.TwinCombo.prototype.initComponent = Ext.form.TwinTriggerField.prototype.initComponent;
Lino.TwinCombo.prototype.getTrigger = Ext.form.TwinTriggerField.prototype.getTrigger;
Lino.TwinCombo.prototype.getOuterSize = Ext.form.TwinTriggerField.prototype.getOuterSize;
Lino.TwinCombo.prototype.initTrigger = Ext.form.TwinTriggerField.prototype.initTrigger;
Lino.TwinCombo.prototype.onTrigger1Click = Ext.form.ComboBox.prototype.onTriggerClick;
//~ Lino.TwinCombo.prototype.onTrigger2Click = function() {
    //~ console.log('onTrigger2Click',arguments);
//~ };



Lino.SimpleRemoteComboFieldElement = Ext.extend(Lino.RemoteComboFieldElement,{
  displayField: 'value',
  valueField: null,
  forceSelection: false
});




Lino.Window = Ext.extend(Ext.Window,{
  //~ layout: "fit",
  closeAction : 'hide',
  renderTo: 'main_area',
  constrain: true,
  maximized: true,
  draggable: false,
  width: 700,
  height: 500,
  maximizable: false,
  constructor : function (config) {
    if (config.main_item.params_panel) {
        config.layout = 'border';
        config.main_item.region = 'center';
        config.main_item.params_panel.region = 'north';
        //~ config.main_item.params_panel.autoHeight = false; // 20130924
        config.main_item.params_panel.hidden = config.main_item.params_panel_hidden;
        config.items = [config.main_item.params_panel, config.main_item];
        //~ 20130923b
    } else {
        config.layout = 'fit';
        config.items = config.main_item;
    }
    this.main_item = config.main_item;

    if (typeof config.width == "string" && config.width.slice(-1) == "%") {
        config.width = Lino.perc2width(parseInt(config.width.slice(0, -1)));
    }

    delete config.main_item;
    //~ delete config.params_item;

    //~ this.main_item = config.items.get(0);
    this.main_item.containing_window = this;

    //~ console.log('20120110 Lino.Window.constructor() 1');
    //~ if (Lino.current_window) { // all windows except the top are closable
    if (this.main_item.hide_window_title) {
      config.closable = false;
      config.frame = false;
      config.shadow = false;
      //~ config.border = true;
      //~ config.title = undefined;
      //~ config.tools = null;
      delete config.title;
      delete config.tools;
    } else {
      config.title = this.main_item.empty_title;
      config.closable = true;
      config.tools = [
        { qtip: 'permalink',
         handler: Lino.permalink_handler(this),
          id: "pin" },
        { qtip: "Speichern und Fenster schließen."
        , handler: Lino.close_and_save_handler(this),
         id: "save" }
      ];
      if (this.main_item.content_type && this.main_item.action_name != 'insert') {
        config.tools = [ {
          handler: Lino.help_text_editor,
          qtip: "Hilfetexte der Eingabefelder dieser Tabelle bearbeiten",
          scope: this.main_item,
          id: "gear"
        }].concat(config.tools);
      }

    //~ { qtip: '', handler: Lino.save_wc_handler(this), id: "save" },
    //~ { qtip: this.config.qtip, handler: Lino.save_wc_handler(this), id: "save" },
    //~ { qtip: 'Call doLayout() on main Container.', handler: Lino.refresh_handler(this), id: "refresh" },
    //~ if (this.main_item.params_panel) {
        //~ config.tools = config.tools.concat([
          //~ { qtip: 'Show/hide parameter panel', handler: this.toggle_params_panel, id: "gear", scope:this }
        //~ ]);
    //~ }
    //~ if (config.closable !== false) {
      // if undefined, will take default behaviour
      //~ config.tools = config.tools.concat([
        //~ { qtip: 'close', handler: this.hide, id: "close", scope:this }
      //~ ]);
    }

    this.main_item.config_containing_window(config);

    // console.log('20150514 Lino.Window.constructor() 2');
    Lino.Window.superclass.constructor.call(this, config);

    //~ console.log('20120110 Lino.Window.constructor() 3');

  },
  initComponent : function() {
    this.main_item.init_containing_window(this);
    Lino.Window.superclass.initComponent.call(this);

  },
  hide : function() {
      this.main_item.do_when_clean(false,function() {
        if (Lino.current_window){
          Lino.close_window();
        }
        });

  },
  hide_really : function() {
    Lino.Window.superclass.hide.call(this);
  },
  onRender : function(ct, position){
    // console.log('20140829 Lino.Window.onRender() 1');
    Lino.Window.superclass.onRender.call(this, ct, position);
    var main_area = Ext.getCmp('main_area')
    //~ console.log('20120110 Lino.Window.onRender() 2');

    this.on('show', function(win) {
        // console.log('20140829 Lino.Window.on(show) : add resize handler');
        main_area.on('resize', win.onWindowResize, win);
    });
    this.on('hide', function(win) {
        // console.log('20140829 Lino.Window.on(hide) : remove resize handler');
        main_area.un('resize', win.onWindowResize, win);
    });
    // console.log('20140829 Lino.Window.onRender() 3');
  }
});


Ext.override(Ext.form.BasicForm,{
    my_loadRecord : function(record_data){
    //~ loadRecord : function(record){
        /* Same as ExtJS's loadRecord() (setValues()), except that we
        forward also the record_data to field.setValue(). This second
        parameter is used by Lino.Combobox.
        */
        // console.log('20181102 my_loadRecord', record_data)
        if(Ext.isArray(record_data)){
            for(var i = 0, len = record_data.length; i < len; i++){
                var v = record_data[i];
                var f = this.findField(v.id);
                if(f){
                    f.setValue(v.value, record_data);
                    if(this.trackResetOnLoad){
                        f.originalValue = f.getValue();
                    }
                }
            }
        }else{
            var field, id;
            for(id in record_data){
                if(!Ext.isFunction(record_data[id]) && (field = this.findField(id))){
                    // console.log('20181102 setValue', field, record_data[id]);
                    field.setValue(record_data[id], record_data);
                    if(this.trackResetOnLoad){
                        field.originalValue = field.getValue();
                        //~ if (field.hiddenField) {
                          //~ field.hiddenField.originalValue = field.hiddenField.value;
                        //~ }
                    }
                } // else console.log('20181102 not for ', id);
            }
        }
        return this;
    }
});




function initializeFooBarDropZone(cmp) {
    //~ console.log('initializeFooBarDropZone',cmp);
    cmp.dropTarget = new Ext.dd.DropTarget(cmp.bwrap, {
      //~ ddGroup     : 'gridDDGroup',
      notifyEnter : function(ddSource, e, data) {
        console.log('notifyEnter',ddSource,e,data);
        //Add some flare to invite drop.
        cmp.body.stopFx();
        cmp.body.highlight();
      },
      notifyDrop  : function(ddSource, e, data){
        console.log('notifyDrop',ddSource,e,data);
        // Reference the record (single selection) for readability
        //~ var selectedRecord = ddSource.dragData.selections[0];


        // Load the record into the form
        //~ formPanel.getForm().my_loadRecord(selectedRecord);


        // Delete record from the grid.  not really required.
        //~ ddSource.grid.store.remove(selectedRecord);

        return(true);
      }
    })
}



Lino.show_mti_child = function(fieldname,detail_handler) {
  //~ console.log('show_mti_child',this);
  //~ console.log('show_mti_child',panel.find("main_area"));
  rec = Lino.current_window.main_item.get_current_record();
  //~ rec = panel.get_current_record();
  if (rec) {
    //~ console.log('show_mti_child',Lino.current_window,rec);
    if (rec.phantom) {
      Lino.notify('Not allowed on phantom record.');
    }else if (rec.data[fieldname]) {
      //~ console.log('show_mti_child',rec.id);
      //~ detail_handler(Lino.current_window.main_item,{},{record_id:rec.id});
      detail_handler.run(null,{record_id:rec.id});
      //~ window.open(urlroot + '/' + rec.id);
      //~ document.location = urlroot + '/' + rec.id;
      //~ window.open(urlroot + '/' + rec.id,'_blank');
    } else {
      Lino.alert("Kann MTI-Kind nicht anzeigen wenn Checkbox abgeschlatet ist.");
    }
  } else {
    Lino.notify('No current record.');
  }
};


/*
captureEvents utility by Aaron Conran
<http://www.sencha.com/learn/grid-faq/>

Ext.onReady(function(){
    var grid = new Ext.grid.GridPanel({
        ...
    });
    captureEvents(grid);
});
*/
function captureEvents(observable) {
    Ext.util.Observable.capture(
        observable,
        function(eventName) {
            console.info(eventName);
        },
        this
    );
}

// settings.SITE.get_plugin_snippets()



// from lino_xl.lib.sepa:iban/uppercasetextfield.js

Lino.UppercaseTextField = Ext.extend(Ext.form.TextField,{
  style: 'text-transform:uppercase;',
  listeners:{
    change: function(field, newValue, oldValue){
      // console.log("20140403 UppercaseTextField",newValue, newValue.toUpperCase());
      field.setRawValue(newValue.toUpperCase());
    }
  }
});


Lino.iban_renderer = function(
    value, metaData, record, rowIndex, colIndex, store) 
{
    var reg = new RegExp(".{4}", "g");
    if(value) {
        return value.replace(reg, function (a) { return a + ' '; });
    }
    return value;
}




// from lino.modlib.tinymce (media_name=tinymce-3.5.11):tinymce/tinymce.js

/* Copyright 2009-2018 Rumma & Ko Ltd */


Lino.edit_tinymce_text = function(panel, tinymce_options) {
  // edit the text in own window.
  // `panel` is the RichTextPanel
  // console.log(20150520, panel);
  //~ var rec = panel.get_current_record();
  var rec = panel.containing_panel.get_current_record();
  var value = rec ? rec.data[panel.editor.name] : '';
  var saving = false;
  var todo_after_save = false;
  var discard_changes = false;
  
  
  function save() {
    if (saving) {alert('tried to save again'); return; }
    var url = panel.containing_panel.get_record_url(rec.id);
    var params = Ext.apply({}, panel.containing_panel.get_base_params());
    params[panel.editor.name] = editor.getValue();
    //~ params.su = Lino.subst_user;
    //~ Lino.insert_subst_user(params);

    // 20150325 http://trac.lino-framework.org/ticket/131
    var action_name = panel.containing_panel.save_action_name;
    if (!action_name) 
        action_name = panel.containing_panel.action_name;
    params.an = action_name;

    var a = { 
      params: params, 
      method: 'PUT',
      url: url,
      failure: function() {
          //~ if (editor.ed.getContainer()) 
          editor.ed.setProgressState(0);
          todo_after_save = false;
          saving = false;
          console.log('tinymce.save() failed. sorry.',arguments);
        },
      success: function() {
        saving = false;
        //~ if (editor.ed.getContainer()) 
        editor.ed.setProgressState(0);
        rec.data[panel.editor.name] = editor.getValue();
        if(todo_after_save) {
            var fn = todo_after_save;
            todo_after_save = false;
            fn();
        }
        //~ panel.containing_window.set_current_record(rec);
        panel.refresh();
      }
    };
    //~ if (editor.ed.getContainer()) 
    editor.ed.setProgressState(1); // Show progress
    saving = true;
    //~ console.log(a);
    Ext.Ajax.request(a);
  };
  function save_callback() {
      save();
      //~ save(function(){editor.ed.setDirty(false);})
      /* return true have the save button disabled.  
      That's not perfect because the PUT is asynchronous 
      and the response is not yet known.
      */
      return true;
  }
  //~ var actions = [
    //~ {text:"Save",handler:save}
  //~ ]; 
  //~ console.log(20110610,panel.editor.disabled);
  var settings = {};
  Ext.apply(settings,{
        readonly: panel.editor.disabled,
        //~ language: "de",
        plugins : "save,emotions,spellchecker,advhr,insertdatetime,preview,table,searchreplace,template", 
        // Theme options - button# indicated the row# only
        theme_advanced_buttons1 : "save,cancel,|,bold,italic,underline,|,justifyleft,justifycenter,justifyright,fontselect,fontsizeselect,formatselect,|,search,replace",
        theme_advanced_buttons2 : "cut,copy,paste,template,|,bullist,numlist,|,outdent,indent,|,undo,redo,|,link,unlink,anchor,image,|,code,preview,|,forecolor,backcolor",
        theme_advanced_buttons3 : "insertdate,inserttime,|,spellchecker,advhr,,removeformat,|,sub,sup,|,charmap,emotions,|,tablecontrols",
        theme_advanced_resizing : false,
        convert_urls : false,
        save_onsavecallback : save_callback,
        save_enablewhendirty : true
        //~ save_oncancelcallback: on_cancel
  });
  Ext.apply(settings, tinymce_options);
  var editor = new Ext.ux.TinyMCE({
      value : value,
      tinymceSettings: settings
    });
  var win = new Ext.Window({
    title: rec.title, 
    //~ bbar: actions,
    layout: 'fit',
    items: editor,
    width: 500, 
    height: 400,
    minWidth: 100,
    minHeight: 100,
    modal: true,
    resizable: true,
    maximizable: true,
    //~ maximized: true,
    //~ closeAction: "close"
    closeAction: "hide"
    //~ hideMode: "offsets",
    //~ constrainHeader: true,
    //~ bodyStyle: 'padding: 10px'
  });

  //~ win.on('beforeclose',function() {
  win.on('beforehide',function() {
    if (todo_after_save) return false;
    if (discard_changes) return true;
    if (editor.isDirty()) {
        //~ var ok = false;
        //~ var allowClose = true;
        var config = {title:"Bestätigung"};
        config.buttons = Ext.MessageBox.YESNOCANCEL;
        config.msg = "Save changes to text ?";
        config.modal = true;
        config.fn = function(buttonId,text,opt) {
          //~ console.log('do_when_clean',buttonId)
          if (buttonId == "yes") {
              /* we cancel this close, but save()'s onSuccess will call again.*/
              //~ allowClose = false;
              todo_after_save = function(){win.hide();}
              editor.ed.execCommand('mceSave');
              //~ editor.ed.save(function(){win.close();});
          } else if (buttonId == "no") { 
              discard_changes = true;
              win.hide()
          //~ } else if (buttonId == "cancel") { 
            //~ ok = true;
              //~ allowClose = false;
          //~ } else { 
            //~ console.log('unknwon buttonId:',buttonId);
          }
        }
        Ext.MessageBox.show(config);
        return false;
        //~ return allowClose;
    }
  });
  win.show();
}


Lino.RichTextPanel = Ext.extend(Ext.Panel,Lino.PanelMixin);
Lino.RichTextPanel = Ext.extend(Lino.RichTextPanel,Lino.FieldBoxMixin);
Lino.RichTextPanel = Ext.extend(Lino.RichTextPanel,{
    
  //~ initComponent : function(){
    //~ Lino.RichTextPanel.superclass.initComponent.call(this);
  //~ },
  constructor : function(config, params) {
      // console.log('20150520a Lino.RichTextPanel.initComponent', this);
    //~ var url = TEMPLATES_URL + config.ls_url + "/" + String(rec.id) + "/" + config.name;
    //~ var url = TEMPLATES_URL + config.ls_url + "/" + config.name;
    var t = this;
    var tinymce_options = {
        theme : "advanced",
        content_css: '/static/extjs/lino.css,/static/tinymce_content.css',

        theme_advanced_font_sizes : "12px,13px,14px,16px,18px,20px,24px",
        font_size_style_values : "12px,13px,14px,16px,18px,20px,24px",
        language: 'de',
        //~ template_external_list_url : url,
        theme_advanced_toolbar_location : "top",
        theme_advanced_toolbar_align : "left",
        theme_advanced_statusbar_location : "bottom",
        template_popup_width : 500,
        template_popup_height : 400,
        template_replace_values : { 
            data_field : function(element){ 
                //~ console.log(20110722,fieldName,t.containing_window.get_current_record()); 
                var fieldName = element.innerHTML;
                element.innerHTML = t.containing_panel.get_current_record().data[fieldName];
            } 
        }
      };
      
    var editorConfig = {
      tinymceSettings: {
        plugins : "noneditable,template", 
        // Theme options - button# indicated the row# only
        theme_advanced_buttons1 : "bold,italic,underline,|,justifyleft,justifycenter,justifyright,|,bullist,numlist,|,outdent,indent,|,undo,redo,|,removeformat,template",
        theme_advanced_buttons2 : "",
        theme_advanced_buttons3 : "", // ,|,sub,sup,|,charmap",      
        theme_advanced_resizing : false
        //~ save_onsavecallback : save_callback,
        //~ save_enablewhendirty : true
        //~ save_oncancelcallback: on_cancel
        
    }};
    Ext.apply(editorConfig.tinymceSettings, tinymce_options);
    //~ editorConfig.name = config.action_name;
    editorConfig.name = config.name;
    delete config.name;
    //~ config.title = config.label;
    //~ delete config.label;
    this.before_init(config,params);
    
    // console.log('20150520b Lino.RichTextPanel.initComponent', this);

    this.editor = new Ext.ux.TinyMCE(editorConfig);
    var t = this;
    function save_cmd() { 
        // console.log("20150902 save_cmd()", arguments);            
        var cw = t.get_containing_window();
        if (cw) {
            cw.main_item.save();
        }
    }
    this.editor.withEd(function(){
        if (!t.editor.ed.addShortcut(
            'ctrl+s', 'Save the content', save_cmd)) {
            console.log("20150902 addShortcut() failed");            
        };
        // t.editor.ed.onKeyDown.add(function(ed, e) {
        //     if (e.keyCode == 13 && e.ctrlKey) {
        //         save_cmd(); 
        //         return tinymce.dom.Event.cancel(e); 
        //         // e.preventDefault();
        //         // http://stackoverflow.com/questions/18971284/event-preventdefault-vs-return-false-no-jquery
        //     }
        // });
    });
    config.tools = [{
                      qtip: "Edit text in own window", 
                      id: "up",
                      handler: function(){
                        if(t.editor.isDirty()) {
                            var record = t.containing_panel.get_current_record();
                            record.data[t.editor.name] = t.editor.getValue();
                        }
                        Lino.edit_tinymce_text(t, tinymce_options)
                      }
                    }];
    
    config.items = this.editor;
    config.layout = "fit";
    // console.log('20150520c Lino.RichTextPanel.initComponent', this);
    Lino.RichTextPanel.superclass.constructor.call(this, config);
    // console.log('20150520d Lino.RichTextPanel.initComponent', this);
  },
  getValue : function(v) {
      return this.editor.getValue(v);
  },
  refresh : function(unused) { 
      this.refresh_with_after();
  },
  /* RichTextPanel */
  refresh_with_after : function(after) {
    // when called from the dashboard:    
    if (!this.containing_panel.get_current_record) { return; }
    var record = this.containing_panel.get_current_record();
    // console.log('20140504 RichTextPanel.refresh()',
    //             this.title,record.title, record);
    var todo = function() {
      if (record) {
        var url = '/tinymce/templates' 
              + this.containing_panel.ls_url + "/" 
              + String(record.id) + "/" + this.editor.name;
        // console.log('20150415 RichTextPanel.refresh()',url);
        if (this.editor.ed)
            this.editor.ed.settings.template_external_list_url = url;
            // else {console.log("20150415 no editor")}
        this.set_base_params(this.containing_panel.get_master_params());
        //~ var v = record ? this.format_data(record.data[this.editor.name]) : ''
        var v = this.format_data(record.data[this.editor.name])
        this.editor.setValue(v);
      } else {
        this.editor.setValue('(no data)');
      }
    };
    Lino.do_when_visible(this,todo.createDelegate(this));
  }
});
//~ Ext.override(Lino.RichTextPanel,Lino.FieldBoxMixin);


// from lino.modlib.comments:comments/comments.js

function toggle_visibility(id) {
   var e = document.getElementById(id);
   if(e.style.display == 'block'|| (e.style.display != 'block' && e.style.display != 'none'))
      e.style.display = 'none';
   else
      e.style.display = 'block';
}
Lino.main_menu = [ { "menu": { "items": [ { "handler": function() {Lino.contacts.Persons.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Shows all persons.") }, "text": "Personen" }, { "handler": function() {Lino.contacts.Companies.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Base table for all tables showing companies.") }, "text": "Organisationen" }, { "handler": function() {Lino.households.Households.grid.run(null)}, "text": "Haushalte" }, { "handler": function() {Lino.lists.Lists.grid.run(null)}, "text": "Partnerlisten" } ] }, "text": "Kontakte" }, { "menu": { "items": [ { "handler": function() {Lino.checkdata.MyProblems.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Shows the problem messages assigned to me.") }, "text": "Meine Datenkontrollliste" }, { "handler": function() {Lino.blogs.MyEntries.grid.run(null)}, "text": "Meine Blog-Eintr\u00e4ge" }, { "handler": function() {Lino.excerpts.MyExcerpts.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Base class for all tables on Excerpt.") }, "text": "Meine Ausz\u00fcge" }, { "handler": function() {Lino.comments.MyComments.grid.run(null)}, "text": "Meine Kommentare" }, { "handler": function() {Lino.comments.RecentComments.grid.run(null)}, "text": "Recent comments" }, { "handler": function() {Lino.uploads.MyUploads.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Shows my uploads (i.e. those whose author is the current user).") }, "text": "Meine Upload-Dateien" } ] }, "text": "B\u00fcro" }, { "menu": { "items": [ { "handler": function() {Lino.cal.MyEntries.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Table of appointments for which I am responsible.") }, "text": "Meine Termine" }, { "handler": function() {Lino.cal.OverdueAppointments.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Shows overdue appointments, i.e. appointments whose date is\nover but who are still in a nonstable state.") }, "text": "\u00dcberf\u00e4llige Termine" }, { "handler": function() {Lino.cal.MyUnconfirmedAppointments.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Shows my appointments in the near future which are in suggested or\ndraft state.") }, "text": "Meine unbest\u00e4tigten Termine" }, { "handler": function() {Lino.cal.MyTasks.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Shows my tasks whose start date is today or in the future.") }, "text": "Meine Aufgaben" }, { "handler": function() {Lino.cal.MyGuests.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The default table of presences.") }, "text": "Meine G\u00e4ste" }, { "handler": function() {Lino.cal.MyPresences.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Shows all my presences in calendar events, independently of their\nstate.") }, "text": "Meine Anwesenheiten" }, { "handler": function() {Lino.cal.MyOverdueAppointments.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Like OverdueAppointments, but only for myself.") }, "text": "Meine \u00fcberf\u00e4lligen Termine" }, { "handler": function() {Lino.calview.WeeklyView.detail.run(null,{ "record_id": 0 })}, "iconCls": "x-tbar-application_form", "text": "Kalender" } ] }, "text": "Kalender" }, { "menu": { "items": [ { "handler": function() {Lino.courses.MyActivities.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Show the courses authored by me (i.e. where I am the responsible\nmanager).  Compare MyCoursesGiven.") }, "text": "Meine Aktivit\u00e4ten" }, { "handler": function() {Lino.courses.ActivitiesByLayout.grid.run(null)}, "text": "Aktivit\u00e4ten" }, "-", { "handler": function() {Lino.courses.Lines.grid.run(null)}, "text": "Aktivit\u00e4tenreihen" }, { "handler": function() {Lino.courses.PendingRequestedEnrolments.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Show all requested enrolments.") }, "text": "Offene Einschreibungsanfragen" }, { "handler": function() {Lino.courses.PendingConfirmedEnrolments.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Show all confirmed enrolments.") }, "text": "Auszustellende Teilnahmebescheinigungen" } ] }, "text": "Aktivit\u00e4ten" }, { "menu": { "items": [ { "menu": { "items": [ { "handler": function() {Lino.users.AllUsers.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Shows the list of all users on this site.") }, "text": "Benutzer" }, { "handler": function() {Lino.system.SiteConfigs.detail.run(null,{ "record_id": 1 })}, "iconCls": "x-tbar-application_form", "text": "Site-Parameter" }, { "handler": function() {Lino.gfks.HelpTexts.grid.run(null)}, "text": "Hilfetexte" } ] }, "text": "System" }, { "menu": { "items": [ { "handler": function() {Lino.contacts.CompanyTypes.grid.run(null)}, "text": "Organisationsarten" }, { "handler": function() {Lino.contacts.RoleTypes.grid.run(null)}, "text": "Funktionen" }, { "handler": function() {Lino.households.Types.grid.run(null)}, "text": "Haushaltsarten" }, { "handler": function() {Lino.lists.ListTypes.grid.run(null)}, "text": "Listenarten" } ] }, "text": "Kontakte" }, { "menu": { "items": [ { "handler": function() {Lino.cal.Calendars.grid.run(null)}, "text": "Kalenderliste" }, { "handler": function() {Lino.cal.AllRooms.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Show a list of all rooms.") }, "text": "R\u00e4ume" }, { "handler": function() {Lino.cal.RecurrentEvents.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The list of all recurrent events (RecurrentEvent).") }, "text": "Regelm\u00e4\u00dfige Ereignisse" }, { "handler": function() {Lino.cal.GuestRoles.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Global table of guest roles.") }, "text": "Gastrollen" }, { "handler": function() {Lino.cal.EventTypes.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The list of entry types defined on this site.") }, "text": "Kalendereintragsarten" }, { "handler": function() {Lino.cal.EventPolicies.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Global table of all possible recurrencly policies.") }, "text": "Wiederholungsregeln" }, { "handler": function() {Lino.cal.RemoteCalendars.grid.run(null)}, "text": "Externe Kalender" }, { "handler": function() {Lino.calview.DailyPlannerRows.grid.run(null)}, "text": "Tagesplanerzeilen" } ] }, "text": "Kalender" }, { "menu": { "items": [ { "handler": function() {Lino.courses.Topics.grid.run(null)}, "text": "Themen" }, { "handler": function() {Lino.courses.Slots.grid.run(null)}, "text": "Timetable Slots" } ] }, "text": "Aktivit\u00e4ten" }, { "menu": { "items": [ { "handler": function() {Lino.topics.AllTopics.grid.run(null)}, "text": "Themen" } ] }, "text": "Themen" }, { "menu": { "items": [ { "handler": function() {Lino.blogs.EntryTypes.grid.run(null)}, "text": "Blog-Eintrags-Arten" } ] }, "text": "Blog" }, { "menu": { "items": [ { "handler": function() {Lino.excerpts.ExcerptTypes.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Displays all rows of ExcerptType.") }, "text": "Auszugsarten" }, { "handler": function() {Lino.tinymce.MyTextFieldTemplates.grid.run(null)}, "text": "Meine Einf\u00fcgetexte" }, { "handler": function() {Lino.comments.CommentTypes.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The table with all existing comment types.") }, "text": "Kommentar-Arten" }, { "handler": function() {Lino.uploads.Volumes.grid.run(null)}, "text": "Dateibibliotheken" }, { "handler": function() {Lino.uploads.UploadTypes.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The table with all existing upload types.") }, "text": "Upload-Arten" } ] }, "text": "B\u00fcro" }, { "menu": { "items": [ { "handler": function() {Lino.countries.Countries.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The table of all countries.") }, "text": "L\u00e4nder" }, { "handler": function() {Lino.countries.Places.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The table of known geographical places.\nA geographical place can be a city, a town, a suburb,\na province, a lake... any named geographic entity,\nexcept for countries because these have their own table.") }, "text": "Orte" } ] }, "text": "Orte" } ] }, "text": "Konfigurierung" }, { "menu": { "items": [ { "menu": { "items": [ { "handler": function() {Lino.users.Authorities.grid.run(null)}, "text": "Vollmachten" }, { "handler": function() {Lino.users.UserTypes.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The list of user types available in this application.") }, "text": "Benutzerarten" }, { "handler": function() {Lino.users.UserRoles.grid.run(null)}, "text": "Benutzerrollen" }, { "handler": function() {Lino.checkdata.Checkers.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The list of data checkers known by this application.") }, "text": "Datentests" }, { "handler": function() {Lino.checkdata.AllProblems.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The base table for problem messages.") }, "text": "Datenprobleme" }, { "handler": function() {Lino.dashboard.AllWidgets.grid.run(null)}, "text": "All dashboard widgets" }, { "handler": function() {Lino.gfks.ContentTypes.grid.run(null)}, "text": "Datenbankmodelle" } ] }, "text": "System" }, { "menu": { "items": [ { "handler": function() {Lino.contacts.Roles.grid.run(null)}, "text": "Kontaktpersonen" }, { "handler": function() {Lino.contacts.Partners.grid.run(null)}, "text": "Partner" }, { "handler": function() {Lino.addresses.AddressTypes.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","A choicelist with all available address types.") }, "text": "Adressenarten" }, { "handler": function() {Lino.addresses.Addresses.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Shows all addresses in the database.") }, "text": "Adressen" }, { "handler": function() {Lino.phones.ContactDetailTypes.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The list of \"built-in\" types of contact detail items.") }, "text": "Kontaktangabenarten" }, { "handler": function() {Lino.phones.ContactDetails.grid.run(null)}, "text": "Kontaktangaben" }, { "handler": function() {Lino.households.MemberRoles.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The list of allowed choices for the role of a household member.") }, "text": "Haushaltsmitgliedsrollen" }, { "handler": function() {Lino.households.Members.grid.run(null)}, "text": "Mitglieder" }, { "handler": function() {Lino.humanlinks.Links.grid.run(null)}, "text": "Verwandtschaftsbeziehungen" }, { "handler": function() {Lino.humanlinks.LinkTypes.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The global list of human link types.  This is used as choicelist\nfor the type\nfield of a human link.") }, "text": "Verwandschaftsarten" }, { "handler": function() {Lino.lists.AllMembers.grid.run(null)}, "text": "Listenmitgliedschaften" } ] }, "text": "Kontakte" }, { "menu": { "items": [ { "handler": function() {Lino.cal.AllEntries.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Table which shows all calendar events.") }, "text": "Kalendereintr\u00e4ge" }, { "handler": function() {Lino.cal.Tasks.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Global table of all tasks for all users.") }, "text": "Aufgaben" }, { "handler": function() {Lino.cal.AllGuests.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The default table of presences.") }, "text": "Anwesenheiten" }, { "handler": function() {Lino.cal.Subscriptions.grid.run(null)}, "text": "Abonnements" }, { "handler": function() {Lino.cal.EntryStates.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The list of possible states of a calendar entry.") }, "text": "Kalendereintrag-Zust\u00e4nde" }, { "handler": function() {Lino.cal.GuestStates.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Global choicelist of possible guest states.") }, "text": "Anwesenheits-Zust\u00e4nde" }, { "handler": function() {Lino.cal.TaskStates.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Possible values for the state of a Task. The list of\nchoices for the Task.state field.") }, "text": "Aufgaben-Zust\u00e4nde" }, { "handler": function() {Lino.cal.PlannerColumns.grid.run(null)}, "text": "Tagesplanerkolonnen" }, { "handler": function() {Lino.cal.AccessClasses.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The sitewide list of access classes.") }, "text": "Zugriffsklassen" }, { "handler": function() {Lino.cal.DisplayColors.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","A list of colors to be specified for displaying.") }, "text": "Display colors" } ] }, "text": "Kalender" }, { "menu": { "items": [ { "handler": function() {Lino.sepa.Accounts.grid.run(null)}, "text": "Bankkonten" } ] }, "text": "SEPA" }, { "menu": { "items": [ { "handler": function() {Lino.courses.AllActivities.grid.run(null)}, "text": "Aktivit\u00e4ten" }, { "handler": function() {Lino.courses.AllEnrolments.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Show global list of all enrolments.") }, "text": "Einschreibungen" }, { "handler": function() {Lino.courses.EnrolmentStates.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The list of possible states of an enrolment.") }, "text": "Zust\u00e4nde Einschreibung" }, { "handler": function() {Lino.courses.ActivityLayouts.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","The global choicelist of activity layouts.  Every\nchoice is an instance of ActivityLayout.") }, "text": "Aktivit\u00e4tenlayouts" }, { "handler": function() {Lino.courses.CourseStates.grid.run(null)}, "text": "Zust\u00e4nde Aktivit\u00e4t" } ] }, "text": "Aktivit\u00e4ten" }, { "menu": { "items": [ { "handler": function() {Lino.topics.AllInterests.grid.run(null)}, "text": "Interessen" } ] }, "text": "Themen" }, { "menu": { "items": [ { "handler": function() {Lino.blogs.AllEntries.grid.run(null)}, "text": "Blog-Eintr\u00e4ge" } ] }, "text": "Blog" }, { "menu": { "items": [ { "handler": function() {Lino.excerpts.AllExcerpts.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Base class for all tables on Excerpt.") }, "text": "Ausz\u00fcge" }, { "handler": function() {Lino.tinymce.TextFieldTemplates.grid.run(null)}, "text": "Einf\u00fcgetexte" }, { "handler": function() {Lino.comments.AllComments.grid.run(null)}, "text": "Kommentare" }, { "handler": function() {Lino.comments.Mentions.grid.run(null)}, "text": "Erw\u00e4hnungen" }, { "handler": function() {Lino.comments.Reactions.grid.run(null)}, "text": "Reaktionen" }, { "handler": function() {Lino.uploads.AllUploads.grid.run(null)}, "text": "Upload-Dateien" }, { "handler": function() {Lino.uploads.UploadAreas.grid.run(null)}, "text": "Upload-Bereiche" } ] }, "text": "B\u00fcro" } ] }, "text": "Explorer" }, { "menu": { "items": [ { "handler": function() {Lino.about.About.show.run(null,{ "record_id": -99998 })}, "listeners": { "render": Lino.quicktip_renderer("Foo","A dialog window which displays some information about the site.") }, "text": "Info" }, { "handler": function() {Lino.users.Sessions.grid.run(null)}, "listeners": { "render": Lino.quicktip_renderer("Foo","Show a list of all user sessions.") }, "text": "Benutzersitzungen" } ] }, "text": "Site" }, { "handler": function() {Lino.handle_home_button()}, "text": "Startseite" }, { "handler": function() {Lino.set_user_language("en")}, "text": "en" }, { "handler": function() {Lino.set_user_language("de")}, "text": "de" }, { "handler": function() {Lino.set_user_language("fr")}, "text": "fr" } ];
Ext.namespace('Lino.system.SiteConfigs')
Ext.namespace('Lino.countries.Countries')
Ext.namespace('Lino.countries.Places')
Ext.namespace('Lino.contacts.Partners')
Ext.namespace('Lino.contacts.Persons')
Ext.namespace('Lino.contacts.CompanyTypes')
Ext.namespace('Lino.contacts.Companies')
Ext.namespace('Lino.contacts.RoleTypes')
Ext.namespace('Lino.contacts.Roles')
Ext.namespace('Lino.gfks.ContentTypes')
Ext.namespace('Lino.gfks.HelpTexts')
Ext.namespace('Lino.checkdata.Problems')
Ext.namespace('Lino.checkdata.AllProblems')
Ext.namespace('Lino.checkdata.MyProblems')
Ext.namespace('Lino.cal.RemoteCalendars')
Ext.namespace('Lino.cal.Rooms')
Ext.namespace('Lino.cal.AllRooms')
Ext.namespace('Lino.cal.Calendars')
Ext.namespace('Lino.cal.Subscriptions')
Ext.namespace('Lino.cal.Tasks')
Ext.namespace('Lino.cal.MyTasks')
Ext.namespace('Lino.cal.GuestRoles')
Ext.namespace('Lino.cal.Guests')
Ext.namespace('Lino.cal.AllGuests')
Ext.namespace('Lino.cal.MyPresences')
Ext.namespace('Lino.cal.MyPendingPresences')
Ext.namespace('Lino.cal.MyGuests')
Ext.namespace('Lino.cal.EventTypes')
Ext.namespace('Lino.cal.RecurrentEvents')
Ext.namespace('Lino.cal.Events')
Ext.namespace('Lino.cal.AllEntries')
Ext.namespace('Lino.cal.PublicEntries')
Ext.namespace('Lino.cal.EntriesByDay')
Ext.namespace('Lino.cal.OneEvent')
Ext.namespace('Lino.cal.MyEntries')
Ext.namespace('Lino.cal.MyEntriesToday')
Ext.namespace('Lino.cal.MyAssignedEvents')
Ext.namespace('Lino.cal.OverdueAppointments')
Ext.namespace('Lino.cal.MyOverdueAppointments')
Ext.namespace('Lino.cal.MyUnconfirmedAppointments')
Ext.namespace('Lino.cal.EventPolicies')
Ext.namespace('Lino.calview.DailyPlannerRows')
Ext.namespace('Lino.uploads.Volumes')
Ext.namespace('Lino.uploads.UploadTypes')
Ext.namespace('Lino.uploads.Uploads')
Ext.namespace('Lino.uploads.AllUploads')
Ext.namespace('Lino.uploads.MyUploads')
Ext.namespace('Lino.uploads.AreaUploads')
Ext.namespace('Lino.ledger.Accounts')
Ext.namespace('Lino.ledger.Journals')
Ext.namespace('Lino.ledger.JournalsOverview')
Ext.namespace('Lino.ledger.AccountingPeriods')
Ext.namespace('Lino.ledger.PaymentTerms')
Ext.namespace('Lino.ledger.PaymentMethods')
Ext.namespace('Lino.ledger.AllVouchers')
Ext.namespace('Lino.ledger.MatchRules')
Ext.namespace('Lino.ledger.PartnerVouchers')
Ext.namespace('Lino.ledger.GeneralAccountBalances')
Ext.namespace('Lino.ledger.PartnerBalancesByTradeType')
Ext.namespace('Lino.ledger.Movements')
Ext.namespace('Lino.ledger.AllMovements')
Ext.namespace('Lino.ledger.FiscalYears')
Ext.namespace('Lino.sepa.Accounts')
Ext.namespace('Lino.addresses.Addresses')
Ext.namespace('Lino.phones.ContactDetails')
Ext.namespace('Lino.households.Types')
Ext.namespace('Lino.households.Households')
Ext.namespace('Lino.households.Members')
Ext.namespace('Lino.humanlinks.Links')
Ext.namespace('Lino.topics.Topics')
Ext.namespace('Lino.topics.AllTopics')
Ext.namespace('Lino.topics.Interests')
Ext.namespace('Lino.topics.AllInterests')
Ext.namespace('Lino.lists.ListTypes')
Ext.namespace('Lino.lists.Lists')
Ext.namespace('Lino.lists.Members')
Ext.namespace('Lino.lists.AllMembers')
Ext.namespace('Lino.blogs.EntryTypes')
Ext.namespace('Lino.blogs.Entries')
Ext.namespace('Lino.blogs.MyEntries')
Ext.namespace('Lino.blogs.AllEntries')
Ext.namespace('Lino.blogs.LatestEntries')
Ext.namespace('Lino.excerpts.ExcerptTypes')
Ext.namespace('Lino.excerpts.Excerpts')
Ext.namespace('Lino.excerpts.AllExcerpts')
Ext.namespace('Lino.excerpts.MyExcerpts')
Ext.namespace('Lino.tinymce.TextFieldTemplates')
Ext.namespace('Lino.tinymce.MyTextFieldTemplates')
Ext.namespace('Lino.comments.CommentTypes')
Ext.namespace('Lino.comments.Comments')
Ext.namespace('Lino.comments.MyComments')
Ext.namespace('Lino.comments.AllComments')
Ext.namespace('Lino.comments.CommentsByX')
Ext.namespace('Lino.comments.RecentComments')
Ext.namespace('Lino.comments.Mentions')
Ext.namespace('Lino.comments.Reactions')
Ext.namespace('Lino.dashboard.Widgets')
Ext.namespace('Lino.dashboard.AllWidgets')
Ext.namespace('Lino.users.AllUsers')
Ext.namespace('Lino.users.UsersOverview')
Ext.namespace('Lino.users.MySettings')
Ext.namespace('Lino.users.Authorities')
Ext.namespace('Lino.users.Sessions')
Ext.namespace('Lino.courses.Slots')
Ext.namespace('Lino.courses.Topics')
Ext.namespace('Lino.courses.Lines')
Ext.namespace('Lino.courses.Activities')
Ext.namespace('Lino.courses.ActivitiesByLayout')
Ext.namespace('Lino.courses.AllActivities')
Ext.namespace('Lino.courses.MyActivities')
Ext.namespace('Lino.courses.MyCoursesGiven')
Ext.namespace('Lino.courses.DraftActivities')
Ext.namespace('Lino.courses.ActiveActivities')
Ext.namespace('Lino.courses.InactiveActivities')
Ext.namespace('Lino.courses.ClosedActivities')
Ext.namespace('Lino.courses.Enrolments')
Ext.namespace('Lino.courses.AllEnrolments')
Ext.namespace('Lino.courses.PendingRequestedEnrolments')
Ext.namespace('Lino.courses.PendingConfirmedEnrolments')
Ext.namespace('Lino.ledger.LedgerInfoTable')
Ext.namespace('Lino.countries.PlacesByPlace')
Ext.namespace('Lino.countries.PlacesByCountry')
Ext.namespace('Lino.contacts.PartnersByCity')
Ext.namespace('Lino.contacts.PartnersByCountry')
Ext.namespace('Lino.contacts.RolesByCompany')
Ext.namespace('Lino.contacts.RolesByPerson')
Ext.namespace('Lino.contacts.CompaniesByCompany')
Ext.namespace('Lino.checkdata.ProblemsByChecker')
Ext.namespace('Lino.cal.SubscriptionsByUser')
Ext.namespace('Lino.cal.SubscriptionsByCalendar')
Ext.namespace('Lino.cal.TasksByUser')
Ext.namespace('Lino.cal.GuestsByEvent')
Ext.namespace('Lino.cal.GuestsByRole')
Ext.namespace('Lino.cal.GuestsByPartner')
Ext.namespace('Lino.cal.EntriesByType')
Ext.namespace('Lino.cal.ConflictingEvents')
Ext.namespace('Lino.cal.EntriesByRoom')
Ext.namespace('Lino.cal.EntriesByGuest')
Ext.namespace('Lino.calview.DailyPlanner')
Ext.namespace('Lino.calview.DailySlave')
Ext.namespace('Lino.calview.WeeklySlave')
Ext.namespace('Lino.uploads.UploadsByType')
Ext.namespace('Lino.ledger.MatchRulesByAccount')
Ext.namespace('Lino.ledger.MatchRulesByJournal')
Ext.namespace('Lino.ledger.MovementsByVoucher')
Ext.namespace('Lino.ledger.MovementsByPartner')
Ext.namespace('Lino.ledger.MovementsByAccount')
Ext.namespace('Lino.ledger.MovementsByMatch')
Ext.namespace('Lino.sepa.AccountsByPartner')
Ext.namespace('Lino.addresses.AddressesByPartner')
Ext.namespace('Lino.addresses.AddressesByCity')
Ext.namespace('Lino.phones.ContactDetailsByPartner')
Ext.namespace('Lino.households.HouseholdsByType')
Ext.namespace('Lino.households.MembersByHousehold')
Ext.namespace('Lino.households.SiblingsByPerson')
Ext.namespace('Lino.households.MembersByPerson')
Ext.namespace('Lino.humanlinks.LinksByHuman')
Ext.namespace('Lino.topics.InterestsByPartner')
Ext.namespace('Lino.topics.InterestsByTopic')
Ext.namespace('Lino.lists.MembersByList')
Ext.namespace('Lino.lists.MembersByPartner')
Ext.namespace('Lino.blogs.EntriesByType')
Ext.namespace('Lino.excerpts.ExcerptsByType')
Ext.namespace('Lino.comments.CommentsByType')
Ext.namespace('Lino.comments.CommentsByMentioned')
Ext.namespace('Lino.comments.RepliesByComment')
Ext.namespace('Lino.dashboard.WidgetsByUser')
Ext.namespace('Lino.users.AuthoritiesGiven')
Ext.namespace('Lino.users.AuthoritiesTaken')
Ext.namespace('Lino.courses.LinesByTopic')
Ext.namespace('Lino.courses.EntriesByTeacher')
Ext.namespace('Lino.courses.ActivitiesByTeacher')
Ext.namespace('Lino.courses.ActivitiesByLine')
Ext.namespace('Lino.courses.ActivitiesByTopic')
Ext.namespace('Lino.courses.ActivitiesBySlot')
Ext.namespace('Lino.courses.EnrolmentsByPupil')
Ext.namespace('Lino.courses.EnrolmentsByCourse')
Ext.namespace('Lino.gfks.HelpTextsByModel')
Ext.namespace('Lino.checkdata.ProblemsByOwner')
Ext.namespace('Lino.cal.TasksByController')
Ext.namespace('Lino.cal.EntriesByController')
Ext.namespace('Lino.uploads.UploadsByController')
Ext.namespace('Lino.topics.InterestsByController')
Ext.namespace('Lino.blogs.EntriesByController')
Ext.namespace('Lino.excerpts.ExcerptsByOwner')
Ext.namespace('Lino.comments.CommentsByRFC')
Ext.namespace('Lino.comments.MentionsByOwner')
Ext.namespace('Lino.about.SiteSearch')
Ext.namespace('Lino.gfks.BrokenGFKs')
Ext.namespace('Lino.gfks.BrokenGFKsByModel')
Ext.namespace('Lino.calview.MonthlySlave')
Ext.namespace('Lino.calview.DailyView')
Ext.namespace('Lino.calview.WeeklyView')
Ext.namespace('Lino.calview.MonthlyView')
Ext.namespace('Lino.ledger.ExpectedMovements')
Ext.namespace('Lino.ledger.DebtsByAccount')
Ext.namespace('Lino.ledger.DebtsByPartner')
Ext.namespace('Lino.ledger.Debtors')
Ext.namespace('Lino.ledger.Creditors')
Ext.namespace('Lino.users.UserRoles')
Ext.namespace('Lino.about.About')
Ext.namespace('Lino.ledger.Situation')
Ext.namespace('Lino.courses.StatusReport')
Ext.namespace('Lino.system.YesNo')
Ext.namespace('Lino.system.Genders')
Ext.namespace('Lino.system.PeriodEvents')
Ext.namespace('Lino.checkdata.Checkers')
Ext.namespace('Lino.printing.BuildMethods')
Ext.namespace('Lino.users.UserTypes')
Ext.namespace('Lino.about.TimeZones')
Ext.namespace('Lino.xl.Priorities')
Ext.namespace('Lino.countries.PlaceTypes')
Ext.namespace('Lino.uploads.Shortcuts')
Ext.namespace('Lino.uploads.UploadAreas')
Ext.namespace('Lino.phones.ContactDetailTypes')
Ext.namespace('Lino.contacts.PartnerEvents')
Ext.namespace('Lino.contacts.CivilStates')
Ext.namespace('Lino.cal.DisplayColors')
Ext.namespace('Lino.cal.Weekdays')
Ext.namespace('Lino.cal.YearMonths')
Ext.namespace('Lino.cal.DurationUnits')
Ext.namespace('Lino.cal.Recurrencies')
Ext.namespace('Lino.cal.AccessClasses')
Ext.namespace('Lino.cal.PlannerColumns')
Ext.namespace('Lino.cal.TaskStates')
Ext.namespace('Lino.cal.GuestStates')
Ext.namespace('Lino.cal.EventEvents')
Ext.namespace('Lino.cal.EntryStates')
Ext.namespace('Lino.cal.ReservationStates')
Ext.namespace('Lino.calview.Planners')
Ext.namespace('Lino.ledger.DC')
Ext.namespace('Lino.ledger.JournalGroups')
Ext.namespace('Lino.ledger.PeriodStates')
Ext.namespace('Lino.ledger.CommonAccounts')
Ext.namespace('Lino.ledger.VoucherTypes')
Ext.namespace('Lino.ledger.TradeTypes')
Ext.namespace('Lino.ledger.VoucherStates')
Ext.namespace('Lino.addresses.AddressTypes')
Ext.namespace('Lino.addresses.DataSources')
Ext.namespace('Lino.households.MemberDependencies')
Ext.namespace('Lino.households.MemberRoles')
Ext.namespace('Lino.humanlinks.LinkTypes')
Ext.namespace('Lino.courses.CourseStates')
Ext.namespace('Lino.courses.EnrolmentStates')
Ext.namespace('Lino.courses.ActivityLayouts')
Ext.namespace('Lino.excerpts.Shortcuts')
Ext.namespace('Lino.comments.Emotions')
Ext.namespace('Lino.comments.CommentEvents')

// ChoiceLists: 
Lino.system.YesNo = [ [ "y", "Ja" ], [ "n", "Nein" ] ];
Lino.system.Genders = [ [ "M", "M\u00e4nnlich" ], [ "F", "Weiblich" ] ];
Lino.system.PeriodEvents = [ [ "10", "Beginnt" ], [ "20", "Ist aktiv" ], [ "30", "Ended" ] ];
Lino.checkdata.Checkers = [ [ "addresses.AddressOwnerChecker", "Adressen pr\u00fcfen" ], [ "cal.ConflictingEventsChecker", "Auf Termin\u00fcberschneidungen pr\u00fcfen" ], [ "cal.EventGuestChecker", "Termine ohne Teilnehmer" ], [ "cal.LongEntryChecker", "Dauer \u00fcberschreitende Kalendereintr\u00e4ge" ], [ "cal.ObsoleteEventTypeChecker", "Veraltete generierte Kalendereintr\u00e4ge" ], [ "countries.PlaceChecker", "Check data of geographical places." ], [ "ledger.VoucherChecker", "Check integrity of ledger vouchers" ], [ "memo.PreviewableChecker", "Check for previewables needing update" ], [ "phones.ContactDetailsOwnerChecker", "Check for mismatches between contact details and owner" ], [ "printing.CachedPrintableChecker", "Check for missing target files" ], [ "system.BleachChecker", "Find unbleached html content" ], [ "uploads.UploadChecker", "Check metadata of upload files" ], [ "uploads.UploadsFolderChecker", "Find orphaned files in uploads folder" ] ];
Lino.printing.BuildMethods = [ [ "appydoc", "AppyDocBuildMethod" ], [ "appyodt", "AppyOdtBuildMethod" ], [ "appypdf", "AppyPdfBuildMethod" ], [ "appyrtf", "AppyRtfBuildMethod" ], [ "latex", "LatexBuildMethod" ], [ "rtf", "RtfBuildMethod" ], [ "weasy2html", "WeasyHtmlBuildMethod" ], [ "weasy2pdf", "WeasyPdfBuildMethod" ], [ "xml", "XmlBuildMethod" ] ];
Lino.users.UserTypes = [ [ "000", "000 (000 (Anonym))" ], [ "100", "100 (100 (Benutzer))" ], [ "200", "200 (200 (Collector))" ], [ "300", "300 (300 (Project manager))" ], [ "800", "800 (800 (Staff))" ], [ "900", "900 (900 (Verwalter))" ] ];
Lino.about.TimeZones = [ [ "01", "UTC" ] ];
Lino.xl.Priorities = [ [ "10", "Kritisch" ], [ "20", "Hoch" ], [ "30", "Normal" ], [ "40", "Niedrig" ], [ "50", "Very Low" ] ];
Lino.countries.PlaceTypes = [ [ "10", "Bundesland" ], [ "11", "Division" ], [ "12", "Region" ], [ "13", "Gemeinschaft" ], [ "14", "Territorium" ], [ "20", "Regierungsbezirk" ], [ "21", "Provinz" ], [ "22", "Grafschaft" ], [ "23", "Unterregion" ], [ "24", "Departement" ], [ "25", "Arrondissement" ], [ "26", "Pr\u00e4fektur" ], [ "27", "Distrikt" ], [ "28", "Sektor" ], [ "50", "Stadt" ], [ "51", "Kleinstadt" ], [ "52", "Gemeinde" ], [ "54", "Pfarre" ], [ "55", "Stadtteil" ], [ "56", "Viertel" ], [ "61", "Ortschaft" ], [ "62", "Kleine Ortschaft" ], [ "70", "Dorf" ] ];
Lino.uploads.Shortcuts = [  ];
Lino.uploads.UploadAreas = [ [ "90", "Uploads" ] ];
Lino.phones.ContactDetailTypes = [ [ "010", "E-Mail" ], [ "020", "Handy" ], [ "030", "Telefon" ], [ "040", "Website" ], [ "050", "Fax" ], [ "090", "Sonstige" ] ];
Lino.contacts.PartnerEvents = [ [ "has_open_movements", "Has open movements" ] ];
Lino.contacts.CivilStates = [ [ "10", "Ledig" ], [ "20", "Verheiratet" ], [ "30", "Verwitwet" ], [ "40", "Geschieden" ], [ "50", "Getrennt von Tisch und Bett" ], [ "51", "Faktisch getrennt" ], [ "60", "Zusammenwohnend" ] ];
Lino.cal.DisplayColors = [ [ "White", "White" ], [ "Silver", "Silver" ], [ "Gray", "Gray" ], [ "Black", "Black" ], [ "Red", "Red" ], [ "Maroon", "Maroon" ], [ "Yellow", "Yellow" ], [ "Olive", "Olive" ], [ "Lime", "Lime" ], [ "Green", "Green" ], [ "Aqua", "Aqua" ], [ "Teal", "Teal" ], [ "Blue", "Blue" ], [ "Navy", "Navy" ], [ "Fuchsia", "Fuchsia" ], [ "Purple", "Purple" ] ];
Lino.cal.Weekdays = [ [ "1", "Montag" ], [ "2", "Dienstag" ], [ "3", "Mittwoch" ], [ "4", "Donnerstag" ], [ "5", "Freitag" ], [ "6", "Samstag" ], [ "7", "Sonntag" ] ];
Lino.cal.YearMonths = [ [ "1", "Januar" ], [ "2", "Februar" ], [ "3", "M\u00e4rz" ], [ "4", "April" ], [ "5", "Mai" ], [ "6", "Juni" ], [ "7", "Juli" ], [ "8", "August" ], [ "9", "September" ], [ "10", "Oktober" ], [ "11", "November" ], [ "12", "Dezember" ] ];
Lino.cal.DurationUnits = [ [ "s", "Sekunden" ], [ "m", "Minuten" ], [ "h", "Stunden" ], [ "D", "Tage" ], [ "W", "Wochen" ], [ "M", "Monate" ], [ "Y", "Jahre" ] ];
Lino.cal.Recurrencies = [ [ "O", "einmalig" ], [ "D", "t\u00e4glich" ], [ "W", "w\u00f6chentlich" ], [ "M", "monatlich" ], [ "Y", "j\u00e4hrlich" ], [ "P", "pro Wochentag" ], [ "E", "Beweglich mit Ostern" ] ];
Lino.cal.AccessClasses = [ [ "10", "Privat" ], [ "20", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")" ], [ "30", "\u00d6ffentlich" ] ];
Lino.cal.PlannerColumns = [ [ "10", "Extern" ], [ "20", "Intern" ] ];
Lino.cal.TaskStates = [ [ "10", "Zu tun" ], [ "15", "Wichtig" ], [ "20", "Begonnen" ], [ "30", "Erledigt" ], [ "50", "Storniert" ] ];
Lino.cal.GuestStates = [ [ "10", "Eingeladen" ], [ "40", "Anwesend" ], [ "50", "Fehlt" ], [ "60", "Entschuldigt" ] ];
Lino.cal.EventEvents = [ [ "10", "Stabil" ], [ "20", "Unstabil" ] ];
Lino.cal.EntryStates = [ [ "10", "Vorschlag" ], [ "20", "Entwurf" ], [ "50", "Stattgefunden" ], [ "70", "Storniert" ] ];
Lino.cal.ReservationStates = [  ];
Lino.calview.Planners = [ [ "default", "Kalender" ] ];
Lino.ledger.DC = [ [ "D", "Debit" ], [ "C", "Kredit" ] ];
Lino.ledger.JournalGroups = [ [ "10", "Verkauf" ], [ "20", "Einkauf" ], [ "30", "L\u00f6hne und Geh\u00e4lter" ], [ "40", "Finanzjournale" ], [ "50", "MwSt." ], [ "60", "Miscellaneous transactions" ] ];
Lino.ledger.PeriodStates = [ [ "10", "In Bearbeitung" ], [ "20", "Abgeschlossen" ] ];
Lino.ledger.CommonAccounts = [ [ "1000", "Net income (loss)" ], [ "4000", "Kunden" ], [ "4100", "Lieferanten" ], [ "4200", "Angestellte" ], [ "4300", "Offene Zahlungsauftr\u00e4ge" ], [ "4500", "Steuer\u00e4mter" ], [ "4510", "Geschuldete Mehrwertsteuer" ], [ "4513", "Deklarierte Mehrwertsteuer" ], [ "4520", "Abziehbare Mehrwertsteuer" ], [ "4530", "R\u00fcckzahlbare Mehrwertsteuer" ], [ "4800", "Internal clearings" ], [ "4900", "Wartekonto" ], [ "5500", "BestBank" ], [ "5700", "Kasse" ], [ "6010", "Eink\u00e4ufe von Dienstleistungen" ], [ "6020", "Investierungsk\u00e4ufe" ], [ "6040", "Wareneink\u00e4ufe" ], [ "6300", "L\u00f6hne und Geh\u00e4lter" ], [ "6900", "Net income" ], [ "7000", "Verkauf" ], [ "7900", "Net loss" ] ];
Lino.ledger.VoucherTypes = [  ];
Lino.ledger.TradeTypes = [ [ "S", "Verkauf" ], [ "P", "Einkauf" ], [ "W", "L\u00f6hne und Geh\u00e4lter" ], [ "T", "Steuern" ], [ "C", "Begleichungen" ], [ "B", "Zahlungsauftr\u00e4ge" ] ];
Lino.ledger.VoucherStates = [ [ "10", "Entwurf" ], [ "20", "Registriert" ], [ "30", "Unterschrieben" ], [ "40", "Storniert" ] ];
Lino.addresses.AddressTypes = [ [ "01", "Offizielle Adresse" ], [ "02", "Ungepr\u00fcfte Adresse" ], [ "03", "Deklarierte Addresse" ], [ "04", "Referenzadresse" ], [ "98", "Veraltet" ], [ "99", "Sonstige" ] ];
Lino.addresses.DataSources = [ [ "01", "Manuell eingegeben" ], [ "02", "Eingelesen von eID-Karte" ] ];
Lino.households.MemberDependencies = [ [ "01", "Zu Lasten" ], [ "02", "Nicht zu Lasten" ], [ "03", "Lasten geteilt" ] ];
Lino.households.MemberRoles = [ [ "01", "Vorstand" ], [ "02", "Ehepartner" ], [ "03", "Partner" ], [ "04", "Mitbewohner" ], [ "05", "Kind" ], [ "06", "Verwandt" ], [ "07", "Adoptivkind" ], [ "08", "Pflegekind" ], [ "10", "Sonstige" ] ];
Lino.humanlinks.LinkTypes = [ [ "01", "Vater(Mutter)" ], [ "02", "Adoptivvater(Adoptivmutter)" ], [ "03", "Gro\u00dfvater(Gro\u00dfmutter)" ], [ "05", "Ehemann(Ehefrau)" ], [ "06", "Freund(Freundin)" ], [ "07", "Partner(Partnerin)" ], [ "08", "Stiefvater(Stiefmutter)" ], [ "09", "Pflegevater(Pflegemutter)" ], [ "10", "Bruder(Schwester)" ], [ "11", "Vetter(Kusine)" ], [ "12", "Onkel(Tante)" ], [ "80", "Verwandter(Verwandte)" ], [ "90", "Sonstiger(Sonstige)" ] ];
Lino.courses.CourseStates = [ [ "10", "Entwurf" ], [ "20", "Gestartet" ], [ "30", "Inaktiv" ], [ "40", "Abgeschlossen" ] ];
Lino.courses.EnrolmentStates = [ [ "10", "Angefragt" ], [ "11", "Test" ], [ "20", "Best\u00e4tigt" ], [ "30", "Storniert" ] ];
Lino.courses.ActivityLayouts = [ [ "C", "Aktivit\u00e4ten" ] ];
Lino.excerpts.Shortcuts = [  ];
Lino.comments.Emotions = [ [ "ok", "Okay" ], [ "agree", "Einverstanden" ], [ "disagree", "Disagree" ] ];
Lino.comments.CommentEvents = [ [ "10", "Erstellt" ], [ "20", "Bearbeitet" ] ];

Lino.ledger.FiscalYears.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var start_date1 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(ledger.FiscalYears.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date2 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(ledger.FiscalYears.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    this.items = [ { "autoHeight": true, "flex": 50, "items": start_date1, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": end_date2, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ start_date1, end_date2 ];
    Lino.ledger.FiscalYears.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.dashboard.Widgets.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var user6 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(dashboard.Widgets.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/dashboard/Widgets/user" }) }), "value": null });
    this.items = [ { "autoHeight": true, "items": user6, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user6 ];
    Lino.dashboard.Widgets.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.users.UsersOverview.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user_type9 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Benutzerart", "forceSelection": true, "hiddenName": "user_typeHidden", "listeners": { "render": Lino.quicktip_renderer("User type","(users.UsersOverview.user_type) ") }, "name": "user_type", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.users.UserTypes) });
    var start_date10 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(users.UsersOverview.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date11 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(users.UsersOverview.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    this.items = [ { "autoHeight": true, "flex": 60, "items": user_type9, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": start_date10, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": end_date11, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user_type9, start_date10, end_date11 ];
    Lino.users.UsersOverview.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Persons.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var observed_event16 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beobachtungskriterium</span>", "forceSelection": true, "hiddenName": "observed_eventHidden", "listeners": { "render": Lino.quicktip_renderer("Observed event","(contacts.Persons.observed_event) Extended filter criteria") }, "name": "observed_event", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.contacts.PartnerEvents) });
    var start_date17 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(contacts.Persons.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date18 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(contacts.Persons.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var company19 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Companies.detail", "emptyText": "Organisation ausw\u00e4hlen...", "fieldLabel": "Organisation", "hiddenName": "companyHidden", "insert_action": "Lino.contacts.Companies.insert", "listeners": { "render": Lino.quicktip_renderer("Organization","(contacts.Persons.company) ") }, "name": "company", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Companies.detail,Lino.contacts.Companies.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Persons/company" }) }) });
    var function20 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Funktion ausw\u00e4hlen...", "fieldLabel": "Funktion", "hiddenName": "functionHidden", "listeners": { "render": Lino.quicktip_renderer("Function","(contacts.Persons.function) ") }, "name": "function", "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Persons/function" }) }) });
    var topic21 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.topics.Topics.detail", "emptyText": "Thema ausw\u00e4hlen...", "fieldLabel": "Thema", "hiddenName": "topicHidden", "insert_action": "Lino.topics.Topics.insert", "listeners": { "render": Lino.quicktip_renderer("Topic","(contacts.Persons.topic) ") }, "name": "topic", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.topics.Topics.detail,Lino.topics.Topics.insert)}, "pageSize": 20, "related_actor_id": "topics.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Persons/topic" }) }) });
    this.items = [ { "autoHeight": true, "flex": 19, "items": observed_event16, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": start_date17, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": end_date18, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": company19, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": function20, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": topic21, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ observed_event16, start_date17, end_date18, company19, function20, topic21 ];
    Lino.contacts.Persons.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Subscriptions.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var user29 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(cal.Subscriptions.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Subscriptions/user" }) }), "value": null });
    this.items = [ { "autoHeight": true, "items": user29, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user29 ];
    Lino.cal.Subscriptions.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.DailySlave.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user32 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(calview.DailySlave.user) The responsible user.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailySlave/user" }) }), "value": null });
    var assigned_to33 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zugewiesen zu</span>", "hiddenName": "assigned_toHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Assigned to","(calview.DailySlave.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "name": "assigned_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailySlave/assigned_to" }) }), "value": null });
    var event_type34 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(calview.DailySlave.event_type) The type of this calendar entry.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailySlave/event_type" }) }), "value": null });
    var room35 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(calview.DailySlave.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailySlave/room" }) }), "value": null });
    var state36 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(calview.DailySlave.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EntryStates), "value": null });
    var show_appointments37 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Termine", "forceSelection": true, "hiddenName": "show_appointmentsHidden", "listeners": { "render": Lino.quicktip_renderer("Appointments","(calview.DailySlave.show_appointments) ") }, "name": "show_appointments", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    this.items = [ { "autoHeight": true, "flex": 18, "items": user32, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": assigned_to33, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": event_type34, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": room35, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": state36, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": show_appointments37, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user32, assigned_to33, event_type34, room35, state36, show_appointments37 ];
    Lino.calview.DailySlave.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.DailyPlanner.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user45 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(calview.DailyPlanner.user) The responsible user.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailyPlanner/user" }) }), "value": null });
    var assigned_to46 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zugewiesen zu</span>", "hiddenName": "assigned_toHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Assigned to","(calview.DailyPlanner.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "name": "assigned_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailyPlanner/assigned_to" }) }), "value": null });
    var event_type47 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(calview.DailyPlanner.event_type) The type of this calendar entry.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailyPlanner/event_type" }) }), "value": null });
    var room48 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(calview.DailyPlanner.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailyPlanner/room" }) }), "value": null });
    var state49 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(calview.DailyPlanner.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EntryStates), "value": null });
    var show_appointments50 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Termine", "forceSelection": true, "hiddenName": "show_appointmentsHidden", "listeners": { "render": Lino.quicktip_renderer("Appointments","(calview.DailyPlanner.show_appointments) ") }, "name": "show_appointments", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    this.items = [ { "autoHeight": true, "flex": 18, "items": user45, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": assigned_to46, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": event_type47, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": room48, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": state49, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": show_appointments50, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user45, assigned_to46, event_type47, room48, state49, show_appointments50 ];
    Lino.calview.DailyPlanner.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.WeeklySlave.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user58 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(calview.WeeklySlave.user) The responsible user.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/WeeklySlave/user" }) }), "value": null });
    var assigned_to59 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zugewiesen zu</span>", "hiddenName": "assigned_toHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Assigned to","(calview.WeeklySlave.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "name": "assigned_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/WeeklySlave/assigned_to" }) }), "value": null });
    var event_type60 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(calview.WeeklySlave.event_type) The type of this calendar entry.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/WeeklySlave/event_type" }) }), "value": null });
    var room61 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(calview.WeeklySlave.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/WeeklySlave/room" }) }), "value": null });
    var state62 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(calview.WeeklySlave.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EntryStates), "value": null });
    var show_appointments63 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Termine", "forceSelection": true, "hiddenName": "show_appointmentsHidden", "listeners": { "render": Lino.quicktip_renderer("Appointments","(calview.WeeklySlave.show_appointments) ") }, "name": "show_appointments", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    this.items = [ { "autoHeight": true, "flex": 18, "items": user58, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": assigned_to59, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": event_type60, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": room61, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": state62, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": show_appointments63, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user58, assigned_to59, event_type60, room61, state62, show_appointments63 ];
    Lino.calview.WeeklySlave.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.DailyView.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user71 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(calview.DailyView.user) The responsible user.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailyView/user" }) }), "value": null });
    var assigned_to72 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zugewiesen zu</span>", "hiddenName": "assigned_toHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Assigned to","(calview.DailyView.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "name": "assigned_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailyView/assigned_to" }) }), "value": null });
    var event_type73 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(calview.DailyView.event_type) The type of this calendar entry.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailyView/event_type" }) }), "value": null });
    var room74 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(calview.DailyView.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/DailyView/room" }) }), "value": null });
    var state75 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(calview.DailyView.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EntryStates), "value": null });
    var show_appointments76 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Termine", "forceSelection": true, "hiddenName": "show_appointmentsHidden", "listeners": { "render": Lino.quicktip_renderer("Appointments","(calview.DailyView.show_appointments) ") }, "name": "show_appointments", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    this.items = [ { "autoHeight": true, "flex": 18, "items": user71, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": assigned_to72, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": event_type73, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": room74, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": state75, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": show_appointments76, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user71, assigned_to72, event_type73, room74, state75, show_appointments76 ];
    Lino.calview.DailyView.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Movements.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var start_period84 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "hiddenName": "start_periodHidden", "listeners": { "render": Lino.quicktip_renderer("Period from","(ledger.Movements.start_period) Start of observed period range.") }, "name": "start_period", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/Movements/start_period" }) }) });
    var end_period85 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Period until</span>", "hiddenName": "end_periodHidden", "listeners": { "render": Lino.quicktip_renderer("Period until","(ledger.Movements.end_period) Optional end of observed period range. Leave empty to observe only the start period.") }, "name": "end_period", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/Movements/end_period" }) }) });
    var start_date86 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datum von</span>", "listeners": { "render": Lino.quicktip_renderer("Date from","(ledger.Movements.start_date) Start of observed date range") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date87 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(ledger.Movements.end_date) End of observed date range") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var cleared88 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beglichene Bewegungen zeigen", "forceSelection": true, "hiddenName": "clearedHidden", "listeners": { "render": Lino.quicktip_renderer("Show cleared movements","(ledger.Movements.cleared) ") }, "name": "cleared", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    var main_1_panel89 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 24, "items": start_period84, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 24, "items": end_period85, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": start_date86, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": end_date87, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": cleared88, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var journal_group95 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Journalgruppe", "forceSelection": true, "hiddenName": "journal_groupHidden", "listeners": { "render": Lino.quicktip_renderer("Journal group","(ledger.Movements.journal_group) ") }, "name": "journal_group", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.ledger.JournalGroups) });
    var journal96 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.ledger.Journals.detail", "emptyText": "Journal ausw\u00e4hlen...", "fieldLabel": "Journal", "hiddenName": "journalHidden", "insert_action": "Lino.ledger.Journals.insert", "listeners": { "render": Lino.quicktip_renderer("Journal","(ledger.Movements.journal) ") }, "name": "journal", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.Journals.detail,Lino.ledger.Journals.insert)}, "pageSize": 20, "related_actor_id": "ledger.Journals", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/Movements/journal" }) }) });
    var year97 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Gesch\u00e4ftsjahr ausw\u00e4hlen...", "fieldLabel": "Gesch\u00e4ftsjahr", "hiddenName": "yearHidden", "listeners": { "render": Lino.quicktip_renderer("Fiscal year","(ledger.Movements.year) ") }, "name": "year", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.FiscalYears", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/Movements/year" }) }) });
    var partner98 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "Partner", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(ledger.Movements.partner) ") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/Movements/partner" }) }) });
    var account99 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.ledger.Accounts.detail", "emptyText": "Konto ausw\u00e4hlen...", "fieldLabel": "Konto", "hiddenName": "accountHidden", "insert_action": "Lino.ledger.Accounts.insert", "listeners": { "render": Lino.quicktip_renderer("Account","(ledger.Movements.account) ") }, "name": "account", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.Accounts.detail,Lino.ledger.Accounts.insert)}, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/Movements/account" }) }) });
    var main_2_panel100 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 26, "items": journal_group95, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": journal96, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": year97, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": partner98, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": account99, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.items = [ main_1_panel89, main_2_panel100 ];
    this.fields = [ start_period84, end_period85, start_date86, end_date87, cleared88, journal_group95, journal96, year97, partner98, account99 ];
    Lino.ledger.Movements.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.MonthlyView.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user107 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(calview.MonthlyView.user) The responsible user.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/MonthlyView/user" }) }), "value": null });
    var assigned_to108 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zugewiesen zu</span>", "hiddenName": "assigned_toHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Assigned to","(calview.MonthlyView.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "name": "assigned_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/MonthlyView/assigned_to" }) }), "value": null });
    var event_type109 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(calview.MonthlyView.event_type) The type of this calendar entry.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/MonthlyView/event_type" }) }), "value": null });
    var room110 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(calview.MonthlyView.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/MonthlyView/room" }) }), "value": null });
    var state111 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(calview.MonthlyView.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EntryStates), "value": null });
    var show_appointments112 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Termine", "forceSelection": true, "hiddenName": "show_appointmentsHidden", "listeners": { "render": Lino.quicktip_renderer("Appointments","(calview.MonthlyView.show_appointments) ") }, "name": "show_appointments", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    this.items = [ { "autoHeight": true, "flex": 18, "items": user107, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": assigned_to108, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": event_type109, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": room110, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": state111, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": show_appointments112, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user107, assigned_to108, event_type109, room110, state111, show_appointments112 ];
    Lino.calview.MonthlyView.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.users.Authorities.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var user120 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(users.Authorities.user) The user who gives the right of representation. author of this\nauthority") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/Authorities/user" }) }), "value": null });
    this.items = [ { "autoHeight": true, "items": user120, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user120 ];
    Lino.users.Authorities.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.ExpectedMovements.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var trade_type123 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Handelsart</span>", "forceSelection": true, "hiddenName": "trade_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Trade type","(ledger.ExpectedMovements.trade_type) Show only movements in the given trade type.") }, "name": "trade_type", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.ledger.TradeTypes) });
    var date_until124 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datum bis</span>", "listeners": { "render": Lino.quicktip_renderer("Date until","(ledger.ExpectedMovements.date_until) Show only movements whose booking date is before or on the given date.") }, "name": "date_until", "selectOnFocus": true });
    var from_journal125 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.ledger.Journals.detail", "emptyText": "Journal ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Journal</span>", "hiddenName": "from_journalHidden", "insert_action": "Lino.ledger.Journals.insert", "listeners": { "render": Lino.quicktip_renderer("Journal","(ledger.ExpectedMovements.from_journal) Show only movements generated by a voucher in the given journal.") }, "name": "from_journal", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.Journals.detail,Lino.ledger.Journals.insert)}, "pageSize": 20, "related_actor_id": "ledger.Journals", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/ExpectedMovements/from_journal" }) }) });
    var for_journal126 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.ledger.Journals.detail", "emptyText": "Journal ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Begleichbar durch</span>", "hiddenName": "for_journalHidden", "insert_action": "Lino.ledger.Journals.insert", "listeners": { "render": Lino.quicktip_renderer("Clearable by","(ledger.ExpectedMovements.for_journal) Show only movements that may be matched by the given journal (i.e. for\nwhich a match rule exists).") }, "name": "for_journal", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.Journals.detail,Lino.ledger.Journals.insert)}, "pageSize": 20, "related_actor_id": "ledger.Journals", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/ExpectedMovements/for_journal" }) }) });
    var main_1_panel127 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 29, "items": trade_type123, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 17, "items": date_until124, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 26, "items": from_journal125, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 26, "items": for_journal126, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var partner132 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Partner</span>", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(ledger.ExpectedMovements.partner) Show only movements with the given partner.") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/ExpectedMovements/partner" }) }) });
    var account133 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.ledger.Accounts.detail", "emptyText": "Konto ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Konto</span>", "hiddenName": "accountHidden", "insert_action": "Lino.ledger.Accounts.insert", "listeners": { "render": Lino.quicktip_renderer("Account","(ledger.ExpectedMovements.account) Show only movements on the given account.") }, "name": "account", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.Accounts.detail,Lino.ledger.Accounts.insert)}, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/ExpectedMovements/account" }) }) });
    var show_sepa134 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Mit SEPA</span>", "forceSelection": true, "hiddenName": "show_sepaHidden", "listeners": { "render": Lino.quicktip_renderer("With SEPA","(ledger.ExpectedMovements.show_sepa) Show only movements whose partner has a SEPA account.") }, "name": "show_sepa", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    var same_dc135 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Same D/C</span>", "forceSelection": true, "hiddenName": "same_dcHidden", "listeners": { "render": Lino.quicktip_renderer("Same D/C","(ledger.ExpectedMovements.same_dc) Show only movements having the same booking direction as the target\nvoucher.") }, "name": "same_dc", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    var main_2_panel136 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 28, "items": partner132, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 28, "items": account133, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": show_sepa134, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": same_dc135, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.items = [ main_1_panel127, main_2_panel136 ];
    this.fields = [ trade_type123, date_until124, from_journal125, for_journal126, partner132, account133, show_sepa134, same_dc135 ];
    Lino.ledger.ExpectedMovements.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.WeeklyView.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user142 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(calview.WeeklyView.user) The responsible user.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/WeeklyView/user" }) }), "value": null });
    var assigned_to143 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zugewiesen zu</span>", "hiddenName": "assigned_toHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Assigned to","(calview.WeeklyView.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "name": "assigned_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/WeeklyView/assigned_to" }) }), "value": null });
    var event_type144 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(calview.WeeklyView.event_type) The type of this calendar entry.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/WeeklyView/event_type" }) }), "value": null });
    var room145 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(calview.WeeklyView.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/WeeklyView/room" }) }), "value": null });
    var state146 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(calview.WeeklyView.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EntryStates), "value": null });
    var show_appointments147 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Termine", "forceSelection": true, "hiddenName": "show_appointmentsHidden", "listeners": { "render": Lino.quicktip_renderer("Appointments","(calview.WeeklyView.show_appointments) ") }, "name": "show_appointments", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    this.items = [ { "autoHeight": true, "flex": 18, "items": user142, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": assigned_to143, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": event_type144, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": room145, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": state146, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": show_appointments147, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user142, assigned_to143, event_type144, room145, state146, show_appointments147 ];
    Lino.calview.WeeklyView.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Accounts.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var common_account155 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Gemeinkonto", "forceSelection": true, "hiddenName": "common_accountHidden", "listeners": { "render": Lino.quicktip_renderer("Common account","(ledger.Accounts.common_account) ") }, "name": "common_account", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.ledger.CommonAccounts), "value": null });
    this.items = [ { "autoHeight": true, "items": common_account155, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ common_account155 ];
    Lino.ledger.Accounts.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.addresses.Addresses.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var place158 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.countries.Places.detail", "emptyText": "Ort ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Ort</span>", "hiddenName": "placeHidden", "insert_action": "Lino.countries.Places.insert", "listeners": { "render": Lino.quicktip_renderer("Place","(addresses.Addresses.place) Show only addresses having the given place in Address.city.") }, "name": "place", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.countries.Places.detail,Lino.countries.Places.insert)}, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/place" }) }) });
    var partner159 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Partner</span>", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(addresses.Addresses.partner) Show only addresses of the given partner in Address.partner.") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/partner" }) }), "value": null });
    var address_type160 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Adressenart</span>", "forceSelection": true, "hiddenName": "address_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Address type","(addresses.Addresses.address_type) Show only addresses having the given type.") }, "name": "address_type", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.addresses.AddressTypes), "value": null });
    this.items = [ { "autoHeight": true, "flex": 32, "items": place158, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 32, "items": partner159, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 34, "items": address_type160, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ place158, partner159, address_type160 ];
    Lino.addresses.Addresses.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.MonthlySlave.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user165 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(calview.MonthlySlave.user) The responsible user.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/MonthlySlave/user" }) }), "value": null });
    var assigned_to166 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zugewiesen zu</span>", "hiddenName": "assigned_toHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Assigned to","(calview.MonthlySlave.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "name": "assigned_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/MonthlySlave/assigned_to" }) }), "value": null });
    var event_type167 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(calview.MonthlySlave.event_type) The type of this calendar entry.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/MonthlySlave/event_type" }) }), "value": null });
    var room168 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(calview.MonthlySlave.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/calview/MonthlySlave/room" }) }), "value": null });
    var state169 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(calview.MonthlySlave.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EntryStates), "value": null });
    var show_appointments170 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Termine", "forceSelection": true, "hiddenName": "show_appointmentsHidden", "listeners": { "render": Lino.quicktip_renderer("Appointments","(calview.MonthlySlave.show_appointments) ") }, "name": "show_appointments", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    this.items = [ { "autoHeight": true, "flex": 18, "items": user165, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": assigned_to166, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": event_type167, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": room168, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": state169, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": show_appointments170, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user165, assigned_to166, event_type167, room168, state169, show_appointments170 ];
    Lino.calview.MonthlySlave.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Guests.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var start_date178 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datum von</span>", "listeners": { "render": Lino.quicktip_renderer("Date from","(cal.Guests.start_date) Start of observed date range") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date179 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(cal.Guests.end_date) End of observed date range") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var user180 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(cal.Guests.user) Only rows managed by this user.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/user" }) }) });
    var event_state181 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand Termin</span>", "forceSelection": true, "hiddenName": "event_stateHidden", "listeners": { "render": Lino.quicktip_renderer("Event state","(cal.Guests.event_state) Only rows on calendar entries having this state.") }, "name": "event_state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EntryStates) });
    var guest_state182 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand Gast</span>", "forceSelection": true, "hiddenName": "guest_stateHidden", "listeners": { "render": Lino.quicktip_renderer("Guest state","(cal.Guests.guest_state) Only rows having this guest state.") }, "name": "guest_state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.GuestStates) });
    var main_1_panel183 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 18, "items": start_date178, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": end_date179, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 28, "items": user180, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": event_state181, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": guest_state182, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var partner189 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Person", "forceSelection": false, "hiddenName": "partnerHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Person","(cal.Guests.partner) ") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/partner" }) }) });
    this.items = [ main_1_panel183, { "anchor": "-20", "autoHeight": true, "items": partner189, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ start_date178, end_date179, user180, event_state181, guest_state182, partner189 ];
    Lino.cal.Guests.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.PartnerBalancesByTradeType.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var start_period192 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "hiddenName": "start_periodHidden", "listeners": { "render": Lino.quicktip_renderer("Period from","(ledger.PartnerBalancesByTradeType.start_period) Start of observed period range") }, "name": "start_period", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/PartnerBalancesByTradeType/start_period" }) }) });
    var end_period193 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "hiddenName": "end_periodHidden", "listeners": { "render": Lino.quicktip_renderer("until","(ledger.PartnerBalancesByTradeType.end_period) Optional end of observed period range. Leave empty to consider only the Start period.") }, "name": "end_period", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/PartnerBalancesByTradeType/end_period" }) }) });
    this.items = [ { "autoHeight": true, "flex": 50, "items": start_period192, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": end_period193, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ start_period192, end_period193 ];
    Lino.ledger.PartnerBalancesByTradeType.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.users.AllUsers.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user_type197 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Benutzerart", "forceSelection": true, "hiddenName": "user_typeHidden", "listeners": { "render": Lino.quicktip_renderer("User type","(users.AllUsers.user_type) ") }, "name": "user_type", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.users.UserTypes) });
    var start_date198 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(users.AllUsers.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date199 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(users.AllUsers.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    this.items = [ { "autoHeight": true, "flex": 60, "items": user_type197, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": start_date198, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": end_date199, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user_type197, start_date198, end_date199 ];
    Lino.users.AllUsers.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Activities.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var topic204 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.courses.Topics.detail", "emptyText": "Thema ausw\u00e4hlen...", "fieldLabel": "Thema", "hiddenName": "topicHidden", "listeners": { "render": Lino.quicktip_renderer("Topic","(courses.Activities.topic) ") }, "name": "topic", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Topics.detail,null)}, "pageSize": 20, "related_actor_id": "courses.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/topic" }) }) });
    var line205 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.courses.Lines.detail", "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "fieldLabel": "Aktivit\u00e4tenreihe", "hiddenName": "lineHidden", "insert_action": "Lino.courses.Lines.insert", "listeners": { "render": Lino.quicktip_renderer("Activity line","(courses.Activities.line) ") }, "name": "line", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Lines.detail,Lino.courses.Lines.insert)}, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/line" }) }) });
    var user206 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(courses.Activities.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/user" }) }), "value": null });
    var teacher207 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Kursleiter", "hiddenName": "teacherHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Instructor","(courses.Activities.teacher) ") }, "name": "teacher", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/teacher" }) }) });
    var state208 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Zustand", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(courses.Activities.state) ") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.courses.CourseStates) });
    var main_1_panel209 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 21, "items": topic204, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": line205, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": user206, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": teacher207, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": state208, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var room215 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(courses.Activities.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/room" }) }), "value": null });
    var can_enroll216 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "can enroll", "forceSelection": true, "hiddenName": "can_enrollHidden", "listeners": { "render": Lino.quicktip_renderer("can enroll","(courses.Activities.can_enroll) ") }, "name": "can_enroll", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    var start_date217 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datum von</span>", "listeners": { "render": Lino.quicktip_renderer("Date from","(courses.Activities.start_date) Start of observed date range") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date218 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(courses.Activities.end_date) End of observed date range") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var show_exposed219 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Exponiert</span>", "forceSelection": true, "hiddenName": "show_exposedHidden", "listeners": { "render": Lino.quicktip_renderer("Exposed","(courses.Activities.show_exposed) Whether to show rows in an exposed state") }, "name": "show_exposed", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    var main_2_panel220 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 28, "items": room215, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": can_enroll216, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": start_date217, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": end_date218, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": show_exposed219, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.items = [ main_1_panel209, main_2_panel220 ];
    this.fields = [ topic204, line205, user206, teacher207, state208, room215, can_enroll216, start_date217, end_date218, show_exposed219 ];
    Lino.courses.Activities.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.ActivitiesByTopic.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var line227 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.courses.Lines.detail", "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "fieldLabel": "Aktivit\u00e4tenreihe", "hiddenName": "lineHidden", "insert_action": "Lino.courses.Lines.insert", "listeners": { "render": Lino.quicktip_renderer("Activity line","(courses.ActivitiesByTopic.line) ") }, "name": "line", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Lines.detail,Lino.courses.Lines.insert)}, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTopic/line" }) }) });
    var teacher228 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Kursleiter", "hiddenName": "teacherHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Instructor","(courses.ActivitiesByTopic.teacher) ") }, "name": "teacher", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTopic/teacher" }) }) });
    var user229 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(courses.ActivitiesByTopic.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTopic/user" }) }), "value": null });
    var state230 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Zustand", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(courses.ActivitiesByTopic.state) ") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.courses.CourseStates) });
    var can_enroll231 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "can enroll", "forceSelection": true, "hiddenName": "can_enrollHidden", "listeners": { "render": Lino.quicktip_renderer("can enroll","(courses.ActivitiesByTopic.can_enroll) ") }, "name": "can_enroll", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    this.items = [ { "autoHeight": true, "flex": 24, "items": line227, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 24, "items": teacher228, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 24, "items": user229, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": state230, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": can_enroll231, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ line227, teacher228, user229, state230, can_enroll231 ];
    Lino.courses.ActivitiesByTopic.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.checkdata.Problems.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user238 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible","(checkdata.Problems.user) The user responsible for fixing this\nproblem.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/Problems/user" }) }), "value": null });
    var checker239 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Checker</span>", "forceSelection": true, "hiddenName": "checkerHidden", "listeners": { "render": Lino.quicktip_renderer("Checker","(checkdata.Problems.checker) The Checker that reported this\nproblem.") }, "name": "checker", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.checkdata.Checkers), "value": null });
    this.items = [ { "autoHeight": true, "flex": 50, "items": user238, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": checker239, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user238, checker239 ];
    Lino.checkdata.Problems.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.AllVouchers.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var journal243 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.ledger.Journals.detail", "emptyText": "Journal ausw\u00e4hlen...", "fieldLabel": "Journal", "hiddenName": "journalHidden", "insert_action": "Lino.ledger.Journals.insert", "listeners": { "render": Lino.quicktip_renderer("Journal","(ledger.AllVouchers.journal) ") }, "name": "journal", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.Journals.detail,Lino.ledger.Journals.insert)}, "pageSize": 20, "related_actor_id": "ledger.Journals", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/AllVouchers/journal" }) }) });
    var start_period244 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "hiddenName": "start_periodHidden", "listeners": { "render": Lino.quicktip_renderer("Period from","(ledger.AllVouchers.start_period) Start of observed period range.") }, "name": "start_period", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/AllVouchers/start_period" }) }) });
    var end_period245 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Period until</span>", "hiddenName": "end_periodHidden", "listeners": { "render": Lino.quicktip_renderer("Period until","(ledger.AllVouchers.end_period) Optional end of observed period range. Leave empty to observe only the start period.") }, "name": "end_period", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/AllVouchers/end_period" }) }) });
    var user246 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(ledger.AllVouchers.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/AllVouchers/user" }) }), "value": null });
    this.items = [ { "autoHeight": true, "flex": 25, "items": journal243, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": start_period244, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": end_period245, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": user246, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ journal243, start_period244, end_period245, user246 ];
    Lino.ledger.AllVouchers.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.households.Members.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var start_date252 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(households.Members.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date253 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(households.Members.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var aged_from254 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Alter von</span>", "listeners": { "render": Lino.quicktip_renderer("Aged from","(households.Members.aged_from) Select only persons aged at least the given number of years.") }, "name": "aged_from", "selectOnFocus": true });
    var aged_to255 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Alter bis</span>", "listeners": { "render": Lino.quicktip_renderer("Aged to","(households.Members.aged_to) Select only persons aged at most the given number of years.") }, "name": "aged_to", "selectOnFocus": true });
    var gender256 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Geschlecht</span>", "forceSelection": true, "hiddenName": "genderHidden", "listeners": { "render": Lino.quicktip_renderer("Gender","(households.Members.gender) The sex of this person (male or female).") }, "name": "gender", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.Genders), "value": null });
    this.items = [ { "autoHeight": true, "flex": 25, "items": start_date252, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": end_date253, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": aged_from254, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": aged_to255, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 23, "items": gender256, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ start_date252, end_date253, aged_from254, aged_to255, gender256 ];
    Lino.households.Members.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.AllEntries.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var start_date263 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(cal.AllEntries.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date264 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(cal.AllEntries.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var observed_event265 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beobachtungskriterium", "forceSelection": true, "hiddenName": "observed_eventHidden", "listeners": { "render": Lino.quicktip_renderer("Observed event","(cal.AllEntries.observed_event) ") }, "name": "observed_event", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EventEvents) });
    var state266 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(cal.AllEntries.state) Show only entries having this state.") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EntryStates), "value": null });
    var main_1_panel267 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 26, "items": start_date263, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 26, "items": end_date264, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 22, "items": observed_event265, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 26, "items": state266, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var user272 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(cal.AllEntries.user) Show only entries having this user as author.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllEntries/user" }) }), "value": null });
    var assigned_to273 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zugewiesen zu</span>", "hiddenName": "assigned_toHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Assigned to","(cal.AllEntries.assigned_to) Show only entries assigned to this user.") }, "name": "assigned_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllEntries/assigned_to" }) }), "value": null });
    var event_type274 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(cal.AllEntries.event_type) Show only entries having this type.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllEntries/event_type" }) }), "value": null });
    var room275 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(cal.AllEntries.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllEntries/room" }) }), "value": null });
    var show_appointments276 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Termine</span>", "forceSelection": true, "hiddenName": "show_appointmentsHidden", "listeners": { "render": Lino.quicktip_renderer("Appointments","(cal.AllEntries.show_appointments) Whether only appointments should be shown.  \"Yes\" means only\nappointments, \"No\" means no appointments and leaving it to\nblank shows both types of events.") }, "name": "show_appointments", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    var main_2_panel277 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 21, "items": user272, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": assigned_to273, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": event_type274, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": room275, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 15, "items": show_appointments276, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.items = [ main_1_panel267, main_2_panel277 ];
    this.fields = [ start_date263, end_date264, observed_event265, state266, user272, assigned_to273, event_type274, room275, show_appointments276 ];
    Lino.cal.AllEntries.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Events.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user284 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(cal.Events.user) Show only entries having this user as author.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/user" }) }), "value": null });
    var event_type285 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(cal.Events.event_type) Show only entries having this type.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/event_type" }) }), "value": null });
    var room286 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(cal.Events.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/room" }) }), "value": null });
    var presence_guest287 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Gast</span>", "hiddenName": "presence_guestHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Guest","(cal.Events.presence_guest) Show only entries that have a presence for the specified guest.") }, "name": "presence_guest", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/presence_guest" }) }) });
    this.items = [ { "autoHeight": true, "flex": 25, "items": user284, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": event_type285, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": room286, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": presence_guest287, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user284, event_type285, room286, presence_guest287 ];
    Lino.cal.Events.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Partners.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var observed_event293 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beobachtungskriterium</span>", "forceSelection": true, "hiddenName": "observed_eventHidden", "listeners": { "render": Lino.quicktip_renderer("Observed event","(contacts.Partners.observed_event) Extended filter criteria") }, "name": "observed_event", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.contacts.PartnerEvents) });
    var start_date294 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(contacts.Partners.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date295 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(contacts.Partners.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    this.items = [ { "autoHeight": true, "flex": 44, "items": observed_event293, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 27, "items": start_date294, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 27, "items": end_date295, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ observed_event293, start_date294, end_date295 ];
    Lino.contacts.Partners.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.comments.Mentions.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var user300 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(comments.Mentions.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Mentions/user" }) }), "value": null });
    this.items = [ { "autoHeight": true, "items": user300, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user300 ];
    Lino.comments.Mentions.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.OneEvent.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user303 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(cal.OneEvent.user) Show only entries having this user as author.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OneEvent/user" }) }), "value": null });
    var event_type304 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(cal.OneEvent.event_type) Show only entries having this type.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OneEvent/event_type" }) }), "value": null });
    var room305 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(cal.OneEvent.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OneEvent/room" }) }), "value": null });
    var presence_guest306 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Gast</span>", "hiddenName": "presence_guestHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Guest","(cal.OneEvent.presence_guest) Show only entries that have a presence for the specified guest.") }, "name": "presence_guest", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OneEvent/presence_guest" }) }) });
    this.items = [ { "autoHeight": true, "flex": 25, "items": user303, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": event_type304, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": room305, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": presence_guest306, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user303, event_type304, room305, presence_guest306 ];
    Lino.cal.OneEvent.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.uploads.Uploads.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var start_date312 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datum von</span>", "listeners": { "render": Lino.quicktip_renderer("Date from","(uploads.Uploads.start_date) Start of observed date range") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date313 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(uploads.Uploads.end_date) End of observed date range") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var user314 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Hochgeladen durch</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Uploaded by","(uploads.Uploads.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/user" }) }), "value": null });
    var upload_type315 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.uploads.UploadTypes.detail", "emptyText": "Upload-Art ausw\u00e4hlen...", "fieldLabel": "Upload-Art", "hiddenName": "upload_typeHidden", "insert_action": "Lino.uploads.UploadTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Upload type","(uploads.Uploads.upload_type) ") }, "name": "upload_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.uploads.UploadTypes.detail,Lino.uploads.UploadTypes.insert)}, "pageSize": 20, "related_actor_id": "uploads.UploadTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/upload_type" }) }) });
    this.items = [ { "autoHeight": true, "flex": 19, "items": start_date312, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": end_date313, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": user314, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": upload_type315, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ start_date312, end_date313, user314, upload_type315 ];
    Lino.uploads.Uploads.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.PartnerVouchers.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var partner321 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "Partner", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(ledger.PartnerVouchers.partner) ") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/PartnerVouchers/partner" }) }) });
    var state322 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Belegzustand", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("Voucher state","(ledger.PartnerVouchers.state) ") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.ledger.VoucherStates) });
    var journal323 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.ledger.Journals.detail", "emptyText": "Journal ausw\u00e4hlen...", "fieldLabel": "Journal", "hiddenName": "journalHidden", "insert_action": "Lino.ledger.Journals.insert", "listeners": { "render": Lino.quicktip_renderer("Journal","(ledger.PartnerVouchers.journal) ") }, "name": "journal", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.Journals.detail,Lino.ledger.Journals.insert)}, "pageSize": 20, "related_actor_id": "ledger.Journals", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/PartnerVouchers/journal" }) }) });
    var start_period324 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "hiddenName": "start_periodHidden", "listeners": { "render": Lino.quicktip_renderer("Period from","(ledger.PartnerVouchers.start_period) Start of observed period range.") }, "name": "start_period", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/PartnerVouchers/start_period" }) }) });
    var end_period325 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Period until</span>", "hiddenName": "end_periodHidden", "listeners": { "render": Lino.quicktip_renderer("Period until","(ledger.PartnerVouchers.end_period) Optional end of observed period range. Leave empty to observe only the start period.") }, "name": "end_period", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/PartnerVouchers/end_period" }) }) });
    var cleared326 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beglichene Bewegungen zeigen", "forceSelection": true, "hiddenName": "clearedHidden", "listeners": { "render": Lino.quicktip_renderer("Show cleared vouchers","(ledger.PartnerVouchers.cleared) ") }, "name": "cleared", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    this.items = [ { "autoHeight": true, "flex": 18, "items": partner321, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": state322, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": journal323, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": start_period324, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": end_period325, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": cleared326, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ partner321, state322, journal323, start_period324, end_period325, cleared326 ];
    Lino.ledger.PartnerVouchers.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.comments.Comments.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var start_date334 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(comments.Comments.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date335 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(comments.Comments.end_date) The date range to filter.") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var observed_event336 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beobachtungskriterium</span>", "forceSelection": true, "hiddenName": "observed_eventHidden", "listeners": { "render": Lino.quicktip_renderer("Observed event","(comments.Comments.observed_event) Which event (created, modified or published) to consider when\napplying the date range given by start_date and\nend_date.") }, "name": "observed_event", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.comments.CommentEvents) });
    var user337 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(comments.Comments.user) The author of the comment.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/user" }) }), "value": null });
    var reply_to338 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.comments.Comments.detail", "emptyText": "Kommentar ausw\u00e4hlen...", "fieldLabel": "Antwort auf", "hiddenName": "reply_toHidden", "insert_action": "Lino.comments.Comments.insert", "listeners": { "render": Lino.quicktip_renderer("Reply to","(comments.Comments.reply_to) ") }, "name": "reply_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.comments.Comments.detail,Lino.comments.Comments.insert)}, "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/reply_to" }) }), "value": null });
    this.items = [ { "autoHeight": true, "flex": 16, "items": start_date334, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": end_date335, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": observed_event336, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": user337, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": reply_to338, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ start_date334, end_date335, observed_event336, user337, reply_to338 ];
    Lino.comments.Comments.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Enrolments.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var start_date345 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(courses.Enrolments.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date346 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(courses.Enrolments.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var author347 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "Benutzer", "hiddenName": "authorHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("User","(courses.Enrolments.author) ") }, "name": "author", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Enrolments/author" }) }) });
    var state348 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Zustand", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(courses.Enrolments.state) ") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.courses.EnrolmentStates) });
    var course_state349 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Zustand Kurs", "forceSelection": true, "hiddenName": "course_stateHidden", "listeners": { "render": Lino.quicktip_renderer("Course state","(courses.Enrolments.course_state) ") }, "name": "course_state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.courses.CourseStates) });
    var participants_only350 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Nur Teilnehmer", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Participants only","(courses.Enrolments.participants_only) Hide cancelled enrolments. Ignored if you specify an explicit enrolment state.") }, "name": "participants_only", "selectOnFocus": true });
    this.items = [ { "autoHeight": true, "flex": 13, "items": start_date345, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": end_date346, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 27, "items": author347, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": state348, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 15, "items": course_state349, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": participants_only350, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ start_date345, end_date346, author347, state348, course_state349, participants_only350 ];
    Lino.courses.Enrolments.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.blogs.Entries.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var user358 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(blogs.Entries.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/Entries/user" }) }), "value": null });
    this.items = [ { "autoHeight": true, "items": user358, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user358 ];
    Lino.blogs.Entries.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Situation.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var today361 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Situation am</span>", "listeners": { "render": Lino.quicktip_renderer("Situation on","(ledger.Situation.today) Date of observation") }, "name": "today", "selectOnFocus": true });
    this.items = [ { "autoHeight": true, "items": today361, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ today361 ];
    Lino.ledger.Situation.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Tasks.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var start_date364 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(cal.Tasks.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date365 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(cal.Tasks.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var user366 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(cal.Tasks.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Tasks/user" }) }), "value": null });
    var state367 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(cal.Tasks.state) The state of this Task. one of TaskStates.") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.TaskStates), "value": null });
    var main_1_panel368 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 22, "items": start_date364, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 22, "items": end_date365, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 34, "items": user366, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": state367, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.items = [ main_1_panel368 ];
    this.fields = [ start_date364, end_date365, user366, state367 ];
    Lino.cal.Tasks.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Debtors.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var today374 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Situation am</span>", "listeners": { "render": Lino.quicktip_renderer("Situation on","(ledger.Debtors.today) Date of observation") }, "name": "today", "selectOnFocus": true });
    this.items = [ { "autoHeight": true, "items": today374, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ today374 ];
    Lino.ledger.Debtors.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.RecurrentEvents.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var user377 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(cal.RecurrentEvents.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/RecurrentEvents/user" }) }), "value": null });
    this.items = [ { "autoHeight": true, "items": user377, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user377 ];
    Lino.cal.RecurrentEvents.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.MyEntries.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var start_date380 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(cal.MyEntries.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date381 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(cal.MyEntries.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var observed_event382 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beobachtungskriterium", "forceSelection": true, "hiddenName": "observed_eventHidden", "listeners": { "render": Lino.quicktip_renderer("Observed event","(cal.MyEntries.observed_event) ") }, "name": "observed_event", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EventEvents) });
    var state383 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(cal.MyEntries.state) Show only entries having this state.") }, "name": "state", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.EntryStates), "value": null });
    var main_1_panel384 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 26, "items": start_date380, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 26, "items": end_date381, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 22, "items": observed_event382, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 26, "items": state383, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var user389 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(cal.MyEntries.user) Show only entries having this user as author.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntries/user" }) }), "value": null });
    var assigned_to390 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zugewiesen zu</span>", "hiddenName": "assigned_toHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Assigned to","(cal.MyEntries.assigned_to) Show only entries assigned to this user.") }, "name": "assigned_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntries/assigned_to" }) }), "value": null });
    var event_type391 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(cal.MyEntries.event_type) Show only entries having this type.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntries/event_type" }) }), "value": null });
    var room392 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(cal.MyEntries.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntries/room" }) }), "value": null });
    var show_appointments393 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Termine</span>", "forceSelection": true, "hiddenName": "show_appointmentsHidden", "listeners": { "render": Lino.quicktip_renderer("Appointments","(cal.MyEntries.show_appointments) Whether only appointments should be shown.  \"Yes\" means only\nappointments, \"No\" means no appointments and leaving it to\nblank shows both types of events.") }, "name": "show_appointments", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    var main_2_panel394 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 21, "items": user389, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": assigned_to390, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": event_type391, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": room392, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 15, "items": show_appointments393, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.items = [ main_1_panel384, main_2_panel394 ];
    this.fields = [ start_date380, end_date381, observed_event382, state383, user389, assigned_to390, event_type391, room392, show_appointments393 ];
    Lino.cal.MyEntries.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.phones.ContactDetails.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var partner401 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "Partner", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(phones.ContactDetails.partner) ") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/phones/ContactDetails/partner" }) }), "value": null });
    var detail_type402 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Kontaktangabenart", "forceSelection": true, "hiddenName": "detail_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Contact detail type","(phones.ContactDetails.detail_type) ") }, "name": "detail_type", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.phones.ContactDetailTypes), "value": null });
    this.items = [ { "autoHeight": true, "flex": 66, "items": partner401, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": detail_type402, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ partner401, detail_type402 ];
    Lino.phones.ContactDetails.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.comments.Reactions.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var start_date406 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(comments.Reactions.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date407 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(comments.Reactions.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var user408 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(comments.Reactions.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Reactions/user" }) }), "value": null });
    this.items = [ { "autoHeight": true, "flex": 28, "items": start_date406, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 28, "items": end_date407, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 43, "items": user408, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ start_date406, end_date407, user408 ];
    Lino.comments.Reactions.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.excerpts.Excerpts.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var start_date413 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datum von</span>", "listeners": { "render": Lino.quicktip_renderer("Date from","(excerpts.Excerpts.start_date) Start of observed date range") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date414 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(excerpts.Excerpts.end_date) End of observed date range") }, "name": "end_date", "selectOnFocus": true, "value": null });
    var pcertifying415 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Certifying excerpts", "forceSelection": true, "hiddenName": "pcertifyingHidden", "listeners": { "render": Lino.quicktip_renderer("Certifying excerpts","(excerpts.Excerpts.pcertifying) ") }, "name": "pcertifying", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.YesNo) });
    var main_1_panel416 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 31, "items": start_date413, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 31, "items": end_date414, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 36, "items": pcertifying415, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var user420 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(excerpts.Excerpts.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/user" }) }), "value": null });
    var excerpt_type421 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.excerpts.ExcerptTypes.detail", "emptyText": "Auszugsart ausw\u00e4hlen...", "fieldLabel": "Auszugsart", "hiddenName": "excerpt_typeHidden", "insert_action": "Lino.excerpts.ExcerptTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Excerpt Type","(excerpts.Excerpts.excerpt_type) ") }, "name": "excerpt_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.excerpts.ExcerptTypes.detail,Lino.excerpts.ExcerptTypes.insert)}, "pageSize": 20, "related_actor_id": "excerpts.ExcerptTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/excerpt_type" }) }) });
    var main_2_panel422 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": user420, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": excerpt_type421, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.items = [ main_1_panel416, main_2_panel422 ];
    this.fields = [ start_date413, end_date414, pcertifying415, user420, excerpt_type421 ];
    Lino.excerpts.Excerpts.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.tinymce.TextFieldTemplates.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var user426 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(tinymce.TextFieldTemplates.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/tinymce/TextFieldTemplates/user" }) }), "value": null });
    this.items = [ { "autoHeight": true, "items": user426, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user426 ];
    Lino.tinymce.TextFieldTemplates.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.AccountingPeriods.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var start_date429 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(ledger.AccountingPeriods.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date430 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(ledger.AccountingPeriods.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    this.items = [ { "autoHeight": true, "flex": 50, "items": start_date429, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": end_date430, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ start_date429, end_date430 ];
    Lino.ledger.AccountingPeriods.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.users.MySettings.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var user_type434 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Benutzerart", "forceSelection": true, "hiddenName": "user_typeHidden", "listeners": { "render": Lino.quicktip_renderer("User type","(users.MySettings.user_type) ") }, "name": "user_type", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.users.UserTypes) });
    var start_date435 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "listeners": { "render": Lino.quicktip_renderer("Period from","(users.MySettings.start_date) Start date of observed period") }, "name": "start_date", "selectOnFocus": true, "value": null });
    var end_date436 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(users.MySettings.end_date) End date of observed period") }, "name": "end_date", "selectOnFocus": true, "value": null });
    this.items = [ { "autoHeight": true, "flex": 60, "items": user_type434, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": start_date435, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": end_date436, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ user_type434, start_date435, end_date436 ];
    Lino.users.MySettings.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Creditors.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'form',
  autoHeight: true,
  initComponent : function() {
    var today441 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Situation am</span>", "listeners": { "render": Lino.quicktip_renderer("Situation on","(ledger.Creditors.today) Date of observation") }, "name": "today", "selectOnFocus": true });
    this.items = [ { "autoHeight": true, "items": today441, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ today441 ];
    Lino.ledger.Creditors.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.GeneralAccountBalances.ParamsPanel = Ext.extend(Ext.form.FormPanel, {
  hideCheckBoxLabels: true,
  autoHeight: true,
  layoutConfig: { "align": "stretchmax" },
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  layout: 'hbox',
  autoHeight: true,
  initComponent : function() {
    var start_period444 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Periode vom</span>", "hiddenName": "start_periodHidden", "listeners": { "render": Lino.quicktip_renderer("Period from","(ledger.GeneralAccountBalances.start_period) Start of observed period range") }, "name": "start_period", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/GeneralAccountBalances/start_period" }) }) });
    var end_period445 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "hiddenName": "end_periodHidden", "listeners": { "render": Lino.quicktip_renderer("until","(ledger.GeneralAccountBalances.end_period) Optional end of observed period range. Leave empty to consider only the Start period.") }, "name": "end_period", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/GeneralAccountBalances/end_period" }) }) });
    this.items = [ { "autoHeight": true, "flex": 50, "items": start_period444, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": end_period445, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ start_period444, end_period445 ];
    Lino.ledger.GeneralAccountBalances.ParamsPanel.superclass.initComponent.call(this);
  }
});


Lino.households.Households.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to552 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.households.Households.detail", "emptyText": "Haushalt ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "insert_action": "Lino.households.Households.insert", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.households.Households.detail,Lino.households.Households.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "households.Households", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/households/Households/merge_row/merge_to" }) }) });
    this.households_Member553 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Mitglieder", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Household Members","(Merge.households_Member) ") }, "name": "households_Member", "selectOnFocus": true });
    this.addresses_Address554 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Adressen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Addresses","(Merge.addresses_Address) ") }, "name": "addresses_Address", "selectOnFocus": true });
    var keep_volatiles_1_panel555 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": this.households_Member553, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": this.addresses_Address554, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.lists_Member558 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Listenmitgliedschaften", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("List memberships","(Merge.lists_Member) ") }, "name": "lists_Member", "selectOnFocus": true });
    this.phones_ContactDetail559 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Kontaktangaben", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Contact details","(Merge.phones_ContactDetail) ") }, "name": "phones_ContactDetail", "selectOnFocus": true });
    var keep_volatiles_2_panel560 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": this.lists_Member558, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": this.phones_ContactDetail559, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.sepa_Account563 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Bankkonten", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Bank accounts","(Merge.sepa_Account) ") }, "name": "sepa_Account", "selectOnFocus": true });
    this.topics_Interest564 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Interessen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Interests","(Merge.topics_Interest) ") }, "name": "topics_Interest", "selectOnFocus": true });
    var keep_volatiles_3_panel565 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": this.sepa_Account563, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": this.topics_Interest564, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var keep_volatiles_panel568 = new Ext.form.FieldSet({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ keep_volatiles_1_panel555, keep_volatiles_2_panel560, keep_volatiles_3_panel565 ], "labelAlign": "top", "layout": "form", "title": "Auch verg\u00e4ngliche verkn\u00fcpfte Objekte \u00fcberweisen" });
    this.reason569 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to552, "labelAlign": "top", "layout": "form", "xtype": "panel" }, keep_volatiles_panel568, { "anchor": "-20", "autoHeight": true, "items": this.reason569, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to552, this.households_Member553, this.addresses_Address554, this.lists_Member558, this.phones_ContactDetail559, this.sepa_Account563, this.topics_Interest564, this.reason569 ];
    this.http_method = "GET"
    Lino.households.Households.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.lists.Lists.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to578 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.lists.Lists.detail", "emptyText": "Partnerliste ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "insert_action": "Lino.lists.Lists.insert", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.lists.Lists.detail,Lino.lists.Lists.insert)}, "pageSize": 20, "related_actor_id": "lists.Lists", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/lists/Lists/merge_row/merge_to" }) }) });
    this.lists_Member579 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Auch verg\u00e4ngliche verkn\u00fcpfte Objekte \u00fcberweisen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("List memberships","(Merge.lists_Member) ") }, "name": "lists_Member", "selectOnFocus": true });
    this.reason580 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to578, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.lists_Member579, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason580, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to578, this.lists_Member579, this.reason580 ];
    this.http_method = "GET"
    Lino.lists.Lists.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.users.AllUsers.change_password_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'change_password',
  window_title: "Passwort \u00e4ndern",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.current588 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Aktuelles Passwort</span>", "inputType": "password", "listeners": { "render": Lino.quicktip_renderer("Current password","(Change password.current) The current password. Leave empty if the user has no password\nyet. And SiteAdmin users don't need to specify this at all.") }, "name": "current", "selectOnFocus": true });
    this.new1589 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Neues Passwort</span>", "inputType": "password", "listeners": { "render": Lino.quicktip_renderer("New password","(Change password.new1) The new password.") }, "name": "new1", "selectOnFocus": true });
    this.new2590 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Neues Passwort nochmal</span>", "inputType": "password", "listeners": { "render": Lino.quicktip_renderer("New password again","(Change password.new2) The new password a second time. Both passwords must match.") }, "name": "new2", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.current588, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.new1589, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.new2590, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.current588, this.new1589, this.new2590 ];
    this.http_method = "GET"
    Lino.users.AllUsers.change_password_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.users.UsersOverview.sign_in_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "left",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'sign_in',
  window_title: "Anmelden",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.username600 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Benutzername", "listeners": { "render": Lino.quicktip_renderer("Username","(Sign in.username) ") }, "name": "username", "selectOnFocus": true });
    this.password601 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Passwort", "inputType": "password", "listeners": { "render": Lino.quicktip_renderer("Password","(Sign in.password) ") }, "name": "password", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.username600, "labelAlign": "left", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.password601, "labelAlign": "left", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.username600, this.password601 ];
    this.http_method = "POST"
    Lino.users.UsersOverview.sign_in_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.PaymentTerms.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to542 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.ledger.PaymentTerms.detail", "emptyText": "Zahlungsbedingungen ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.PaymentTerms.detail,null)}, "pageSize": 20, "related_actor_id": "ledger.PaymentTerms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/ledger/PaymentTerms/merge_row/merge_to" }) }) });
    this.reason543 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to542, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason543, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to542, this.reason543 ];
    this.http_method = "GET"
    Lino.ledger.PaymentTerms.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Journals.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to530 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.ledger.Journals.detail", "emptyText": "Journal ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "insert_action": "Lino.ledger.Journals.insert", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.Journals.detail,Lino.ledger.Journals.insert)}, "pageSize": 20, "related_actor_id": "ledger.Journals", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/ledger/Journals/merge_row/merge_to" }) }) });
    this.ledger_MatchRule531 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Auch verg\u00e4ngliche verkn\u00fcpfte Objekte \u00fcberweisen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Match rules","(Merge.ledger_MatchRule) ") }, "name": "ledger_MatchRule", "selectOnFocus": true });
    this.reason532 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to530, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.ledger_MatchRule531, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason532, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to530, this.ledger_MatchRule531, this.reason532 ];
    this.http_method = "GET"
    Lino.ledger.Journals.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.EventTypes.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to515 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/cal/EventTypes/merge_row/merge_to" }) }) });
    this.reason516 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to515, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason516, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to515, this.reason516 ];
    this.http_method = "GET"
    Lino.cal.EventTypes.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Lines.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to605 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.courses.Lines.detail", "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "insert_action": "Lino.courses.Lines.insert", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Lines.detail,Lino.courses.Lines.insert)}, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/courses/Lines/merge_row/merge_to" }) }) });
    this.reason606 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to605, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason606, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to605, this.reason606 ];
    this.http_method = "GET"
    Lino.courses.Lines.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Persons.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to467 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/contacts/Persons/merge_row/merge_to" }) }) });
    this.addresses_Address468 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Adressen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Addresses","(Merge.addresses_Address) ") }, "name": "addresses_Address", "selectOnFocus": true });
    this.lists_Member469 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Listenmitgliedschaften", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("List memberships","(Merge.lists_Member) ") }, "name": "lists_Member", "selectOnFocus": true });
    var keep_volatiles_1_panel470 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": this.addresses_Address468, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": this.lists_Member469, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.phones_ContactDetail473 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Kontaktangaben", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Contact details","(Merge.phones_ContactDetail) ") }, "name": "phones_ContactDetail", "selectOnFocus": true });
    this.sepa_Account474 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Bankkonten", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Bank accounts","(Merge.sepa_Account) ") }, "name": "sepa_Account", "selectOnFocus": true });
    var keep_volatiles_2_panel475 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": this.phones_ContactDetail473, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": this.sepa_Account474, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.topics_Interest478 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Interessen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Interests","(Merge.topics_Interest) ") }, "name": "topics_Interest", "selectOnFocus": true });
    var keep_volatiles_panel479 = new Ext.form.FieldSet({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ keep_volatiles_1_panel470, keep_volatiles_2_panel475, { "anchor": "-20", "autoHeight": true, "items": this.topics_Interest478, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form", "title": "Auch verg\u00e4ngliche verkn\u00fcpfte Objekte \u00fcberweisen" });
    this.reason481 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to467, "labelAlign": "top", "layout": "form", "xtype": "panel" }, keep_volatiles_panel479, { "anchor": "-20", "autoHeight": true, "items": this.reason481, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to467, this.addresses_Address468, this.lists_Member469, this.phones_ContactDetail473, this.sepa_Account474, this.topics_Interest478, this.reason481 ];
    this.http_method = "GET"
    Lino.contacts.Persons.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Persons.create_household_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'create_household',
  window_title: "Haushalt erstellen",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.head485 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Vorstand", "hiddenName": "headHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Head of household","(Create Household.head) ") }, "name": "head", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/contacts/Persons/create_household/head" }) }) });
    this.type486 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.households.Types.detail", "emptyText": "Haushaltsart ausw\u00e4hlen...", "fieldLabel": "Haushaltsart", "hiddenName": "typeHidden", "listeners": { "render": Lino.quicktip_renderer("Household Type","(Create Household.type) ") }, "name": "type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.households.Types.detail,null)}, "pageSize": 20, "related_actor_id": "households.Types", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/contacts/Persons/create_household/type" }) }) });
    this.partner487 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Partner", "hiddenName": "partnerHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Partner","(Create Household.partner) ") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/contacts/Persons/create_household/partner" }) }) });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.head485, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.type486, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.partner487, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.head485, this.type486, this.partner487 ];
    this.http_method = "GET"
    Lino.contacts.Persons.create_household_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Activities.print_presence_sheet_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'print_presence_sheet',
  window_title: "Anwesenheitsliste",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.start_date610 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datum von</span>", "listeners": { "render": Lino.quicktip_renderer("Date from","(Presence sheet.start_date) Start of observed date range") }, "name": "start_date", "selectOnFocus": true });
    this.end_date611 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(Presence sheet.end_date) End of observed date range") }, "name": "end_date", "selectOnFocus": true });
    this.show_remarks612 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Bemerkungen drucken", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Show remarks","(Presence sheet.show_remarks) ") }, "name": "show_remarks", "selectOnFocus": true });
    this.show_states613 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Einschreibestatus drucken", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Show states","(Presence sheet.show_states) ") }, "name": "show_states", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.start_date610, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.end_date611, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.show_remarks612, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.show_states613, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.start_date610, this.end_date611, this.show_remarks612, this.show_states613 ];
    this.http_method = "GET"
    Lino.courses.Activities.print_presence_sheet_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Accounts.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to525 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.ledger.Accounts.detail", "emptyText": "Konto ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "insert_action": "Lino.ledger.Accounts.insert", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.Accounts.detail,Lino.ledger.Accounts.insert)}, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/ledger/Accounts/merge_row/merge_to" }) }) });
    this.reason526 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to525, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason526, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to525, this.reason526 ];
    this.http_method = "GET"
    Lino.ledger.Accounts.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.users.AllUsers.send_welcome_email_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'send_welcome_email',
  window_title: "Welcome mail",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.email595 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "E-Mail-Adresse", "listeners": { "render": Lino.quicktip_renderer("e-mail address","(Welcome mail.email) ") }, "maxLength": 254, "name": "email", "selectOnFocus": true });
    this.subject596 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Betreff", "listeners": { "render": Lino.quicktip_renderer("Subject","(Welcome mail.subject) ") }, "maxLength": 250, "name": "subject", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.email595, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.subject596, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.email595, this.subject596 ];
    this.http_method = "GET"
    Lino.users.AllUsers.send_welcome_email_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.GuestRoles.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to510 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.GuestRoles.detail", "emptyText": "Gastrolle ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.GuestRoles.detail,null)}, "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/cal/GuestRoles/merge_row/merge_to" }) }) });
    this.reason511 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to510, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason511, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to510, this.reason511 ];
    this.http_method = "GET"
    Lino.cal.GuestRoles.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.AccountingPeriods.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to537 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "emptyText": "Buchungsperiode ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.AccountingPeriods", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/ledger/AccountingPeriods/merge_row/merge_to" }) }) });
    this.reason538 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to537, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason538, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to537, this.reason538 ];
    this.http_method = "GET"
    Lino.ledger.AccountingPeriods.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Activities.print_presence_sheet_html_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'print_presence_sheet_html',
  window_title: "Anwesenheitsliste (HTML)",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.start_date619 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datum von</span>", "listeners": { "render": Lino.quicktip_renderer("Date from","(Presence sheet (HTML).start_date) Start of observed date range") }, "name": "start_date", "selectOnFocus": true });
    this.end_date620 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">bis</span>", "listeners": { "render": Lino.quicktip_renderer("until","(Presence sheet (HTML).end_date) End of observed date range") }, "name": "end_date", "selectOnFocus": true });
    this.show_remarks621 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Bemerkungen drucken", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Show remarks","(Presence sheet (HTML).show_remarks) ") }, "name": "show_remarks", "selectOnFocus": true });
    this.show_states622 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Einschreibestatus drucken", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Show states","(Presence sheet (HTML).show_states) ") }, "name": "show_states", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.start_date619, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.end_date620, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.show_remarks621, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.show_states622, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.start_date619, this.end_date620, this.show_remarks621, this.show_states622 ];
    this.http_method = "GET"
    Lino.courses.Activities.print_presence_sheet_html_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.comments.Comments.do_pick_my_emotion_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "fit",
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'do_pick_my_emotion',
  window_title: "Emotion",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.choice585 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Emotion", "forceSelection": true, "hiddenName": "choiceHidden", "listeners": { "render": Lino.quicktip_renderer("Emotion","(Emotion.choice) ") }, "name": "choice", "selectOnFocus": true, "store": Lino.comments.Emotions });
    this.items = [ { "autoHeight": true, "items": this.choice585, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.choice585 ];
    this.http_method = "GET"
    Lino.comments.Comments.do_pick_my_emotion_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.topics.Topics.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to573 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.topics.Topics.detail", "emptyText": "Thema ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "insert_action": "Lino.topics.Topics.insert", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.topics.Topics.detail,Lino.topics.Topics.insert)}, "pageSize": 20, "related_actor_id": "topics.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/topics/Topics/merge_row/merge_to" }) }) });
    this.reason574 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to573, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason574, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to573, this.reason574 ];
    this.http_method = "GET"
    Lino.topics.Topics.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.uploads.Volumes.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to520 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.uploads.Volumes.detail", "emptyText": "Dateibibliothek ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "insert_action": "Lino.uploads.Volumes.insert", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.uploads.Volumes.detail,Lino.uploads.Volumes.insert)}, "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/uploads/Volumes/merge_row/merge_to" }) }) });
    this.reason521 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to520, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason521, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to520, this.reason521 ];
    this.http_method = "GET"
    Lino.uploads.Volumes.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.FiscalYears.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to547 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "emptyText": "Gesch\u00e4ftsjahr ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "pageSize": 20, "preferred_width": 10, "related_actor_id": "ledger.FiscalYears", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/ledger/FiscalYears/merge_row/merge_to" }) }) });
    this.reason548 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to547, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": this.reason548, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to547, this.reason548 ];
    this.http_method = "GET"
    Lino.ledger.FiscalYears.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Companies.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to492 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Companies.detail", "emptyText": "Organisation ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "insert_action": "Lino.contacts.Companies.insert", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Companies.detail,Lino.contacts.Companies.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/contacts/Companies/merge_row/merge_to" }) }) });
    this.addresses_Address493 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Adressen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Addresses","(Merge.addresses_Address) ") }, "name": "addresses_Address", "selectOnFocus": true });
    this.lists_Member494 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Listenmitgliedschaften", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("List memberships","(Merge.lists_Member) ") }, "name": "lists_Member", "selectOnFocus": true });
    var keep_volatiles_1_panel495 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": this.addresses_Address493, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": this.lists_Member494, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.phones_ContactDetail498 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Kontaktangaben", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Contact details","(Merge.phones_ContactDetail) ") }, "name": "phones_ContactDetail", "selectOnFocus": true });
    this.sepa_Account499 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Bankkonten", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Bank accounts","(Merge.sepa_Account) ") }, "name": "sepa_Account", "selectOnFocus": true });
    var keep_volatiles_2_panel500 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": this.phones_ContactDetail498, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": this.sepa_Account499, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.topics_Interest503 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Interessen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Interests","(Merge.topics_Interest) ") }, "name": "topics_Interest", "selectOnFocus": true });
    var keep_volatiles_panel504 = new Ext.form.FieldSet({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ keep_volatiles_1_panel495, keep_volatiles_2_panel500, { "anchor": "-20", "autoHeight": true, "items": this.topics_Interest503, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form", "title": "Auch verg\u00e4ngliche verkn\u00fcpfte Objekte \u00fcberweisen" });
    this.reason506 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to492, "labelAlign": "top", "layout": "form", "xtype": "panel" }, keep_volatiles_panel504, { "anchor": "-20", "autoHeight": true, "items": this.reason506, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to492, this.addresses_Address493, this.lists_Member494, this.phones_ContactDetail498, this.sepa_Account499, this.topics_Interest503, this.reason506 ];
    this.http_method = "GET"
    Lino.contacts.Companies.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Partners.merge_row_ActionFormPanel = Ext.extend(Lino.ActionFormPanel,{
  hideCheckBoxLabels: true,
  layout: "form",
  autoHeight: true,
  labelAlign: "top",
  autoScroll: false,
  labelWidth: 0,
  frame: true,
  bodyBorder: false,
  border: false,
  action_name: 'merge_row',
  window_title: "Fusionieren",
  before_row_edit : function(record) {
  },
  autoHeight: true,
  initComponent : function() {
    this.merge_to449 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "nach...", "hiddenName": "merge_toHidden", "listeners": { "render": Lino.quicktip_renderer("into...","(Merge.merge_to) ") }, "name": "merge_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/apchoices/contacts/Partners/merge_row/merge_to" }) }) });
    this.addresses_Address450 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Adressen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Addresses","(Merge.addresses_Address) ") }, "name": "addresses_Address", "selectOnFocus": true });
    this.lists_Member451 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Listenmitgliedschaften", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("List memberships","(Merge.lists_Member) ") }, "name": "lists_Member", "selectOnFocus": true });
    var keep_volatiles_1_panel452 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": this.addresses_Address450, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": this.lists_Member451, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.phones_ContactDetail455 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Kontaktangaben", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Contact details","(Merge.phones_ContactDetail) ") }, "name": "phones_ContactDetail", "selectOnFocus": true });
    this.sepa_Account456 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Bankkonten", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Bank accounts","(Merge.sepa_Account) ") }, "name": "sepa_Account", "selectOnFocus": true });
    var keep_volatiles_2_panel457 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": this.phones_ContactDetail455, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": this.sepa_Account456, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    this.topics_Interest460 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Interessen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Interests","(Merge.topics_Interest) ") }, "name": "topics_Interest", "selectOnFocus": true });
    var keep_volatiles_panel461 = new Ext.form.FieldSet({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ keep_volatiles_1_panel452, keep_volatiles_2_panel457, { "anchor": "-20", "autoHeight": true, "items": this.topics_Interest460, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form", "title": "Auch verg\u00e4ngliche verkn\u00fcpfte Objekte \u00fcberweisen" });
    this.reason463 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Begr\u00fcndung", "listeners": { "render": Lino.quicktip_renderer("Reason","(Merge.reason) ") }, "maxLength": 100, "name": "reason", "selectOnFocus": true });
    this.items = [ { "anchor": "-20", "autoHeight": true, "items": this.merge_to449, "labelAlign": "top", "layout": "form", "xtype": "panel" }, keep_volatiles_panel461, { "anchor": "-20", "autoHeight": true, "items": this.reason463, "labelAlign": "top", "layout": "form", "xtype": "panel" } ];
    this.fields = [ this.merge_to449, this.addresses_Address450, this.lists_Member451, this.phones_ContactDetail455, this.sepa_Account456, this.topics_Interest460, this.reason463 ];
    this.http_method = "GET"
    Lino.contacts.Partners.merge_row_ActionFormPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Companies.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel contacts-Companies",
  layout: 'fit',
  auto_save: true,
  content_type: 11,
  initComponent : function() {
    var overview_htmlbox628 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 50, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer(null,"(contacts.Companies.overview) ") }, "name": "overview", "value": "<br/>" });
    var name629 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Name</span>", "listeners": { "render": Lino.quicktip_renderer("Name","(contacts.Companies.name) The full name of this partner. Used for alphabetic sorting.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var id630 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(contacts.Companies.id) ") }, "name": "id", "selectOnFocus": true });
    var data_box_1_panel631 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 77, "items": name629, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 22, "items": id630, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var language634 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Sprache</span>", "hiddenName": "languageHidden", "listeners": { "render": Lino.quicktip_renderer("Language","(contacts.Companies.language) The language to use when communicating with this partner.") }, "name": "language", "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var type635 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Organisationsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Organisationsart</span>", "hiddenName": "typeHidden", "listeners": { "render": Lino.quicktip_renderer("Organization type","(contacts.Companies.type) Pointer to the CompanyType.") }, "name": "type", "pageSize": 20, "related_actor_id": "contacts.CompanyTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Companies/type" }) }) });
    var data_box_panel636 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "flex": 50, "frame": true, "hideCheckBoxLabels": true, "items": [ data_box_1_panel631, { "anchor": "-20", "autoHeight": true, "items": language634, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": type635, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    var general_1_panel639 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ overview_htmlbox628, data_box_panel636 ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var contacts_RolesByCompany_grid647 = new Lino.contacts.RolesByCompany.GridPanel({ "containing_panel": this, "flex": 50, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Contact persons","(contacts.contacts.RolesByCompany) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.contacts.RolesByCompany.grid) ] });
    var sepa_AccountsByPartner_grid663 = new Lino.sepa.AccountsByPartner.GridPanel({ "containing_panel": this, "flex": 50, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Bank accounts","(sepa.sepa.AccountsByPartner) Show the bank account(s) defined for a given partner. To be\nincluded to a detail window on partner.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.sepa.AccountsByPartner.grid) ] });
    var general_2_panel664 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 62, "frame": false, "hideCheckBoxLabels": true, "items": [ contacts_RolesByCompany_grid647, sepa_AccountsByPartner_grid663 ], "labelAlign": "top", "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var general_panel665 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ general_1_panel639, general_2_panel664 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Allgemein" });
    var CompaniesByCompany_grid726 = new Lino.contacts.CompaniesByCompany.GridPanel({ "containing_panel": this, "flex": 80, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Child organisations","(contacts.contacts.CompaniesByCompany) Base table for all tables showing companies.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.contacts.CompaniesByCompany.grid) ] });
    var lists_MembersByPartner_htmlbox727 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 20, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("List memberships","(contacts.Companies.lists_MembersByPartner) ") }, "master_panel": this, "name": "lists_MembersByPartner", "title": "Listenmitgliedschaften", "tools": [ Lino.show_in_own_window_button(Lino.lists.MembersByPartner.grid) ], "value": "<br/>" });
    var contact_1_panel728 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 5, "frame": false, "hideCheckBoxLabels": true, "items": [ CompaniesByCompany_grid726, lists_MembersByPartner_htmlbox727 ], "labelAlign": "top", "labelWidth": 207, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "region": "north", "split": true });
    var remarks729 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Bemerkungen", "flex": 66, "name": "remarks", "selectOnFocus": true, "title": "Bemerkungen" });
    var checkdata_ProblemsByOwner_htmlbox730 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 33, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Data problems","(contacts.Companies.checkdata_ProblemsByOwner) The base table for problem messages.") }, "master_panel": this, "name": "checkdata_ProblemsByOwner", "title": "Datenprobleme", "tools": [ Lino.show_in_own_window_button(Lino.checkdata.ProblemsByOwner.grid) ], "value": "<br/>" });
    var contact_2_panel731 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 5, "frame": false, "hideCheckBoxLabels": true, "items": [ remarks729, checkdata_ProblemsByOwner_htmlbox730 ], "labelAlign": "top", "labelWidth": 126, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "region": "center", "split": true });
    var contact_panel732 = new Lino.VBorderPanel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ contact_1_panel728, contact_2_panel731 ], "labelAlign": "top", "listeners": { "activate": Lino.on_tab_activate }, "title": "Kontakt" });
    var uploads_UploadsByController_htmlbox733 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 28, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Upload files","(contacts.Companies.uploads_UploadsByController) Shows the uploads controlled by this database object.") }, "master_panel": this, "name": "uploads_UploadsByController", "title": "Upload-Dateien", "tools": [ Lino.show_in_own_window_button(Lino.uploads.UploadsByController.grid) ], "value": "<br/>" });
    var comments_CommentsByRFC_htmlbox734 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 71, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Comments","(contacts.Companies.comments_CommentsByRFC) Shows the comments for a given database object.") }, "master_panel": this, "name": "comments_CommentsByRFC", "title": "Kommentare", "tools": [ Lino.show_in_own_window_button(Lino.comments.CommentsByRFC.grid) ], "value": "<br/>" });
    var more_1_panel735 = new Ext.Panel({ "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ uploads_UploadsByController_htmlbox733, comments_CommentsByRFC_htmlbox734 ], "labelAlign": "top", "labelWidth": 135, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Mehr" });
    var main_panel736 = new Ext.TabPanel({ "activeTab": 0, "autoScroll": false, "bodyBorder": false, "border": false, "enableTabScroll": true, "frame": true, "hideCheckBoxLabels": true, "items": [ general_panel665, contact_panel732, more_1_panel735 ], "labelAlign": "top", "split": true });
    this.items = main_panel736;
    this.before_row_edit = function(record) {
      overview_htmlbox628.refresh();
      contacts_RolesByCompany_grid647.on_master_changed();
      sepa_AccountsByPartner_grid663.on_master_changed();
      CompaniesByCompany_grid726.on_master_changed();
      lists_MembersByPartner_htmlbox727.refresh();
      remarks729.refresh();
      checkdata_ProblemsByOwner_htmlbox730.refresh();
      uploads_UploadsByController_htmlbox733.refresh();
      comments_CommentsByRFC_htmlbox734.refresh();
    }
    Lino.contacts.Companies.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.lists.Members.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel lists-Members",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 56,
  initComponent : function() {
    var list737 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.lists.Lists.detail", "emptyText": "Partnerliste ausw\u00e4hlen...", "fieldLabel": "Partnerliste", "hiddenName": "listHidden", "insert_action": "Lino.lists.Lists.insert", "listeners": { "render": Lino.quicktip_renderer("Partner List","(lists.Members.list) ") }, "name": "list", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.lists.Lists.detail,Lino.lists.Lists.insert)}, "pageSize": 20, "related_actor_id": "lists.Lists", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/Members/list" }) }) });
    var partner738 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "Partner", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(lists.Members.partner) ") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/Members/partner" }) }) });
    var remark739 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(lists.Members.remark) ") }, "maxLength": 200, "name": "remark", "selectOnFocus": true });
    var main_panel740 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": list737, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": partner738, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": remark739, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel740;
    this.before_row_edit = function(record) {
    }
    Lino.lists.Members.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Companies.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel contacts-Companies",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 11,
  initComponent : function() {
    var name719 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Name</span>", "listeners": { "render": Lino.quicktip_renderer("Name","(contacts.Companies.name) The full name of this partner. Used for alphabetic sorting.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var email720 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">E-Mail-Adresse</span>", "listeners": { "render": Lino.quicktip_renderer("e-mail address","(contacts.Companies.email) The primary email address.") }, "maxLength": 254, "name": "email", "selectOnFocus": true });
    var type721 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Organisationsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Organisationsart</span>", "hiddenName": "typeHidden", "listeners": { "render": Lino.quicktip_renderer("Organization type","(contacts.Companies.type) Pointer to the CompanyType.") }, "name": "type", "pageSize": 20, "related_actor_id": "contacts.CompanyTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Companies/type" }) }) });
    var main_panel722 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": name719, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": email720, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": type721, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel722;
    this.before_row_edit = function(record) {
    }
    Lino.contacts.Companies.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.excerpts.Excerpts.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel excerpts-Excerpts",
  layout: 'fit',
  auto_save: true,
  content_type: 60,
  initComponent : function() {
    var id744 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(excerpts.Excerpts.id) ") }, "name": "id", "selectOnFocus": true });
    var excerpt_type745 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.excerpts.ExcerptTypes.detail", "emptyText": "Auszugsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Auszugsart</span>", "hiddenName": "excerpt_typeHidden", "insert_action": "Lino.excerpts.ExcerptTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Excerpt Type","(excerpts.Excerpts.excerpt_type) The type of this excerpt (ForeignKey to ExcerptType).") }, "name": "excerpt_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.excerpts.ExcerptTypes.detail,Lino.excerpts.ExcerptTypes.insert)}, "pageSize": 20, "related_actor_id": "excerpts.ExcerptTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/excerpt_type" }) }) });
    var main_1_panel746 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 16, "items": id744, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 83, "items": excerpt_type745, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var user749 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(excerpts.Excerpts.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/user" }) }) });
    var build_method750 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Druckmethode", "forceSelection": true, "hiddenName": "build_methodHidden", "listeners": { "render": Lino.quicktip_renderer("Print method","(excerpts.Excerpts.build_method) ") }, "name": "build_method", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var main_2_panel751 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 30, "items": user749, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 69, "items": build_method750, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var company754 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Companies.detail", "emptyText": "Organisation ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Empf\u00e4nger (Organisation)</span>", "hiddenName": "companyHidden", "insert_action": "Lino.contacts.Companies.insert", "listeners": { "render": Lino.quicktip_renderer("Recipient (Organization)","(excerpts.Excerpts.company) The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.") }, "name": "company", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Companies.detail,Lino.contacts.Companies.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/company" }) }) });
    var contact_person755 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Empf\u00e4nger (Person)</span>", "hiddenName": "contact_personHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Recipient (Person)","(excerpts.Excerpts.contact_person) The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.") }, "name": "contact_person", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/contact_person" }) }) });
    var language756 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Sprache</span>", "hiddenName": "languageHidden", "listeners": { "render": Lino.quicktip_renderer("Language","(excerpts.Excerpts.language) The language used for printing this excerpt.") }, "name": "language", "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var main_3_panel757 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": company754, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": contact_person755, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": language756, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var owner_disp761 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verkn\u00fcpft mit</span>", "name": "owner" });
    var build_time762 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Druckdatum</span>", "listeners": { "render": Lino.quicktip_renderer("build time","(excerpts.Excerpts.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "name": "build_time", "value": "<br>" });
    var main_4_panel763 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 38, "items": owner_disp761, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 61, "items": build_time762, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel766 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel746, main_2_panel751, main_3_panel757, main_4_panel763 ], "labelAlign": "top", "layout": "form" });
    this.items = main_panel766;
    this.before_row_edit = function(record) {
      excerpt_type745.setContextValue('owner', record ? record.data['owner'] : undefined);
      contact_person755.setContextValue('company', record ? record.data['companyHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof owner_disp761 !== 'undefined' && owner_disp761.on('change',Lino.chooser_handler(excerpt_type745,'owner'));
      typeof company754 !== 'undefined' && company754.on('change',Lino.chooser_handler(contact_person755,'company'));
      Lino.excerpts.Excerpts.DetailFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.excerpts.Excerpts.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Slots.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel courses-Slots",
  layout: 'fit',
  auto_save: true,
  content_type: 47,
  initComponent : function() {
    var name767 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Name", "listeners": { "render": Lino.quicktip_renderer("Name","(courses.Slots.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var start_time768 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("Start Time","(courses.Slots.start_time) ") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "start_time", "selectOnFocus": true });
    var end_time769 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Endet um", "listeners": { "render": Lino.quicktip_renderer("End Time","(courses.Slots.end_time) ") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "end_time", "selectOnFocus": true });
    var main_1_panel770 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 56, "items": name767, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": start_time768, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": end_time769, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var courses_ActivitiesBySlot_grid888 = new Lino.courses.ActivitiesBySlot.GridPanel({ "containing_panel": this, "flex": 83, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Activities","(courses.courses.ActivitiesBySlot) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.courses.ActivitiesBySlot.grid) ] });
    var main_panel889 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel770, courses_ActivitiesBySlot_grid888 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel889;
    this.before_row_edit = function(record) {
      courses_ActivitiesBySlot_grid888.on_master_changed();
    }
    Lino.courses.Slots.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.humanlinks.Links.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel humanlinks-Links",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 46,
  initComponent : function() {
    var parent890 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Wer ist...</span>", "hiddenName": "parentHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Who is...","(humanlinks.Links.parent) Pointer to the person who is \"parent\".") }, "name": "parent", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/humanlinks/Links/parent" }) }) });
    var type891 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verwandschaftsart</span>", "forceSelection": true, "hiddenName": "typeHidden", "listeners": { "render": Lino.quicktip_renderer("Parency type","(humanlinks.Links.type) The type of link.  Pointer to LinkTypes.") }, "name": "type", "selectOnFocus": true, "store": Lino.humanlinks.LinkTypes });
    var child892 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Von wem...</span>", "hiddenName": "childHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("To whom...","(humanlinks.Links.child) Pointer to the person who is \"child\".") }, "name": "child", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/humanlinks/Links/child" }) }) });
    var main_panel893 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": parent890, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": type891, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": child892, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel893;
    this.before_row_edit = function(record) {
    }
    Lino.humanlinks.Links.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Slots.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel courses-Slots",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 47,
  initComponent : function() {
    var start_time897 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("Start Time","(courses.Slots.start_time) ") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "start_time", "selectOnFocus": true });
    var end_time898 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Endet um", "listeners": { "render": Lino.quicktip_renderer("End Time","(courses.Slots.end_time) ") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "end_time", "selectOnFocus": true });
    var main_1_panel899 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": start_time897, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": end_time898, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var name902 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Name", "listeners": { "render": Lino.quicktip_renderer("Name","(courses.Slots.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var main_panel903 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel899, { "anchor": "-20", "autoHeight": true, "items": name902, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel903;
    this.before_row_edit = function(record) {
    }
    Lino.courses.Slots.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Topics.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel courses-Topics",
  layout: 'fit',
  auto_save: true,
  content_type: 48,
  initComponent : function() {
    var id905 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(courses.Topics.id) ") }, "name": "id", "selectOnFocus": true });
    var name906 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(courses.Topics.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de907 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(courses.Topics.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr908 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(courses.Topics.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel909 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 7, "items": id905, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name906, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_de907, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_fr908, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" }, "region": "north", "split": true });
    var courses_LinesByTopic_grid1004 = new Lino.courses.LinesByTopic.GridPanel({ "containing_panel": this, "flex": 5, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Activity lines","(courses.courses.LinesByTopic) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "region": "center", "split": true, "tools": [ Lino.show_in_own_window_button(Lino.courses.LinesByTopic.grid) ] });
    var courses_ActivitiesByTopic_grid1044 = new Lino.courses.ActivitiesByTopic.GridPanel({ "containing_panel": this, "flex": 5, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Activities","(courses.courses.ActivitiesByTopic) Shows the courses of a given topic.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "region": "south", "split": true, "tools": [ Lino.show_in_own_window_button(Lino.courses.ActivitiesByTopic.grid) ] });
    var main_panel1045 = new Lino.VBorderPanel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel909, courses_LinesByTopic_grid1004, courses_ActivitiesByTopic_grid1044 ], "labelAlign": "top" });
    this.items = main_panel1045;
    this.before_row_edit = function(record) {
      courses_LinesByTopic_grid1004.on_master_changed();
      courses_ActivitiesByTopic_grid1044.on_master_changed();
    }
    Lino.courses.Topics.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Lines.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel courses-Lines",
  layout: 'fit',
  auto_save: true,
  content_type: 49,
  initComponent : function() {
    var id936 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(courses.Lines.id) ") }, "name": "id", "selectOnFocus": true });
    var name937 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(courses.Lines.name) The designation of this activity line as seen by the user\ne.g. when selecting the line.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de938 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(courses.Lines.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr939 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(courses.Lines.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var ref940 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(courses.Lines.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var main_1_panel941 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 4, "items": id936, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": name937, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": name_de938, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": name_fr939, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 37, "items": ref940, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var company947 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Companies.detail", "emptyText": "Organisation ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Organisation</span>", "hiddenName": "companyHidden", "insert_action": "Lino.contacts.Companies.insert", "listeners": { "render": Lino.quicktip_renderer("Organization","(courses.Lines.company) Pointer to Company.") }, "name": "company", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Companies.detail,Lino.contacts.Companies.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/company" }) }) });
    var contact_person948 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Vertreten durch</span>", "hiddenName": "contact_personHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("represented by","(courses.Lines.contact_person) Pointer to Person.") }, "name": "contact_person", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/contact_person" }) }) });
    var main_2_panel949 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": company947, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": contact_person948, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var course_area952 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Layout</span>", "forceSelection": true, "hiddenName": "course_areaHidden", "listeners": { "render": Lino.quicktip_renderer("Layout","(courses.Lines.course_area) Pointer to ActivityLayouts.  This is used only when an\napplication defines several variants of\nEnrolmentsByPupil.") }, "name": "course_area", "selectOnFocus": true, "store": Lino.courses.ActivityLayouts });
    var topic953 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.courses.Topics.detail", "emptyText": "Thema ausw\u00e4hlen...", "fieldLabel": "Thema", "hiddenName": "topicHidden", "listeners": { "render": Lino.quicktip_renderer("Topic","(courses.Lines.topic) ") }, "name": "topic", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Topics.detail,null)}, "pageSize": 20, "related_actor_id": "courses.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/topic" }) }) });
    var body_template954 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Textk\u00f6rper-Vorlage</span>", "listeners": { "render": Lino.quicktip_renderer("Body template","(courses.Lines.body_template) The body template to use when printing an activity of this\nline.  Leave empty to use the site's default (defined by\nbody_template on the\nlino_xl.lib.excerpts.models.ExcerptType for\nCourse)") }, "name": "body_template", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/body_template" }) }) });
    var main_3_panel955 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 30, "items": course_area952, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 46, "items": topic953, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 23, "items": body_template954, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var event_type959 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(courses.Lines.event_type) The type of calendar entries to be generated. If this is empty, no calendar entries will be generated.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/event_type" }) }) });
    var guest_role960 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.GuestRoles.detail", "emptyText": "Gastrolle ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Anwesenheiten erfassen als</span>", "hiddenName": "guest_roleHidden", "listeners": { "render": Lino.quicktip_renderer("Manage presences as","(courses.Lines.guest_role) The default guest role for particpants of calendar entries for activities in this series. Leave empty if you don't want any presences management.") }, "name": "guest_role", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.GuestRoles.detail,null)}, "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/guest_role" }) }) });
    var every_unit961 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Wiederholung", "forceSelection": true, "hiddenName": "every_unitHidden", "listeners": { "render": Lino.quicktip_renderer("Recurrency","(courses.Lines.every_unit) ") }, "name": "every_unit", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every962 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "... alle", "listeners": { "render": Lino.quicktip_renderer("Repeat every","(courses.Lines.every) ") }, "name": "every", "selectOnFocus": true, "value": 1 });
    var main_4_panel963 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 30, "items": event_type959, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": guest_role960, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 31, "items": every_unit961, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 7, "items": every962, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var excerpt_title968 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Excerpt title</span>", "listeners": { "render": Lino.quicktip_renderer("Excerpt title","(courses.Lines.excerpt_title) The text to print as title in enrolments.") }, "maxLength": 200, "name": "excerpt_title", "selectOnFocus": true });
    var excerpt_title_de969 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Excerpt title (de)", "listeners": { "render": Lino.quicktip_renderer("Excerpt title (de)","(courses.Lines.excerpt_title_de) ") }, "maxLength": 200, "name": "excerpt_title_de", "selectOnFocus": true });
    var excerpt_title_fr970 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Excerpt title (fr)", "listeners": { "render": Lino.quicktip_renderer("Excerpt title (fr)","(courses.Lines.excerpt_title_fr) ") }, "maxLength": 200, "name": "excerpt_title_fr", "selectOnFocus": true });
    var main_5_panel971 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": excerpt_title968, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": excerpt_title_de969, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": excerpt_title_fr970, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var description975 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung", "flex": 33, "name": "description", "selectOnFocus": true, "title": "Beschreibung" });
    var description_de976 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung (de)", "flex": 33, "name": "description_de", "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr977 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung (fr)", "flex": 33, "name": "description_fr", "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var main_6_panel978 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 50, "frame": false, "hideCheckBoxLabels": true, "items": [ description975, description_de976, description_fr977 ], "labelAlign": "top", "labelWidth": 162, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var main_panel979 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel941, main_2_panel949, main_3_panel955, main_4_panel963, main_5_panel971, main_6_panel978 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel979;
    this.before_row_edit = function(record) {
      contact_person948.setContextValue('company', record ? record.data['companyHidden'] : undefined);
      description975.refresh();
      description_de976.refresh();
      description_fr977.refresh();
    }
    this.onRender = function(ct, position) {
      typeof company947 !== 'undefined' && company947.on('change',Lino.chooser_handler(contact_person948,'company'));
      Lino.courses.Lines.DetailFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.courses.Lines.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.gfks.ContentTypes.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel gfks-ContentTypes",
  layout: 'fit',
  auto_save: true,
  content_type: 12,
  initComponent : function() {
    var id1046 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(gfks.ContentTypes.id) ") }, "name": "id", "selectOnFocus": true });
    var app_label1047 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "app label", "listeners": { "render": Lino.quicktip_renderer("app label","(gfks.ContentTypes.app_label) ") }, "maxLength": 100, "name": "app_label", "selectOnFocus": true });
    var model1048 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Python Modell-Klassenname", "listeners": { "render": Lino.quicktip_renderer("python model class name","(gfks.ContentTypes.model) ") }, "maxLength": 100, "name": "model", "selectOnFocus": true });
    var base_classes_disp1049 = new Ext.form.DisplayField({ "always_enabled": true, "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Base classes", "listeners": { "render": Lino.quicktip_renderer("Base classes","(gfks.ContentTypes.base_classes) ") }, "name": "base_classes", "value": "<br/>" });
    var main_1_panel1050 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 6, "items": id1046, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 27, "items": app_label1047, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 27, "items": model1048, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 38, "items": base_classes_disp1049, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" }, "region": "north", "split": true });
    var HelpTextsByModel_grid1061 = new Lino.gfks.HelpTextsByModel.GridPanel({ "containing_panel": this, "flex": 5, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Help Texts","(gfks.gfks.HelpTextsByModel) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "region": "center", "split": true, "tools": [ Lino.show_in_own_window_button(Lino.gfks.HelpTextsByModel.grid) ] });
    var BrokenGFKsByModel_grid1066 = new Lino.gfks.BrokenGFKsByModel.GridPanel({ "containing_panel": this, "flex": 5, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Broken GFKs","(gfks.gfks.BrokenGFKsByModel) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "region": "south", "split": true, "tools": [ Lino.show_in_own_window_button(Lino.gfks.BrokenGFKsByModel.grid) ] });
    var main_panel1067 = new Lino.VBorderPanel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1050, HelpTextsByModel_grid1061, BrokenGFKsByModel_grid1066 ], "labelAlign": "top" });
    this.items = main_panel1067;
    this.before_row_edit = function(record) {
      HelpTextsByModel_grid1061.on_master_changed();
      BrokenGFKsByModel_grid1066.on_master_changed();
    }
    Lino.gfks.ContentTypes.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.WeeklyView.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel calview-WeeklyView",
  layout: 'fit',
  auto_save: true,
  disable_editing: true,
  initComponent : function() {
    var navigation_panel_htmlbox1068 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 15, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer(null,"(calview.WeeklyView.navigation_panel) ") }, "name": "navigation_panel", "value": "<br/>" });
    var calview_WeeklySlave_grid1078 = new Lino.calview.WeeklySlave.GridPanel({ "containing_panel": this, "flex": 85, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Planner","(calview.calview.WeeklySlave) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 0 });
    var body_panel1079 = new Ext.Panel({ "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ navigation_panel_htmlbox1068, calview_WeeklySlave_grid1078 ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "region": "center" });
    var main_panel1080 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ body_panel1079 ], "labelAlign": "top", "layout": "fit" });
    this.items = main_panel1080;
    this.before_row_edit = function(record) {
      navigation_panel_htmlbox1068.refresh();
      calview_WeeklySlave_grid1078.on_master_changed();
    }
    Lino.calview.WeeklyView.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.about.About.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel about-About",
  layout: 'fit',
  auto_save: true,
  disable_editing: true,
  initComponent : function() {
    var main_panel1082 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "html": "<div class=\"htmlText\"><span>This is <a href=\"http://amici.lino-framework.org/\" target=\"_blank\">Lino Amici</a> 20.12.0 using <a href=\"http://www.lino-framework.org\" target=\"_blank\">Lino</a> 21.3.1, <a href=\"http://www.djangoproject.com\" target=\"_blank\">Django</a> 3.1.7, <a href=\"http://www.python.org/\" target=\"_blank\">Python</a> 3.6.8, <a href=\"http://babel.edgewall.org/\" target=\"_blank\">Babel</a> 2.9.0, <a href=\"http://jinja.pocoo.org/\" target=\"_blank\">Jinja</a> 2.11.2, <a href=\"http://labix.org/python-dateutil\" target=\"_blank\">python-dateutil</a> 2.8.0, <a href=\"http://getbootstrap.com\" target=\"_blank\">Bootstrap</a> 3.3.4, <a href=\"http://www.sencha.com\" target=\"_blank\">ExtJS</a> <a href=\"#\" onclick=\"alert('ExtJS client version is ' + Ext.version);\" title=\"Click to see ExtJS client version\">(version)</a>, <a href=\"http://www.famfamfam.com/lab/icons/silk/\" target=\"_blank\">Silk Icons</a> 1.3, <a href=\"http://www.tinymce.com/\" target=\"_blank\">TinyMCE</a> 3.5.11, <a href=\"http://www.byte-force.com\" target=\"_blank\">Ext.ux.TinyMCE</a> 0.8.4, <a href=\"http://appyframework.org/pod.html\" target=\"_blank\">Appy</a> (unknown)</span><p>Languages: en, de, fr</p><p>This is a Lino demo site.</p><p>We are running with simulated date set to Monday, 16 December 2019.</p><p>Source timestamps:</p><ul><li>Server timestamp : <b>26/03/2021 at 01:35</b></li><li>django : <b>15/03/2021 at 09:29</b></li><li>lino_xl : <b>25/03/2021 at 11:35</b></li><li>lino : <b>26/03/2021 at 01:34</b></li><li>lino_amici : <b>26/03/2021 at 01:35</b></li></ul><p>Complexity factors : 39 plugins, 67 models, 3 users, 6 user types, 252 views, 21 dialog actions</p></div>", "region": "center", "xtype": "label" } ], "labelAlign": "top", "layout": "fit" });
    this.items = main_panel1082;
    this.before_row_edit = function(record) {
    }
    Lino.about.About.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Situation.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel utils-Report",
  layout: 'fit',
  auto_save: true,
  disable_editing: true,
  initComponent : function() {
    var body_htmlbox1083 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer(null,"(utils.Report.body) ") }, "name": "body", "region": "center", "value": "<br/>" });
    var main_panel1084 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ body_htmlbox1083 ], "labelAlign": "top", "labelWidth": 0, "layout": "fit" });
    this.items = main_panel1084;
    this.before_row_edit = function(record) {
      body_htmlbox1083.refresh();
    }
    Lino.ledger.Situation.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.system.SiteConfigs.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel system-SiteConfigs",
  layout: 'fit',
  auto_save: true,
  content_type: 1,
  initComponent : function() {
    var site_company1085 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Companies.detail", "emptyText": "Organisation ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Site-Besitzer</span>", "hiddenName": "site_companyHidden", "insert_action": "Lino.contacts.Companies.insert", "listeners": { "render": Lino.quicktip_renderer("Site owner","(system.SiteConfigs.site_company) The site operator, i.e. the legal person that operates this\nLino site.") }, "name": "site_company", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Companies.detail,Lino.contacts.Companies.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/system/SiteConfigs/site_company" }) }) });
    var next_partner_id1086 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">N\u00e4chste Partnernummer</span>", "listeners": { "render": Lino.quicktip_renderer("Next partner id","(system.SiteConfigs.next_partner_id) The next automatic id for any new partner.") }, "name": "next_partner_id", "selectOnFocus": true, "value": 100 });
    var default_build_method1087 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Standard-Konstruktionsmethode</span>", "forceSelection": true, "hiddenName": "default_build_methodHidden", "listeners": { "render": Lino.quicktip_renderer("Default build method","(system.SiteConfigs.default_build_method) The default build method to use when rendering printable documents.") }, "name": "default_build_method", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var main_1_panel1088 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 37, "items": site_company1085, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": next_partner_id1086, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 43, "items": default_build_method1087, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel1092 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1088 ], "labelAlign": "top", "layout": "fit" });
    this.items = main_panel1092;
    this.before_row_edit = function(record) {
    }
    Lino.system.SiteConfigs.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.addresses.Addresses.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel addresses-Addresses",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 41,
  initComponent : function() {
    var country1093 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.countries.Countries.detail", "emptyText": "Land ausw\u00e4hlen...", "fieldLabel": "Land", "hiddenName": "countryHidden", "insert_action": "Lino.countries.Countries.insert", "listeners": { "render": Lino.quicktip_renderer("Country","(addresses.Addresses.country) ") }, "name": "country", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.countries.Countries.detail,Lino.countries.Countries.insert)}, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/country" }) }) });
    var city1094 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": true, "detail_action": "Lino.countries.Places.detail", "emptyText": "Ort ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Ortschaft</span>", "forceSelection": false, "hiddenName": "cityHidden", "insert_action": "Lino.countries.Places.insert", "listeners": { "render": Lino.quicktip_renderer("Locality","(addresses.Addresses.city) The locality, i.e. usually a village, city or town.") }, "name": "city", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.countries.Places.detail,Lino.countries.Places.insert)}, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/city" }) }) });
    var zip_code1095 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(10), "fieldLabel": "Postleitzahl", "listeners": { "render": Lino.quicktip_renderer("Zip code","(addresses.Addresses.zip_code) ") }, "maxLength": 10, "name": "zip_code", "selectOnFocus": true });
    var main_1_panel1096 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 39, "items": country1093, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 39, "items": city1094, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": zip_code1095, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var addr11100 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Adresszeile vor Stra\u00dfe</span>", "listeners": { "render": Lino.quicktip_renderer("Address line before street","(addresses.Addresses.addr1) Address line before street") }, "maxLength": 200, "name": "addr1", "selectOnFocus": true });
    var street1101 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Stra\u00dfe</span>", "listeners": { "render": Lino.quicktip_renderer("Street","(addresses.Addresses.street) Name of street, without house number.") }, "maxLength": 200, "name": "street", "selectOnFocus": true });
    var street_no1102 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(10), "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Nr.</span>", "listeners": { "render": Lino.quicktip_renderer("No.","(addresses.Addresses.street_no) House number.") }, "maxLength": 10, "name": "street_no", "selectOnFocus": true });
    var street_box1103 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(10), "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Box</span>", "listeners": { "render": Lino.quicktip_renderer("Box","(addresses.Addresses.street_box) Text to print after street number on the same line.") }, "maxLength": 10, "name": "street_box", "selectOnFocus": true });
    var main_3_panel1104 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 48, "items": street1101, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": street_no1102, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": street_box1103, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var addr21108 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Adresszeile nach Stra\u00dfe</span>", "listeners": { "render": Lino.quicktip_renderer("Address line after street","(addresses.Addresses.addr2) Address line to print below street line.") }, "maxLength": 200, "name": "addr2", "selectOnFocus": true });
    var address_type1109 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Adressenart</span>", "forceSelection": true, "hiddenName": "address_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Address type","(addresses.Addresses.address_type) The type of this address record.\nA pointer to AddressTypes.\nThe default value is AddressTypes.official.") }, "name": "address_type", "selectOnFocus": true, "store": Lino.addresses.AddressTypes });
    var remark1110 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(addresses.Addresses.remark) ") }, "maxLength": 50, "name": "remark", "selectOnFocus": true });
    var main_5_panel1111 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": address_type1109, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": remark1110, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var data_source1114 = new Lino.ChoicesFieldElement({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datenquelle</span>", "forceSelection": true, "hiddenName": "data_sourceHidden", "listeners": { "render": Lino.quicktip_renderer("Data source","(addresses.Addresses.data_source) Pointer to DataSources.") }, "name": "data_source", "store": Lino.addresses.DataSources });
    var partner1115 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "Partner", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(addresses.Addresses.partner) ") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/partner" }) }) });
    var main_6_panel1116 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 48, "items": data_source1114, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 51, "items": partner1115, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel1119 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1096, { "anchor": "-20", "autoHeight": true, "items": addr11100, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_3_panel1104, { "anchor": "-20", "autoHeight": true, "items": addr21108, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_5_panel1111, main_6_panel1116 ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1119;
    this.before_row_edit = function(record) {
      city1094.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city1094.setContextValue('region', record ? record.data['regionHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof country1093 !== 'undefined' && country1093.on('change',Lino.chooser_handler(city1094,'country'));
      Lino.addresses.Addresses.DetailFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.addresses.Addresses.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.countries.Countries.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel countries-Countries",
  layout: 'fit',
  auto_save: true,
  content_type: 4,
  initComponent : function() {
    var isocode1122 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(4), "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">ISO-Code</span>", "listeners": { "render": Lino.quicktip_renderer("ISO code","(countries.Countries.isocode) The two-letter code for this country as defined by ISO 3166-1.\nFor countries that no longer exist it may be a 4-letter code.") }, "maxLength": 4, "name": "isocode", "selectOnFocus": true });
    var name1123 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(countries.Countries.name) The designation of this country.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1124 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(countries.Countries.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1125 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(countries.Countries.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var short_code1126 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(4), "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Short code</span>", "listeners": { "render": Lino.quicktip_renderer("Short code","(countries.Countries.short_code) A short abbreviation for regional usage. Obsolete.") }, "maxLength": 4, "name": "short_code", "selectOnFocus": true });
    var main_1_panel1127 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 12, "items": isocode1122, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": name1123, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": name_de1124, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": name_fr1125, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": short_code1126, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var countries_PlacesByCountry_grid1294 = new Lino.countries.PlacesByCountry.GridPanel({ "containing_panel": this, "flex": 83, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Places","(countries.countries.PlacesByCountry) The table of known geographical places.\nA geographical place can be a city, a town, a suburb,\na province, a lake... any named geographic entity,\nexcept for countries because these have their own table.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.countries.PlacesByCountry.grid) ] });
    var main_panel1295 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1127, countries_PlacesByCountry_grid1294 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1295;
    this.before_row_edit = function(record) {
      countries_PlacesByCountry_grid1294.on_master_changed();
    }
    Lino.countries.Countries.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.uploads.UploadsByController.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel uploads-UploadsByController",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 29,
  initComponent : function() {
    var file1296 = Lino.file_field_handler(this,{ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datei</span>", "listeners": { "render": Lino.quicktip_renderer("File","(uploads.UploadsByController.file) Pointer to the uploaded file itself (a Django FileField).") }, "maxLength": 100, "name": "file", "selectOnFocus": true });
    var volume1297 = new Lino.TwinCombo({ "allowBlank": true, "detail_action": "Lino.uploads.Volumes.detail", "emptyText": "Dateibibliothek ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Dateibibliothek</span>", "flex": 66, "hidden": true, "hiddenName": "volumeHidden", "insert_action": "Lino.uploads.Volumes.insert", "listeners": { "render": Lino.quicktip_renderer("Library volume","(uploads.UploadsByController.volume) A pointer to the library volume where this file is stored.") }, "name": "volume", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.uploads.Volumes.detail,Lino.uploads.Volumes.insert)}, "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByController/volume" }) }) });
    var library_file1298 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bibliotheksdatei</span>", "listeners": { "render": Lino.quicktip_renderer("Library file","(uploads.UploadsByController.library_file) The path of this file, relative the volume's root.") }, "name": "library_file", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByController/library_file" }) }) });
    var main_2_panel1299 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ volume1297, { "autoHeight": true, "flex": 33, "items": library_file1298, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 144, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var type1301 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.uploads.UploadTypes.detail", "emptyText": "Upload-Art ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Upload-Art</span>", "hiddenName": "typeHidden", "insert_action": "Lino.uploads.UploadTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Upload type","(uploads.UploadsByController.type) The type of this upload.") }, "name": "type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.uploads.UploadTypes.detail,Lino.uploads.UploadTypes.insert)}, "pageSize": 20, "related_actor_id": "uploads.UploadTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByController/type" }) }) });
    var description1302 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beschreibung</span>", "listeners": { "render": Lino.quicktip_renderer("Description","(uploads.UploadsByController.description) A short description entered manually by the user.") }, "maxLength": 200, "name": "description", "selectOnFocus": true });
    var main_panel1303 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": file1296, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_2_panel1299, { "anchor": "-20", "autoHeight": true, "items": type1301, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": description1302, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1303;
    this.before_row_edit = function(record) {
      library_file1298.setContextValue('volume', record ? record.data['volumeHidden'] : undefined);
      type1301.setContextValue('upload_area', record ? record.data['upload_areaHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof volume1297 !== 'undefined' && volume1297.on('change',Lino.chooser_handler(library_file1298,'volume'));
      Lino.uploads.UploadsByController.InsertFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.uploads.UploadsByController.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.countries.Countries.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel countries-Countries",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 4,
  initComponent : function() {
    var isocode1307 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(4), "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">ISO-Code</span>", "listeners": { "render": Lino.quicktip_renderer("ISO code","(countries.Countries.isocode) The two-letter code for this country as defined by ISO 3166-1.\nFor countries that no longer exist it may be a 4-letter code.") }, "maxLength": 4, "name": "isocode", "selectOnFocus": true });
    var short_code1308 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(4), "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Short code</span>", "listeners": { "render": Lino.quicktip_renderer("Short code","(countries.Countries.short_code) A short abbreviation for regional usage. Obsolete.") }, "maxLength": 4, "name": "short_code", "selectOnFocus": true });
    var main_1_panel1309 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": isocode1307, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": short_code1308, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var name1312 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(countries.Countries.name) The designation of this country.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1313 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(countries.Countries.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1314 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(countries.Countries.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_2_panel1315 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name1312, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de1313, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr1314, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel1319 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1309, main_2_panel1315 ], "labelAlign": "top", "layout": "form" });
    this.items = main_panel1319;
    this.before_row_edit = function(record) {
    }
    Lino.countries.Countries.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.countries.Places.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel countries-Places",
  layout: 'fit',
  auto_save: true,
  content_type: 5,
  initComponent : function() {
    var name1143 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(countries.Places.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1144 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(countries.Places.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1145 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(countries.Places.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var country1146 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.countries.Countries.detail", "emptyText": "Land ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Land</span>", "hiddenName": "countryHidden", "insert_action": "Lino.countries.Countries.insert", "listeners": { "render": Lino.quicktip_renderer("Country","(countries.Places.country) The country this place is in.") }, "name": "country", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.countries.Countries.detail,Lino.countries.Countries.insert)}, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/Places/country" }) }) });
    var main_1_panel1147 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 25, "items": name1143, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": name_de1144, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": name_fr1145, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 24, "items": country1146, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var type1152 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Ortsart</span>", "hiddenName": "typeHidden", "listeners": { "render": Lino.quicktip_renderer("Place Type","(countries.Places.type) The type of this place (whether it's a city. a village, a province...)") }, "name": "type", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/Places/type" }) }) });
    var parent1153 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.countries.Places.detail", "emptyText": "Ort ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Teil von</span>", "hiddenName": "parentHidden", "insert_action": "Lino.countries.Places.insert", "listeners": { "render": Lino.quicktip_renderer("Part of","(countries.Places.parent) The superordinate geographic place of which this place is a part.") }, "name": "parent", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.countries.Places.detail,Lino.countries.Places.insert)}, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/Places/parent" }) }) });
    var zip_code1154 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(8), "fieldLabel": "zip code", "listeners": { "render": Lino.quicktip_renderer("zip code","(countries.Places.zip_code) ") }, "maxLength": 8, "name": "zip_code", "selectOnFocus": true });
    var id1155 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(countries.Places.id) ") }, "name": "id", "selectOnFocus": true });
    var main_2_panel1156 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 22, "items": type1152, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 45, "items": parent1153, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": zip_code1154, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 11, "items": id1155, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var addresses_AddressesByCity_grid1196 = new Lino.addresses.AddressesByCity.GridPanel({ "containing_panel": this, "flex": 41, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Addresses","(addresses.addresses.AddressesByCity) Shows all addresses in the database.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.addresses.AddressesByCity.grid) ] });
    var contacts_PartnersByCity_grid1239 = new Lino.contacts.PartnersByCity.GridPanel({ "containing_panel": this, "flex": 50, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Partners","(contacts.contacts.PartnersByCity) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.contacts.PartnersByCity.grid) ] });
    var PlacesByPlace_grid1291 = new Lino.countries.PlacesByPlace.GridPanel({ "containing_panel": this, "flex": 50, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Subdivisions","(countries.countries.PlacesByPlace) The table of known geographical places.\nA geographical place can be a city, a town, a suburb,\na province, a lake... any named geographic entity,\nexcept for countries because these have their own table.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.countries.PlacesByPlace.grid) ] });
    var main_4_panel1292 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 41, "frame": false, "hideCheckBoxLabels": true, "items": [ contacts_PartnersByCity_grid1239, PlacesByPlace_grid1291 ], "labelAlign": "top", "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var main_panel1293 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1147, main_2_panel1156, addresses_AddressesByCity_grid1196, main_4_panel1292 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1293;
    this.before_row_edit = function(record) {
      type1152.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      addresses_AddressesByCity_grid1196.on_master_changed();
      contacts_PartnersByCity_grid1239.on_master_changed();
      PlacesByPlace_grid1291.on_master_changed();
    }
    this.onRender = function(ct, position) {
      typeof country1146 !== 'undefined' && country1146.on('change',Lino.chooser_handler(type1152,'country'));
      Lino.countries.Places.DetailFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.countries.Places.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.countries.Places.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel countries-Places",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 5,
  initComponent : function() {
    var name1274 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(countries.Places.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1275 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(countries.Places.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1276 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(countries.Places.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel1277 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name1274, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de1275, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr1276, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var country1281 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.countries.Countries.detail", "emptyText": "Land ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Land</span>", "hiddenName": "countryHidden", "insert_action": "Lino.countries.Countries.insert", "listeners": { "render": Lino.quicktip_renderer("Country","(countries.Places.country) The country this place is in.") }, "name": "country", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.countries.Countries.detail,Lino.countries.Countries.insert)}, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/Places/country" }) }) });
    var zip_code1282 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(8), "fieldLabel": "zip code", "listeners": { "render": Lino.quicktip_renderer("zip code","(countries.Places.zip_code) ") }, "maxLength": 8, "name": "zip_code", "selectOnFocus": true });
    var type1283 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Ortsart</span>", "hiddenName": "typeHidden", "listeners": { "render": Lino.quicktip_renderer("Place Type","(countries.Places.type) The type of this place (whether it's a city. a village, a province...)") }, "name": "type", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/Places/type" }) }) });
    var main_3_panel1284 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 47, "items": zip_code1282, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 52, "items": type1283, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var parent1287 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.countries.Places.detail", "emptyText": "Ort ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Teil von</span>", "hiddenName": "parentHidden", "insert_action": "Lino.countries.Places.insert", "listeners": { "render": Lino.quicktip_renderer("Part of","(countries.Places.parent) The superordinate geographic place of which this place is a part.") }, "name": "parent", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.countries.Places.detail,Lino.countries.Places.insert)}, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/Places/parent" }) }) });
    var main_panel1288 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1277, { "anchor": "-20", "autoHeight": true, "items": country1281, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_3_panel1284, { "anchor": "-20", "autoHeight": true, "items": parent1287, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1288;
    this.before_row_edit = function(record) {
      type1283.setContextValue('country', record ? record.data['countryHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof country1281 !== 'undefined' && country1281.on('change',Lino.chooser_handler(type1283,'country'));
      Lino.countries.Places.InsertFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.countries.Places.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.EventTypes.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel cal-EventTypes",
  layout: 'fit',
  auto_save: true,
  content_type: 17,
  initComponent : function() {
    var ref1320 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(cal.EventTypes.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var id1321 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(cal.EventTypes.id) ") }, "name": "id", "selectOnFocus": true });
    var planner_column1322 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Tagesplanerkolonne", "forceSelection": true, "hiddenName": "planner_columnHidden", "listeners": { "render": Lino.quicktip_renderer("Planner column","(cal.EventTypes.planner_column) ") }, "name": "planner_column", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.PlannerColumns) });
    var default_duration1323 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(6), "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Vorschlag Dauer</span>", "listeners": { "render": Lino.quicktip_renderer("Default duration","(cal.EventTypes.default_duration) An optional default duration for calendar entries of this type.") }, "maxLength": 6, "name": "default_duration", "selectOnFocus": true });
    var main_1_panel1324 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 14, "items": ref1320, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": id1321, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 40, "items": planner_column1322, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": default_duration1323, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var name1329 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(cal.EventTypes.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1330 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(cal.EventTypes.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1331 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(cal.EventTypes.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_2_panel1332 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name1329, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de1330, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr1331, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var event_label1336 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung Termin</span>", "listeners": { "render": Lino.quicktip_renderer("Entry label","(cal.EventTypes.event_label) Default text for summary of new entries.") }, "maxLength": 200, "name": "event_label", "selectOnFocus": true });
    var event_label_de1337 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung Termin (de)", "listeners": { "render": Lino.quicktip_renderer("Entry label (de)","(cal.EventTypes.event_label_de) ") }, "maxLength": 200, "name": "event_label_de", "selectOnFocus": true });
    var event_label_fr1338 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung Termin (fr)", "listeners": { "render": Lino.quicktip_renderer("Entry label (fr)","(cal.EventTypes.event_label_fr) ") }, "maxLength": 200, "name": "event_label_fr", "selectOnFocus": true });
    var main_3_panel1339 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": event_label1336, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": event_label_de1337, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": event_label_fr1338, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var start_date1343 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("Start date","(cal.EventTypes.start_date) ") }, "name": "start_date", "selectOnFocus": true });
    var max_days1344 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Tage maximal</span>", "listeners": { "render": Lino.quicktip_renderer("Maximum days","(cal.EventTypes.max_days) The maximal number of days allowed as duration. 0 means no limit.") }, "name": "max_days", "selectOnFocus": true, "value": 1 });
    var max_conflicting1345 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Gleichzeitige Termine</span>", "listeners": { "render": Lino.quicktip_renderer("Simultaneous entries","(cal.EventTypes.max_conflicting) How many conflicting events should be tolerated.") }, "name": "max_conflicting", "selectOnFocus": true, "value": 1 });
    var email_template1346 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">E-Mail-Vorlage</span>", "listeners": { "render": Lino.quicktip_renderer("Email template","(cal.EventTypes.email_template) The name of the file to be used as template when creating an email from a mailable of this type.") }, "name": "email_template", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EventTypes/email_template" }) }) });
    var attach_to_email1347 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "als Anhang per E-Mail", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Attach to email","(cal.EventTypes.attach_to_email) Whether the printable file should be attached to the email\nwhen creating an email from a mailable of this type.\n") }, "name": "attach_to_email", "selectOnFocus": true });
    var main_4_panel1348 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 30, "items": start_date1343, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 11, "items": max_days1344, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 11, "items": max_conflicting1345, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 23, "items": email_template1346, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 23, "items": attach_to_email1347, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var is_appointment1354 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Termin", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Appointment","(cal.EventTypes.is_appointment) Whether entries of this type are considered \"appointments\" (i.e. whose\ntime and place have been agreed upon with other users or external\nparties).") }, "name": "is_appointment", "selectOnFocus": true });
    var force_guest_states1355 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Anwesenheiten automatisch", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Automatic presences","(cal.EventTypes.force_guest_states) Whether presence states should be forced to those defined by the\nentry state.") }, "name": "force_guest_states", "selectOnFocus": true });
    var fill_presences1356 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "G\u00e4ste ausf\u00fcllen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Fill guests","(cal.EventTypes.fill_presences) Whether guests should be automatically filled for calendar entries of\nthis type.") }, "name": "fill_presences", "selectOnFocus": true });
    var all_rooms1357 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Blockiert alle R\u00e4ume", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Locks all rooms","(cal.EventTypes.all_rooms) ") }, "name": "all_rooms", "selectOnFocus": true });
    var locks_user1358 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Blockiert den Autor", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Locks the user","(cal.EventTypes.locks_user) Whether calendar entries of this type make the user\nunavailable for other locking events at the same time.") }, "name": "locks_user", "selectOnFocus": true });
    var transparent1359 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "nicht blockierend", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Transparent","(cal.EventTypes.transparent) Allow entries of this type to conflict with other events.") }, "name": "transparent", "selectOnFocus": true });
    var main_5_panel1360 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 16, "items": is_appointment1354, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": force_guest_states1355, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": fill_presences1356, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": all_rooms1357, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": locks_user1358, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": transparent1359, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var EntriesByType_grid1467 = new Lino.cal.EntriesByType.GridPanel({ "containing_panel": this, "flex": 50, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Calendar entries","(cal.cal.EntriesByType) Table which shows all calendar events.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.cal.EntriesByType.grid) ] });
    var main_panel1468 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1324, main_2_panel1332, main_3_panel1339, main_4_panel1348, main_5_panel1360, EntriesByType_grid1467 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1468;
    this.before_row_edit = function(record) {
      EntriesByType_grid1467.on_master_changed();
    }
    Lino.cal.EventTypes.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Partners.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel contacts-Partners",
  layout: 'fit',
  auto_save: true,
  content_type: 6,
  initComponent : function() {
    var overview_htmlbox1221 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 50, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer(null,"(contacts.Partners.overview) ") }, "name": "overview", "value": "<br/>" });
    var name1222 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Name</span>", "listeners": { "render": Lino.quicktip_renderer("Name","(contacts.Partners.name) The full name of this partner. Used for alphabetic sorting.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var id1223 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(contacts.Partners.id) ") }, "name": "id", "selectOnFocus": true });
    var contact_box_1_panel1224 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 80, "items": name1222, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": id1223, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var url1227 = new Lino.URLField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Adresse (URL)", "listeners": { "render": Lino.quicktip_renderer("URL","(contacts.Partners.url) ") }, "maxLength": 200, "name": "url", "selectOnFocus": true });
    var phone1228 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Telefon</span>", "listeners": { "render": Lino.quicktip_renderer("Phone","(contacts.Partners.phone) The primary phone number.") }, "maxLength": 200, "name": "phone", "selectOnFocus": true });
    var gsm1229 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">GSM</span>", "listeners": { "render": Lino.quicktip_renderer("GSM","(contacts.Partners.gsm) The primary mobile phone number.") }, "maxLength": 200, "name": "gsm", "selectOnFocus": true });
    var contact_box_panel1230 = new Ext.form.FieldSet({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "flex": 50, "frame": true, "hideCheckBoxLabels": true, "items": [ contact_box_1_panel1224, { "anchor": "-20", "autoHeight": true, "items": url1227, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": phone1228, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": gsm1229, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form", "title": "Kontakt" });
    var main_1_panel1234 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ overview_htmlbox1221, contact_box_panel1230 ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var remarks1235 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Bemerkungen", "flex": 66, "name": "remarks", "selectOnFocus": true, "title": "Bemerkungen" });
    var lists_MembersByPartner_htmlbox1236 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 33, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("List memberships","(contacts.Partners.lists_MembersByPartner) ") }, "master_panel": this, "name": "lists_MembersByPartner", "title": "Listenmitgliedschaften", "tools": [ Lino.show_in_own_window_button(Lino.lists.MembersByPartner.grid) ], "value": "<br/>" });
    var bottom_box_1_panel1237 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 55, "frame": false, "hideCheckBoxLabels": true, "items": [ remarks1235, lists_MembersByPartner_htmlbox1236 ], "labelAlign": "top", "labelWidth": 207, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var main_panel1238 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1234, bottom_box_1_panel1237 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1238;
    this.before_row_edit = function(record) {
      overview_htmlbox1221.refresh();
      remarks1235.refresh();
      lists_MembersByPartner_htmlbox1236.refresh();
    }
    Lino.contacts.Partners.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Rooms.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel cal-Rooms",
  layout: 'fit',
  auto_save: true,
  content_type: 16,
  initComponent : function() {
    var id1469 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(cal.Rooms.id) ") }, "name": "id", "selectOnFocus": true });
    var name1470 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(cal.Rooms.name) The designation of the room. This is not required to be unique.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1471 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(cal.Rooms.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1472 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(cal.Rooms.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel1473 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 7, "items": id1469, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name1470, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_de1471, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_fr1472, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var company1478 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Companies.detail", "emptyText": "Organisation ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "companyHidden", "insert_action": "Lino.contacts.Companies.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible","(cal.Rooms.company) Pointer to Company.") }, "name": "company", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Companies.detail,Lino.contacts.Companies.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Rooms/company" }) }) });
    var contact_person1479 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kontaktperson</span>", "hiddenName": "contact_personHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Contact person","(cal.Rooms.contact_person) Pointer to Person.") }, "name": "contact_person", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Rooms/contact_person" }) }) });
    var display_color1480 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Color</span>", "forceSelection": true, "hiddenName": "display_colorHidden", "listeners": { "render": Lino.quicktip_renderer("Color","(cal.Rooms.display_color) The color to use when displaying entries in this room in the calendar\nview.") }, "name": "display_color", "selectOnFocus": true, "store": Lino.cal.DisplayColors });
    var main_2_panel1481 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 40, "items": company1478, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 40, "items": contact_person1479, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": display_color1480, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var description1485 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung", "flex": 41, "name": "description", "selectOnFocus": true, "title": "Beschreibung" });
    var cal_EntriesByRoom_grid1512 = new Lino.cal.EntriesByRoom.GridPanel({ "containing_panel": this, "flex": 41, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Calendar entries","(cal.cal.EntriesByRoom) Displays the calendar entries at a given Room.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.cal.EntriesByRoom.grid) ] });
    var main_panel1513 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1473, main_2_panel1481, description1485, cal_EntriesByRoom_grid1512 ], "labelAlign": "top", "labelWidth": 117, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1513;
    this.before_row_edit = function(record) {
      contact_person1479.setContextValue('company', record ? record.data['companyHidden'] : undefined);
      description1485.refresh();
      cal_EntriesByRoom_grid1512.on_master_changed();
    }
    this.onRender = function(ct, position) {
      typeof company1478 !== 'undefined' && company1478.on('change',Lino.chooser_handler(contact_person1479,'company'));
      Lino.cal.Rooms.DetailFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.cal.Rooms.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Rooms.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel cal-Rooms",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 16,
  initComponent : function() {
    var id1514 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(cal.Rooms.id) ") }, "name": "id", "selectOnFocus": true });
    var name1515 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(cal.Rooms.name) The designation of the room. This is not required to be unique.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1516 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(cal.Rooms.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1517 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(cal.Rooms.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var display_color1518 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Color</span>", "forceSelection": true, "hiddenName": "display_colorHidden", "listeners": { "render": Lino.quicktip_renderer("Color","(cal.Rooms.display_color) The color to use when displaying entries in this room in the calendar\nview.") }, "name": "display_color", "selectOnFocus": true, "store": Lino.cal.DisplayColors });
    var main_1_panel1519 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 6, "items": id1514, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 26, "items": name1515, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 26, "items": name_de1516, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 26, "items": name_fr1517, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 12, "items": display_color1518, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var company1525 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Companies.detail", "emptyText": "Organisation ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "companyHidden", "insert_action": "Lino.contacts.Companies.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible","(cal.Rooms.company) Pointer to Company.") }, "name": "company", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Companies.detail,Lino.contacts.Companies.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Rooms/company" }) }) });
    var contact_person1526 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kontaktperson</span>", "hiddenName": "contact_personHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Contact person","(cal.Rooms.contact_person) Pointer to Person.") }, "name": "contact_person", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Rooms/contact_person" }) }) });
    var main_panel1527 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1519, { "anchor": "-20", "autoHeight": true, "items": company1525, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": contact_person1526, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1527;
    this.before_row_edit = function(record) {
      contact_person1526.setContextValue('company', record ? record.data['companyHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof company1525 !== 'undefined' && company1525.on('change',Lino.chooser_handler(contact_person1526,'company'));
      Lino.cal.Rooms.InsertFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.cal.Rooms.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Calendars.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel cal-Calendars",
  layout: 'fit',
  auto_save: true,
  content_type: 19,
  initComponent : function() {
    var name1530 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(cal.Calendars.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1531 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(cal.Calendars.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1532 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(cal.Calendars.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var color1533 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Farbe</span>", "listeners": { "render": Lino.quicktip_renderer("color","(cal.Calendars.color) The color to use for entries of this calendar (in\nlino_xl.lib.extensible).") }, "name": "color", "selectOnFocus": true });
    var id1534 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(cal.Calendars.id) ") }, "name": "id", "selectOnFocus": true });
    var main_1_panel1535 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 28, "items": name1530, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 28, "items": name_de1531, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 28, "items": name_fr1532, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 6, "items": color1533, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 6, "items": id1534, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var description1541 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung", "flex": 52, "name": "description", "selectOnFocus": true, "title": "Beschreibung" });
    var SubscriptionsByCalendar_grid1547 = new Lino.cal.SubscriptionsByCalendar.GridPanel({ "containing_panel": this, "flex": 47, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Subscriptions","(cal.cal.SubscriptionsByCalendar) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.cal.SubscriptionsByCalendar.grid) ] });
    var main_2_panel1548 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 83, "frame": false, "hideCheckBoxLabels": true, "items": [ description1541, SubscriptionsByCalendar_grid1547 ], "labelAlign": "top", "labelWidth": 117, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var main_panel1549 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1535, main_2_panel1548 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1549;
    this.before_row_edit = function(record) {
      description1541.refresh();
      SubscriptionsByCalendar_grid1547.on_master_changed();
    }
    Lino.cal.Calendars.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Calendars.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel cal-Calendars",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 19,
  initComponent : function() {
    var name1550 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(cal.Calendars.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1551 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(cal.Calendars.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1552 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(cal.Calendars.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel1553 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name1550, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de1551, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr1552, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var color1557 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Farbe</span>", "listeners": { "render": Lino.quicktip_renderer("color","(cal.Calendars.color) The color to use for entries of this calendar (in\nlino_xl.lib.extensible).") }, "name": "color", "selectOnFocus": true });
    var main_panel1558 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1553, { "anchor": "-20", "autoHeight": true, "items": color1557, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1558;
    this.before_row_edit = function(record) {
    }
    Lino.cal.Calendars.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Tasks.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel cal-Tasks",
  layout: 'fit',
  auto_save: true,
  content_type: 21,
  initComponent : function() {
    var start_date1560 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("Start date","(cal.Tasks.start_date) ") }, "name": "start_date", "selectOnFocus": true });
    var priority1561 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Priorit\u00e4t</span>", "forceSelection": true, "hiddenName": "priorityHidden", "listeners": { "render": Lino.quicktip_renderer("Priority","(cal.Tasks.priority) How urgent this task is.") }, "name": "priority", "selectOnFocus": true, "store": Lino.xl.Priorities });
    var due_date1562 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Zahlungsziel", "listeners": { "render": Lino.quicktip_renderer("Due date","(cal.Tasks.due_date) ") }, "name": "due_date", "selectOnFocus": true });
    var id1563 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(cal.Tasks.id) ") }, "name": "id", "selectOnFocus": true });
    var workflow_buttons_disp1564 = new Ext.form.DisplayField({ "always_enabled": true, "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Workflow</span>", "listeners": { "render": Lino.quicktip_renderer("Workflow","(cal.Tasks.workflow_buttons) List of actions that change the workflow state of this object.") }, "name": "workflow_buttons", "value": "<br/>" });
    var main_1_panel1565 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 18, "items": start_date1560, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 15, "items": priority1561, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": due_date1562, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 6, "items": id1563, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 41, "items": workflow_buttons_disp1564, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var summary1571 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("Short description","(cal.Tasks.summary) ") }, "maxLength": 200, "name": "summary", "selectOnFocus": true });
    var user1572 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(cal.Tasks.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Tasks/user" }) }) });
    var owner_disp1573 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Verkn\u00fcpft mit", "name": "owner" });
    var created1574 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Erstellt</span>", "listeners": { "render": Lino.quicktip_renderer("Created","(cal.Tasks.created) The time when this object was created.") }, "name": "created", "value": "<br>" });
    var modified1575 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bearbeitet</span>", "listeners": { "render": Lino.quicktip_renderer("Modified","(cal.Tasks.modified) The time when this database object was last modified.") }, "name": "modified", "value": "<br>" });
    var main_4_panel1576 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 20, "items": owner_disp1573, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 40, "items": created1574, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 40, "items": modified1575, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var description1580 = new Ext.form.TextArea({ "allowBlank": true, "anchor": "-20 -10", "fieldLabel": "Beschreibung", "growMax": 2000, "listeners": { "render": Lino.quicktip_renderer("Description","(cal.Tasks.description) ") }, "name": "description", "selectOnFocus": true });
    var main_panel1581 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1565, { "autoHeight": true, "items": summary1571, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "items": user1572, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_4_panel1576, { "flex": 45, "items": description1580, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1581;
    this.before_row_edit = function(record) {
    }
    Lino.cal.Tasks.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Enrolments.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel courses-Enrolments",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 51,
  initComponent : function() {
    var request_date1585 = new Lino.DateField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Datum der Anfrage", "listeners": { "render": Lino.quicktip_renderer("Date of request","(courses.Enrolments.request_date) ") }, "name": "request_date", "selectOnFocus": true });
    var user1586 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(courses.Enrolments.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Enrolments/user" }) }) });
    var main_1_panel1587 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 39, "items": request_date1585, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 60, "items": user1586, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var course1590 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.courses.Activities.detail", "emptyText": "Aktivit\u00e4t ausw\u00e4hlen...", "fieldLabel": "Aktivit\u00e4t", "hiddenName": "courseHidden", "insert_action": "Lino.courses.Activities.insert", "listeners": { "render": Lino.quicktip_renderer("Activity","(courses.Enrolments.course) ") }, "name": "course", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Activities.detail,Lino.courses.Activities.insert)}, "pageSize": 20, "related_actor_id": "courses.Activities", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Enrolments/course" }) }) });
    var pupil1591 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "can_create_choice": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Teilnehmer", "forceSelection": false, "hiddenName": "pupilHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Participant","(courses.Enrolments.pupil) ") }, "name": "pupil", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Enrolments/pupil" }) }) });
    var main_2_panel1592 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": course1590, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": pupil1591, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var remark1595 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(courses.Enrolments.remark) ") }, "maxLength": 200, "name": "remark", "selectOnFocus": true });
    var main_panel1596 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1587, main_2_panel1592, { "anchor": "-20", "autoHeight": true, "items": remark1595, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1596;
    this.before_row_edit = function(record) {
      course1590.setContextValue('course_area', record ? record.data['course_areaHidden'] : undefined);
      course1590.setContextValue('request_date', record ? record.data['request_date'] : undefined);
      pupil1591.setContextValue('course', record ? record.data['courseHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof request_date1585 !== 'undefined' && request_date1585.on('change',Lino.chooser_handler(course1590,'request_date'));
      typeof course1590 !== 'undefined' && course1590.on('change',Lino.chooser_handler(pupil1591,'course'));
      Lino.courses.Enrolments.InsertFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.courses.Enrolments.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Activities.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel courses-Activities",
  layout: 'fit',
  auto_save: true,
  content_type: 50,
  initComponent : function() {
    var line806 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.courses.Lines.detail", "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "fieldLabel": "Aktivit\u00e4tenreihe", "hiddenName": "lineHidden", "insert_action": "Lino.courses.Lines.insert", "listeners": { "render": Lino.quicktip_renderer("Activity line","(courses.Activities.line) ") }, "name": "line", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Lines.detail,Lino.courses.Lines.insert)}, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/line" }) }) });
    var teacher807 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Kursleiter", "hiddenName": "teacherHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Instructor","(courses.Activities.teacher) ") }, "name": "teacher", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/teacher" }) }) });
    var start_date808 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beginnt am</span>", "listeners": { "render": Lino.quicktip_renderer("Start date","(courses.Activities.start_date) The start date of the first meeting to be generated.") }, "name": "start_date", "selectOnFocus": true });
    var start_time809 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("Start time","(courses.Activities.start_time) ") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "start_time", "selectOnFocus": true });
    var end_time810 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Endet um", "listeners": { "render": Lino.quicktip_renderer("End Time","(courses.Activities.end_time) ") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "end_time", "selectOnFocus": true });
    var end_date811 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Enddatum</span>", "listeners": { "render": Lino.quicktip_renderer("End Date","(courses.Activities.end_date) The end date of the first meeting to be generated.  Leave\nthis field empty if the meetings last less than one day.") }, "name": "end_date", "selectOnFocus": true });
    var general_1_panel812 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 24, "items": line806, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 24, "items": teacher807, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 15, "items": start_date808, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 9, "items": start_time809, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 9, "items": end_time810, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 15, "items": end_date811, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var room819 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(courses.Activities.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/room" }) }) });
    var workflow_buttons_disp820 = new Ext.form.DisplayField({ "always_enabled": true, "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Workflow</span>", "listeners": { "render": Lino.quicktip_renderer("Workflow","(courses.Activities.workflow_buttons) List of actions that change the workflow state of this object.") }, "name": "workflow_buttons", "value": "<br/>" });
    var id821 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(courses.Activities.id) ") }, "name": "id", "selectOnFocus": true });
    var user822 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(courses.Activities.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/user" }) }) });
    var general_2_panel823 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 25, "items": room819, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 38, "items": workflow_buttons_disp820, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 10, "items": id821, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": user822, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var name828 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(courses.Activities.name) ") }, "maxLength": 100, "name": "name", "selectOnFocus": true });
    var description829 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung", "flex": 33, "name": "description", "selectOnFocus": true, "title": "Beschreibung" });
    var description_de830 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung (de)", "flex": 33, "name": "description_de", "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr831 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung (fr)", "flex": 33, "name": "description_fr", "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var general_4_panel832 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 50, "frame": false, "hideCheckBoxLabels": true, "items": [ description829, description_de830, description_fr831 ], "labelAlign": "top", "labelWidth": 162, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var general_panel833 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ general_1_panel812, general_2_panel823, { "autoHeight": true, "items": name828, "labelAlign": "top", "layout": "form", "xtype": "panel" }, general_4_panel832 ], "labelAlign": "top", "labelWidth": 0, "layout": "vbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Allgemein" });
    var max_events835 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Anzahl Termine</span>", "listeners": { "render": Lino.quicktip_renderer("Number of events","(courses.Activities.max_events) Maximum number of calendar entries to generate.") }, "name": "max_events", "selectOnFocus": true });
    var max_date836 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Termine generieren bis</span>", "listeners": { "render": Lino.quicktip_renderer("Generate events until","(courses.Activities.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "name": "max_date", "selectOnFocus": true });
    var every_unit837 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Wiederholung</span>", "forceSelection": true, "hiddenName": "every_unitHidden", "listeners": { "render": Lino.quicktip_renderer("Recurrency","(courses.Activities.every_unit) The interval between each periodic iteration.") }, "name": "every_unit", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every838 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">... alle</span>", "listeners": { "render": Lino.quicktip_renderer("Repeat every","(courses.Activities.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "name": "every", "selectOnFocus": true });
    var positions839 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Positionen</span>", "listeners": { "render": Lino.quicktip_renderer("Positions","(courses.Activities.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "maxLength": 50, "name": "positions", "selectOnFocus": true });
    var cal_tab_1_panel840 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 7, "items": max_events835, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": max_date836, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 32, "items": every_unit837, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 7, "items": every838, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 32, "items": positions839, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var monday846 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Montag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Monday","(courses.Activities.monday) ") }, "name": "monday", "selectOnFocus": true });
    var tuesday847 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Dienstag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Tuesday","(courses.Activities.tuesday) ") }, "name": "tuesday", "selectOnFocus": true });
    var wednesday848 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Mittwoch", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Wednesday","(courses.Activities.wednesday) ") }, "name": "wednesday", "selectOnFocus": true });
    var thursday849 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Donnerstag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Thursday","(courses.Activities.thursday) ") }, "name": "thursday", "selectOnFocus": true });
    var friday850 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Freitag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Friday","(courses.Activities.friday) ") }, "name": "friday", "selectOnFocus": true });
    var saturday851 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Samstag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Saturday","(courses.Activities.saturday) ") }, "name": "saturday", "selectOnFocus": true });
    var sunday852 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Sonntag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Sunday","(courses.Activities.sunday) ") }, "name": "sunday", "selectOnFocus": true });
    var cal_tab_2_panel853 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 14, "items": monday846, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": tuesday847, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": wednesday848, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": thursday849, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": friday850, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": saturday851, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": sunday852, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var cal_EntriesByController_htmlbox861 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 60, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Calendar entries","(courses.Activities.cal_EntriesByController) Shows the calendar entries controlled by this database object.") }, "master_panel": this, "name": "cal_EntriesByController", "title": "Kalendereintr\u00e4ge", "tools": [ Lino.show_in_own_window_button(Lino.cal.EntriesByController.grid) ], "value": "<br/>" });
    var cal_tab_panel862 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ cal_tab_1_panel840, cal_tab_2_panel853, cal_EntriesByController_htmlbox861 ], "labelAlign": "top", "labelWidth": 153, "layout": "vbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Kalender" });
    var enrolments_until863 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Einschreibung m\u00f6glich bis</span>", "listeners": { "render": Lino.quicktip_renderer("Enrolments until","(courses.Activities.enrolments_until) Until when new enrolments are accepted.") }, "name": "enrolments_until", "selectOnFocus": true });
    var max_places864 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verf\u00fcgbare Pl\u00e4tze</span>", "listeners": { "render": Lino.quicktip_renderer("Available places","(courses.Activities.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "name": "max_places", "selectOnFocus": true });
    var confirmed865 = new Ext.form.NumberField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Best\u00e4tigt</span>", "listeners": { "render": Lino.quicktip_renderer("Confirmed","(courses.Activities.confirmed) Number of confirmed places.") }, "name": "confirmed" });
    var free_places866 = new Ext.form.NumberField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Freie Pl\u00e4tze</span>", "listeners": { "render": Lino.quicktip_renderer("Free places","(courses.Activities.free_places) Number of free places.") }, "name": "free_places" });
    var print_actions_disp867 = new Ext.form.DisplayField({ "always_enabled": true, "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Drucken", "listeners": { "render": Lino.quicktip_renderer("Print","(courses.Activities.print_actions) ") }, "name": "print_actions", "value": "<br/>" });
    var enrolments_top_panel868 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 24, "items": enrolments_until863, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": max_places864, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 9, "items": confirmed865, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": free_places866, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 28, "items": print_actions_disp867, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var EnrolmentsByCourse_htmlbox874 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 50, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Enrolments","(courses.Activities.EnrolmentsByCourse) Show the enrolments of a this course.") }, "master_panel": this, "name": "EnrolmentsByCourse", "title": "Einschreibungen", "tools": [ Lino.show_in_own_window_button(Lino.courses.EnrolmentsByCourse.grid) ], "value": "<br/>" });
    var enrolments_panel875 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ enrolments_top_panel868, EnrolmentsByCourse_htmlbox874 ], "labelAlign": "top", "labelWidth": 144, "layout": "vbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Einschreibungen" });
    var main_panel876 = new Ext.TabPanel({ "activeTab": 0, "autoScroll": false, "bodyBorder": false, "border": false, "enableTabScroll": true, "frame": true, "hideCheckBoxLabels": true, "items": [ general_panel833, cal_tab_panel862, enrolments_panel875 ], "labelAlign": "top", "split": true });
    this.items = main_panel876;
    this.before_row_edit = function(record) {
      description829.refresh();
      description_de830.refresh();
      description_fr831.refresh();
      cal_EntriesByController_htmlbox861.refresh();
      EnrolmentsByCourse_htmlbox874.refresh();
    }
    Lino.courses.Activities.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Activities.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel courses-Activities",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 50,
  initComponent : function() {
    var line877 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.courses.Lines.detail", "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "fieldLabel": "Aktivit\u00e4tenreihe", "hiddenName": "lineHidden", "insert_action": "Lino.courses.Lines.insert", "listeners": { "render": Lino.quicktip_renderer("Activity line","(courses.Activities.line) ") }, "name": "line", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Lines.detail,Lino.courses.Lines.insert)}, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/line" }) }) });
    var teacher878 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Kursleiter", "hiddenName": "teacherHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Instructor","(courses.Activities.teacher) ") }, "name": "teacher", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/teacher" }) }) });
    var main_1_panel879 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": line877, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": teacher878, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var name882 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(courses.Activities.name) ") }, "maxLength": 100, "name": "name", "selectOnFocus": true });
    var start_date883 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beginnt am</span>", "listeners": { "render": Lino.quicktip_renderer("Start date","(courses.Activities.start_date) The start date of the first meeting to be generated.") }, "name": "start_date", "selectOnFocus": true });
    var main_2_panel884 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 61, "items": name882, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 38, "items": start_date883, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel887 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel879, main_2_panel884 ], "labelAlign": "top", "layout": "form" });
    this.items = main_panel887;
    this.before_row_edit = function(record) {
    }
    Lino.courses.Activities.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Enrolments.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel courses-Enrolments",
  layout: 'fit',
  auto_save: true,
  content_type: 51,
  initComponent : function() {
    var request_date1598 = new Lino.DateField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Datum der Anfrage", "listeners": { "render": Lino.quicktip_renderer("Date of request","(courses.Enrolments.request_date) ") }, "name": "request_date", "selectOnFocus": true });
    var user1599 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(courses.Enrolments.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Enrolments/user" }) }) });
    var start_date1600 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("Start date","(courses.Enrolments.start_date) ") }, "name": "start_date", "selectOnFocus": true });
    var end_date1601 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Enddatum", "listeners": { "render": Lino.quicktip_renderer("End date","(courses.Enrolments.end_date) ") }, "name": "end_date", "selectOnFocus": true });
    var main_1_panel1602 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 24, "items": request_date1598, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 37, "items": user1599, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": start_date1600, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 18, "items": end_date1601, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var course1607 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.courses.Activities.detail", "emptyText": "Aktivit\u00e4t ausw\u00e4hlen...", "fieldLabel": "Aktivit\u00e4t", "hiddenName": "courseHidden", "insert_action": "Lino.courses.Activities.insert", "listeners": { "render": Lino.quicktip_renderer("Activity","(courses.Enrolments.course) ") }, "name": "course", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Activities.detail,Lino.courses.Activities.insert)}, "pageSize": 20, "related_actor_id": "courses.Activities", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Enrolments/course" }) }) });
    var pupil1608 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "can_create_choice": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Teilnehmer", "forceSelection": false, "hiddenName": "pupilHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Participant","(courses.Enrolments.pupil) ") }, "name": "pupil", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Enrolments/pupil" }) }) });
    var main_2_panel1609 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": course1607, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": pupil1608, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var remark1612 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(courses.Enrolments.remark) ") }, "maxLength": 200, "name": "remark", "selectOnFocus": true });
    var workflow_buttons_disp1613 = new Ext.form.DisplayField({ "always_enabled": true, "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Workflow</span>", "listeners": { "render": Lino.quicktip_renderer("Workflow","(courses.Enrolments.workflow_buttons) List of actions that change the workflow state of this object.") }, "name": "workflow_buttons", "value": "<br/>" });
    var main_3_panel1614 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 41, "items": remark1612, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 58, "items": workflow_buttons_disp1613, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var confirmation_details1617 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Details Best\u00e4tigung", "flex": 50, "name": "confirmation_details", "selectOnFocus": true, "title": "Details Best\u00e4tigung" });
    var main_panel1618 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1602, main_2_panel1609, main_3_panel1614, confirmation_details1617 ], "labelAlign": "top", "labelWidth": 180, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1618;
    this.before_row_edit = function(record) {
      course1607.setContextValue('course_area', record ? record.data['course_areaHidden'] : undefined);
      course1607.setContextValue('request_date', record ? record.data['request_date'] : undefined);
      pupil1608.setContextValue('course', record ? record.data['courseHidden'] : undefined);
      confirmation_details1617.refresh();
    }
    this.onRender = function(ct, position) {
      typeof request_date1598 !== 'undefined' && request_date1598.on('change',Lino.chooser_handler(course1607,'request_date'));
      typeof course1607 !== 'undefined' && course1607.on('change',Lino.chooser_handler(pupil1608,'course'));
      Lino.courses.Enrolments.DetailFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.courses.Enrolments.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.MonthlyView.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel calview-MonthlyView",
  layout: 'fit',
  auto_save: true,
  disable_editing: true,
  initComponent : function() {
    var navigation_panel_htmlbox1619 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 15, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer(null,"(calview.MonthlyView.navigation_panel) ") }, "name": "navigation_panel", "value": "<br/>" });
    var calview_MonthlySlave_grid1629 = new Lino.calview.MonthlySlave.GridPanel({ "containing_panel": this, "flex": 85, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer(null,"(calview.calview.MonthlySlave) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 0 });
    var body_panel1630 = new Ext.Panel({ "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ navigation_panel_htmlbox1619, calview_MonthlySlave_grid1629 ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "region": "center" });
    var main_panel1631 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ body_panel1630 ], "labelAlign": "top", "layout": "fit" });
    this.items = main_panel1631;
    this.before_row_edit = function(record) {
      navigation_panel_htmlbox1619.refresh();
      calview_MonthlySlave_grid1629.on_master_changed();
    }
    Lino.calview.MonthlyView.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Persons.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel contacts-Persons",
  layout: 'fit',
  auto_save: true,
  content_type: 10,
  initComponent : function() {
    var navigation_panel_htmlbox1632 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 25, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer(null,"(contacts.Persons.navigation_panel) ") }, "name": "navigation_panel", "value": "<br/>" });
    var overview_htmlbox1633 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 45, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer(null,"(contacts.Persons.overview) ") }, "name": "overview", "value": "<br/>" });
    var last_name1634 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Familienname</span>", "listeners": { "render": Lino.quicktip_renderer("Last name","(contacts.Persons.last_name) The last name, also known as family name.") }, "maxLength": 200, "name": "last_name", "selectOnFocus": true });
    var first_name1635 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Vorname</span>", "listeners": { "render": Lino.quicktip_renderer("First name","(contacts.Persons.first_name) The first name, also known as given name.") }, "maxLength": 200, "name": "first_name", "selectOnFocus": true });
    var contact_box_1_panel1636 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 58, "items": last_name1634, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 41, "items": first_name1635, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var gender1639 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Geschlecht</span>", "forceSelection": true, "hiddenName": "genderHidden", "listeners": { "render": Lino.quicktip_renderer("Gender","(contacts.Persons.gender) The sex of this person (male or female).") }, "name": "gender", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.Genders) });
    var language1640 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Sprache</span>", "hiddenName": "languageHidden", "listeners": { "render": Lino.quicktip_renderer("Language","(contacts.Persons.language) The language to use when communicating with this partner.") }, "name": "language", "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var contact_box_2_panel1641 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 47, "items": gender1639, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 52, "items": language1640, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var birth_date1644 = new Lino.IncompleteDateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Geburtsdatum</span>", "listeners": { "render": Lino.quicktip_renderer("Birth date","(contacts.Persons.birth_date) Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".") }, "name": "birth_date", "selectOnFocus": true });
    var age_disp1645 = new Ext.form.DisplayField({ "always_enabled": true, "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Alter</span>", "listeners": { "render": Lino.quicktip_renderer("Age","(contacts.Persons.age) Virtual field displaying the age in years.") }, "name": "age", "value": "<br/>" });
    var id1646 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(contacts.Persons.id) ") }, "name": "id", "selectOnFocus": true });
    var contact_box_3_panel1647 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 42, "items": birth_date1644, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 35, "items": age_disp1645, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": id1646, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var contact_box_panel1651 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "flex": 54, "frame": true, "hideCheckBoxLabels": true, "items": [ contact_box_1_panel1636, contact_box_2_panel1641, contact_box_3_panel1647 ], "labelAlign": "top", "layout": "form" });
    var general_box_1_panel1652 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ overview_htmlbox1633, contact_box_panel1651 ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var contacts_RolesByPerson_grid1660 = new Lino.contacts.RolesByPerson.GridPanel({ "containing_panel": this, "flex": 33, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Contact for","(contacts.contacts.RolesByPerson) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.contacts.RolesByPerson.grid) ] });
    var lists_MembersByPartner_htmlbox1661 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 33, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("List memberships","(contacts.Persons.lists_MembersByPartner) ") }, "master_panel": this, "name": "lists_MembersByPartner", "title": "Listenmitgliedschaften", "tools": [ Lino.show_in_own_window_button(Lino.lists.MembersByPartner.grid) ], "value": "<br/>" });
    var cal_EntriesByGuest_htmlbox1662 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 33, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Calendar entries","(contacts.Persons.cal_EntriesByGuest) Show the calendar entries having this partner as a guest.") }, "master_panel": this, "name": "cal_EntriesByGuest", "title": "Kalendereintr\u00e4ge", "tools": [ Lino.show_in_own_window_button(Lino.cal.EntriesByGuest.grid) ], "value": "<br/>" });
    var general_box_2_panel1663 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 50, "frame": false, "hideCheckBoxLabels": true, "items": [ contacts_RolesByPerson_grid1660, lists_MembersByPartner_htmlbox1661, cal_EntriesByGuest_htmlbox1662 ], "labelAlign": "top", "labelWidth": 207, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var general_box_panel1664 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "flex": 75, "frame": true, "hideCheckBoxLabels": true, "items": [ general_box_1_panel1652, general_box_2_panel1663 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    var general_panel1665 = new Ext.Panel({ "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ navigation_panel_htmlbox1632, general_box_panel1664 ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Allgemein" });
    var humanlinks_LinksByHuman_htmlbox1666 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 62, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Human Links","(contacts.Persons.humanlinks_LinksByHuman) Show all links for which this human is either parent or child.") }, "master_panel": this, "name": "humanlinks_LinksByHuman", "title": "Beziehungen", "tools": [ Lino.show_in_own_window_button(Lino.humanlinks.LinksByHuman.grid) ], "value": "<br/>" });
    var households_MembersByPerson_htmlbox1667 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 37, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Household memberships","(contacts.Persons.households_MembersByPerson) ") }, "master_panel": this, "name": "households_MembersByPerson", "title": "Mitgliedschaft in Haushalten", "tools": [ Lino.show_in_own_window_button(Lino.households.MembersByPerson.grid) ], "value": "<br/>" });
    var family_1_panel1668 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 3, "frame": false, "hideCheckBoxLabels": true, "items": [ humanlinks_LinksByHuman_htmlbox1666, households_MembersByPerson_htmlbox1667 ], "labelAlign": "top", "labelWidth": 261, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "region": "north", "split": true });
    var households_SiblingsByPerson_grid1685 = new Lino.households.SiblingsByPerson.GridPanel({ "containing_panel": this, "flex": 5, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Household composition","(households.households.SiblingsByPerson) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "region": "center", "split": true, "tools": [ Lino.show_in_own_window_button(Lino.households.SiblingsByPerson.grid) ] });
    var family_panel1686 = new Lino.VBorderPanel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ family_1_panel1668, households_SiblingsByPerson_grid1685 ], "labelAlign": "top", "listeners": { "activate": Lino.on_tab_activate }, "title": "Familie" });
    var remarks1687 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Bemerkungen", "flex": 5, "name": "remarks", "region": "north", "selectOnFocus": true, "split": true, "title": "Bemerkungen" });
    var checkdata_ProblemsByOwner_htmlbox1688 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 40, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Data problems","(contacts.Persons.checkdata_ProblemsByOwner) The base table for problem messages.") }, "master_panel": this, "name": "checkdata_ProblemsByOwner", "title": "Datenprobleme", "tools": [ Lino.show_in_own_window_button(Lino.checkdata.ProblemsByOwner.grid) ], "value": "<br/>" });
    var sepa_AccountsByPartner_grid1689 = new Lino.sepa.AccountsByPartner.GridPanel({ "containing_panel": this, "flex": 60, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Bank accounts","(sepa.sepa.AccountsByPartner) Show the bank account(s) defined for a given partner. To be\nincluded to a detail window on partner.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.sepa.AccountsByPartner.grid) ] });
    var more_left_2_panel1690 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 5, "frame": false, "hideCheckBoxLabels": true, "items": [ checkdata_ProblemsByOwner_htmlbox1688, sepa_AccountsByPartner_grid1689 ], "labelAlign": "top", "labelWidth": 126, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "region": "center", "split": true });
    var uploads_UploadsByController_htmlbox1691 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 3, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Upload files","(contacts.Persons.uploads_UploadsByController) Shows the uploads controlled by this database object.") }, "master_panel": this, "name": "uploads_UploadsByController", "region": "south", "split": true, "title": "Upload-Dateien", "tools": [ Lino.show_in_own_window_button(Lino.uploads.UploadsByController.grid) ], "value": "<br/>" });
    var more_left_panel1692 = new Lino.VBorderPanel({ "autoScroll": false, "bodyBorder": false, "border": false, "flex": 66, "frame": true, "hideCheckBoxLabels": true, "items": [ remarks1687, more_left_2_panel1690, uploads_UploadsByController_htmlbox1691 ], "labelAlign": "top", "labelWidth": 135 });
    var comments_CommentsByRFC_htmlbox1693 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 33, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Comments","(contacts.Persons.comments_CommentsByRFC) Shows the comments for a given database object.") }, "master_panel": this, "name": "comments_CommentsByRFC", "title": "Kommentare", "tools": [ Lino.show_in_own_window_button(Lino.comments.CommentsByRFC.grid) ], "value": "<br/>" });
    var more_1_panel1694 = new Ext.Panel({ "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ more_left_panel1692, comments_CommentsByRFC_htmlbox1693 ], "labelAlign": "top", "labelWidth": 99, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Mehr" });
    var main_panel1695 = new Ext.TabPanel({ "activeTab": 0, "autoScroll": false, "bodyBorder": false, "border": false, "enableTabScroll": true, "frame": true, "hideCheckBoxLabels": true, "items": [ general_panel1665, family_panel1686, more_1_panel1694 ], "labelAlign": "top", "split": true });
    this.items = main_panel1695;
    this.before_row_edit = function(record) {
      navigation_panel_htmlbox1632.refresh();
      overview_htmlbox1633.refresh();
      contacts_RolesByPerson_grid1660.on_master_changed();
      lists_MembersByPartner_htmlbox1661.refresh();
      cal_EntriesByGuest_htmlbox1662.refresh();
      humanlinks_LinksByHuman_htmlbox1666.refresh();
      households_MembersByPerson_htmlbox1667.refresh();
      households_SiblingsByPerson_grid1685.on_master_changed();
      remarks1687.refresh();
      checkdata_ProblemsByOwner_htmlbox1688.refresh();
      sepa_AccountsByPartner_grid1689.on_master_changed();
      uploads_UploadsByController_htmlbox1691.refresh();
      comments_CommentsByRFC_htmlbox1693.refresh();
    }
    Lino.contacts.Persons.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.contacts.Persons.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel contacts-Persons",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 10,
  initComponent : function() {
    var first_name1696 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Vorname</span>", "listeners": { "render": Lino.quicktip_renderer("First name","(contacts.Persons.first_name) The first name, also known as given name.") }, "maxLength": 200, "name": "first_name", "selectOnFocus": true });
    var last_name1697 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Familienname</span>", "listeners": { "render": Lino.quicktip_renderer("Last name","(contacts.Persons.last_name) The last name, also known as family name.") }, "maxLength": 200, "name": "last_name", "selectOnFocus": true });
    var main_1_panel1698 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": first_name1696, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": last_name1697, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var gender1701 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Geschlecht</span>", "forceSelection": true, "hiddenName": "genderHidden", "listeners": { "render": Lino.quicktip_renderer("Gender","(contacts.Persons.gender) The sex of this person (male or female).") }, "name": "gender", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.Genders) });
    var country1702 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.countries.Countries.detail", "emptyText": "Land ausw\u00e4hlen...", "fieldLabel": "Land", "hiddenName": "countryHidden", "insert_action": "Lino.countries.Countries.insert", "listeners": { "render": Lino.quicktip_renderer("Country","(contacts.Persons.country) ") }, "name": "country", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.countries.Countries.detail,Lino.countries.Countries.insert)}, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Persons/country" }) }) });
    var language1703 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Sprache</span>", "hiddenName": "languageHidden", "listeners": { "render": Lino.quicktip_renderer("Language","(contacts.Persons.language) The language to use when communicating with this partner.") }, "name": "language", "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var main_2_panel1704 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 18, "items": gender1701, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 40, "items": country1702, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 40, "items": language1703, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var email1708 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">E-Mail-Adresse</span>", "listeners": { "render": Lino.quicktip_renderer("e-mail address","(contacts.Persons.email) The primary email address.") }, "maxLength": 254, "name": "email", "selectOnFocus": true });
    var gsm1709 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">GSM</span>", "listeners": { "render": Lino.quicktip_renderer("GSM","(contacts.Persons.gsm) The primary mobile phone number.") }, "maxLength": 200, "name": "gsm", "selectOnFocus": true });
    var main_panel1710 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1698, main_2_panel1704, { "anchor": "-20", "autoHeight": true, "items": email1708, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": gsm1709, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1710;
    this.before_row_edit = function(record) {
    }
    Lino.contacts.Persons.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.uploads.Uploads.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel uploads-Uploads",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 29,
  initComponent : function() {
    var file1713 = Lino.file_field_handler(this,{ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datei</span>", "listeners": { "render": Lino.quicktip_renderer("File","(uploads.Uploads.file) Pointer to the uploaded file itself (a Django FileField).") }, "maxLength": 100, "name": "file", "selectOnFocus": true });
    var user1714 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Hochgeladen durch</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Uploaded by","(uploads.Uploads.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/user" }) }) });
    var main_1_panel1715 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 51, "items": file1713, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 48, "items": user1714, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var volume1718 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.uploads.Volumes.detail", "emptyText": "Dateibibliothek ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Dateibibliothek</span>", "hiddenName": "volumeHidden", "insert_action": "Lino.uploads.Volumes.insert", "listeners": { "render": Lino.quicktip_renderer("Library volume","(uploads.Uploads.volume) A pointer to the library volume where this file is stored.") }, "name": "volume", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.uploads.Volumes.detail,Lino.uploads.Volumes.insert)}, "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/volume" }) }) });
    var library_file1719 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bibliotheksdatei</span>", "listeners": { "render": Lino.quicktip_renderer("Library file","(uploads.Uploads.library_file) The path of this file, relative the volume's root.") }, "name": "library_file", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/library_file" }) }) });
    var main_2_panel1720 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 20, "items": volume1718, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 80, "items": library_file1719, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var upload_area1723 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Upload-Bereich</span>", "forceSelection": true, "hiddenName": "upload_areaHidden", "listeners": { "render": Lino.quicktip_renderer("Upload area","(uploads.Uploads.upload_area) The upload area this file belongs to.") }, "name": "upload_area", "selectOnFocus": true, "store": Lino.uploads.UploadAreas });
    var type1724 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.uploads.UploadTypes.detail", "emptyText": "Upload-Art ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Upload-Art</span>", "hiddenName": "typeHidden", "insert_action": "Lino.uploads.UploadTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Upload type","(uploads.Uploads.type) The type of this upload.") }, "name": "type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.uploads.UploadTypes.detail,Lino.uploads.UploadTypes.insert)}, "pageSize": 20, "related_actor_id": "uploads.UploadTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/type" }) }) });
    var description1725 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beschreibung</span>", "listeners": { "render": Lino.quicktip_renderer("Description","(uploads.Uploads.description) A short description entered manually by the user.") }, "maxLength": 200, "name": "description", "selectOnFocus": true });
    var main_3_panel1726 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 19, "items": upload_area1723, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 39, "items": type1724, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 41, "items": description1725, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var owner_disp1730 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Verkn\u00fcpft mit", "name": "owner" });
    var main_panel1731 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1715, main_2_panel1720, main_3_panel1726, { "anchor": "-20", "autoHeight": true, "items": owner_disp1730, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1731;
    this.before_row_edit = function(record) {
      library_file1719.setContextValue('volume', record ? record.data['volumeHidden'] : undefined);
      type1724.setContextValue('upload_area', record ? record.data['upload_areaHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof volume1718 !== 'undefined' && volume1718.on('change',Lino.chooser_handler(library_file1719,'volume'));
      typeof upload_area1723 !== 'undefined' && upload_area1723.on('change',Lino.chooser_handler(type1724,'upload_area'));
      Lino.uploads.Uploads.DetailFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.uploads.Uploads.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.GuestRoles.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel cal-GuestRoles",
  layout: 'fit',
  auto_save: true,
  content_type: 18,
  initComponent : function() {
    var ref1733 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(cal.GuestRoles.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var name1734 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(cal.GuestRoles.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1735 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(cal.GuestRoles.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1736 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(cal.GuestRoles.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var id1737 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(cal.GuestRoles.id) ") }, "name": "id", "selectOnFocus": true });
    var main_1_panel1738 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 5, "items": ref1733, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 29, "items": name1734, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 29, "items": name_de1735, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 29, "items": name_fr1736, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 6, "items": id1737, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var cal_GuestsByRole_grid1752 = new Lino.cal.GuestsByRole.GridPanel({ "containing_panel": this, "flex": 83, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Presences","(cal.cal.GuestsByRole) The default table of presences.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.cal.GuestsByRole.grid) ] });
    var main_panel1753 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1738, cal_GuestsByRole_grid1752 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1753;
    this.before_row_edit = function(record) {
      cal_GuestsByRole_grid1752.on_master_changed();
    }
    Lino.cal.GuestRoles.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.Lines.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel courses-Lines",
  layout: 'fit',
  auto_save: true,
  content_type: 49,
  initComponent : function() {
    var name980 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(courses.Lines.name) The designation of this activity line as seen by the user\ne.g. when selecting the line.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de981 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(courses.Lines.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr982 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(courses.Lines.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel983 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name980, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de981, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr982, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var ref987 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(courses.Lines.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var topic988 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.courses.Topics.detail", "emptyText": "Thema ausw\u00e4hlen...", "fieldLabel": "Thema", "hiddenName": "topicHidden", "listeners": { "render": Lino.quicktip_renderer("Topic","(courses.Lines.topic) ") }, "name": "topic", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Topics.detail,null)}, "pageSize": 20, "related_actor_id": "courses.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/topic" }) }) });
    var main_2_panel989 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 66, "items": ref987, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": topic988, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var every_unit992 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Wiederholung", "forceSelection": true, "hiddenName": "every_unitHidden", "listeners": { "render": Lino.quicktip_renderer("Recurrency","(courses.Lines.every_unit) ") }, "name": "every_unit", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every993 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "... alle", "listeners": { "render": Lino.quicktip_renderer("Repeat every","(courses.Lines.every) ") }, "name": "every", "selectOnFocus": true, "value": 1 });
    var event_type994 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(courses.Lines.event_type) The type of calendar entries to be generated. If this is empty, no calendar entries will be generated.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/event_type" }) }) });
    var main_3_panel995 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 45, "items": every_unit992, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 10, "items": every993, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 43, "items": event_type994, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var description999 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung", "flex": 33, "name": "description", "selectOnFocus": true, "title": "Beschreibung" });
    var description_de1000 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung (de)", "flex": 33, "name": "description_de", "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr1001 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung (fr)", "flex": 33, "name": "description_fr", "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var main_4_panel1002 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 62, "frame": false, "hideCheckBoxLabels": true, "items": [ description999, description_de1000, description_fr1001 ], "labelAlign": "top", "labelWidth": 162, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var main_panel1003 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel983, main_2_panel989, main_3_panel995, main_4_panel1002 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1003;
    this.before_row_edit = function(record) {
      description999.refresh();
      description_de1000.refresh();
      description_fr1001.refresh();
    }
    Lino.courses.Lines.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Guests.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel cal-Guests",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 25,
  initComponent : function() {
    var event1429 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.OneEvent.detail", "emptyText": "Kalendereintrag ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintrag</span>", "hiddenName": "eventHidden", "insert_action": "Lino.cal.OneEvent.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry","(cal.Guests.event) The calendar event to which this presence applies.") }, "name": "event", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.OneEvent.detail,Lino.cal.OneEvent.insert)}, "pageSize": 20, "related_actor_id": "cal.OneEvent", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/event" }) }) });
    var partner1430 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "can_create_choice": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Person</span>", "forceSelection": false, "hiddenName": "partnerHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Person","(cal.Guests.partner) The partner to which this presence applies.") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/partner" }) }) });
    var role1431 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.GuestRoles.detail", "emptyText": "Gastrolle ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Rolle</span>", "hiddenName": "roleHidden", "listeners": { "render": Lino.quicktip_renderer("Role","(cal.Guests.role) The role of this partner in this presence.") }, "name": "role", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.GuestRoles.detail,null)}, "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/role" }) }) });
    var main_1_panel1432 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": event1429, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": partner1430, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": role1431, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var state1436 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zustand</span>", "forceSelection": true, "hiddenName": "stateHidden", "listeners": { "render": Lino.quicktip_renderer("State","(cal.Guests.state) The state of this presence.  See GuestStates.") }, "name": "state", "selectOnFocus": true, "store": Lino.cal.GuestStates });
    var workflow_buttons_disp1437 = new Ext.form.DisplayField({ "always_enabled": true, "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Workflow</span>", "listeners": { "render": Lino.quicktip_renderer("Workflow","(cal.Guests.workflow_buttons) List of actions that change the workflow state of this object.") }, "name": "workflow_buttons", "value": "<br/>" });
    var main_2_panel1438 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 25, "items": state1436, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 75, "items": workflow_buttons_disp1437, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var remark1441 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(cal.Guests.remark) ") }, "maxLength": 200, "name": "remark", "selectOnFocus": true });
    var main_panel1442 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1432, main_2_panel1438, { "anchor": "-20", "autoHeight": true, "items": remark1441, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1442;
    this.before_row_edit = function(record) {
    }
    Lino.cal.Guests.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.RecurrentEvents.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel cal-RecurrentEvents",
  layout: 'fit',
  auto_save: true,
  content_type: 23,
  initComponent : function() {
    var name1754 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(cal.RecurrentEvents.name) See lino.utils.mldbc.mixins.BabelNamed.name.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1755 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(cal.RecurrentEvents.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1756 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(cal.RecurrentEvents.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel1757 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name1754, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de1755, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr1756, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var id1761 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(cal.RecurrentEvents.id) ") }, "name": "id", "selectOnFocus": true });
    var user1762 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(cal.RecurrentEvents.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/RecurrentEvents/user" }) }) });
    var event_type1763 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "Kalendereintragsart", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(cal.RecurrentEvents.event_type) ") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/RecurrentEvents/event_type" }) }) });
    var main_2_panel1764 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 11, "items": id1761, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 44, "items": user1762, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 44, "items": event_type1763, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var start_date1768 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beginnt am</span>", "listeners": { "render": Lino.quicktip_renderer("Start date","(cal.RecurrentEvents.start_date) The start date of the first meeting to be generated.") }, "name": "start_date", "selectOnFocus": true });
    var start_time1769 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("Start time","(cal.RecurrentEvents.start_time) ") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "start_time", "selectOnFocus": true });
    var end_date1770 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Enddatum</span>", "listeners": { "render": Lino.quicktip_renderer("End Date","(cal.RecurrentEvents.end_date) The end date of the first meeting to be generated.  Leave\nthis field empty if the meetings last less than one day.") }, "name": "end_date", "selectOnFocus": true });
    var end_time1771 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Endet um", "listeners": { "render": Lino.quicktip_renderer("End Time","(cal.RecurrentEvents.end_time) ") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "end_time", "selectOnFocus": true });
    var main_3_panel1772 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 30, "items": start_date1768, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": start_time1769, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": end_date1770, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": end_time1771, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var every_unit1777 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Wiederholung</span>", "forceSelection": true, "hiddenName": "every_unitHidden", "listeners": { "render": Lino.quicktip_renderer("Recurrency","(cal.RecurrentEvents.every_unit) Inherited from RecurrentSet.every_unit.") }, "name": "every_unit", "selectOnFocus": true, "store": Lino.cal.Recurrencies });
    var every1778 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">... alle</span>", "listeners": { "render": Lino.quicktip_renderer("Repeat every","(cal.RecurrentEvents.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "name": "every", "selectOnFocus": true, "value": 1 });
    var positions1779 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Positionen</span>", "listeners": { "render": Lino.quicktip_renderer("Positions","(cal.RecurrentEvents.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "maxLength": 50, "name": "positions", "selectOnFocus": true });
    var max_events1780 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Anzahl Termine</span>", "listeners": { "render": Lino.quicktip_renderer("Number of events","(cal.RecurrentEvents.max_events) Maximum number of calendar entries to generate.") }, "name": "max_events", "selectOnFocus": true });
    var main_4_panel1781 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 40, "items": every_unit1777, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 9, "items": every1778, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 40, "items": positions1779, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 9, "items": max_events1780, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var monday1786 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Montag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Monday","(cal.RecurrentEvents.monday) ") }, "name": "monday", "selectOnFocus": true });
    var tuesday1787 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Dienstag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Tuesday","(cal.RecurrentEvents.tuesday) ") }, "name": "tuesday", "selectOnFocus": true });
    var wednesday1788 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Mittwoch", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Wednesday","(cal.RecurrentEvents.wednesday) ") }, "name": "wednesday", "selectOnFocus": true });
    var thursday1789 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Donnerstag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Thursday","(cal.RecurrentEvents.thursday) ") }, "name": "thursday", "selectOnFocus": true });
    var friday1790 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Freitag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Friday","(cal.RecurrentEvents.friday) ") }, "name": "friday", "selectOnFocus": true });
    var saturday1791 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Samstag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Saturday","(cal.RecurrentEvents.saturday) ") }, "name": "saturday", "selectOnFocus": true });
    var sunday1792 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Sonntag", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Sunday","(cal.RecurrentEvents.sunday) ") }, "name": "sunday", "selectOnFocus": true });
    var main_5_panel1793 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 14, "items": monday1786, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": tuesday1787, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": wednesday1788, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": thursday1789, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": friday1790, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": saturday1791, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": sunday1792, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var description1801 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Beschreibung", "flex": 66, "name": "description", "selectOnFocus": true, "title": "Beschreibung" });
    var cal_EntriesByController_htmlbox1802 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 33, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Calendar entries","(cal.RecurrentEvents.cal_EntriesByController) Shows the calendar entries controlled by this database object.") }, "master_panel": this, "name": "cal_EntriesByController", "title": "Kalendereintr\u00e4ge", "tools": [ Lino.show_in_own_window_button(Lino.cal.EntriesByController.grid) ], "value": "<br/>" });
    var main_6_panel1803 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 50, "frame": false, "hideCheckBoxLabels": true, "items": [ description1801, cal_EntriesByController_htmlbox1802 ], "labelAlign": "top", "labelWidth": 153, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var main_panel1804 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1757, main_2_panel1764, main_3_panel1772, main_4_panel1781, main_5_panel1793, main_6_panel1803 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1804;
    this.before_row_edit = function(record) {
      description1801.refresh();
      cal_EntriesByController_htmlbox1802.refresh();
    }
    Lino.cal.RecurrentEvents.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.RecurrentEvents.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel cal-RecurrentEvents",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 23,
  initComponent : function() {
    var name1805 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(cal.RecurrentEvents.name) See lino.utils.mldbc.mixins.BabelNamed.name.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1806 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(cal.RecurrentEvents.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1807 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(cal.RecurrentEvents.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel1808 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name1805, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de1806, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr1807, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var start_date1812 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beginnt am</span>", "listeners": { "render": Lino.quicktip_renderer("Start date","(cal.RecurrentEvents.start_date) The start date of the first meeting to be generated.") }, "name": "start_date", "selectOnFocus": true });
    var end_date1813 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Enddatum</span>", "listeners": { "render": Lino.quicktip_renderer("End Date","(cal.RecurrentEvents.end_date) The end date of the first meeting to be generated.  Leave\nthis field empty if the meetings last less than one day.") }, "name": "end_date", "selectOnFocus": true });
    var every_unit1814 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Wiederholung</span>", "forceSelection": true, "hiddenName": "every_unitHidden", "listeners": { "render": Lino.quicktip_renderer("Recurrency","(cal.RecurrentEvents.every_unit) Inherited from RecurrentSet.every_unit.") }, "name": "every_unit", "selectOnFocus": true, "store": Lino.cal.Recurrencies });
    var event_type1815 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "Kalendereintragsart", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(cal.RecurrentEvents.event_type) ") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/RecurrentEvents/event_type" }) }) });
    var main_2_panel1816 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 19, "items": start_date1812, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": end_date1813, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 31, "items": every_unit1814, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 29, "items": event_type1815, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel1821 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1808, main_2_panel1816 ], "labelAlign": "top", "layout": "form" });
    this.items = main_panel1821;
    this.before_row_edit = function(record) {
    }
    Lino.cal.RecurrentEvents.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Events.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel cal-Events",
  layout: 'fit',
  auto_save: true,
  content_type: 24,
  initComponent : function() {
    var event_type1393 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(cal.Events.event_type) The type of this calendar entry.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/event_type" }) }) });
    var summary1394 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kurzbeschreibung</span>", "listeners": { "render": Lino.quicktip_renderer("Short description","(cal.Events.summary) A one-line descriptive text.") }, "maxLength": 200, "name": "summary", "selectOnFocus": true });
    var user1395 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible user","(cal.Events.user) The responsible user.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/user" }) }) });
    var main_1_panel1396 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 32, "items": event_type1393, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 34, "items": summary1394, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 32, "items": user1395, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var start_date1400 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beginnt am</span>", "listeners": { "render": Lino.quicktip_renderer("Start date","(cal.Events.start_date) The starting date of this entry.  May not be empty.") }, "name": "start_date", "selectOnFocus": true });
    var start_time1401 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beginnt um</span>", "listeners": { "render": Lino.quicktip_renderer("Start time","(cal.Events.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "start_time", "selectOnFocus": true });
    var start_panel1402 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "flex": 33, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 61, "items": start_date1400, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 38, "items": start_time1401, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var end_date1405 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Enddatum</span>", "listeners": { "render": Lino.quicktip_renderer("End Date","(cal.Events.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "name": "end_date", "selectOnFocus": true });
    var end_time1406 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Endet um</span>", "listeners": { "render": Lino.quicktip_renderer("End Time","(cal.Events.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "end_time", "selectOnFocus": true });
    var end_panel1407 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "flex": 33, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 61, "items": end_date1405, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 38, "items": end_time1406, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var assigned_to1410 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Zugewiesen zu</span>", "hiddenName": "assigned_toHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Assigned to","(cal.Events.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "name": "assigned_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/assigned_to" }) }) });
    var main_2_panel1411 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ start_panel1402, end_panel1407, { "autoHeight": true, "flex": 32, "items": assigned_to1410, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var room1413 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.Rooms.detail", "emptyText": "Raum ausw\u00e4hlen...", "fieldLabel": "Raum", "hiddenName": "roomHidden", "insert_action": "Lino.cal.Rooms.insert", "listeners": { "render": Lino.quicktip_renderer("Room","(cal.Events.room) ") }, "name": "room", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.Rooms.detail,Lino.cal.Rooms.insert)}, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/room" }) }) });
    var owner_disp1414 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Verkn\u00fcpft mit", "name": "owner" });
    var workflow_buttons_disp1415 = new Ext.form.DisplayField({ "always_enabled": true, "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Workflow</span>", "listeners": { "render": Lino.quicktip_renderer("Workflow","(cal.Events.workflow_buttons) List of actions that change the workflow state of this object.") }, "name": "workflow_buttons", "value": "<br/>" });
    var main_3_panel1416 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": room1413, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": owner_disp1414, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": workflow_buttons_disp1415, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var description1420 = new Ext.form.TextArea({ "allowBlank": true, "anchor": "-20 -10", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beschreibung</span>", "growMax": 2000, "listeners": { "render": Lino.quicktip_renderer("Description","(cal.Events.description) A longer descriptive text.") }, "name": "description", "selectOnFocus": true });
    var GuestsByEvent_grid1451 = new Lino.cal.GuestsByEvent.GridPanel({ "containing_panel": this, "flex": 66, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Presences","(cal.cal.GuestsByEvent) The default table of presences.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.cal.GuestsByEvent.grid) ] });
    var main_4_panel1452 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 50, "frame": false, "hideCheckBoxLabels": true, "items": [ { "flex": 33, "items": description1420, "labelAlign": "top", "layout": "form", "xtype": "panel" }, GuestsByEvent_grid1451 ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var main_panel1454 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1396, main_2_panel1411, main_3_panel1416, main_4_panel1452 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1454;
    this.before_row_edit = function(record) {
      GuestsByEvent_grid1451.on_master_changed();
    }
    Lino.cal.Events.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Events.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel cal-Events",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 24,
  initComponent : function() {
    var start_date1455 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beginnt am</span>", "listeners": { "render": Lino.quicktip_renderer("Start date","(cal.Events.start_date) The starting date of this entry.  May not be empty.") }, "name": "start_date", "selectOnFocus": true });
    var start_time1456 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beginnt um</span>", "listeners": { "render": Lino.quicktip_renderer("Start time","(cal.Events.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "start_time", "selectOnFocus": true });
    var end_date1457 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Enddatum</span>", "listeners": { "render": Lino.quicktip_renderer("End Date","(cal.Events.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "name": "end_date", "selectOnFocus": true });
    var end_time1458 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Endet um</span>", "listeners": { "render": Lino.quicktip_renderer("End Time","(cal.Events.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "end_time", "selectOnFocus": true });
    var main_1_panel1459 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 30, "items": start_date1455, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": start_time1456, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": end_date1457, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": end_time1458, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var summary1464 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kurzbeschreibung</span>", "listeners": { "render": Lino.quicktip_renderer("Short description","(cal.Events.summary) A one-line descriptive text.") }, "maxLength": 200, "name": "summary", "selectOnFocus": true });
    var main_panel1465 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1459, { "anchor": "-20", "autoHeight": true, "items": summary1464, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1465;
    this.before_row_edit = function(record) {
    }
    Lino.cal.Events.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Tasks.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel cal-Tasks",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 21,
  initComponent : function() {
    var summary1822 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("Short description","(cal.Tasks.summary) ") }, "maxLength": 200, "name": "summary", "selectOnFocus": true });
    var user1823 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(cal.Tasks.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Tasks/user" }) }) });
    var main_panel1824 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": summary1822, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": user1823, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1824;
    this.before_row_edit = function(record) {
    }
    Lino.cal.Tasks.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.uploads.Volumes.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel uploads-Volumes",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 27,
  initComponent : function() {
    var ref1827 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(uploads.Volumes.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var description1828 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("Description","(uploads.Volumes.description) ") }, "maxLength": 255, "name": "description", "selectOnFocus": true });
    var main_1_panel1829 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 65, "items": ref1827, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 34, "items": description1828, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var root_dir1832 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Root directory", "listeners": { "render": Lino.quicktip_renderer("Root directory","(uploads.Volumes.root_dir) ") }, "maxLength": 255, "name": "root_dir", "selectOnFocus": true });
    var base_url1833 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Base URL", "listeners": { "render": Lino.quicktip_renderer("Base URL","(uploads.Volumes.base_url) ") }, "maxLength": 255, "name": "base_url", "selectOnFocus": true });
    var main_panel1834 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1829, { "anchor": "-20", "autoHeight": true, "items": root_dir1832, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": base_url1833, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1834;
    this.before_row_edit = function(record) {
    }
    Lino.uploads.Volumes.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.households.MembersByPerson.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel households-MembersByPerson",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 44,
  initComponent : function() {
    var person1837 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Person", "hiddenName": "personHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Person","(households.MembersByPerson.person) ") }, "name": "person", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/MembersByPerson/person" }) }) });
    var role1838 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Rolle", "forceSelection": true, "hiddenName": "roleHidden", "listeners": { "render": Lino.quicktip_renderer("Role","(households.MembersByPerson.role) ") }, "name": "role", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.households.MemberRoles) });
    var household1839 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.households.Households.detail", "emptyText": "Haushalt ausw\u00e4hlen...", "fieldLabel": "Haushalt", "hiddenName": "householdHidden", "insert_action": "Lino.households.Households.insert", "listeners": { "render": Lino.quicktip_renderer("Household","(households.MembersByPerson.household) ") }, "name": "household", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.households.Households.detail,Lino.households.Households.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "households.Households", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/MembersByPerson/household" }) }) });
    var primary1840 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Prim\u00e4r", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Primary","(households.MembersByPerson.primary) Whether this is the primary household of this person.\nChecking this field will automatically disable any other primary memberships.") }, "name": "primary", "selectOnFocus": true });
    var main_panel1841 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": person1837, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": role1838, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": household1839, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": primary1840, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1841;
    this.before_row_edit = function(record) {
    }
    Lino.households.MembersByPerson.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.uploads.UploadTypes.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel uploads-UploadTypes",
  layout: 'fit',
  auto_save: true,
  content_type: 28,
  initComponent : function() {
    var id1846 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(uploads.UploadTypes.id) ") }, "name": "id", "selectOnFocus": true });
    var upload_area1847 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Upload-Bereich", "forceSelection": true, "hiddenName": "upload_areaHidden", "listeners": { "render": Lino.quicktip_renderer("Upload area","(uploads.UploadTypes.upload_area) ") }, "name": "upload_area", "selectOnFocus": true, "store": Lino.uploads.UploadAreas });
    var wanted1848 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Wanted", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Wanted","(uploads.UploadTypes.wanted) Add a (+) button when there is no upload of this type.") }, "name": "wanted", "selectOnFocus": true });
    var max_number1849 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Max. number</span>", "listeners": { "render": Lino.quicktip_renderer("Max. number","(uploads.UploadTypes.max_number) No need to upload more uploads than N of this type.\n-1 means no limit.") }, "name": "max_number", "selectOnFocus": true, "value": -1 });
    var shortcut1850 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Upload shortcut</span>", "listeners": { "render": Lino.quicktip_renderer("Upload shortcut","(uploads.UploadTypes.shortcut) Optional pointer to a virtual upload shortcut field.  If\nthis is not empty, then the given shortcut field will manage\nuploads of this type.  See also Shortcuts.") }, "maxLength": 50, "name": "shortcut", "selectOnFocus": true });
    var main_1_panel1851 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 9, "items": id1846, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": upload_area1847, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 19, "items": wanted1848, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 9, "items": max_number1849, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 41, "items": shortcut1850, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var name1857 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(uploads.UploadTypes.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1858 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(uploads.UploadTypes.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1859 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(uploads.UploadTypes.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_2_panel1860 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name1857, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de1858, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr1859, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var uploads_UploadsByType_grid1892 = new Lino.uploads.UploadsByType.GridPanel({ "containing_panel": this, "flex": 71, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Upload files","(uploads.uploads.UploadsByType) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.uploads.UploadsByType.grid) ] });
    var main_panel1893 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1851, main_2_panel1860, uploads_UploadsByType_grid1892 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1893;
    this.before_row_edit = function(record) {
      uploads_UploadsByType_grid1892.on_master_changed();
    }
    Lino.uploads.UploadTypes.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.uploads.UploadTypes.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel uploads-UploadTypes",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 28,
  initComponent : function() {
    var name1894 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(uploads.UploadTypes.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1895 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(uploads.UploadTypes.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1896 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(uploads.UploadTypes.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel1897 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name1894, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de1895, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr1896, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var upload_area1901 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Upload-Bereich", "forceSelection": true, "hiddenName": "upload_areaHidden", "listeners": { "render": Lino.quicktip_renderer("Upload area","(uploads.UploadTypes.upload_area) ") }, "name": "upload_area", "selectOnFocus": true, "store": Lino.uploads.UploadAreas });
    var main_panel1902 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1897, { "anchor": "-20", "autoHeight": true, "items": upload_area1901, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1902;
    this.before_row_edit = function(record) {
    }
    Lino.uploads.UploadTypes.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.uploads.Uploads.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel uploads-Uploads",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 29,
  initComponent : function() {
    var type1878 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.uploads.UploadTypes.detail", "emptyText": "Upload-Art ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Upload-Art</span>", "hiddenName": "typeHidden", "insert_action": "Lino.uploads.UploadTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Upload type","(uploads.Uploads.type) The type of this upload.") }, "name": "type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.uploads.UploadTypes.detail,Lino.uploads.UploadTypes.insert)}, "pageSize": 20, "related_actor_id": "uploads.UploadTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/type" }) }) });
    var description1879 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beschreibung</span>", "listeners": { "render": Lino.quicktip_renderer("Description","(uploads.Uploads.description) A short description entered manually by the user.") }, "maxLength": 200, "name": "description", "selectOnFocus": true });
    var file1880 = Lino.file_field_handler(this,{ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Datei</span>", "listeners": { "render": Lino.quicktip_renderer("File","(uploads.Uploads.file) Pointer to the uploaded file itself (a Django FileField).") }, "maxLength": 100, "name": "file", "selectOnFocus": true });
    var volume1881 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.uploads.Volumes.detail", "emptyText": "Dateibibliothek ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Dateibibliothek</span>", "hiddenName": "volumeHidden", "insert_action": "Lino.uploads.Volumes.insert", "listeners": { "render": Lino.quicktip_renderer("Library volume","(uploads.Uploads.volume) A pointer to the library volume where this file is stored.") }, "name": "volume", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.uploads.Volumes.detail,Lino.uploads.Volumes.insert)}, "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/volume" }) }) });
    var library_file1882 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bibliotheksdatei</span>", "listeners": { "render": Lino.quicktip_renderer("Library file","(uploads.Uploads.library_file) The path of this file, relative the volume's root.") }, "name": "library_file", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/library_file" }) }) });
    var main_4_panel1883 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 66, "items": volume1881, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": library_file1882, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var user1886 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Hochgeladen durch</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Uploaded by","(uploads.Uploads.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/user" }) }) });
    var main_panel1887 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": type1878, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": description1879, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": file1880, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_4_panel1883, { "anchor": "-20", "autoHeight": true, "items": user1886, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1887;
    this.before_row_edit = function(record) {
      type1878.setContextValue('upload_area', record ? record.data['upload_areaHidden'] : undefined);
      library_file1882.setContextValue('volume', record ? record.data['volumeHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof volume1881 !== 'undefined' && volume1881.on('change',Lino.chooser_handler(library_file1882,'volume'));
      Lino.uploads.Uploads.InsertFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.uploads.Uploads.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Accounts.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel ledger-Accounts",
  layout: 'fit',
  auto_save: true,
  content_type: 36,
  initComponent : function() {
    var ref1904 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(ledger.Accounts.ref) An optional unique name which can be used to reference a given\naccount.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var common_account1905 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Gemeinkonto", "forceSelection": true, "hiddenName": "common_accountHidden", "listeners": { "render": Lino.quicktip_renderer("Common account","(ledger.Accounts.common_account) ") }, "name": "common_account", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.ledger.CommonAccounts) });
    var id1906 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(ledger.Accounts.id) ") }, "name": "id", "selectOnFocus": true });
    var main_1_panel1907 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 11, "items": ref1904, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 74, "items": common_account1905, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": id1906, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var name1911 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(ledger.Accounts.name) The multilingual designation of this account, as the users see\nit.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1912 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(ledger.Accounts.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1913 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(ledger.Accounts.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_2_panel1914 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name1911, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de1912, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr1913, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var needs_partner1918 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Braucht Partner", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Needs partner","(ledger.Accounts.needs_partner) Whether bookings to this account need a partner specified.") }, "name": "needs_partner", "selectOnFocus": true });
    var clearable1919 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Auszugleichen", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Clearable","(ledger.Accounts.clearable) ") }, "name": "clearable", "selectOnFocus": true });
    var default_amount1920 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "decimalPrecision": 2, "decimalSeparator": ",", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Vorschlag Betrag</span>", "listeners": { "render": Lino.quicktip_renderer("Default amount","(ledger.Accounts.default_amount) The default amount to book in bank statements or journal\nentries when this account has been selected manually. The\ndefault booking direction is that of the type.") }, "name": "default_amount", "selectOnFocus": true });
    var main_3_panel1921 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 42, "items": needs_partner1918, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 42, "items": clearable1919, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": default_amount1920, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel1926 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1907, main_2_panel1914, main_3_panel1921 ], "labelAlign": "top", "labelWidth": 99, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1926;
    this.before_row_edit = function(record) {
    }
    Lino.ledger.Accounts.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.comments.Comments.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel comments-Comments",
  layout: 'fit',
  auto_save: true,
  content_type: 63,
  initComponent : function() {
    var reply_to1927 = new Lino.TwinCombo({ "allowBlank": true, "detail_action": "Lino.comments.Comments.detail", "emptyText": "Kommentar ausw\u00e4hlen...", "fieldLabel": "Antwort auf", "flex": 33, "hidden": true, "hiddenName": "reply_toHidden", "insert_action": "Lino.comments.Comments.insert", "listeners": { "render": Lino.quicktip_renderer("Reply to","(comments.Comments.reply_to) ") }, "name": "reply_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.comments.Comments.detail,Lino.comments.Comments.insert)}, "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/reply_to" }) }) });
    var owner_disp1928 = new Ext.form.DisplayField({ "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Thema</span>", "flex": 16, "hidden": true, "name": "owner" });
    var owner_type1929 = new Lino.TwinCombo({ "allowBlank": true, "detail_action": "Lino.gfks.ContentTypes.detail", "emptyText": "Datenbankmodell ausw\u00e4hlen...", "fieldLabel": "Thema (Modell)", "flex": 33, "hidden": true, "hiddenName": "owner_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Topic (type)","(comments.Comments.owner_type) ") }, "name": "owner_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.gfks.ContentTypes.detail,null)}, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/owner_type" }) }) });
    var owner_id1930 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "fieldLabel": "Thema (Objekt)", "flex": 16, "hidden": true, "hiddenName": "owner_idHidden", "listeners": { "render": Lino.quicktip_renderer("Topic (object)","(comments.Comments.owner_id) ") }, "name": "owner_id", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/owner_id" }) }) });
    var main_1_panel1931 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hidden": true, "hideCheckBoxLabels": true, "items": [ reply_to1927, owner_disp1928, owner_type1929, owner_id1930 ], "labelAlign": "top", "labelWidth": 135, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var body1932 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Inhalt</span>", "flex": 71, "name": "body", "selectOnFocus": true, "title": "Inhalt" });
    var private1933 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Privat", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Private","(comments.Comments.private) ") }, "name": "private", "selectOnFocus": true });
    var main_panel1934 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1931, body1932, { "autoHeight": true, "items": private1933, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 63, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1934;
    this.before_row_edit = function(record) {
      owner_id1930.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      body1932.refresh();
    }
    this.onRender = function(ct, position) {
      typeof owner_type1929 !== 'undefined' && owner_type1929.on('change',Lino.chooser_handler(owner_id1930,'owner_type'));
      Lino.comments.Comments.InsertFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.comments.Comments.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.EnrolmentsByPupil.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel courses-EnrolmentsByPupil",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 51,
  initComponent : function() {
    var course1936 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.courses.Activities.detail", "emptyText": "Aktivit\u00e4t ausw\u00e4hlen...", "fieldLabel": "Aktivit\u00e4t", "hiddenName": "courseHidden", "insert_action": "Lino.courses.Activities.insert", "listeners": { "render": Lino.quicktip_renderer("Activity","(courses.EnrolmentsByPupil.course) ") }, "name": "course", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.courses.Activities.detail,Lino.courses.Activities.insert)}, "pageSize": 20, "related_actor_id": "courses.Activities", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EnrolmentsByPupil/course" }) }) });
    var remark1937 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(courses.EnrolmentsByPupil.remark) ") }, "maxLength": 200, "name": "remark", "selectOnFocus": true });
    var request_date1938 = new Lino.DateField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Datum der Anfrage", "listeners": { "render": Lino.quicktip_renderer("Date of request","(courses.EnrolmentsByPupil.request_date) ") }, "name": "request_date", "selectOnFocus": true });
    var user1939 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(courses.EnrolmentsByPupil.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EnrolmentsByPupil/user" }) }) });
    var main_3_panel1940 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 39, "items": request_date1938, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 60, "items": user1939, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel1943 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": course1936, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": remark1937, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_3_panel1940 ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1943;
    this.before_row_edit = function(record) {
      course1936.setContextValue('course_area', record ? record.data['course_areaHidden'] : undefined);
      course1936.setContextValue('request_date', record ? record.data['request_date'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof request_date1938 !== 'undefined' && request_date1938.on('change',Lino.chooser_handler(course1936,'request_date'));
      Lino.courses.EnrolmentsByPupil.InsertFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.courses.EnrolmentsByPupil.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.topics.Interests.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel topics-Interests",
  layout: 'fit',
  auto_save: true,
  content_type: 52,
  initComponent : function() {
    var partner1946 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "Partner", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(topics.Interests.partner) ") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/topics/Interests/partner" }) }) });
    var topic1947 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.topics.Topics.detail", "emptyText": "Thema ausw\u00e4hlen...", "fieldLabel": "Thema", "hiddenName": "topicHidden", "insert_action": "Lino.topics.Topics.insert", "listeners": { "render": Lino.quicktip_renderer("Topic","(topics.Interests.topic) ") }, "name": "topic", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.topics.Topics.detail,Lino.topics.Topics.insert)}, "pageSize": 20, "related_actor_id": "topics.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/topics/Interests/topic" }) }) });
    var owner_disp1948 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Verkn\u00fcpft mit", "name": "owner" });
    var main_2_panel1949 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 66, "items": topic1947, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": owner_disp1948, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var remark1952 = new Ext.form.TextArea({ "allowBlank": true, "anchor": "-20 -10", "fieldLabel": "Bemerkung", "growMax": 2000, "listeners": { "render": Lino.quicktip_renderer("Remark","(topics.Interests.remark) ") }, "name": "remark", "selectOnFocus": true });
    var main_panel1953 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "items": partner1946, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_2_panel1949, { "flex": 71, "items": remark1952, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel1953;
    this.before_row_edit = function(record) {
    }
    Lino.topics.Interests.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Accounts.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel ledger-Accounts",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 36,
  initComponent : function() {
    var ref1956 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(ledger.Accounts.ref) An optional unique name which can be used to reference a given\naccount.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var name1957 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(ledger.Accounts.name) The multilingual designation of this account, as the users see\nit.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1958 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(ledger.Accounts.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1959 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(ledger.Accounts.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_2_panel1960 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name1957, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de1958, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr1959, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel1964 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": ref1956, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_2_panel1960 ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1964;
    this.before_row_edit = function(record) {
    }
    Lino.ledger.Accounts.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Journals.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel ledger-Journals",
  layout: 'fit',
  auto_save: true,
  content_type: 31,
  initComponent : function() {
    var name1966 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(ledger.Journals.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de1967 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(ledger.Journals.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr1968 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(ledger.Journals.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var ref1969 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(ledger.Journals.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var main_1_panel1970 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 30, "items": name1966, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_de1967, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_fr1968, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 7, "items": ref1969, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var journal_group1975 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Journalgruppe</span>", "forceSelection": true, "hiddenName": "journal_groupHidden", "listeners": { "render": Lino.quicktip_renderer("Journal group","(ledger.Journals.journal_group) Pointer to an item of JournalGroups.") }, "name": "journal_group", "selectOnFocus": true, "store": Lino.ledger.JournalGroups });
    var voucher_type1976 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Belegart</span>", "listeners": { "render": Lino.quicktip_renderer("Voucher type","(ledger.Journals.voucher_type) Pointer to an item of VoucherTypes.") }, "maxLength": 100, "name": "voucher_type", "selectOnFocus": true });
    var trade_type1977 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Handelsart</span>", "forceSelection": true, "hiddenName": "trade_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Trade type","(ledger.Journals.trade_type) Pointer to TradeTypes.") }, "name": "trade_type", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.ledger.TradeTypes) });
    var seqno1978 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Nr.</span>", "listeners": { "render": Lino.quicktip_renderer("No.","(ledger.Journals.seqno) The sequence number of this item with its parent.") }, "name": "seqno", "selectOnFocus": true });
    var id1979 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(ledger.Journals.id) ") }, "name": "id", "selectOnFocus": true });
    var main_2_panel1980 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 23, "items": journal_group1975, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": voucher_type1976, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": trade_type1977, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 7, "items": seqno1978, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 7, "items": id1979, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var account1986 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.ledger.Accounts.detail", "emptyText": "Konto ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Konto</span>", "hiddenName": "accountHidden", "insert_action": "Lino.ledger.Accounts.insert", "listeners": { "render": Lino.quicktip_renderer("Account","(ledger.Journals.account) The account to use for the counter-movements generated by\nvouchers in this journal.") }, "name": "account", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.ledger.Accounts.detail,Lino.ledger.Accounts.insert)}, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/Journals/account" }) }) });
    var partner1987 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Companies.detail", "emptyText": "Organisation ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Organisation</span>", "hiddenName": "partnerHidden", "insert_action": "Lino.contacts.Companies.insert", "listeners": { "render": Lino.quicktip_renderer("Organization","(ledger.Journals.partner) The partner to use as default partner for all vouchers in this\njournal.") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Companies.detail,Lino.contacts.Companies.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/Journals/partner" }) }) });
    var build_method1988 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Druckmethode</span>", "forceSelection": true, "hiddenName": "build_methodHidden", "listeners": { "render": Lino.quicktip_renderer("Print method","(ledger.Journals.build_method) A pointer to an item of\nlino.modlib.printing.choicelists.BuildMethods.") }, "name": "build_method", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var template1989 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Vorlage</span>", "listeners": { "render": Lino.quicktip_renderer("Template","(ledger.Journals.template) See PrintableType.template.") }, "name": "template", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/Journals/template" }) }) });
    var uploads_volume1990 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.uploads.Volumes.detail", "emptyText": "Dateibibliothek ausw\u00e4hlen...", "fieldLabel": "Dateibibliothek", "hiddenName": "uploads_volumeHidden", "insert_action": "Lino.uploads.Volumes.insert", "listeners": { "render": Lino.quicktip_renderer("Library volume","(ledger.Journals.uploads_volume) ") }, "name": "uploads_volume", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.uploads.Volumes.detail,Lino.uploads.Volumes.insert)}, "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/ledger/Journals/uploads_volume" }) }) });
    var main_3_panel1991 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 20, "items": account1986, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": partner1987, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": build_method1988, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": template1989, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": uploads_volume1990, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var dc1997 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Prim\u00e4re Buchungsrichtung</span>", "forceSelection": true, "hiddenName": "dcHidden", "listeners": { "render": Lino.quicktip_renderer("Primary booking direction","(ledger.Journals.dc) The primary booking direction. Voucher items in this direction increase\nthe total amount of the voucher.") }, "name": "dc", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.ledger.DC) });
    var force_sequence1998 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Chronologische Reihenfolge", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Force chronological sequence","(ledger.Journals.force_sequence) ") }, "name": "force_sequence", "selectOnFocus": true });
    var yearly_numbering1999 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Yearly numbering", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Yearly numbering","(ledger.Journals.yearly_numbering) Whether the number of\nvouchers should restart at 1 every year.") }, "name": "yearly_numbering", "selectOnFocus": true });
    var auto_fill_suggestions2000 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Fill suggestions", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Fill suggestions","(ledger.Journals.auto_fill_suggestions) Whether to automatically fill voucher item from due payments\nof the partner when entering a financial voucher.") }, "name": "auto_fill_suggestions", "selectOnFocus": true });
    var auto_check_clearings2001 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Begleichung pr\u00fcfen", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Check clearing","(ledger.Journals.auto_check_clearings) Whether to automatically check and update the 'cleared' status\nof involved transactions when (de)registering a voucher of\nthis journal.") }, "name": "auto_check_clearings", "selectOnFocus": true });
    var must_declare2002 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "must declare", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("must declare","(ledger.Journals.must_declare) ") }, "name": "must_declare", "selectOnFocus": true });
    var preliminary2003 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Preliminary", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Preliminary","(ledger.Journals.preliminary) Whether transactions in this journal are considered preliminary.") }, "name": "preliminary", "selectOnFocus": true });
    var main_4_panel2004 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 13, "items": dc1997, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": force_sequence1998, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": yearly_numbering1999, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": auto_fill_suggestions2000, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": auto_check_clearings2001, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": must_declare2002, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": preliminary2003, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var printed_name2012 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Dokumentbezeichnung Ausdruck", "listeners": { "render": Lino.quicktip_renderer("Printed document designation","(ledger.Journals.printed_name) ") }, "maxLength": 100, "name": "printed_name", "selectOnFocus": true });
    var printed_name_de2013 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Dokumentbezeichnung Ausdruck (de)", "listeners": { "render": Lino.quicktip_renderer("Printed document designation (de)","(ledger.Journals.printed_name_de) ") }, "maxLength": 100, "name": "printed_name_de", "selectOnFocus": true });
    var printed_name_fr2014 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Dokumentbezeichnung Ausdruck (fr)", "listeners": { "render": Lino.quicktip_renderer("Printed document designation (fr)","(ledger.Journals.printed_name_fr) ") }, "maxLength": 100, "name": "printed_name_fr", "selectOnFocus": true });
    var main_5_panel2015 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": printed_name2012, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": printed_name_de2013, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": printed_name_fr2014, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel2024 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1970, main_2_panel1980, main_3_panel1991, main_4_panel2004, main_5_panel2015 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2024;
    this.before_row_edit = function(record) {
      template1989.setContextValue('build_method', record ? record.data['build_methodHidden'] : undefined);
      template1989.setContextValue('voucher_type', record ? record.data['voucher_type'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof build_method1988 !== 'undefined' && build_method1988.on('change',Lino.chooser_handler(template1989,'build_method'));
      typeof voucher_type1976 !== 'undefined' && voucher_type1976.on('change',Lino.chooser_handler(template1989,'voucher_type'));
      Lino.ledger.Journals.DetailFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.ledger.Journals.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.Guests.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel cal-Guests",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 25,
  initComponent : function() {
    var event1444 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.OneEvent.detail", "emptyText": "Kalendereintrag ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintrag</span>", "hiddenName": "eventHidden", "insert_action": "Lino.cal.OneEvent.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry","(cal.Guests.event) The calendar event to which this presence applies.") }, "name": "event", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.OneEvent.detail,Lino.cal.OneEvent.insert)}, "pageSize": 20, "related_actor_id": "cal.OneEvent", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/event" }) }) });
    var partner1445 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "can_create_choice": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Person</span>", "forceSelection": false, "hiddenName": "partnerHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Person","(cal.Guests.partner) The partner to which this presence applies.") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/partner" }) }) });
    var role1446 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.GuestRoles.detail", "emptyText": "Gastrolle ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Rolle</span>", "hiddenName": "roleHidden", "listeners": { "render": Lino.quicktip_renderer("Role","(cal.Guests.role) The role of this partner in this presence.") }, "name": "role", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.GuestRoles.detail,null)}, "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/role" }) }) });
    var main_panel1447 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": event1444, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": partner1445, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": role1446, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel1447;
    this.before_row_edit = function(record) {
    }
    Lino.cal.Guests.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.tinymce.TextFieldTemplates.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel tinymce-TextFieldTemplates",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 61,
  initComponent : function() {
    var name2025 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(tinymce.TextFieldTemplates.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var user2026 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(tinymce.TextFieldTemplates.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/tinymce/TextFieldTemplates/user" }) }) });
    var main_panel2027 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": name2025, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": user2026, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2027;
    this.before_row_edit = function(record) {
    }
    Lino.tinymce.TextFieldTemplates.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.courses.EnrolmentsByCourse.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel courses-EnrolmentsByCourse",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 51,
  initComponent : function() {
    var pupil2030 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "can_create_choice": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "Teilnehmer", "forceSelection": false, "hiddenName": "pupilHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Participant","(courses.EnrolmentsByCourse.pupil) ") }, "name": "pupil", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EnrolmentsByCourse/pupil" }) }) });
    var remark2031 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(courses.EnrolmentsByCourse.remark) ") }, "maxLength": 200, "name": "remark", "selectOnFocus": true });
    var request_date2032 = new Lino.DateField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Datum der Anfrage", "listeners": { "render": Lino.quicktip_renderer("Date of request","(courses.EnrolmentsByCourse.request_date) ") }, "name": "request_date", "selectOnFocus": true });
    var user2033 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(courses.EnrolmentsByCourse.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EnrolmentsByCourse/user" }) }) });
    var main_3_panel2034 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 39, "items": request_date2032, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 60, "items": user2033, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel2037 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": pupil2030, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": remark2031, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_3_panel2034 ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2037;
    this.before_row_edit = function(record) {
      var bp = this.get_base_params();
      pupil2030.setContextValue('mk',bp['mk']);
      pupil2030.setContextValue('mt',bp['mt']);
    }
    Lino.courses.EnrolmentsByCourse.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.EventTypes.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel cal-EventTypes",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 17,
  initComponent : function() {
    var name2040 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(cal.EventTypes.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2041 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(cal.EventTypes.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2042 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(cal.EventTypes.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var ref2043 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(cal.EventTypes.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var main_1_panel2044 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 31, "items": name2040, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 31, "items": name_de2041, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 31, "items": name_fr2042, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 5, "items": ref2043, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var event_label2049 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung Termin</span>", "listeners": { "render": Lino.quicktip_renderer("Entry label","(cal.EventTypes.event_label) Default text for summary of new entries.") }, "maxLength": 200, "name": "event_label", "selectOnFocus": true });
    var event_label_de2050 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung Termin (de)", "listeners": { "render": Lino.quicktip_renderer("Entry label (de)","(cal.EventTypes.event_label_de) ") }, "maxLength": 200, "name": "event_label_de", "selectOnFocus": true });
    var event_label_fr2051 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung Termin (fr)", "listeners": { "render": Lino.quicktip_renderer("Entry label (fr)","(cal.EventTypes.event_label_fr) ") }, "maxLength": 200, "name": "event_label_fr", "selectOnFocus": true });
    var main_2_panel2052 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": event_label2049, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": event_label_de2050, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": event_label_fr2051, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel2056 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2044, main_2_panel2052 ], "labelAlign": "top", "layout": "form" });
    this.items = main_panel2056;
    this.before_row_edit = function(record) {
    }
    Lino.cal.EventTypes.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.checkdata.Checkers.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel checkdata-Checkers",
  layout: 'fit',
  auto_save: true,
  disable_editing: true,
  initComponent : function() {
    var value2057 = new Ext.form.TextField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Wert", "listeners": { "render": Lino.quicktip_renderer("value","(checkdata.Checkers.value) ") }, "maxLength": 20, "name": "value" });
    var text2058 = new Ext.form.TextField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Text", "listeners": { "render": Lino.quicktip_renderer("text","(checkdata.Checkers.text) ") }, "maxLength": 50, "name": "text" });
    var main_1_panel2059 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": value2057, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": text2058, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var checkdata_ProblemsByChecker_grid2082 = new Lino.checkdata.ProblemsByChecker.GridPanel({ "containing_panel": this, "flex": 83, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Data problems","(checkdata.checkdata.ProblemsByChecker) The base table for problem messages.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.checkdata.ProblemsByChecker.grid) ] });
    var main_panel2083 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2059, checkdata_ProblemsByChecker_grid2082 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2083;
    this.before_row_edit = function(record) {
      checkdata_ProblemsByChecker_grid2082.on_master_changed();
    }
    Lino.checkdata.Checkers.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.PaymentTerms.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel ledger-PaymentTerms",
  layout: 'fit',
  auto_save: true,
  content_type: 34,
  initComponent : function() {
    var ref2084 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(ledger.PaymentTerms.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var months2085 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Monate</span>", "listeners": { "render": Lino.quicktip_renderer("Months","(ledger.PaymentTerms.months) Number of months to add to voucher_date.") }, "name": "months", "selectOnFocus": true, "value": 0 });
    var days2086 = new Ext.form.NumberField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Tage</span>", "listeners": { "render": Lino.quicktip_renderer("Days","(ledger.PaymentTerms.days) Number of days to add to voucher_date.") }, "name": "days", "selectOnFocus": true, "value": 0 });
    var end_of_month2087 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Monatsende", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("End of month","(ledger.PaymentTerms.end_of_month) Whether to move voucher_date to the end of month.") }, "name": "end_of_month", "selectOnFocus": true });
    var main_1_panel2088 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 20, "items": ref2084, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": months2085, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": days2086, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 40, "items": end_of_month2087, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var name2093 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(ledger.PaymentTerms.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2094 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(ledger.PaymentTerms.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2095 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(ledger.PaymentTerms.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_2_panel2096 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name2093, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de2094, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr2095, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var printed_text2100 = new Ext.form.TextArea({ "allowBlank": true, "anchor": "-20 -10", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Printed text</span>", "growMax": 2000, "listeners": { "render": Lino.quicktip_renderer("Printed text","(ledger.PaymentTerms.printed_text) Used in sales/VatProductInvoice/trailer.html as\nfollows:") }, "name": "printed_text", "selectOnFocus": true });
    var printed_text_de2101 = new Ext.form.TextArea({ "allowBlank": true, "anchor": "-20 -10", "fieldLabel": "Printed text (de)", "growMax": 2000, "listeners": { "render": Lino.quicktip_renderer("Printed text (de)","(ledger.PaymentTerms.printed_text_de) ") }, "name": "printed_text_de", "selectOnFocus": true });
    var printed_text_fr2102 = new Ext.form.TextArea({ "allowBlank": true, "anchor": "-20 -10", "fieldLabel": "Printed text (fr)", "growMax": 2000, "listeners": { "render": Lino.quicktip_renderer("Printed text (fr)","(ledger.PaymentTerms.printed_text_fr) ") }, "name": "printed_text_fr", "selectOnFocus": true });
    var main_3_panel2103 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 71, "frame": false, "hideCheckBoxLabels": true, "items": [ { "flex": 33, "items": printed_text2100, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "flex": 33, "items": printed_text_de2101, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "flex": 33, "items": printed_text_fr2102, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var main_panel2107 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2088, main_2_panel2096, main_3_panel2103 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2107;
    this.before_row_edit = function(record) {
    }
    Lino.ledger.PaymentTerms.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.comments.CommentsByRFC.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel comments-CommentsByRFC",
  layout: 'fit',
  auto_save: true,
  content_type: 63,
  initComponent : function() {
    var reply_to2108 = new Lino.TwinCombo({ "allowBlank": true, "detail_action": "Lino.comments.Comments.detail", "emptyText": "Kommentar ausw\u00e4hlen...", "fieldLabel": "Antwort auf", "hidden": true, "hiddenName": "reply_toHidden", "insert_action": "Lino.comments.Comments.insert", "listeners": { "render": Lino.quicktip_renderer("Reply to","(comments.CommentsByRFC.reply_to) ") }, "name": "reply_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.comments.Comments.detail,Lino.comments.Comments.insert)}, "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByRFC/reply_to" }) }) });
    var body2109 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Inhalt</span>", "flex": 71, "name": "body", "selectOnFocus": true, "title": "Inhalt" });
    var private2110 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Privat", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Private","(comments.CommentsByRFC.private) ") }, "name": "private", "selectOnFocus": true });
    var main_panel2111 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ reply_to2108, body2109, { "autoHeight": true, "items": private2110, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 108, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2111;
    this.before_row_edit = function(record) {
      body2109.refresh();
    }
    Lino.comments.CommentsByRFC.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.humanlinks.Links.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel humanlinks-Links",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 46,
  initComponent : function() {
    var parent2113 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Wer ist...</span>", "hiddenName": "parentHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Who is...","(humanlinks.Links.parent) Pointer to the person who is \"parent\".") }, "name": "parent", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/humanlinks/Links/parent" }) }) });
    var type2114 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verwandschaftsart</span>", "forceSelection": true, "hiddenName": "typeHidden", "listeners": { "render": Lino.quicktip_renderer("Parency type","(humanlinks.Links.type) The type of link.  Pointer to LinkTypes.") }, "name": "type", "selectOnFocus": true, "store": Lino.humanlinks.LinkTypes });
    var child2115 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Von wem...</span>", "hiddenName": "childHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("To whom...","(humanlinks.Links.child) Pointer to the person who is \"child\".") }, "name": "child", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/humanlinks/Links/child" }) }) });
    var main_panel2116 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": parent2113, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": type2114, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": child2115, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2116;
    this.before_row_edit = function(record) {
    }
    Lino.humanlinks.Links.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.topics.Topics.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel topics-Topics",
  layout: 'fit',
  auto_save: true,
  content_type: 53,
  initComponent : function() {
    var id2120 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(topics.Topics.id) ") }, "name": "id", "selectOnFocus": true });
    var ref2121 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(topics.Topics.ref) The reference.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var name2122 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(topics.Topics.name) The designation in different languages.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2123 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(topics.Topics.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2124 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(topics.Topics.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel2125 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 6, "items": id2120, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 6, "items": ref2121, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 28, "items": name2122, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 28, "items": name_de2123, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 28, "items": name_fr2124, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" }, "region": "north", "split": true });
    var description_text2131 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Long description</span>", "flex": 33, "name": "description_text", "selectOnFocus": true, "title": "Long description" });
    var description_text_de2132 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Long description (de)", "flex": 33, "name": "description_text_de", "selectOnFocus": true, "title": "Long description (de)" });
    var description_text_fr2133 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Long description (fr)", "flex": 33, "name": "description_text_fr", "selectOnFocus": true, "title": "Long description (fr)" });
    var main_2_panel2134 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 5, "frame": false, "hideCheckBoxLabels": true, "items": [ description_text2131, description_text_de2132, description_text_fr2133 ], "labelAlign": "top", "labelWidth": 198, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "region": "center", "split": true });
    var main_panel2144 = new Lino.VBorderPanel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2125, main_2_panel2134 ], "labelAlign": "top" });
    this.items = main_panel2144;
    this.before_row_edit = function(record) {
      description_text2131.refresh();
      description_text_de2132.refresh();
      description_text_fr2133.refresh();
    }
    Lino.topics.Topics.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.topics.Topics.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel topics-Topics",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 53,
  initComponent : function() {
    var ref2145 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(topics.Topics.ref) The reference.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var name2146 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(topics.Topics.name) The designation in different languages.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2147 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(topics.Topics.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2148 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(topics.Topics.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_2_panel2149 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name2146, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de2147, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr2148, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel2153 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": ref2145, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_2_panel2149 ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2153;
    this.before_row_edit = function(record) {
    }
    Lino.topics.Topics.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.topics.InterestsByPartner.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel topics-InterestsByPartner",
  layout: 'fit',
  auto_save: true,
  content_type: 52,
  initComponent : function() {
    var topic2155 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.topics.Topics.detail", "emptyText": "Thema ausw\u00e4hlen...", "fieldLabel": "Thema", "hiddenName": "topicHidden", "insert_action": "Lino.topics.Topics.insert", "listeners": { "render": Lino.quicktip_renderer("Topic","(topics.InterestsByPartner.topic) ") }, "name": "topic", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.topics.Topics.detail,Lino.topics.Topics.insert)}, "pageSize": 20, "related_actor_id": "topics.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/topics/InterestsByPartner/topic" }) }) });
    var remark2156 = new Ext.form.TextArea({ "allowBlank": true, "anchor": "-20 -10", "fieldLabel": "Bemerkung", "growMax": 2000, "listeners": { "render": Lino.quicktip_renderer("Remark","(topics.InterestsByPartner.remark) ") }, "name": "remark", "selectOnFocus": true });
    var main_panel2157 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "items": topic2155, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "flex": 83, "items": remark2156, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2157;
    this.before_row_edit = function(record) {
    }
    Lino.topics.InterestsByPartner.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.lists.MembersByPartner.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel lists-MembersByPartner",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 56,
  initComponent : function() {
    var list2160 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.lists.Lists.detail", "emptyText": "Partnerliste ausw\u00e4hlen...", "fieldLabel": "Partnerliste", "hiddenName": "listHidden", "insert_action": "Lino.lists.Lists.insert", "listeners": { "render": Lino.quicktip_renderer("Partner List","(lists.MembersByPartner.list) ") }, "name": "list", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.lists.Lists.detail,Lino.lists.Lists.insert)}, "pageSize": 20, "related_actor_id": "lists.Lists", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/MembersByPartner/list" }) }) });
    var remark2161 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(lists.MembersByPartner.remark) ") }, "maxLength": 200, "name": "remark", "selectOnFocus": true });
    var main_panel2162 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": list2160, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": remark2161, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2162;
    this.before_row_edit = function(record) {
    }
    Lino.lists.MembersByPartner.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.blogs.EntryTypes.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel blogs-EntryTypes",
  layout: 'fit',
  auto_save: true,
  content_type: 57,
  initComponent : function() {
    var id2165 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(blogs.EntryTypes.id) ") }, "name": "id", "selectOnFocus": true });
    var name2166 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(blogs.EntryTypes.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2167 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(blogs.EntryTypes.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2168 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(blogs.EntryTypes.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel2169 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 7, "items": id2165, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name2166, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_de2167, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_fr2168, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" }, "region": "north", "split": true });
    var remark2174 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Bemerkung", "flex": 5, "name": "remark", "region": "center", "selectOnFocus": true, "split": true, "title": "Bemerkung" });
    var blogs_EntriesByType_grid2218 = new Lino.blogs.EntriesByType.GridPanel({ "containing_panel": this, "flex": 5, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Blog Entries","(blogs.blogs.EntriesByType) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "region": "south", "split": true, "tools": [ Lino.show_in_own_window_button(Lino.blogs.EntriesByType.grid) ] });
    var main_panel2219 = new Lino.VBorderPanel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2169, remark2174, blogs_EntriesByType_grid2218 ], "labelAlign": "top", "labelWidth": 90 });
    this.items = main_panel2219;
    this.before_row_edit = function(record) {
      remark2174.refresh();
      blogs_EntriesByType_grid2218.on_master_changed();
    }
    Lino.blogs.EntryTypes.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.blogs.Entries.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel blogs-Entries",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 58,
  initComponent : function() {
    var title2213 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "\u00dcberschrift", "listeners": { "render": Lino.quicktip_renderer("Heading","(blogs.Entries.title) ") }, "maxLength": 200, "name": "title", "selectOnFocus": true });
    var entry_type2214 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.blogs.EntryTypes.detail", "emptyText": "Blog Entry Type ausw\u00e4hlen...", "fieldLabel": "Blog Entry Type", "hiddenName": "entry_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Blog Entry Type","(blogs.Entries.entry_type) ") }, "name": "entry_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.blogs.EntryTypes.detail,null)}, "pageSize": 20, "related_actor_id": "blogs.EntryTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/Entries/entry_type" }) }) });
    var main_panel2215 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": title2213, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": entry_type2214, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2215;
    this.before_row_edit = function(record) {
    }
    Lino.blogs.Entries.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.cal.EntriesByGuest.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel cal-EntriesByGuest",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 24,
  initComponent : function() {
    var start_date2220 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beginnt am</span>", "listeners": { "render": Lino.quicktip_renderer("Start date","(cal.EntriesByGuest.start_date) The starting date of this entry.  May not be empty.") }, "name": "start_date", "selectOnFocus": true });
    var start_time2221 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Beginnt um</span>", "listeners": { "render": Lino.quicktip_renderer("Start time","(cal.EntriesByGuest.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "start_time", "selectOnFocus": true });
    var end_time2222 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Endet um</span>", "listeners": { "render": Lino.quicktip_renderer("End Time","(cal.EntriesByGuest.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "end_time", "selectOnFocus": true });
    var main_1_panel2223 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 44, "items": start_date2220, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 27, "items": start_time2221, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 27, "items": end_time2222, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var summary2227 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kurzbeschreibung</span>", "listeners": { "render": Lino.quicktip_renderer("Short description","(cal.EntriesByGuest.summary) A one-line descriptive text.") }, "maxLength": 200, "name": "summary", "selectOnFocus": true });
    var event_type2228 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Kalendereintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Calendar entry type","(cal.EntriesByGuest.event_type) The type of this calendar entry.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByGuest/event_type" }) }) });
    var main_panel2229 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2223, { "anchor": "-20", "autoHeight": true, "items": summary2227, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": event_type2228, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2229;
    this.before_row_edit = function(record) {
    }
    Lino.cal.EntriesByGuest.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.lists.Lists.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel lists-Lists",
  layout: 'fit',
  auto_save: true,
  content_type: 55,
  initComponent : function() {
    var ref2232 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(lists.Lists.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var list_type2233 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Listenart ausw\u00e4hlen...", "fieldLabel": "Listenart", "hiddenName": "list_typeHidden", "listeners": { "render": Lino.quicktip_renderer("List Type","(lists.Lists.list_type) ") }, "name": "list_type", "pageSize": 20, "related_actor_id": "lists.ListTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/Lists/list_type" }) }) });
    var main_1_panel2234 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 66, "items": ref2232, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": list_type2233, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var designation2237 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(lists.Lists.designation) ") }, "maxLength": 200, "name": "designation", "selectOnFocus": true });
    var designation_de2238 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(lists.Lists.designation_de) ") }, "maxLength": 200, "name": "designation_de", "selectOnFocus": true });
    var designation_fr2239 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(lists.Lists.designation_fr) ") }, "maxLength": 200, "name": "designation_fr", "selectOnFocus": true });
    var main_2_panel2240 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": designation2237, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": designation_de2238, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": designation_fr2239, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var remarks2244 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Bemerkungen", "flex": 71, "name": "remarks", "selectOnFocus": true, "title": "Bemerkungen" });
    var main_panel2245 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2234, main_2_panel2240, remarks2244 ], "labelAlign": "top", "labelWidth": 108, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2245;
    this.before_row_edit = function(record) {
      remarks2244.refresh();
    }
    Lino.lists.Lists.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.topics.InterestsByController.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel topics-InterestsByController",
  layout: 'fit',
  auto_save: true,
  content_type: 52,
  initComponent : function() {
    var topic2246 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.topics.Topics.detail", "emptyText": "Thema ausw\u00e4hlen...", "fieldLabel": "Thema", "hiddenName": "topicHidden", "insert_action": "Lino.topics.Topics.insert", "listeners": { "render": Lino.quicktip_renderer("Topic","(topics.InterestsByController.topic) ") }, "name": "topic", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.topics.Topics.detail,Lino.topics.Topics.insert)}, "pageSize": 20, "related_actor_id": "topics.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/topics/InterestsByController/topic" }) }) });
    var partner2247 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "Partner", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(topics.InterestsByController.partner) ") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/topics/InterestsByController/partner" }) }) });
    var main_1_panel2248 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": topic2246, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": partner2247, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var remark2251 = new Ext.form.TextArea({ "allowBlank": true, "anchor": "-20 -10", "fieldLabel": "Bemerkung", "growMax": 2000, "listeners": { "render": Lino.quicktip_renderer("Remark","(topics.InterestsByController.remark) ") }, "name": "remark", "selectOnFocus": true });
    var main_panel2252 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2248, { "flex": 83, "items": remark2251, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2252;
    this.before_row_edit = function(record) {
    }
    Lino.topics.InterestsByController.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.excerpts.ExcerptTypes.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel excerpts-ExcerptTypes",
  layout: 'fit',
  auto_save: true,
  content_type: 59,
  initComponent : function() {
    var id2254 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(excerpts.ExcerptTypes.id) ") }, "name": "id", "selectOnFocus": true });
    var name2255 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(excerpts.ExcerptTypes.name) The designation of this excerpt type.\nOne field for every language.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2256 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(excerpts.ExcerptTypes.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2257 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(excerpts.ExcerptTypes.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel2258 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 7, "items": id2254, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name2255, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_de2256, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_fr2257, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var content_type2263 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.gfks.ContentTypes.detail", "emptyText": "Datenbankmodell ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Modell</span>", "hiddenName": "content_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Model","(excerpts.ExcerptTypes.content_type) The database model for which this excerpt type is to be used.") }, "name": "content_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.gfks.ContentTypes.detail,null)}, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/content_type" }) }) });
    var build_method2264 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Druckmethode</span>", "forceSelection": true, "hiddenName": "build_methodHidden", "listeners": { "render": Lino.quicktip_renderer("Print method","(excerpts.ExcerptTypes.build_method) See lino.modlib.printing.mixins.PrintableType.build_method.") }, "name": "build_method", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var template2265 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Vorlage</span>", "listeners": { "render": Lino.quicktip_renderer("Template","(excerpts.ExcerptTypes.template) The main template to be used when printing an excerpt of this type.") }, "name": "template", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/template" }) }) });
    var body_template2266 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Textk\u00f6rper-Vorlage</span>", "listeners": { "render": Lino.quicktip_renderer("Body template","(excerpts.ExcerptTypes.body_template) The body template to use when printing an excerpt of this type.") }, "name": "body_template", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/body_template" }) }) });
    var email_template2267 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">E-Mail-Vorlage</span>", "listeners": { "render": Lino.quicktip_renderer("Email template","(excerpts.ExcerptTypes.email_template) The template to use when sending this an excerpt of this type\nby email.") }, "name": "email_template", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/email_template" }) }) });
    var shortcut2268 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Excerpt shortcut</span>", "listeners": { "render": Lino.quicktip_renderer("Excerpt shortcut","(excerpts.ExcerptTypes.shortcut) Optional pointer to a shortcut field.  If this is not empty, then\nthe given shortcut field will manage excerpts of this type.") }, "maxLength": 50, "name": "shortcut", "selectOnFocus": true });
    var main_2_panel2269 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 15, "items": content_type2263, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 15, "items": build_method2264, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 15, "items": template2265, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 15, "items": body_template2266, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 15, "items": email_template2267, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": shortcut2268, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var primary2276 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Prim\u00e4r", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Primary","(excerpts.ExcerptTypes.primary) Whether this is the default type to use for this model. There's at most one primary type per model. Enabling this field will automatically make the other types non-primary.") }, "name": "primary", "selectOnFocus": true });
    var print_directly2277 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Print directly", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Print directly","(excerpts.ExcerptTypes.print_directly) ") }, "name": "print_directly", "selectOnFocus": true });
    var certifying2278 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Bescheinigend", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Certifying","(excerpts.ExcerptTypes.certifying) Whether an excerpt of this type is a unique printout.") }, "name": "certifying", "selectOnFocus": true });
    var print_recipient2279 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Empf\u00e4nger drucken", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Print recipient","(excerpts.ExcerptTypes.print_recipient) Whether to print a recipient field in document.") }, "name": "print_recipient", "selectOnFocus": true });
    var backward_compat2280 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Backward compatible", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Backward compatible","(excerpts.ExcerptTypes.backward_compat) Check this to have `this` in template context point to owner instead of excerpt.") }, "name": "backward_compat", "selectOnFocus": true });
    var attach_to_email2281 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "als Anhang per E-Mail", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Attach to email","(excerpts.ExcerptTypes.attach_to_email) Whether the printable file should be attached to the email\nwhen creating an email from a mailable of this type.\n") }, "name": "attach_to_email", "selectOnFocus": true });
    var main_3_panel2282 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 16, "items": primary2276, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": print_directly2277, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": certifying2278, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": print_recipient2279, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": backward_compat2280, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 16, "items": attach_to_email2281, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var excerpts_ExcerptsByType_grid2310 = new Lino.excerpts.ExcerptsByType.GridPanel({ "containing_panel": this, "flex": 62, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Excerpts","(excerpts.excerpts.ExcerptsByType) Base class for all tables on Excerpt.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.excerpts.ExcerptsByType.grid) ] });
    var main_panel2311 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2258, main_2_panel2269, main_3_panel2282, excerpts_ExcerptsByType_grid2310 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2311;
    this.before_row_edit = function(record) {
      template2265.setContextValue('build_method', record ? record.data['build_methodHidden'] : undefined);
      template2265.setContextValue('content_type', record ? record.data['content_typeHidden'] : undefined);
      body_template2266.setContextValue('content_type', record ? record.data['content_typeHidden'] : undefined);
      email_template2267.setContextValue('content_type', record ? record.data['content_typeHidden'] : undefined);
      excerpts_ExcerptsByType_grid2310.on_master_changed();
    }
    this.onRender = function(ct, position) {
      typeof build_method2264 !== 'undefined' && build_method2264.on('change',Lino.chooser_handler(template2265,'build_method'));
      typeof content_type2263 !== 'undefined' && content_type2263.on('change',Lino.chooser_handler(template2265,'content_type'));
      typeof content_type2263 !== 'undefined' && content_type2263.on('change',Lino.chooser_handler(body_template2266,'content_type'));
      typeof content_type2263 !== 'undefined' && content_type2263.on('change',Lino.chooser_handler(email_template2267,'content_type'));
      Lino.excerpts.ExcerptTypes.DetailFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.excerpts.ExcerptTypes.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.excerpts.ExcerptTypes.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel excerpts-ExcerptTypes",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 59,
  initComponent : function() {
    var name2312 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bezeichnung</span>", "listeners": { "render": Lino.quicktip_renderer("Designation","(excerpts.ExcerptTypes.name) The designation of this excerpt type.\nOne field for every language.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2313 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(excerpts.ExcerptTypes.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2314 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(excerpts.ExcerptTypes.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel2315 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name2312, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de2313, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr2314, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var content_type2319 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.gfks.ContentTypes.detail", "emptyText": "Datenbankmodell ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Modell</span>", "hiddenName": "content_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Model","(excerpts.ExcerptTypes.content_type) The database model for which this excerpt type is to be used.") }, "name": "content_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.gfks.ContentTypes.detail,null)}, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/content_type" }) }) });
    var primary2320 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Prim\u00e4r", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Primary","(excerpts.ExcerptTypes.primary) Whether this is the default type to use for this model. There's at most one primary type per model. Enabling this field will automatically make the other types non-primary.") }, "name": "primary", "selectOnFocus": true });
    var certifying2321 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Bescheinigend", "checked": false, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Certifying","(excerpts.ExcerptTypes.certifying) Whether an excerpt of this type is a unique printout.") }, "name": "certifying", "selectOnFocus": true });
    var main_2_panel2322 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": content_type2319, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": primary2320, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": certifying2321, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var build_method2326 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Druckmethode</span>", "forceSelection": true, "hiddenName": "build_methodHidden", "listeners": { "render": Lino.quicktip_renderer("Print method","(excerpts.ExcerptTypes.build_method) See lino.modlib.printing.mixins.PrintableType.build_method.") }, "name": "build_method", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var template2327 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Vorlage</span>", "listeners": { "render": Lino.quicktip_renderer("Template","(excerpts.ExcerptTypes.template) The main template to be used when printing an excerpt of this type.") }, "name": "template", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/template" }) }) });
    var body_template2328 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Textk\u00f6rper-Vorlage</span>", "listeners": { "render": Lino.quicktip_renderer("Body template","(excerpts.ExcerptTypes.body_template) The body template to use when printing an excerpt of this type.") }, "name": "body_template", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/body_template" }) }) });
    var main_3_panel2329 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 53, "items": build_method2326, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 23, "items": template2327, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 23, "items": body_template2328, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel2333 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2315, main_2_panel2322, main_3_panel2329 ], "labelAlign": "top", "layout": "form" });
    this.items = main_panel2333;
    this.before_row_edit = function(record) {
      template2327.setContextValue('build_method', record ? record.data['build_methodHidden'] : undefined);
      template2327.setContextValue('content_type', record ? record.data['content_typeHidden'] : undefined);
      body_template2328.setContextValue('content_type', record ? record.data['content_typeHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof build_method2326 !== 'undefined' && build_method2326.on('change',Lino.chooser_handler(template2327,'build_method'));
      typeof content_type2319 !== 'undefined' && content_type2319.on('change',Lino.chooser_handler(template2327,'content_type'));
      typeof content_type2319 !== 'undefined' && content_type2319.on('change',Lino.chooser_handler(body_template2328,'content_type'));
      Lino.excerpts.ExcerptTypes.InsertFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.excerpts.ExcerptTypes.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.sepa.AccountsByPartner.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel sepa-AccountsByPartner",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 40,
  initComponent : function() {
    var iban655 = new Lino.UppercaseTextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "IBAN", "listeners": { "render": Lino.quicktip_renderer("IBAN","(sepa.AccountsByPartner.iban) ") }, "maxLength": 34, "name": "iban", "selectOnFocus": true });
    var bic656 = new Lino.UppercaseTextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "BIC", "listeners": { "render": Lino.quicktip_renderer("BIC","(sepa.AccountsByPartner.bic) ") }, "maxLength": 11, "name": "bic", "selectOnFocus": true });
    var main_1_panel657 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 63, "items": iban655, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 36, "items": bic656, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var remark660 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(sepa.AccountsByPartner.remark) ") }, "maxLength": 200, "name": "remark", "selectOnFocus": true });
    var main_panel661 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel657, { "anchor": "-20", "autoHeight": true, "items": remark660, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel661;
    this.before_row_edit = function(record) {
    }
    Lino.sepa.AccountsByPartner.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.addresses.Addresses.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel addresses-Addresses",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 41,
  initComponent : function() {
    var country1178 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.countries.Countries.detail", "emptyText": "Land ausw\u00e4hlen...", "fieldLabel": "Land", "hiddenName": "countryHidden", "insert_action": "Lino.countries.Countries.insert", "listeners": { "render": Lino.quicktip_renderer("Country","(addresses.Addresses.country) ") }, "name": "country", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.countries.Countries.detail,Lino.countries.Countries.insert)}, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/country" }) }) });
    var city1179 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": true, "detail_action": "Lino.countries.Places.detail", "emptyText": "Ort ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Ortschaft</span>", "forceSelection": false, "hiddenName": "cityHidden", "insert_action": "Lino.countries.Places.insert", "listeners": { "render": Lino.quicktip_renderer("Locality","(addresses.Addresses.city) The locality, i.e. usually a village, city or town.") }, "name": "city", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.countries.Places.detail,Lino.countries.Places.insert)}, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/city" }) }) });
    var main_1_panel1180 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": country1178, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": city1179, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var street1183 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Stra\u00dfe</span>", "listeners": { "render": Lino.quicktip_renderer("Street","(addresses.Addresses.street) Name of street, without house number.") }, "maxLength": 200, "name": "street", "selectOnFocus": true });
    var street_no1184 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(10), "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Nr.</span>", "listeners": { "render": Lino.quicktip_renderer("No.","(addresses.Addresses.street_no) House number.") }, "maxLength": 10, "name": "street_no", "selectOnFocus": true });
    var street_box1185 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(10), "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Box</span>", "listeners": { "render": Lino.quicktip_renderer("Box","(addresses.Addresses.street_box) Text to print after street number on the same line.") }, "maxLength": 10, "name": "street_box", "selectOnFocus": true });
    var main_2_panel1186 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 48, "items": street1183, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": street_no1184, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 25, "items": street_box1185, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var address_type1190 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Adressenart</span>", "forceSelection": true, "hiddenName": "address_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Address type","(addresses.Addresses.address_type) The type of this address record.\nA pointer to AddressTypes.\nThe default value is AddressTypes.official.") }, "name": "address_type", "selectOnFocus": true, "store": Lino.addresses.AddressTypes });
    var remark1191 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(addresses.Addresses.remark) ") }, "maxLength": 50, "name": "remark", "selectOnFocus": true });
    var main_3_panel1192 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": address_type1190, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": remark1191, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel1195 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel1180, main_2_panel1186, main_3_panel1192 ], "labelAlign": "top", "layout": "form" });
    this.items = main_panel1195;
    this.before_row_edit = function(record) {
      city1179.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city1179.setContextValue('region', record ? record.data['regionHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof country1178 !== 'undefined' && country1178.on('change',Lino.chooser_handler(city1179,'country'));
      Lino.addresses.Addresses.InsertFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.addresses.Addresses.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.excerpts.Excerpts.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel excerpts-Excerpts",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 60,
  initComponent : function() {
    var excerpt_type2302 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.excerpts.ExcerptTypes.detail", "emptyText": "Auszugsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Auszugsart</span>", "hiddenName": "excerpt_typeHidden", "insert_action": "Lino.excerpts.ExcerptTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Excerpt Type","(excerpts.Excerpts.excerpt_type) The type of this excerpt (ForeignKey to ExcerptType).") }, "name": "excerpt_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.excerpts.ExcerptTypes.detail,Lino.excerpts.ExcerptTypes.insert)}, "pageSize": 20, "related_actor_id": "excerpts.ExcerptTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/excerpt_type" }) }) });
    var company2303 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Companies.detail", "emptyText": "Organisation ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Empf\u00e4nger (Organisation)</span>", "hiddenName": "companyHidden", "insert_action": "Lino.contacts.Companies.insert", "listeners": { "render": Lino.quicktip_renderer("Recipient (Organization)","(excerpts.Excerpts.company) The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.") }, "name": "company", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Companies.detail,Lino.contacts.Companies.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/company" }) }) });
    var contact_person2304 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "detail_action": "Lino.contacts.Persons.detail", "emptyText": "Person ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Empf\u00e4nger (Person)</span>", "hiddenName": "contact_personHidden", "insert_action": "Lino.contacts.Persons.insert", "listeners": { "render": Lino.quicktip_renderer("Recipient (Person)","(excerpts.Excerpts.contact_person) The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.") }, "name": "contact_person", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Persons.detail,Lino.contacts.Persons.insert)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/contact_person" }) }) });
    var main_2_panel2305 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": company2303, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": contact_person2304, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel2308 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": excerpt_type2302, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_2_panel2305 ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2308;
    this.before_row_edit = function(record) {
      excerpt_type2302.setContextValue('owner', record ? record.data['owner'] : undefined);
      contact_person2304.setContextValue('company', record ? record.data['companyHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof company2303 !== 'undefined' && company2303.on('change',Lino.chooser_handler(contact_person2304,'company'));
      Lino.excerpts.Excerpts.InsertFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.excerpts.Excerpts.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.tinymce.TextFieldTemplates.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel tinymce-TextFieldTemplates",
  layout: 'fit',
  auto_save: true,
  content_type: 61,
  initComponent : function() {
    var id2334 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(tinymce.TextFieldTemplates.id) ") }, "name": "id", "selectOnFocus": true });
    var name2335 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(tinymce.TextFieldTemplates.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var user2336 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(tinymce.TextFieldTemplates.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/tinymce/TextFieldTemplates/user" }) }) });
    var main_1_panel2337 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 10, "items": id2334, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 45, "items": name2335, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 43, "items": user2336, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" }, "region": "north", "split": true });
    var description2341 = new Ext.form.TextArea({ "allowBlank": true, "anchor": "-20 -10", "fieldLabel": "Beschreibung", "growMax": 2000, "listeners": { "render": Lino.quicktip_renderer("Description","(tinymce.TextFieldTemplates.description) ") }, "name": "description", "selectOnFocus": true });
    var text2342 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Vorlagentext", "flex": 5, "name": "text", "region": "south", "selectOnFocus": true, "split": true, "title": "Vorlagentext" });
    var main_panel2343 = new Lino.VBorderPanel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2337, { "flex": 5, "items": description2341, "labelAlign": "top", "layout": "form", "region": "center", "split": true, "xtype": "panel" }, text2342 ], "labelAlign": "top", "labelWidth": 117 });
    this.items = main_panel2343;
    this.before_row_edit = function(record) {
      text2342.refresh();
    }
    Lino.tinymce.TextFieldTemplates.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.users.AllUsers.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel users-Users",
  layout: 'fit',
  auto_save: true,
  content_type: 2,
  initComponent : function() {
    var username2345 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Benutzername</span>", "listeners": { "render": Lino.quicktip_renderer("Username","(users.Users.username) Must be unique and cannot be empty.") }, "maxLength": 30, "name": "username", "selectOnFocus": true });
    var user_type2346 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Benutzerart</span>", "forceSelection": true, "hiddenName": "user_typeHidden", "listeners": { "render": Lino.quicktip_renderer("User type","(users.Users.user_type) The user type given to this user. Users having this field empty\nare considered inactive and cannot log in.") }, "name": "user_type", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.users.UserTypes) });
    var partner2347 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Partner</span>", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(users.Users.partner) Pointer to the Partner instance related to\nthis user.") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/Users/partner" }) }) });
    var box1_1_panel2348 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 34, "items": username2345, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 32, "items": user_type2346, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 32, "items": partner2347, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var first_name2352 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Vorname", "listeners": { "render": Lino.quicktip_renderer("First name","(users.Users.first_name) ") }, "maxLength": 30, "name": "first_name", "selectOnFocus": true });
    var last_name2353 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Familienname", "listeners": { "render": Lino.quicktip_renderer("Last name","(users.Users.last_name) ") }, "maxLength": 30, "name": "last_name", "selectOnFocus": true });
    var initials2354 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "boxMinWidth": Lino.chars2width(10), "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Initialien</span>", "listeners": { "render": Lino.quicktip_renderer("Initials","(users.Users.initials) The nickname or initials of this user. This does not need to\nbe unique but should provide a reasonably identifying\nfunction.") }, "maxLength": 10, "name": "initials", "selectOnFocus": true });
    var box1_2_panel2355 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 39, "items": first_name2352, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 39, "items": last_name2353, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": initials2354, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var email2359 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "E-Mail-Adresse", "listeners": { "render": Lino.quicktip_renderer("e-mail address","(users.Users.email) ") }, "maxLength": 254, "name": "email", "selectOnFocus": true });
    var language2360 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Sprache", "hiddenName": "languageHidden", "listeners": { "render": Lino.quicktip_renderer("Language","(users.Users.language) ") }, "name": "language", "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var box1_3_panel2361 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 51, "items": email2359, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 48, "items": language2360, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var id2364 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(users.Users.id) ") }, "name": "id", "selectOnFocus": true });
    var created2365 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Erstellt</span>", "listeners": { "render": Lino.quicktip_renderer("Created","(users.Users.created) The time when this object was created.") }, "name": "created", "value": "<br>" });
    var modified2366 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bearbeitet</span>", "listeners": { "render": Lino.quicktip_renderer("Modified","(users.Users.modified) The time when this database object was last modified.") }, "name": "modified", "value": "<br>" });
    var box1_4_panel2367 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 13, "items": id2364, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 43, "items": created2365, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 43, "items": modified2366, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var box1_panel2371 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ box1_1_panel2348, box1_2_panel2355, box1_3_panel2361, box1_4_panel2367 ], "labelAlign": "top", "layout": "form" });
    var remarks2372 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Bemerkungen", "flex": 66, "name": "remarks", "selectOnFocus": true, "title": "Bemerkungen" });
    var AuthoritiesGiven_grid2375 = new Lino.users.AuthoritiesGiven.GridPanel({ "containing_panel": this, "flex": 33, "hideHeaders": true, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Authorities given","(users.users.AuthoritiesGiven) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.users.AuthoritiesGiven.grid) ] });
    var general_2_panel2376 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 55, "frame": false, "hideCheckBoxLabels": true, "items": [ remarks2372, AuthoritiesGiven_grid2375 ], "labelAlign": "top", "labelWidth": 108, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var general_panel2377 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ box1_panel2371, general_2_panel2376 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Allgemein" });
    var event_type2378 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.cal.EventTypes.detail", "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Standard-Kalenderintragsart</span>", "hiddenName": "event_typeHidden", "insert_action": "Lino.cal.EventTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Default Event Type","(users.Users.event_type) The default event type for your calendar events.") }, "name": "event_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.cal.EventTypes.detail,Lino.cal.EventTypes.insert)}, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/Users/event_type" }) }) });
    var access_class2379 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Standardm\u00e4\u00dfige Zugriffsklasse</span>", "forceSelection": true, "hiddenName": "access_classHidden", "listeners": { "render": Lino.quicktip_renderer("Default access class","(users.Users.access_class) The default access class for your calendar events and tasks.") }, "name": "access_class", "selectOnFocus": true, "store": Lino.cal.AccessClasses });
    var calendar_1_panel2380 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 62, "items": event_type2378, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 37, "items": access_class2379, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var cal_SubscriptionsByUser_grid2388 = new Lino.cal.SubscriptionsByUser.GridPanel({ "containing_panel": this, "flex": 83, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Subscriptions","(cal.cal.SubscriptionsByUser) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.cal.SubscriptionsByUser.grid) ] });
    var calendar_panel2389 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ calendar_1_panel2380, cal_SubscriptionsByUser_grid2388 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Kalender" });
    var dashboard_WidgetsByUser_grid2398 = new Lino.dashboard.WidgetsByUser.GridPanel({ "containing_panel": this, "hide_top_toolbar": true, "listeners": { "activate": Lino.on_tab_activate }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "title": "Dashboard", "tools": [ Lino.show_in_own_window_button(Lino.dashboard.WidgetsByUser.grid) ] });
    var main_panel2399 = new Ext.TabPanel({ "activeTab": 0, "autoScroll": false, "bodyBorder": false, "border": false, "enableTabScroll": true, "frame": true, "hideCheckBoxLabels": true, "items": [ general_panel2377, calendar_panel2389, dashboard_WidgetsByUser_grid2398 ], "labelAlign": "top", "split": true });
    this.items = main_panel2399;
    this.before_row_edit = function(record) {
      remarks2372.refresh();
      AuthoritiesGiven_grid2375.on_master_changed();
      cal_SubscriptionsByUser_grid2388.on_master_changed();
      dashboard_WidgetsByUser_grid2398.on_master_changed();
    }
    Lino.users.AllUsers.DetailFormPanel.superclass.initComponent.call(this);
    // active_fields:
    partner2347.on("change", function(){ this.save() }, this);
  }
});


Lino.comments.CommentTypes.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel comments-CommentTypes",
  layout: 'fit',
  auto_save: true,
  content_type: 62,
  initComponent : function() {
    var id2400 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(comments.CommentTypes.id) ") }, "name": "id", "selectOnFocus": true });
    var name2401 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(comments.CommentTypes.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2402 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(comments.CommentTypes.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2403 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(comments.CommentTypes.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel2404 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 7, "items": id2400, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name2401, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_de2402, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_fr2403, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var comments_CommentsByType_htmlbox2409 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 75, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Comments","(comments.CommentTypes.comments_CommentsByType) ") }, "master_panel": this, "name": "comments_CommentsByType", "title": "Kommentare", "tools": [ Lino.show_in_own_window_button(Lino.comments.CommentsByType.grid) ], "value": "<br/>" });
    var main_panel2410 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2404, comments_CommentsByType_htmlbox2409 ], "labelAlign": "top", "labelWidth": 99, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2410;
    this.before_row_edit = function(record) {
      comments_CommentsByType_htmlbox2409.refresh();
    }
    Lino.comments.CommentTypes.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.comments.CommentTypes.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel comments-CommentTypes",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 62,
  initComponent : function() {
    var name2411 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(comments.CommentTypes.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2412 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(comments.CommentTypes.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2413 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(comments.CommentTypes.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel2414 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name2411, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de2412, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr2413, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var id2418 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(comments.CommentTypes.id) ") }, "name": "id", "selectOnFocus": true });
    var main_panel2419 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2414, { "anchor": "-20", "autoHeight": true, "items": id2418, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2419;
    this.before_row_edit = function(record) {
    }
    Lino.comments.CommentTypes.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.phones.ContactDetails.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel phones-ContactDetails",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 42,
  initComponent : function() {
    var detail_type2421 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Kontaktangabenart", "forceSelection": true, "hiddenName": "detail_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Contact detail type","(phones.ContactDetails.detail_type) ") }, "name": "detail_type", "selectOnFocus": true, "store": Lino.phones.ContactDetailTypes });
    var value2422 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Wert", "listeners": { "render": Lino.quicktip_renderer("Value","(phones.ContactDetails.value) ") }, "maxLength": 200, "name": "value", "selectOnFocus": true });
    var remark2423 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(phones.ContactDetails.remark) ") }, "maxLength": 200, "name": "remark", "selectOnFocus": true });
    var main_panel2424 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": detail_type2421, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": value2422, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": remark2423, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2424;
    this.before_row_edit = function(record) {
    }
    Lino.phones.ContactDetails.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.comments.Comments.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel comments-Comments",
  layout: 'fit',
  auto_save: true,
  content_type: 63,
  initComponent : function() {
    var owner_disp2428 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Thema</span>", "name": "owner" });
    var private2429 = new Ext.form.Checkbox({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "boxLabel": "Privat", "checked": true, "hideLabel": true, "listeners": { "render": Lino.quicktip_renderer("Private","(comments.Comments.private) ") }, "name": "private", "selectOnFocus": true });
    var general1_1_panel2430 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": owner_disp2428, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": private2429, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var reply_to2433 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.comments.Comments.detail", "emptyText": "Kommentar ausw\u00e4hlen...", "fieldLabel": "Antwort auf", "hiddenName": "reply_toHidden", "insert_action": "Lino.comments.Comments.insert", "listeners": { "render": Lino.quicktip_renderer("Reply to","(comments.Comments.reply_to) ") }, "name": "reply_to", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.comments.Comments.detail,Lino.comments.Comments.insert)}, "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/reply_to" }) }) });
    var pick_my_emotion_disp2434 = new Ext.form.DisplayField({ "always_enabled": true, "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Emotion ausw\u00e4hlen", "listeners": { "render": Lino.quicktip_renderer("Pick Emotion","(comments.Comments.pick_my_emotion) ") }, "name": "pick_my_emotion", "value": "<br/>" });
    var general1_2_panel2435 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 40, "items": reply_to2433, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 60, "items": pick_my_emotion_disp2434, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var full_preview2438 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Vorschau (komplett)</span>", "flex": 55, "name": "full_preview", "title": "Vorschau (komplett)" });
    var general1_panel2439 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "flex": 50, "frame": true, "hideCheckBoxLabels": true, "items": [ general1_1_panel2430, general1_2_panel2435, full_preview2438 ], "labelAlign": "top", "labelWidth": 180, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    var comments_RepliesByComment_htmlbox2440 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 50, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Replies","(comments.Comments.comments_RepliesByComment) ") }, "master_panel": this, "name": "comments_RepliesByComment", "title": "Antworten", "tools": [ Lino.show_in_own_window_button(Lino.comments.RepliesByComment.grid) ], "value": "<br/>" });
    var general_1_panel2441 = new Ext.Panel({ "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ general1_panel2439, comments_RepliesByComment_htmlbox2440 ], "labelAlign": "top", "labelWidth": 90, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Allgemein" });
    var body2442 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Inhalt</span>", "flex": 65, "name": "body", "selectOnFocus": true, "title": "Inhalt" });
    var id2443 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(comments.Comments.id) ") }, "name": "id", "selectOnFocus": true });
    var user2444 = new Lino.TwinCombo({ "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(comments.Comments.user) The author of the comment.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers" });
    var more2_1_panel2445 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 20, "items": id2443, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 80, "items": user2444, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var owner_type2448 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.gfks.ContentTypes.detail", "emptyText": "Datenbankmodell ausw\u00e4hlen...", "fieldLabel": "Thema (Modell)", "hiddenName": "owner_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Topic (type)","(comments.Comments.owner_type) ") }, "name": "owner_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.gfks.ContentTypes.detail,null)}, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/owner_type" }) }) });
    var owner_id2449 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "can_create_choice": false, "fieldLabel": "Thema (Objekt)", "hiddenName": "owner_idHidden", "listeners": { "render": Lino.quicktip_renderer("Topic (object)","(comments.Comments.owner_id) ") }, "name": "owner_id", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/owner_id" }) }) });
    var more2_2_panel2450 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 66, "items": owner_type2448, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": owner_id2449, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var created2453 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Erstellt</span>", "listeners": { "render": Lino.quicktip_renderer("Created","(comments.Comments.created) The time when this object was created.") }, "name": "created", "value": "<br>" });
    var modified2454 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Bearbeitet</span>", "listeners": { "render": Lino.quicktip_renderer("Modified","(comments.Comments.modified) The time when this database object was last modified.") }, "name": "modified", "value": "<br>" });
    var more2_3_panel2455 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": created2453, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": modified2454, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var comment_type2458 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.comments.CommentTypes.detail", "emptyText": "Kommentar-Art ausw\u00e4hlen...", "fieldLabel": "Kommentar-Art", "hiddenName": "comment_typeHidden", "insert_action": "Lino.comments.CommentTypes.insert", "listeners": { "render": Lino.quicktip_renderer("Comment Type","(comments.Comments.comment_type) ") }, "name": "comment_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.comments.CommentTypes.detail,Lino.comments.CommentTypes.insert)}, "pageSize": 20, "related_actor_id": "comments.CommentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/comment_type" }) }) });
    var more2_panel2459 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "flex": 34, "frame": true, "hideCheckBoxLabels": true, "items": [ more2_1_panel2445, more2_2_panel2450, more2_3_panel2455, { "anchor": "-20", "autoHeight": true, "items": comment_type2458, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    var more_1_panel2461 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ body2442, more2_panel2459 ], "labelAlign": "top", "labelWidth": 63, "layout": "hbox", "layoutConfig": { "align": "stretchmax" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Mehr" });
    var main_panel2462 = new Ext.TabPanel({ "activeTab": 0, "autoScroll": false, "bodyBorder": false, "border": false, "enableTabScroll": true, "frame": true, "hideCheckBoxLabels": true, "items": [ general_1_panel2441, more_1_panel2461 ], "labelAlign": "top", "split": true });
    this.items = main_panel2462;
    this.before_row_edit = function(record) {
      full_preview2438.refresh();
      comments_RepliesByComment_htmlbox2440.refresh();
      body2442.refresh();
      owner_id2449.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    }
    this.onRender = function(ct, position) {
      typeof owner_type2448 !== 'undefined' && owner_type2448.on('change',Lino.chooser_handler(owner_id2449,'owner_type'));
      Lino.comments.Comments.DetailFormPanel.superclass.onRender.call(this, ct, position);
    }
    Lino.comments.Comments.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.households.Types.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel households-Types",
  layout: 'fit',
  auto_save: true,
  content_type: 43,
  initComponent : function() {
    var name2463 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(households.Types.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2464 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(households.Types.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2465 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(households.Types.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel2466 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": name2463, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_de2464, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": name_fr2465, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var HouseholdsByType_grid2537 = new Lino.households.HouseholdsByType.GridPanel({ "containing_panel": this, "flex": 83, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Households","(households.households.HouseholdsByType) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.households.HouseholdsByType.grid) ] });
    var main_panel2538 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2466, HouseholdsByType_grid2537 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2538;
    this.before_row_edit = function(record) {
      HouseholdsByType_grid2537.on_master_changed();
    }
    Lino.households.Types.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.lists.Lists.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel lists-Lists",
  layout: 'fit',
  auto_save: true,
  content_type: 55,
  initComponent : function() {
    var id2539 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(lists.Lists.id) ") }, "name": "id", "selectOnFocus": true });
    var ref2540 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(lists.Lists.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var list_type2541 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "emptyText": "Listenart ausw\u00e4hlen...", "fieldLabel": "Listenart", "hiddenName": "list_typeHidden", "listeners": { "render": Lino.quicktip_renderer("List Type","(lists.Lists.list_type) ") }, "name": "list_type", "pageSize": 20, "related_actor_id": "lists.ListTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/Lists/list_type" }) }) });
    var print_actions_disp2542 = new Ext.form.DisplayField({ "always_enabled": true, "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Drucken", "listeners": { "render": Lino.quicktip_renderer("Print","(lists.Lists.print_actions) ") }, "name": "print_actions", "value": "<br/>" });
    var main_1_panel2543 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 5, "items": id2539, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 42, "items": ref2540, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 21, "items": list_type2541, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 31, "items": print_actions_disp2542, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var designation2548 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(lists.Lists.designation) ") }, "maxLength": 200, "name": "designation", "selectOnFocus": true });
    var designation_de2549 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(lists.Lists.designation_de) ") }, "maxLength": 200, "name": "designation_de", "selectOnFocus": true });
    var designation_fr2550 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(lists.Lists.designation_fr) ") }, "maxLength": 200, "name": "designation_fr", "selectOnFocus": true });
    var main_2_panel2551 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 33, "items": designation2548, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": designation_de2549, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": designation_fr2550, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var remarks2555 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "Bemerkungen", "flex": 35, "name": "remarks", "selectOnFocus": true, "title": "Bemerkungen" });
    var MembersByList_grid2565 = new Lino.lists.MembersByList.GridPanel({ "containing_panel": this, "flex": 35, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Members","(lists.lists.MembersByList) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.lists.MembersByList.grid) ] });
    var main_panel2566 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2543, main_2_panel2551, remarks2555, MembersByList_grid2565 ], "labelAlign": "top", "labelWidth": 108, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2566;
    this.before_row_edit = function(record) {
      remarks2555.refresh();
      MembersByList_grid2565.on_master_changed();
    }
    Lino.lists.Lists.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.blogs.Entries.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel blogs-Entries",
  layout: 'fit',
  auto_save: true,
  content_type: 58,
  initComponent : function() {
    var title2189 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "\u00dcberschrift", "listeners": { "render": Lino.quicktip_renderer("Heading","(blogs.Entries.title) ") }, "maxLength": 200, "name": "title", "selectOnFocus": true });
    var entry_type2190 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.blogs.EntryTypes.detail", "emptyText": "Blog Entry Type ausw\u00e4hlen...", "fieldLabel": "Blog Entry Type", "hiddenName": "entry_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Blog Entry Type","(blogs.Entries.entry_type) ") }, "name": "entry_type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.blogs.EntryTypes.detail,null)}, "pageSize": 20, "related_actor_id": "blogs.EntryTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/Entries/entry_type" }) }) });
    var id2191 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(blogs.Entries.id) ") }, "name": "id", "selectOnFocus": true });
    var main_1_panel2192 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 55, "items": title2189, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 31, "items": entry_type2190, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 13, "items": id2191, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var pub_date2196 = new Lino.DateField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bildungsart", "listeners": { "render": Lino.quicktip_renderer("Publication date","(blogs.Entries.pub_date) ") }, "name": "pub_date", "selectOnFocus": true });
    var pub_time2197 = new Lino.TimeField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bildungsart", "listeners": { "render": Lino.quicktip_renderer("Publication time","(blogs.Entries.pub_time) ") }, "maxValue": "9:00 PM", "minValue": "7:00", "name": "pub_time", "selectOnFocus": true });
    var user2198 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Autor</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Author","(blogs.Entries.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/Entries/user" }) }) });
    var language2199 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Sprache", "hiddenName": "languageHidden", "listeners": { "render": Lino.quicktip_renderer("Language","(blogs.Entries.language) ") }, "name": "language", "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var owner_disp2200 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Verkn\u00fcpft mit", "name": "owner" });
    var add_interest2201 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.topics.Topics.detail", "emptyText": "Thema ausw\u00e4hlen...", "fieldLabel": "Add interest", "hiddenName": "add_interestHidden", "insert_action": "Lino.topics.Topics.insert", "listeners": { "render": Lino.quicktip_renderer("Add interest","(blogs.Entries.add_interest) ") }, "name": "add_interest", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.topics.Topics.detail,Lino.topics.Topics.insert)}, "pageSize": 20, "related_actor_id": "topics.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/Entries/add_interest" }) }) });
    var main_2_panel2202 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 18, "items": pub_date2196, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 11, "items": pub_time2197, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": user2198, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": language2199, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 14, "items": owner_disp2200, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 28, "items": add_interest2201, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var body2209 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Inhalt</span>", "flex": 75, "name": "body", "region": "center", "selectOnFocus": true, "title": "Inhalt" });
    var main_3_panel2211 = new Ext.Panel({ "autoScroll": false, "border": false, "flex": 71, "frame": false, "hideCheckBoxLabels": true, "items": [ body2209 ], "labelAlign": "top", "labelWidth": 99, "layout": "hbox", "layoutConfig": { "align": "stretch" } });
    var main_panel2212 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2192, main_2_panel2202, main_3_panel2211 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2212;
    this.before_row_edit = function(record) {
      body2209.refresh();
    }
    Lino.blogs.Entries.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.checkdata.Problems.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel checkdata-Problems",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 14,
  disable_editing: true,
  initComponent : function() {
    var checker2070 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Checker</span>", "forceSelection": true, "hiddenName": "checkerHidden", "listeners": { "render": Lino.quicktip_renderer("Checker","(checkdata.Problems.checker) The Checker that reported this\nproblem.") }, "name": "checker", "selectOnFocus": true, "store": Lino.checkdata.Checkers });
    var owner_disp2071 = new Ext.form.DisplayField({ "anchor": "-20", "autoHeight": true, "disabled": true, "fieldLabel": "Datenobjekt", "name": "owner" });
    var message2072 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Meldung</span>", "listeners": { "render": Lino.quicktip_renderer("Message","(checkdata.Problems.message) The message text. This is a concatenation of all messages that\nwere yielded by the checker.") }, "maxLength": 250, "name": "message", "selectOnFocus": true });
    var user2073 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.users.AllUsers.detail", "emptyText": "Benutzer ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Verantwortlicher</span>", "hiddenName": "userHidden", "insert_action": "Lino.users.AllUsers.insert", "listeners": { "render": Lino.quicktip_renderer("Responsible","(checkdata.Problems.user) The user responsible for fixing this\nproblem.") }, "name": "user", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.users.AllUsers.detail,Lino.users.AllUsers.insert)}, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/Problems/user" }) }) });
    var id2074 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(checkdata.Problems.id) ") }, "name": "id", "selectOnFocus": true });
    var main_4_panel2075 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 66, "items": user2073, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 33, "items": id2074, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel2078 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": checker2070, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": owner_disp2071, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": message2072, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_4_panel2075 ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2078;
    this.before_row_edit = function(record) {
    }
    Lino.checkdata.Problems.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.households.Households.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel households-Households",
  layout: 'fit',
  auto_save: true,
  content_type: 45,
  initComponent : function() {
    var overview_htmlbox2495 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 40, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer(null,"(households.Households.overview) ") }, "name": "overview", "value": "<br/>" });
    var type2496 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.households.Types.detail", "emptyText": "Haushaltsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Haushaltsart</span>", "hiddenName": "typeHidden", "listeners": { "render": Lino.quicktip_renderer("Household Type","(households.Households.type) The type of this household.  See household types") }, "name": "type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.households.Types.detail,null)}, "pageSize": 20, "related_actor_id": "households.Types", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/Households/type" }) }) });
    var prefix2497 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Name prefix</span>", "listeners": { "render": Lino.quicktip_renderer("Name prefix","(households.Households.prefix) An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.") }, "maxLength": 200, "name": "prefix", "selectOnFocus": true });
    var name2498 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Name</span>", "listeners": { "render": Lino.quicktip_renderer("Name","(households.Households.name) The full name of this partner. Used for alphabetic sorting.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var language2499 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Sprache</span>", "hiddenName": "languageHidden", "listeners": { "render": Lino.quicktip_renderer("Language","(households.Households.language) The language to use when communicating with this partner.") }, "name": "language", "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var id2500 = new Ext.form.NumberField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "ID", "listeners": { "render": Lino.quicktip_renderer("ID","(households.Households.id) ") }, "name": "id", "selectOnFocus": true });
    var data_box_4_panel2501 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 80, "items": language2499, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 20, "items": id2500, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var data_box_panel2504 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "flex": 30, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": type2496, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": prefix2497, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": name2498, "labelAlign": "top", "layout": "form", "xtype": "panel" }, data_box_4_panel2501 ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    var lists_MembersByPartner_htmlbox2508 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 30, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("List memberships","(households.Households.lists_MembersByPartner) ") }, "master_panel": this, "name": "lists_MembersByPartner", "title": "Listenmitgliedschaften", "tools": [ Lino.show_in_own_window_button(Lino.lists.MembersByPartner.grid) ], "value": "<br/>" });
    var address_box_panel2509 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ overview_htmlbox2495, data_box_panel2504, lists_MembersByPartner_htmlbox2508 ], "labelAlign": "top", "labelWidth": 207, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var households_MembersByHousehold_grid2526 = new Lino.households.MembersByHousehold.GridPanel({ "containing_panel": this, "flex": 55, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer("Household Members","(households.households.MembersByHousehold) ") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 15, "tools": [ Lino.show_in_own_window_button(Lino.households.MembersByHousehold.grid) ] });
    var general_panel2527 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ address_box_panel2509, households_MembersByHousehold_grid2526 ], "labelAlign": "top", "layout": "vbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Allgemein" });
    var uploads_UploadsByController_htmlbox2528 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 37, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Upload files","(households.Households.uploads_UploadsByController) Shows the uploads controlled by this database object.") }, "master_panel": this, "name": "uploads_UploadsByController", "title": "Upload-Dateien", "tools": [ Lino.show_in_own_window_button(Lino.uploads.UploadsByController.grid) ], "value": "<br/>" });
    var comments_CommentsByRFC_htmlbox2529 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 62, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer("Comments","(households.Households.comments_CommentsByRFC) Shows the comments for a given database object.") }, "master_panel": this, "name": "comments_CommentsByRFC", "title": "Kommentare", "tools": [ Lino.show_in_own_window_button(Lino.comments.CommentsByRFC.grid) ], "value": "<br/>" });
    var more_1_panel2530 = new Ext.Panel({ "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ uploads_UploadsByController_htmlbox2528, comments_CommentsByRFC_htmlbox2529 ], "labelAlign": "top", "labelWidth": 135, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "listeners": { "activate": Lino.on_tab_activate }, "title": "Mehr" });
    var main_panel2531 = new Ext.TabPanel({ "activeTab": 0, "autoScroll": false, "bodyBorder": false, "border": false, "enableTabScroll": true, "frame": true, "hideCheckBoxLabels": true, "items": [ general_panel2527, more_1_panel2530 ], "labelAlign": "top", "split": true });
    this.items = main_panel2531;
    this.before_row_edit = function(record) {
      overview_htmlbox2495.refresh();
      lists_MembersByPartner_htmlbox2508.refresh();
      households_MembersByHousehold_grid2526.on_master_changed();
      uploads_UploadsByController_htmlbox2528.refresh();
      comments_CommentsByRFC_htmlbox2529.refresh();
    }
    Lino.households.Households.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.users.AllUsers.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel users-Users",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 2,
  initComponent : function() {
    var username2567 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Benutzername</span>", "listeners": { "render": Lino.quicktip_renderer("Username","(users.Users.username) Must be unique and cannot be empty.") }, "maxLength": 30, "name": "username", "selectOnFocus": true });
    var email2568 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "E-Mail-Adresse", "listeners": { "render": Lino.quicktip_renderer("e-mail address","(users.Users.email) ") }, "maxLength": 254, "name": "email", "selectOnFocus": true });
    var main_1_panel2569 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": username2567, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": email2568, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var first_name2572 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Vorname", "listeners": { "render": Lino.quicktip_renderer("First name","(users.Users.first_name) ") }, "maxLength": 30, "name": "first_name", "selectOnFocus": true });
    var last_name2573 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Familienname", "listeners": { "render": Lino.quicktip_renderer("Last name","(users.Users.last_name) ") }, "maxLength": 30, "name": "last_name", "selectOnFocus": true });
    var main_2_panel2574 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": first_name2572, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": last_name2573, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var partner2577 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Partner</span>", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(users.Users.partner) Pointer to the Partner instance related to\nthis user.") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/Users/partner" }) }) });
    var language2578 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Sprache", "hiddenName": "languageHidden", "listeners": { "render": Lino.quicktip_renderer("Language","(users.Users.language) ") }, "name": "language", "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var user_type2579 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Benutzerart</span>", "forceSelection": true, "hiddenName": "user_typeHidden", "listeners": { "render": Lino.quicktip_renderer("User type","(users.Users.user_type) The user type given to this user. Users having this field empty\nare considered inactive and cannot log in.") }, "name": "user_type", "selectOnFocus": true, "store": [['','<br>']].concat(Lino.users.UserTypes) });
    var main_4_panel2580 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 40, "items": language2578, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 60, "items": user_type2579, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var main_panel2583 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2569, main_2_panel2574, { "anchor": "-20", "autoHeight": true, "items": partner2577, "labelAlign": "top", "layout": "form", "xtype": "panel" }, main_4_panel2580 ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2583;
    this.before_row_edit = function(record) {
    }
    Lino.users.AllUsers.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.households.Households.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel households-Households",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 45,
  initComponent : function() {
    var type2585 = new Lino.TwinCombo({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.households.Types.detail", "emptyText": "Haushaltsart ausw\u00e4hlen...", "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Haushaltsart</span>", "hiddenName": "typeHidden", "listeners": { "render": Lino.quicktip_renderer("Household Type","(households.Households.type) The type of this household.  See household types") }, "name": "type", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.households.Types.detail,null)}, "pageSize": 20, "related_actor_id": "households.Types", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/Households/type" }) }) });
    var name2586 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Name</span>", "listeners": { "render": Lino.quicktip_renderer("Name","(households.Households.name) The full name of this partner. Used for alphabetic sorting.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var main_1_panel2587 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 48, "items": type2585, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 51, "items": name2586, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var language2590 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Sprache</span>", "hiddenName": "languageHidden", "listeners": { "render": Lino.quicktip_renderer("Language","(households.Households.language) The language to use when communicating with this partner.") }, "name": "language", "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var main_panel2591 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2587, { "anchor": "-20", "autoHeight": true, "items": language2590, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2591;
    this.before_row_edit = function(record) {
    }
    Lino.households.Households.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.ledger.Journals.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel ledger-Journals",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 31,
  initComponent : function() {
    var ref2593 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(ledger.Journals.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var name2594 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("Designation","(ledger.Journals.name) ") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var name_de2595 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("Designation (de)","(ledger.Journals.name_de) ") }, "maxLength": 200, "name": "name_de", "selectOnFocus": true });
    var name_fr2596 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("Designation (fr)","(ledger.Journals.name_fr) ") }, "maxLength": 200, "name": "name_fr", "selectOnFocus": true });
    var main_1_panel2597 = new Ext.Panel({ "anchor": "-20", "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 7, "items": ref2593, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name2594, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_de2595, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 30, "items": name_fr2596, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var journal_group2602 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Journalgruppe</span>", "forceSelection": true, "hiddenName": "journal_groupHidden", "listeners": { "render": Lino.quicktip_renderer("Journal group","(ledger.Journals.journal_group) Pointer to an item of JournalGroups.") }, "name": "journal_group", "selectOnFocus": true, "store": Lino.ledger.JournalGroups });
    var voucher_type2603 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Belegart</span>", "listeners": { "render": Lino.quicktip_renderer("Voucher type","(ledger.Journals.voucher_type) Pointer to an item of VoucherTypes.") }, "maxLength": 100, "name": "voucher_type", "selectOnFocus": true });
    var main_panel2604 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2597, { "anchor": "-20", "autoHeight": true, "items": journal_group2602, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": voucher_type2603, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2604;
    this.before_row_edit = function(record) {
    }
    Lino.ledger.Journals.InsertFormPanel.superclass.initComponent.call(this);
  }
});


Lino.uploads.Volumes.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel uploads-Volumes",
  layout: 'fit',
  auto_save: true,
  content_type: 27,
  initComponent : function() {
    var ref2607 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Referenz</span>", "listeners": { "render": Lino.quicktip_renderer("Reference","(uploads.Volumes.ref) The reference. This must be either empty or unique.") }, "maxLength": 200, "name": "ref", "selectOnFocus": true });
    var description2608 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("Description","(uploads.Volumes.description) ") }, "maxLength": 255, "name": "description", "selectOnFocus": true });
    var main_1_panel2609 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 65, "items": ref2607, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 34, "items": description2608, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var root_dir2612 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Root directory", "listeners": { "render": Lino.quicktip_renderer("Root directory","(uploads.Volumes.root_dir) ") }, "maxLength": 255, "name": "root_dir", "selectOnFocus": true });
    var base_url2613 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Base URL", "listeners": { "render": Lino.quicktip_renderer("Base URL","(uploads.Volumes.base_url) ") }, "maxLength": 255, "name": "base_url", "selectOnFocus": true });
    var main_2_panel2614 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ { "autoHeight": true, "flex": 50, "items": root_dir2612, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "autoHeight": true, "flex": 50, "items": base_url2613, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretchmax" } });
    var overview_htmlbox2617 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 60, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer(null,"(uploads.Volumes.overview) ") }, "name": "overview", "value": "<br/>" });
    var main_panel2618 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ main_1_panel2609, main_2_panel2614, overview_htmlbox2617 ], "labelAlign": "top", "labelWidth": 0, "layout": "vbox", "layoutConfig": { "align": "stretch" } });
    this.items = main_panel2618;
    this.before_row_edit = function(record) {
      overview_htmlbox2617.refresh();
    }
    Lino.uploads.Volumes.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.DailyView.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel calview-DailyView",
  layout: 'fit',
  auto_save: true,
  disable_editing: true,
  initComponent : function() {
    var navigation_panel_htmlbox2619 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "flex": 15, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "listeners": { "render": Lino.quicktip_renderer(null,"(calview.DailyView.navigation_panel) ") }, "name": "navigation_panel", "value": "<br/>" });
    var calview_DailySlave_grid2624 = new Lino.calview.DailySlave.GridPanel({ "containing_panel": this, "flex": 85, "hide_top_toolbar": true, "listeners": { "render": Lino.quicktip_renderer(null,"(calview.calview.DailySlave) The virtual table used to render the daily planner.") }, "master_panel": this, "params_panel_hidden": true, "preview_limit": 0 });
    var body_panel2625 = new Ext.Panel({ "autoScroll": false, "border": false, "frame": false, "hideCheckBoxLabels": true, "items": [ navigation_panel_htmlbox2619, calview_DailySlave_grid2624 ], "labelAlign": "top", "labelWidth": 0, "layout": "hbox", "layoutConfig": { "align": "stretch" }, "region": "center" });
    var main_panel2626 = new Ext.Panel({ "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ body_panel2625 ], "labelAlign": "top", "layout": "fit" });
    this.items = main_panel2626;
    this.before_row_edit = function(record) {
      navigation_panel_htmlbox2619.refresh();
      calview_DailySlave_grid2624.on_master_changed();
    }
    Lino.calview.DailyView.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.phones.ContactDetails.DetailFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-DetailFormPanel phones-ContactDetails",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 42,
  initComponent : function() {
    var partner2627 = new Lino.TwinCombo({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "detail_action": "Lino.contacts.Partners.detail", "emptyText": "Partner ausw\u00e4hlen...", "fieldLabel": "Partner", "hiddenName": "partnerHidden", "listeners": { "render": Lino.quicktip_renderer("Partner","(phones.ContactDetails.partner) ") }, "name": "partner", "onTrigger2Click": function(e){ Lino.show_fk_detail(this,Lino.contacts.Partners.detail,null)}, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/phones/ContactDetails/partner" }) }) });
    var detail_type2628 = new Lino.ChoicesFieldElement({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "Kontaktangabenart", "forceSelection": true, "hiddenName": "detail_typeHidden", "listeners": { "render": Lino.quicktip_renderer("Contact detail type","(phones.ContactDetails.detail_type) ") }, "name": "detail_type", "selectOnFocus": true, "store": Lino.phones.ContactDetailTypes });
    var value2629 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Wert", "listeners": { "render": Lino.quicktip_renderer("Value","(phones.ContactDetails.value) ") }, "maxLength": 200, "name": "value", "selectOnFocus": true });
    var remark2630 = new Ext.form.TextField({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("Remark","(phones.ContactDetails.remark) ") }, "maxLength": 200, "name": "remark", "selectOnFocus": true });
    var main_panel2631 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": partner2627, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": detail_type2628, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": value2629, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": remark2630, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2631;
    this.before_row_edit = function(record) {
    }
    Lino.phones.ContactDetails.DetailFormPanel.superclass.initComponent.call(this);
  }
});


Lino.households.HouseholdsByType.InsertFormPanel = Ext.extend(Lino.FormPanel,{
cls: "l-InsertFormPanel households-HouseholdsByType",
  layout: 'fit',
  auto_save: true,
  autoHeight: true,
  content_type: 45,
  initComponent : function() {
    var name2532 = new Ext.form.TextField({ "allowBlank": false, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Name</span>", "listeners": { "render": Lino.quicktip_renderer("Name","(households.HouseholdsByType.name) The full name of this partner. Used for alphabetic sorting.") }, "maxLength": 200, "name": "name", "selectOnFocus": true });
    var language2533 = new Lino.ChoicesFieldElement({ "allowBlank": true, "anchor": "-20", "autoHeight": true, "fieldLabel": "<span style=\"border-bottom: 1px dotted #000000;\">Sprache</span>", "hiddenName": "languageHidden", "listeners": { "render": Lino.quicktip_renderer("Language","(households.HouseholdsByType.language) The language to use when communicating with this partner.") }, "name": "language", "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var main_panel2534 = new Ext.Panel({ "autoHeight": true, "autoScroll": false, "bodyBorder": false, "border": false, "frame": true, "hideCheckBoxLabels": true, "items": [ { "anchor": "-20", "autoHeight": true, "items": name2532, "labelAlign": "top", "layout": "form", "xtype": "panel" }, { "anchor": "-20", "autoHeight": true, "items": language2533, "labelAlign": "top", "layout": "form", "xtype": "panel" } ], "labelAlign": "top", "labelWidth": 0, "layout": "form" });
    this.items = main_panel2534;
    this.before_row_edit = function(record) {
    }
    Lino.households.HouseholdsByType.InsertFormPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.Partners.merge_row = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/contacts/Partners" };
  return new Lino.contacts.Partners.merge_row_ActionFormPanel(p);
});
Lino.contacts.Persons.merge_row = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/contacts/Persons" };
  return new Lino.contacts.Persons.merge_row_ActionFormPanel(p);
});
Lino.contacts.Persons.create_household = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/contacts/Persons" };
  return new Lino.contacts.Persons.create_household_ActionFormPanel(p);
});
Lino.contacts.Companies.merge_row = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/contacts/Companies" };
  return new Lino.contacts.Companies.merge_row_ActionFormPanel(p);
});
Lino.cal.GuestRoles.merge_row = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/GuestRoles" };
  return new Lino.cal.GuestRoles.merge_row_ActionFormPanel(p);
});
Lino.cal.EventTypes.merge_row = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/EventTypes" };
  return new Lino.cal.EventTypes.merge_row_ActionFormPanel(p);
});
Lino.uploads.Volumes.merge_row = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/uploads/Volumes" };
  return new Lino.uploads.Volumes.merge_row_ActionFormPanel(p);
});
Lino.households.Households.merge_row = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/households/Households" };
  return new Lino.households.Households.merge_row_ActionFormPanel(p);
});
Lino.topics.Topics.merge_row = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/topics/AllTopics" };
  return new Lino.topics.Topics.merge_row_ActionFormPanel(p);
});
Lino.lists.Lists.merge_row = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/lists/Lists" };
  return new Lino.lists.Lists.merge_row_ActionFormPanel(p);
});
Lino.users.AllUsers.change_password = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/users/AllUsers" };
  return new Lino.users.AllUsers.change_password_ActionFormPanel(p);
});
Lino.users.AllUsers.send_welcome_email = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/users/AllUsers" };
  return new Lino.users.AllUsers.send_welcome_email_ActionFormPanel(p);
});
Lino.users.UsersOverview.sign_in = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/users/UsersOverview" };
  return new Lino.users.UsersOverview.sign_in_ActionFormPanel(p);
});
Lino.courses.Lines.merge_row = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/Lines" };
  return new Lino.courses.Lines.merge_row_ActionFormPanel(p);
});
Lino.courses.Activities.print_presence_sheet = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/Activities" };
  return new Lino.courses.Activities.print_presence_sheet_ActionFormPanel(p);
});
Lino.courses.Activities.print_presence_sheet_html = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/Activities" };
  return new Lino.courses.Activities.print_presence_sheet_html_ActionFormPanel(p);
});

// js_render_GridPanel_class system.SiteConfigs
Lino.system.SiteConfigs.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/system/SiteConfigs",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "default_build_method" }, 'default_build_methodHidden', { "dateFormat": "d.m.Y", "name": "simulate_today", "type": "date" }, { "name": "site_company" }, 'site_companyHidden', { "name": "next_partner_id", "type": "int", "useNull": true }, { "name": "default_event_type" }, 'default_event_typeHidden', { "name": "site_calendar" }, 'site_calendarHidden', { "name": "max_auto_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "hide_events_before", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 1,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "itemId": "do_build", "menu_item_text": "Site-Cache rekonstruieren", "overflowText": "Site-Cache rekonstruieren", "panel_btn_handler": Lino.row_action_handler('do_build','GET',null), "text": "Site-Cache rekonstruieren", "tooltip": "Rebuild the site cache.\nThis action is available on About.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Site-Konfigurations",
  disabled_fields_index : 13,
  initComponent : function() {
    this.ls_detail_handler = Lino.system.SiteConfigs.detail;
    var ww = this.containing_window;
    var id2643 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var default_build_method2644 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var simulate_today2645 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var site_company2646 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/system/SiteConfigs/site_company" }) }) });
    var next_partner_id2647 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true, "value": 100 });
    var default_event_type2648 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/system/SiteConfigs/default_event_type" }) }) });
    var site_calendar2649 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalender ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Calendars", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/system/SiteConfigs/site_calendar" }) }) });
    var max_auto_events2650 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true, "value": 72 });
    var hide_events_before2651 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id2643, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(system.SiteConfigs.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "default_build_method", "editable": true, "editor": default_build_method2644, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Standard-Konstruktionsmethode", "listeners": { "render": Lino.quicktip_renderer("","(system.SiteConfigs.default_build_method) The default build method to use when rendering printable documents.") }, "sortable": false, "tooltip": "The default build method to use when rendering printable documents.", "width": Lino.chars2width(24) }, { "colIndex": 2, "dataIndex": "simulate_today", "editable": true, "editor": simulate_today2645, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Simuliertes Datum", "listeners": { "render": Lino.quicktip_renderer("","(system.SiteConfigs.simulate_today) A constant user-defined date to be substituted as current\nsystem date.") }, "sortable": true, "tooltip": "A constant user-defined date to be substituted as current\nsystem date.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 3, "dataIndex": "site_company", "editable": true, "editor": site_company2646, "filter": { "type": "string" }, "header": "Site-Besitzer", "listeners": { "render": Lino.quicktip_renderer("","(system.SiteConfigs.site_company) The site operator, i.e. the legal person that operates this\nLino site.") }, "renderer": Lino.fk_renderer('site_companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "The site operator, i.e. the legal person that operates this\nLino site.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 4, "dataIndex": "next_partner_id", "editable": true, "editor": next_partner_id2647, "filter": { "type": "numeric" }, "format": "0", "header": "N\u00e4chste Partnernummer", "listeners": { "render": Lino.quicktip_renderer("","(system.SiteConfigs.next_partner_id) N\u00e4chste Partnernummer") }, "sortable": true, "tooltip": "N\u00e4chste Partnernummer", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "default_event_type", "editable": true, "editor": default_event_type2648, "filter": { "type": "string" }, "header": "Standard-Kalenderintragsart", "listeners": { "render": Lino.quicktip_renderer("","(system.SiteConfigs.default_event_type) The default type of events on this site.") }, "renderer": Lino.fk_renderer('default_event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The default type of events on this site.", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "site_calendar", "editable": true, "editor": site_calendar2649, "filter": { "type": "string" }, "header": "Site Calendar", "listeners": { "render": Lino.quicktip_renderer("","(system.SiteConfigs.site_calendar) The default calendar of this site.") }, "renderer": Lino.fk_renderer('site_calendarHidden','Lino.cal.Calendars.detail'), "sortable": false, "tooltip": "The default calendar of this site.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 7, "dataIndex": "max_auto_events", "editable": true, "editor": max_auto_events2650, "filter": { "type": "numeric" }, "format": "0", "header": "Max automatic events", "listeners": { "render": Lino.quicktip_renderer("","(system.SiteConfigs.max_auto_events) Maximum number of automatic events to be generated.") }, "sortable": true, "tooltip": "Maximum number of automatic events to be generated.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 8, "dataIndex": "hide_events_before", "editable": true, "editor": hide_events_before2651, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Hide events before", "listeners": { "render": Lino.quicktip_renderer("","(system.SiteConfigs.hide_events_before) If this is not empty, any calendar events before that date are\nbeing hidden in certain places.") }, "sortable": true, "tooltip": "If this is not empty, any calendar events before that date are\nbeing hidden in certain places.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.system.SiteConfigs.GridPanel.superclass.initComponent.call(this);
  }
});


Lino.system.SiteConfigs.detailPanel = Ext.extend(Lino.system.SiteConfigs.DetailFormPanel,{
  empty_title: "Site-Konfigurations",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "do_build", "menu_item_text": "Site-Cache rekonstruieren", "overflowText": "Site-Cache rekonstruieren", "panel_btn_handler": Lino.row_action_handler('do_build','GET',null), "text": "Site-Cache rekonstruieren", "tooltip": "Rebuild the site cache.\nThis action is available on About.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/system/SiteConfigs",
  initComponent : function() {
    this.ls_detail_handler = Lino.system.SiteConfigs.detail;
    Lino.system.SiteConfigs.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.system.SiteConfigs.detail = new Lino.WindowAction({  }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/system/SiteConfigs" };
  return new Lino.system.SiteConfigs.detailPanel(p);
});
Lino.system.SiteConfigs.do_build = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/SiteConfigs", "GET", pk, "do_build", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.SiteConfigs.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/SiteConfigs", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class countries.Countries
Lino.countries.Countries.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/countries/Countries",
  ls_store_fields : [ { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "isocode" }, { "name": "short_code" }, { "name": "iso3" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "isocode",
  pk_index : 3,
  content_type : 4,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/countries/Countries','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/countries/Countries','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/countries/Countries','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/countries/Countries','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/countries/Countries','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Land) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "L\u00e4nder",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.Countries.detail;
    this.ls_insert_handler = Lino.countries.Countries.insert;
    var ww = this.containing_window;
    var name2653 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de2654 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr2655 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var isocode2656 = new Ext.form.TextField({ "allowBlank": false, "boxMinWidth": Lino.chars2width(4), "maxLength": 4, "selectOnFocus": true });
    var short_code2657 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(4), "hidden": true, "maxLength": 4, "selectOnFocus": true });
    var iso32658 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(3), "hidden": true, "maxLength": 3, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name", "editable": true, "editor": name2653, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(countries.Countries.name) The designation of this country.") }, "sortable": true, "tooltip": "The designation of this country.", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name_de", "editable": true, "editor": name_de2654, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(countries.Countries.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_fr", "editable": true, "editor": name_fr2655, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(countries.Countries.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "isocode", "editable": true, "editor": isocode2656, "filter": { "type": "string" }, "header": "ISO-Code", "listeners": { "render": Lino.quicktip_renderer("","(countries.Countries.isocode) The two-letter code for this country as defined by ISO 3166-1.\nFor countries that no longer exist it may be a 4-letter code.") }, "sortable": true, "tooltip": "The two-letter code for this country as defined by ISO 3166-1.\nFor countries that no longer exist it may be a 4-letter code.", "width": Lino.chars2width(11) }, { "colIndex": 4, "dataIndex": "short_code", "editable": true, "editor": short_code2657, "filter": { "type": "string" }, "header": "Short code", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.Countries.short_code) A short abbreviation for regional usage. Obsolete.") }, "sortable": true, "tooltip": "A short abbreviation for regional usage. Obsolete.", "width": Lino.chars2width(11) }, { "colIndex": 5, "dataIndex": "iso3", "editable": true, "editor": iso32658, "filter": { "type": "string" }, "header": "ISO3-Code", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.Countries.iso3) The three-letter code for this country as defined by ISO 3166-1.") }, "sortable": true, "tooltip": "The three-letter code for this country as defined by ISO 3166-1.", "width": Lino.chars2width(5) } ];
    Lino.countries.Countries.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.Countries.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Countries", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Countries.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Countries", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Countries.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Countries", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Countries.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Countries", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.countries.Countries.insertPanel = Ext.extend(Lino.countries.Countries.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/countries/Countries",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.Countries.detail;
    this.ls_insert_handler = Lino.countries.Countries.insert;
    Lino.countries.Countries.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.Countries.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/countries/Countries" };
  return new Lino.countries.Countries.insertPanel(p);
});
Lino.countries.Countries.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Countries", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.countries.Countries.detailPanel = Ext.extend(Lino.countries.Countries.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Land) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/countries/Countries",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.Countries.detail;
    this.ls_insert_handler = Lino.countries.Countries.insert;
    Lino.countries.Countries.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.Countries.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/countries/Countries" };
  return new Lino.countries.Countries.detailPanel(p);
});
Lino.countries.Countries.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Countries", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Countries.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/countries/Countries" };
  return new Lino.countries.Countries.GridPanel(p);
});
Lino.countries.Countries.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Countries", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class countries.Places
Lino.countries.Places.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/countries/Places",
  ls_store_fields : [ { "name": "country" }, 'countryHidden', { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "type" }, 'typeHidden', { "name": "zip_code" }, { "name": "parent" }, 'parentHidden', { "name": "id", "type": "int" }, { "name": "show_type", "type": "boolean" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 10,
  content_type : 5,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/countries/Places','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/countries/Places','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/countries/Places','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/countries/Places','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/countries/Places','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Ort) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Orte",
  disabled_fields_index : 12,
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.Places.detail;
    this.ls_insert_handler = Lino.countries.Places.insert;
    var ww = this.containing_window;
    var country2660 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Land ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/Places/country" }) }) });
    var name2661 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de2662 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr2663 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var type2664 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/Places/type" }) }) });
    var zip_code2665 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(8), "maxLength": 8, "selectOnFocus": true });
    var parent2666 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Ort ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/Places/parent" }) }) });
    var id2667 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var show_type2668 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      type2664.setContextValue('country', record ? record.data['countryHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof country2660 !== 'undefined' && country2660.on('change',Lino.chooser_handler(type2664,'country'));
      Lino.countries.Places.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "country", "editable": true, "editor": country2660, "filter": { "type": "string" }, "header": "Land", "listeners": { "render": Lino.quicktip_renderer("","(countries.Places.country) The country this place is in.") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "The country this place is in.", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name2661, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(countries.Places.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de2662, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(countries.Places.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr2663, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(countries.Places.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "type", "editable": true, "editor": type2664, "filter": { "type": "string" }, "header": "Ortsart", "listeners": { "render": Lino.quicktip_renderer("","(countries.Places.type) The type of this place (whether it's a city. a village, a province...)") }, "sortable": false, "tooltip": "The type of this place (whether it's a city. a village, a province...)", "width": Lino.chars2width(11) }, { "colIndex": 5, "dataIndex": "zip_code", "editable": true, "editor": zip_code2665, "filter": { "type": "string" }, "header": "zip code", "listeners": { "render": Lino.quicktip_renderer("","(countries.Places.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(10) }, { "colIndex": 6, "dataIndex": "parent", "editable": true, "editor": parent2666, "filter": { "type": "string" }, "header": "Teil von", "listeners": { "render": Lino.quicktip_renderer("","(countries.Places.parent) The superordinate geographic place of which this place is a part.") }, "renderer": Lino.fk_renderer('parentHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "The superordinate geographic place of which this place is a part.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 7, "dataIndex": "id", "editable": true, "editor": id2667, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.Places.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 8, "dataIndex": "show_type", "editable": true, "filter": { "type": "boolean" }, "header": "Show type", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.Places.show_type) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" } ];
    Lino.countries.Places.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.Places.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Places", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Places.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Places", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Places.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Places", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Places.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Places", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.countries.Places.insertPanel = Ext.extend(Lino.countries.Places.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/countries/Places",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.Places.detail;
    this.ls_insert_handler = Lino.countries.Places.insert;
    Lino.countries.Places.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.Places.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/countries/Places" };
  return new Lino.countries.Places.insertPanel(p);
});
Lino.countries.Places.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Places", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Places.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Places", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.countries.Places.detailPanel = Ext.extend(Lino.countries.Places.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Ort) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/countries/Places",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.Places.detail;
    this.ls_insert_handler = Lino.countries.Places.insert;
    Lino.countries.Places.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.Places.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/countries/Places" };
  return new Lino.countries.Places.detailPanel(p);
});
Lino.countries.Places.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Places", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Places.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Places", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Places.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Places", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.Places.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/countries/Places" };
  return new Lino.countries.Places.GridPanel(p);
});
Lino.countries.Places.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/Places", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class contacts.Partners
Lino.contacts.Partners.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/Partners",
  ls_store_fields : [ { "name": "name" }, { "name": "id", "type": "int" }, { "name": "mti_navigator" }, { "name": "email" }, { "name": "language" }, 'languageHidden', { "name": "url" }, { "name": "phone" }, { "name": "gsm" }, { "name": "fax" }, { "name": "country" }, 'countryHidden', { "name": "city" }, 'cityHidden', { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street" }, { "name": "street_no" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "prefix" }, { "name": "remarks" }, { "name": "payment_term" }, 'payment_termHidden', { "name": "purchase_account" }, 'purchase_accountHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 1,
  content_type : 6,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/Partners','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Partners','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Partners','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/contacts/Partners','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Partners','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/Partners','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/Partners','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Partners.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Partner",
  disabled_fields_index : 29,
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.Partners.detail;
    var ww = this.containing_window;
    var name2670 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var id2671 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var mti_navigator_disp2672 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var email2673 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 254, "selectOnFocus": true });
    var language2674 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var url2675 = new Lino.URLField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var phone2676 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var gsm2677 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var fax2678 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var country2679 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Partners/country" }) }) });
    var city2680 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Partners/city" }) }) });
    var zip_code2681 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region2682 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Partners/region" }) }) });
    var addr12683 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix2684 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street2685 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_no2686 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var street_box2687 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr22688 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var prefix2689 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var remarks2690 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    var payment_term2691 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Zahlungsbedingungen ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.PaymentTerms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Partners/payment_term" }) }) });
    var purchase_account2692 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Konto ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Partners/purchase_account" }) }) });
    this.before_row_edit = function(record) {
      city2680.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city2680.setContextValue('region', record ? record.data['regionHidden'] : undefined);
      region2682.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      remarks2690.refresh();
    };
    this.onRender = function(ct, position) {
      typeof country2679 !== 'undefined' && country2679.on('change',Lino.chooser_handler(city2680,'country'));
      typeof region2682 !== 'undefined' && region2682.on('change',Lino.chooser_handler(city2680,'region'));
      typeof country2679 !== 'undefined' && country2679.on('change',Lino.chooser_handler(region2682,'country'));
      Lino.contacts.Partners.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name", "editable": true, "editor": name2670, "filter": { "type": "string" }, "header": "Name", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.name) The full name of this partner. Used for alphabetic sorting.") }, "sortable": true, "tooltip": "The full name of this partner. Used for alphabetic sorting.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 1, "dataIndex": "id", "editable": true, "editor": id2671, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 2, "dataIndex": "mti_navigator", "editable": false, "header": "Ansicht als ", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.mti_navigator) A virtual field which defines buttons for switching between the\ndifferent views.") }, "sortable": false, "tooltip": "A virtual field which defines buttons for switching between the\ndifferent views.", "width": Lino.chars2width(31) }, { "colIndex": 3, "dataIndex": "email", "editable": true, "editor": email2673, "filter": { "type": "string" }, "header": "E-Mail-Adresse", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.email) The primary email address.") }, "sortable": true, "tooltip": "The primary email address.", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "language", "editable": true, "editor": language2674, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.language) The language to use when communicating with this partner.") }, "sortable": false, "tooltip": "The language to use when communicating with this partner.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "url", "editable": true, "editor": url2675, "filter": { "type": "string" }, "header": "Adresse (URL)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.url) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "phone", "editable": true, "editor": phone2676, "filter": { "type": "string" }, "header": "Telefon", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.phone) The primary phone number.") }, "sortable": true, "tooltip": "The primary phone number.", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "gsm", "editable": true, "editor": gsm2677, "filter": { "type": "string" }, "header": "GSM", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.gsm) The primary mobile phone number.") }, "sortable": true, "tooltip": "The primary mobile phone number.", "width": Lino.chars2width(22) }, { "colIndex": 8, "dataIndex": "fax", "editable": true, "editor": fax2678, "filter": { "type": "string" }, "header": "Fax", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.fax) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "country", "editable": true, "editor": country2679, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "city", "editable": true, "editor": city2680, "filter": { "type": "string" }, "header": "Ortschaft", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "zip_code", "editable": true, "editor": zip_code2681, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 12, "dataIndex": "region", "editable": true, "editor": region2682, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "addr1", "editable": true, "editor": addr12683, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix2684, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "street", "editable": true, "editor": street2685, "filter": { "type": "string" }, "header": "Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 16, "dataIndex": "street_no", "editable": true, "editor": street_no2686, "filter": { "type": "string" }, "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 17, "dataIndex": "street_box", "editable": true, "editor": street_box2687, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 18, "dataIndex": "addr2", "editable": true, "editor": addr22688, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 19, "dataIndex": "prefix", "editable": true, "editor": prefix2689, "filter": { "type": "string" }, "header": "Name prefix", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.prefix) An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.") }, "sortable": true, "tooltip": "An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.", "width": Lino.chars2width(22) }, { "colIndex": 20, "dataIndex": "remarks", "editable": true, "editor": remarks2690, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 21, "dataIndex": "payment_term", "editable": true, "editor": payment_term2691, "filter": { "type": "string" }, "header": "Zahlungsbedingungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.payment_term) The default payment term for sales invoices to this customer.") }, "sortable": false, "tooltip": "The default payment term for sales invoices to this customer.", "width": Lino.chars2width(21) }, { "colIndex": 22, "dataIndex": "purchase_account", "editable": true, "editor": purchase_account2692, "filter": { "type": "string" }, "header": "Konto Einkauf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Partners.purchase_account) The general account to suggest as default value in purchase\ninvoices from this partner.") }, "sortable": false, "tooltip": "The general account to suggest as default value in purchase\ninvoices from this partner.", "width": Lino.chars2width(21) } ];
    Lino.contacts.Partners.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.Partners.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.export_vcf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "export_vcf", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.contacts.Partners.detailPanel = Ext.extend(Lino.contacts.Partners.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/Partners','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Partners.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/contacts/Partners",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.Partners.detail;
    Lino.contacts.Partners.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.Partners.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/Partners" };
  return new Lino.contacts.Partners.detailPanel(p);
});
Lino.contacts.Partners.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.create_excerpt2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "create_excerpt2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.due = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "due", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.show_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "show_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.del_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "del_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.del_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "del_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.del_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "del_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.del_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "del_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/Partners" };
  p.params_panel = new Lino.contacts.Partners.ParamsPanel({});
  return new Lino.contacts.Partners.GridPanel(p);
});
Lino.contacts.Partners.ins_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "ins_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.ins_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "ins_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.ins_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "ins_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.ins_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "GET", pk, "ins_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Partners.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Partners", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class contacts.Persons
Lino.contacts.Persons.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/Persons",
  ls_store_fields : [ { "name": "last_name" }, { "name": "first_name" }, { "name": "id", "type": "int" }, { "name": "email" }, { "name": "language" }, 'languageHidden', { "name": "url" }, { "name": "phone" }, { "name": "gsm" }, { "name": "fax" }, { "name": "country" }, 'countryHidden', { "name": "city" }, 'cityHidden', { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street" }, { "name": "street_no" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "prefix" }, { "name": "name" }, { "name": "remarks" }, { "name": "payment_term" }, 'payment_termHidden', { "name": "purchase_account" }, 'purchase_accountHidden', { "name": "title" }, { "name": "middle_name" }, { "name": "gender" }, 'genderHidden', { "name": "birth_date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 2,
  content_type : 6,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/Persons','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Persons','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Persons','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/contacts/Persons','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Persons','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/Persons','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/Persons','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Person) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Persons.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "iconCls": "x-tbar-printer", "menu": [ { "auto_save": true, "itemId": "create_excerpt1", "menu_item_text": "Terms & conditions", "overflowText": "Terms & conditions", "panel_btn_handler": Lino.row_action_handler('create_excerpt1','GET',null), "text": "Terms & conditions", "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "text": "Payment reminder", "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" } ], "menu_item_text": "Terms & conditions", "panel_btn_handler": Lino.row_action_handler('create_excerpt1','GET',null), "text": null, "xtype": "splitbutton" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Personen",
  disabled_fields_index : 35,
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.Persons.detail;
    this.ls_insert_handler = Lino.contacts.Persons.insert;
    var ww = this.containing_window;
    var last_name2694 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var first_name2695 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id2696 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var email2697 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 254, "selectOnFocus": true });
    var language2698 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var url2699 = new Lino.URLField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var phone2700 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var gsm2701 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var fax2702 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var country2703 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Persons/country" }) }) });
    var city2704 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Persons/city" }) }) });
    var zip_code2705 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region2706 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Persons/region" }) }) });
    var addr12707 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix2708 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street2709 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_no2710 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var street_box2711 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr22712 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var prefix2713 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var name2714 = new Ext.form.TextField({ "allowBlank": false, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var remarks2715 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    var payment_term2716 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Zahlungsbedingungen ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.PaymentTerms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Persons/payment_term" }) }) });
    var purchase_account2717 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Konto ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Persons/purchase_account" }) }) });
    var title2718 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var middle_name2719 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var gender2720 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.Genders) });
    var birth_date2721 = new Lino.IncompleteDateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      city2704.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city2704.setContextValue('region', record ? record.data['regionHidden'] : undefined);
      region2706.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      remarks2715.refresh();
    };
    this.onRender = function(ct, position) {
      typeof country2703 !== 'undefined' && country2703.on('change',Lino.chooser_handler(city2704,'country'));
      typeof region2706 !== 'undefined' && region2706.on('change',Lino.chooser_handler(city2704,'region'));
      typeof country2703 !== 'undefined' && country2703.on('change',Lino.chooser_handler(region2706,'country'));
      Lino.contacts.Persons.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "last_name", "editable": true, "editor": last_name2694, "filter": { "type": "string" }, "header": "Familienname", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.last_name) The last name, also known as family name.") }, "sortable": true, "tooltip": "The last name, also known as family name.", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "first_name", "editable": true, "editor": first_name2695, "filter": { "type": "string" }, "header": "Vorname", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.first_name) The first name, also known as given name.") }, "sortable": true, "tooltip": "The first name, also known as given name.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 2, "dataIndex": "id", "editable": true, "editor": id2696, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "email", "editable": true, "editor": email2697, "filter": { "type": "string" }, "header": "E-Mail-Adresse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.email) The primary email address.") }, "sortable": true, "tooltip": "The primary email address.", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "language", "editable": true, "editor": language2698, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.language) The language to use when communicating with this partner.") }, "sortable": false, "tooltip": "The language to use when communicating with this partner.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "url", "editable": true, "editor": url2699, "filter": { "type": "string" }, "header": "Adresse (URL)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.url) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "phone", "editable": true, "editor": phone2700, "filter": { "type": "string" }, "header": "Telefon", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.phone) The primary phone number.") }, "sortable": true, "tooltip": "The primary phone number.", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "gsm", "editable": true, "editor": gsm2701, "filter": { "type": "string" }, "header": "GSM", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.gsm) The primary mobile phone number.") }, "sortable": true, "tooltip": "The primary mobile phone number.", "width": Lino.chars2width(22) }, { "colIndex": 8, "dataIndex": "fax", "editable": true, "editor": fax2702, "filter": { "type": "string" }, "header": "Fax", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.fax) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "country", "editable": true, "editor": country2703, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "city", "editable": true, "editor": city2704, "filter": { "type": "string" }, "header": "Ortschaft", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "zip_code", "editable": true, "editor": zip_code2705, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 12, "dataIndex": "region", "editable": true, "editor": region2706, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "addr1", "editable": true, "editor": addr12707, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix2708, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "street", "editable": true, "editor": street2709, "filter": { "type": "string" }, "header": "Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 16, "dataIndex": "street_no", "editable": true, "editor": street_no2710, "filter": { "type": "string" }, "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 17, "dataIndex": "street_box", "editable": true, "editor": street_box2711, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 18, "dataIndex": "addr2", "editable": true, "editor": addr22712, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 19, "dataIndex": "prefix", "editable": true, "editor": prefix2713, "filter": { "type": "string" }, "header": "Name prefix", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.prefix) An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.") }, "sortable": true, "tooltip": "An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.", "width": Lino.chars2width(22) }, { "colIndex": 20, "dataIndex": "name", "editable": true, "editor": name2714, "filter": { "type": "string" }, "header": "Name", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.name) The full name of this partner. Used for alphabetic sorting.") }, "sortable": true, "tooltip": "The full name of this partner. Used for alphabetic sorting.", "width": Lino.chars2width(22) }, { "colIndex": 21, "dataIndex": "remarks", "editable": true, "editor": remarks2715, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 22, "dataIndex": "payment_term", "editable": true, "editor": payment_term2716, "filter": { "type": "string" }, "header": "Zahlungsbedingungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.payment_term) The default payment term for sales invoices to this customer.") }, "sortable": false, "tooltip": "The default payment term for sales invoices to this customer.", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "purchase_account", "editable": true, "editor": purchase_account2717, "filter": { "type": "string" }, "header": "Konto Einkauf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.purchase_account) The general account to suggest as default value in purchase\ninvoices from this partner.") }, "sortable": false, "tooltip": "The general account to suggest as default value in purchase\ninvoices from this partner.", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "title", "editable": true, "editor": title2718, "filter": { "type": "string" }, "header": "Titel", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.title) Eventuelle berufliche Position oder akademischer Titel, z.B. \"Dr.\" oder \"Prof.\"") }, "sortable": true, "tooltip": "Eventuelle berufliche Position oder akademischer Titel, z.B. \"Dr.\" oder \"Prof.\"", "width": Lino.chars2width(22) }, { "colIndex": 25, "dataIndex": "middle_name", "editable": true, "editor": middle_name2719, "filter": { "type": "string" }, "header": "Zwischenname", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.middle_name) A space-separated list of all middle names.") }, "sortable": true, "tooltip": "A space-separated list of all middle names.", "width": Lino.chars2width(22) }, { "colIndex": 26, "dataIndex": "gender", "editable": true, "editor": gender2720, "filter": { "options": [ "M\u00e4nnlich", "Weiblich" ], "type": "list" }, "header": "Geschlecht", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.gender) The sex of this person (male or female).") }, "sortable": false, "tooltip": "The sex of this person (male or female).", "width": Lino.chars2width(10) }, { "colIndex": 27, "dataIndex": "birth_date", "editable": true, "editor": birth_date2721, "filter": { "type": "string" }, "header": "Geburtsdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Persons.birth_date) Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".") }, "sortable": true, "tooltip": "Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".", "width": Lino.chars2width(13) } ];
    Lino.contacts.Persons.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.Persons.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.export_vcf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "export_vcf", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.contacts.Persons.insertPanel = Ext.extend(Lino.contacts.Persons.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/contacts/Persons",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.Persons.detail;
    this.ls_insert_handler = Lino.contacts.Persons.insert;
    Lino.contacts.Persons.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.Persons.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/contacts/Persons" };
  return new Lino.contacts.Persons.insertPanel(p);
});
Lino.contacts.Persons.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.contacts.Persons.detailPanel = Ext.extend(Lino.contacts.Persons.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/Persons','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Person) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Persons.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "iconCls": "x-tbar-printer", "menu": [ { "auto_save": true, "itemId": "create_excerpt1", "menu_item_text": "Terms & conditions", "overflowText": "Terms & conditions", "panel_btn_handler": Lino.row_action_handler('create_excerpt1','GET',null), "text": "Terms & conditions", "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "text": "Payment reminder", "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" } ], "menu_item_text": "Terms & conditions", "panel_btn_handler": Lino.row_action_handler('create_excerpt1','GET',null), "text": null, "xtype": "splitbutton" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/contacts/Persons",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.Persons.detail;
    this.ls_insert_handler = Lino.contacts.Persons.insert;
    Lino.contacts.Persons.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.Persons.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/Persons" };
  return new Lino.contacts.Persons.detailPanel(p);
});
Lino.contacts.Persons.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.create_excerpt1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "create_excerpt1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.create_excerpt2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "create_excerpt2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.due = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "due", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.show_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "show_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.del_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "del_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.del_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "del_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.del_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "del_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.del_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "del_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/Persons" };
  p.params_panel = new Lino.contacts.Persons.ParamsPanel({});
  return new Lino.contacts.Persons.GridPanel(p);
});
Lino.contacts.Persons.ins_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "ins_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.ins_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "ins_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.ins_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "ins_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.ins_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "GET", pk, "ins_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Persons.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Persons", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class contacts.CompanyTypes
Lino.contacts.CompanyTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/CompanyTypes",
  ls_store_fields : [ { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "id", "type": "int" }, { "name": "abbr" }, { "name": "abbr_de" }, { "name": "abbr_fr" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 7,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/CompanyTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/CompanyTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/CompanyTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/CompanyTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/CompanyTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Organisationsarten",
  disabled_fields_index : 7,
  initComponent : function() {
    var ww = this.containing_window;
    var name2723 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de2724 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr2725 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id2726 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var abbr2727 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 30, "selectOnFocus": true });
    var abbr_de2728 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 30, "selectOnFocus": true });
    var abbr_fr2729 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 30, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name", "editable": true, "editor": name2723, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompanyTypes.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name_de", "editable": true, "editor": name_de2724, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompanyTypes.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_fr", "editable": true, "editor": name_fr2725, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompanyTypes.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id2726, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompanyTypes.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "abbr", "editable": true, "editor": abbr2727, "filter": { "type": "string" }, "header": "Abk\u00fcrzung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompanyTypes.abbr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "abbr_de", "editable": true, "editor": abbr_de2728, "filter": { "type": "string" }, "header": "Abk\u00fcrzung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompanyTypes.abbr_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "abbr_fr", "editable": true, "editor": abbr_fr2729, "filter": { "type": "string" }, "header": "Abk\u00fcrzung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompanyTypes.abbr_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) } ];
    Lino.contacts.CompanyTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.CompanyTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompanyTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompanyTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompanyTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompanyTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompanyTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompanyTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompanyTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompanyTypes.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompanyTypes", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompanyTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/CompanyTypes" };
  return new Lino.contacts.CompanyTypes.GridPanel(p);
});

// js_render_GridPanel_class contacts.Companies
Lino.contacts.Companies.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/Companies",
  ls_store_fields : [ { "name": "name_column" }, { "name": "address_column" }, { "name": "email" }, { "name": "phone" }, { "name": "gsm" }, { "name": "id", "type": "int" }, { "name": "language" }, 'languageHidden', { "name": "url" }, { "name": "fax" }, { "name": "country" }, 'countryHidden', { "name": "city" }, 'cityHidden', { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street" }, { "name": "street_no" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "prefix" }, { "name": "name" }, { "name": "remarks" }, { "name": "payment_term" }, 'payment_termHidden', { "name": "purchase_account" }, 'purchase_accountHidden', { "name": "parent" }, 'parentHidden', { "name": "type" }, 'typeHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 6,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/Companies','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Companies','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Companies','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/contacts/Companies','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Companies','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/Companies','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/Companies','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Organisation) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Companies.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Organisationen",
  disabled_fields_index : 34,
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.Companies.detail;
    this.ls_insert_handler = Lino.contacts.Companies.insert;
    var ww = this.containing_window;
    var name_column_disp2731 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var address_column_disp2732 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var email2733 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 254, "selectOnFocus": true });
    var phone2734 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var gsm2735 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id2736 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var language2737 = new Lino.ChoicesFieldElement({ "allowBlank": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var url2738 = new Lino.URLField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var fax2739 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var country2740 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Companies/country" }) }) });
    var city2741 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Companies/city" }) }) });
    var zip_code2742 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region2743 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Companies/region" }) }) });
    var addr12744 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix2745 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street2746 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_no2747 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var street_box2748 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr22749 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var prefix2750 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var name2751 = new Ext.form.TextField({ "allowBlank": false, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var remarks2752 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    var payment_term2753 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Zahlungsbedingungen ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.PaymentTerms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Companies/payment_term" }) }) });
    var purchase_account2754 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Konto ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Companies/purchase_account" }) }) });
    var parent2755 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Companies/parent" }) }) });
    var type2756 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisationsart ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "contacts.CompanyTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Companies/type" }) }) });
    this.before_row_edit = function(record) {
      city2741.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city2741.setContextValue('region', record ? record.data['regionHidden'] : undefined);
      region2743.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      remarks2752.refresh();
    };
    this.onRender = function(ct, position) {
      typeof country2740 !== 'undefined' && country2740.on('change',Lino.chooser_handler(city2741,'country'));
      typeof region2743 !== 'undefined' && region2743.on('change',Lino.chooser_handler(city2741,'region'));
      typeof country2740 !== 'undefined' && country2740.on('change',Lino.chooser_handler(region2743,'country'));
      Lino.contacts.Companies.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name_column", "editable": false, "header": "Name", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.name_column) ") }, "sortable": false, "tooltip": "(contacts.Companies.name_column) ", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "address_column", "editable": false, "header": "Adresse", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.address_column) ") }, "sortable": false, "tooltip": "(contacts.Companies.address_column) ", "width": Lino.chars2width(31) }, { "colIndex": 2, "dataIndex": "email", "editable": true, "editor": email2733, "filter": { "type": "string" }, "header": "E-Mail-Adresse", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.email) The primary email address.") }, "sortable": true, "tooltip": "The primary email address.", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "phone", "editable": true, "editor": phone2734, "filter": { "type": "string" }, "header": "Telefon", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.phone) The primary phone number.") }, "sortable": true, "tooltip": "The primary phone number.", "width": Lino.chars2width(11) }, { "colIndex": 4, "dataIndex": "gsm", "editable": true, "editor": gsm2735, "filter": { "type": "string" }, "header": "GSM", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.gsm) The primary mobile phone number.") }, "sortable": true, "tooltip": "The primary mobile phone number.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id2736, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "language", "editable": true, "editor": language2737, "filter": { "type": "string" }, "header": "Sprache", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.language) The language to use when communicating with this partner.") }, "sortable": false, "tooltip": "The language to use when communicating with this partner.", "width": Lino.chars2width(11) }, { "colIndex": 7, "dataIndex": "url", "editable": true, "editor": url2738, "filter": { "type": "string" }, "header": "Adresse (URL)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.url) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 8, "dataIndex": "fax", "editable": true, "editor": fax2739, "filter": { "type": "string" }, "header": "Fax", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.fax) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "country", "editable": true, "editor": country2740, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "city", "editable": true, "editor": city2741, "filter": { "type": "string" }, "header": "Ortschaft", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "zip_code", "editable": true, "editor": zip_code2742, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 12, "dataIndex": "region", "editable": true, "editor": region2743, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "addr1", "editable": true, "editor": addr12744, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix2745, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "street", "editable": true, "editor": street2746, "filter": { "type": "string" }, "header": "Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 16, "dataIndex": "street_no", "editable": true, "editor": street_no2747, "filter": { "type": "string" }, "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 17, "dataIndex": "street_box", "editable": true, "editor": street_box2748, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 18, "dataIndex": "addr2", "editable": true, "editor": addr22749, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 19, "dataIndex": "prefix", "editable": true, "editor": prefix2750, "filter": { "type": "string" }, "header": "Name prefix", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.prefix) An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.") }, "sortable": true, "tooltip": "An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.", "width": Lino.chars2width(22) }, { "colIndex": 20, "dataIndex": "name", "editable": true, "editor": name2751, "filter": { "type": "string" }, "header": "Name", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.name) The full name of this partner. Used for alphabetic sorting.") }, "sortable": true, "tooltip": "The full name of this partner. Used for alphabetic sorting.", "width": Lino.chars2width(22) }, { "colIndex": 21, "dataIndex": "remarks", "editable": true, "editor": remarks2752, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 22, "dataIndex": "payment_term", "editable": true, "editor": payment_term2753, "filter": { "type": "string" }, "header": "Zahlungsbedingungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.payment_term) The default payment term for sales invoices to this customer.") }, "sortable": false, "tooltip": "The default payment term for sales invoices to this customer.", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "purchase_account", "editable": true, "editor": purchase_account2754, "filter": { "type": "string" }, "header": "Konto Einkauf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.purchase_account) The general account to suggest as default value in purchase\ninvoices from this partner.") }, "sortable": false, "tooltip": "The general account to suggest as default value in purchase\ninvoices from this partner.", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "parent", "editable": true, "editor": parent2755, "filter": { "type": "string" }, "header": "Vater/Mutter", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.parent) ") }, "renderer": Lino.fk_renderer('parentHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 25, "dataIndex": "type", "editable": true, "editor": type2756, "filter": { "type": "string" }, "header": "Organisationsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.Companies.type) Pointer to the CompanyType.") }, "sortable": false, "tooltip": "Pointer to the CompanyType.", "width": Lino.chars2width(21) } ];
    Lino.contacts.Companies.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.Companies.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.export_vcf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "export_vcf", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.contacts.Companies.insertPanel = Ext.extend(Lino.contacts.Companies.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/contacts/Companies",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.Companies.detail;
    this.ls_insert_handler = Lino.contacts.Companies.insert;
    Lino.contacts.Companies.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.Companies.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/contacts/Companies" };
  return new Lino.contacts.Companies.insertPanel(p);
});
Lino.contacts.Companies.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.contacts.Companies.detailPanel = Ext.extend(Lino.contacts.Companies.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/Companies','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Organisation) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Companies.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/contacts/Companies",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.Companies.detail;
    this.ls_insert_handler = Lino.contacts.Companies.insert;
    Lino.contacts.Companies.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.Companies.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/Companies" };
  return new Lino.contacts.Companies.detailPanel(p);
});
Lino.contacts.Companies.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.create_excerpt2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "create_excerpt2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.due = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "due", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.show_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "show_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.del_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "del_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.del_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "del_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.del_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "del_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.del_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "del_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/Companies" };
  p.params_panel = new Lino.contacts.Partners.ParamsPanel({});
  return new Lino.contacts.Companies.GridPanel(p);
});
Lino.contacts.Companies.ins_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "ins_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.ins_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "ins_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.ins_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "ins_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.ins_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "GET", pk, "ins_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Companies.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Companies", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class contacts.RoleTypes
Lino.contacts.RoleTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/RoleTypes",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "can_sign", "type": "boolean" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 8,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/RoleTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/RoleTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/RoleTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/RoleTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/RoleTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Funktionen",
  disabled_fields_index : 5,
  initComponent : function() {
    var ww = this.containing_window;
    var id2758 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var name2759 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de2760 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr2761 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var can_sign2762 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id2758, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RoleTypes.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name2759, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RoleTypes.name) A translatable designation. Used e.g. in document templates\nfor contracts.") }, "sortable": true, "tooltip": "A translatable designation. Used e.g. in document templates\nfor contracts.", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de2760, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RoleTypes.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr2761, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RoleTypes.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "can_sign", "editable": true, "filter": { "type": "boolean" }, "header": "Unterschriftsberechtigt", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RoleTypes.can_sign) Whether this is a signer function.") }, "sortable": false, "tooltip": "Whether this is a signer function.", "width": Lino.chars2width(11), "xtype": "checkcolumn" } ];
    Lino.contacts.RoleTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.RoleTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RoleTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RoleTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RoleTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RoleTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RoleTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RoleTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RoleTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RoleTypes.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RoleTypes", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RoleTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/RoleTypes" };
  return new Lino.contacts.RoleTypes.GridPanel(p);
});

// js_render_GridPanel_class contacts.Roles
Lino.contacts.Roles.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/Roles",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "type" }, 'typeHidden', { "name": "person" }, 'personHidden', { "name": "company" }, 'companyHidden', { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 9,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/Roles','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Roles','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Roles','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/contacts/Roles','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/Roles','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/Roles','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kontaktpersonen",
  disabled_fields_index : 9,
  initComponent : function() {
    var ww = this.containing_window;
    var id2764 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var type2765 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Roles/type" }) }) });
    var person2766 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Roles/person" }) }) });
    var company2767 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Organisation ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/Roles/company" }) }) });
    var start_date2768 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var end_date2769 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id2764, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Roles.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "type", "editable": true, "editor": type2765, "filter": { "type": "string" }, "header": "Funktion", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Roles.type) The function of this person in this organization.") }, "sortable": false, "tooltip": "The function of this person in this organization.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "person", "editable": true, "editor": person2766, "filter": { "type": "string" }, "header": "Person", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Roles.person) The person having this role in this organization.") }, "renderer": Lino.fk_renderer('personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The person having this role in this organization.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "company", "editable": true, "editor": company2767, "filter": { "type": "string" }, "header": "Organisation", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Roles.company) The organization where this person has this role.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "The organization where this person has this role.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "start_date", "editable": true, "editor": start_date2768, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Roles.start_date) When this person started to exercise this function in this\norganization.") }, "sortable": true, "tooltip": "When this person started to exercise this function in this\norganization.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 5, "dataIndex": "end_date", "editable": true, "editor": end_date2769, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "listeners": { "render": Lino.quicktip_renderer("","(contacts.Roles.end_date) When this person stopped to exercise this function in this\norganization.") }, "sortable": true, "tooltip": "When this person stopped to exercise this function in this\norganization.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.contacts.Roles.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.Roles.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Roles", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Roles.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Roles", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Roles.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Roles", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Roles.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Roles", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Roles.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Roles", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Roles.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/Roles", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.Roles.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/Roles" };
  return new Lino.contacts.Roles.GridPanel(p);
});

// js_render_GridPanel_class gfks.ContentTypes
Lino.gfks.ContentTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/gfks/ContentTypes",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "app_label" }, { "name": "model" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 12,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/gfks/ContentTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/ContentTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/ContentTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/ContentTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/gfks/ContentTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Datenbankmodelle",
  disabled_fields_index : 3,
  initComponent : function() {
    this.ls_detail_handler = Lino.gfks.ContentTypes.detail;
    var ww = this.containing_window;
    var id2771 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var app_label2772 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 100, "selectOnFocus": true });
    var model2773 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 100, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id2771, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(gfks.ContentTypes.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "app_label", "editable": true, "editor": app_label2772, "filter": { "type": "string" }, "header": "app label", "listeners": { "render": Lino.quicktip_renderer("","(gfks.ContentTypes.app_label) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "model", "editable": true, "editor": model2773, "filter": { "type": "string" }, "header": "Python Modell-Klassenname", "listeners": { "render": Lino.quicktip_renderer("","(gfks.ContentTypes.model) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) } ];
    Lino.gfks.ContentTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.gfks.ContentTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/ContentTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.ContentTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/ContentTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.ContentTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/ContentTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.ContentTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/ContentTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.gfks.ContentTypes.detailPanel = Ext.extend(Lino.gfks.ContentTypes.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/gfks/ContentTypes",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.gfks.ContentTypes.detail;
    Lino.gfks.ContentTypes.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.gfks.ContentTypes.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/gfks/ContentTypes" };
  return new Lino.gfks.ContentTypes.detailPanel(p);
});
Lino.gfks.ContentTypes.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/ContentTypes", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.ContentTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/gfks/ContentTypes" };
  return new Lino.gfks.ContentTypes.GridPanel(p);
});
Lino.gfks.ContentTypes.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/ContentTypes", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class gfks.HelpTexts
Lino.gfks.HelpTexts.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/gfks/HelpTexts",
  ls_store_fields : [ { "name": "field" }, { "name": "verbose_name" }, { "name": "help_text" }, { "name": "id", "type": "int" }, { "name": "content_type" }, 'content_typeHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 13,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/gfks/HelpTexts','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/HelpTexts','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/HelpTexts','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/HelpTexts','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/gfks/HelpTexts','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Hilfetexte",
  disabled_fields_index : 6,
  initComponent : function() {
    var ww = this.containing_window;
    var field2775 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/gfks/HelpTexts/field" }) }) });
    var verbose_name2776 = new Ext.form.TextField({ "disabled": true, "maxLength": 200 });
    var help_text2777 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "selectOnFocus": true });
    var id2778 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var content_type2779 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/gfks/HelpTexts/content_type" }) }) });
    this.before_row_edit = function(record) {
      field2775.setContextValue('content_type', record ? record.data['content_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof content_type2779 !== 'undefined' && content_type2779.on('change',Lino.chooser_handler(field2775,'content_type'));
      Lino.gfks.HelpTexts.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "field", "editable": true, "editor": field2775, "filter": { "type": "string" }, "header": "Feld", "listeners": { "render": Lino.quicktip_renderer("","(gfks.HelpTexts.field) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "verbose_name", "editable": false, "header": "Feldbezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(gfks.HelpTexts.verbose_name) ") }, "sortable": true, "tooltip": "(gfks.HelpTexts.verbose_name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "help_text", "editable": true, "editor": help_text2777, "filter": { "type": "string" }, "header": "Hilfetext", "listeners": { "render": Lino.quicktip_renderer("","(gfks.HelpTexts.help_text) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id2778, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(gfks.HelpTexts.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "content_type", "editable": true, "editor": content_type2779, "filter": { "type": "string" }, "header": "Modell", "listeners": { "render": Lino.quicktip_renderer("","(gfks.HelpTexts.content_type) ") }, "renderer": Lino.fk_renderer('content_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.gfks.HelpTexts.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.gfks.HelpTexts.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/HelpTexts", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.HelpTexts.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/HelpTexts", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.HelpTexts.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/HelpTexts", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.HelpTexts.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/HelpTexts", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.HelpTexts.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/HelpTexts", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.HelpTexts.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/gfks/HelpTexts" };
  return new Lino.gfks.HelpTexts.GridPanel(p);
});

// js_render_GridPanel_class checkdata.Problems
Lino.checkdata.Problems.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/checkdata/Problems",
  ls_store_fields : [ { "name": "user" }, 'userHidden', { "name": "owner" }, { "name": "message" }, { "name": "checker" }, 'checkerHidden', { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden' ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 14,
  cell_edit : false,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/checkdata/Problems','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/Problems','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/Problems','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/Problems','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/checkdata/Problems','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "update_problem", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problem", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problem','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Datenprobleme",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.Problems.detail;
    var ww = this.containing_window;
    var user2781 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/Problems/user" }) }) });
    var owner_disp2782 = new Ext.form.DisplayField({ "disabled": true });
    var message2783 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 250, "selectOnFocus": true });
    var checker2784 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.checkdata.Checkers });
    var id2785 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type2786 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/Problems/owner_type" }) }) });
    var owner_id2787 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/Problems/owner_id" }) }) });
    this.before_row_edit = function(record) {
    };
    this.onRender = function(ct, position) {
      typeof owner_type2786 !== 'undefined' && owner_type2786.on('change',Lino.chooser_handler(owner_id2787,'owner_type'));
      Lino.checkdata.Problems.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "user", "editable": true, "editor": user2781, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.Problems.user) The user responsible for fixing this\nproblem.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The user responsible for fixing this\nproblem.", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "owner", "editable": false, "header": "Datenobjekt", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.Problems.owner) ") }, "sortable": false, "tooltip": "(checkdata.Problems.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "message", "editable": true, "editor": message2783, "filter": { "type": "string" }, "header": "Meldung", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.Problems.message) The message text. This is a concatenation of all messages that\nwere yielded by the checker.") }, "sortable": true, "tooltip": "The message text. This is a concatenation of all messages that\nwere yielded by the checker.", "width": Lino.chars2width(51) }, { "colIndex": 3, "dataIndex": "checker", "editable": true, "editor": checker2784, "filter": { "options": [ "Adressen pr\u00fcfen", "Auf Termin\u00fcberschneidungen pr\u00fcfen", "Termine ohne Teilnehmer", "Dauer \u00fcberschreitende Kalendereintr\u00e4ge", "Veraltete generierte Kalendereintr\u00e4ge", "Check data of geographical places.", "Check integrity of ledger vouchers", "Check for previewables needing update", "Check for mismatches between contact details and owner", "Check for missing target files", "Find unbleached html content", "Check metadata of upload files", "Find orphaned files in uploads folder" ], "type": "list" }, "header": "Checker", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.Problems.checker) The Checker that reported this\nproblem.") }, "sortable": false, "tooltip": "The Checker that reported this\nproblem.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id2785, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.Problems.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type2786, "filter": { "type": "string" }, "header": "Datenobjekt (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.Problems.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id2787, "filter": { "type": "string" }, "header": "Datenobjekt (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.Problems.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) } ];
    Lino.checkdata.Problems.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.Problems.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/Problems", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.Problems.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/Problems", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.Problems.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/Problems", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.Problems.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/Problems", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.checkdata.Problems.detailPanel = Ext.extend(Lino.checkdata.Problems.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "update_problem", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problem", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problem','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": null, "xtype": "splitbutton" } ],
  ls_url: "/checkdata/Problems",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.Problems.detail;
    Lino.checkdata.Problems.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.Problems.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/Problems" };
  return new Lino.checkdata.Problems.detailPanel(p);
});
Lino.checkdata.Problems.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/Problems" };
  p.params_panel = new Lino.checkdata.Problems.ParamsPanel({});
  return new Lino.checkdata.Problems.GridPanel(p);
});
Lino.checkdata.Problems.update_problem = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/Problems", "GET", pk, "update_problem", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.Problems.fix_problem = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/Problems", "GET", pk, "fix_problem", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class checkdata.AllProblems
Lino.checkdata.AllProblems.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/checkdata/AllProblems",
  ls_store_fields : [ { "name": "user" }, 'userHidden', { "name": "owner" }, { "name": "message" }, { "name": "checker" }, 'checkerHidden', { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden' ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 14,
  cell_edit : false,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/checkdata/AllProblems','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/AllProblems','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/AllProblems','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/AllProblems','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/checkdata/AllProblems','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "update_problem", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problem", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problem','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Datenprobleme",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.AllProblems.detail;
    var ww = this.containing_window;
    var user2789 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/AllProblems/user" }) }) });
    var owner_disp2790 = new Ext.form.DisplayField({ "disabled": true });
    var message2791 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 250, "selectOnFocus": true });
    var checker2792 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.checkdata.Checkers });
    var id2793 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type2794 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/AllProblems/owner_type" }) }) });
    var owner_id2795 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/AllProblems/owner_id" }) }) });
    this.before_row_edit = function(record) {
    };
    this.onRender = function(ct, position) {
      typeof owner_type2794 !== 'undefined' && owner_type2794.on('change',Lino.chooser_handler(owner_id2795,'owner_type'));
      Lino.checkdata.AllProblems.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "user", "editable": true, "editor": user2789, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.AllProblems.user) The user responsible for fixing this\nproblem.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The user responsible for fixing this\nproblem.", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "owner", "editable": false, "header": "Datenobjekt", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.AllProblems.owner) ") }, "sortable": false, "tooltip": "(checkdata.AllProblems.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "message", "editable": true, "editor": message2791, "filter": { "type": "string" }, "header": "Meldung", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.AllProblems.message) The message text. This is a concatenation of all messages that\nwere yielded by the checker.") }, "sortable": true, "tooltip": "The message text. This is a concatenation of all messages that\nwere yielded by the checker.", "width": Lino.chars2width(51) }, { "colIndex": 3, "dataIndex": "checker", "editable": true, "editor": checker2792, "filter": { "options": [ "Adressen pr\u00fcfen", "Auf Termin\u00fcberschneidungen pr\u00fcfen", "Termine ohne Teilnehmer", "Dauer \u00fcberschreitende Kalendereintr\u00e4ge", "Veraltete generierte Kalendereintr\u00e4ge", "Check data of geographical places.", "Check integrity of ledger vouchers", "Check for previewables needing update", "Check for mismatches between contact details and owner", "Check for missing target files", "Find unbleached html content", "Check metadata of upload files", "Find orphaned files in uploads folder" ], "type": "list" }, "header": "Checker", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.AllProblems.checker) The Checker that reported this\nproblem.") }, "sortable": false, "tooltip": "The Checker that reported this\nproblem.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id2793, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.AllProblems.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type2794, "filter": { "type": "string" }, "header": "Datenobjekt (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.AllProblems.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id2795, "filter": { "type": "string" }, "header": "Datenobjekt (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.AllProblems.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) } ];
    Lino.checkdata.AllProblems.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.AllProblems.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/AllProblems", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.AllProblems.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/AllProblems", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.AllProblems.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/AllProblems", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.AllProblems.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/AllProblems", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.checkdata.AllProblems.detailPanel = Ext.extend(Lino.checkdata.Problems.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "update_problem", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problem", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problem','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": null, "xtype": "splitbutton" } ],
  ls_url: "/checkdata/AllProblems",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.AllProblems.detail;
    Lino.checkdata.AllProblems.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.AllProblems.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/AllProblems" };
  return new Lino.checkdata.AllProblems.detailPanel(p);
});
Lino.checkdata.AllProblems.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/AllProblems" };
  p.params_panel = new Lino.checkdata.Problems.ParamsPanel({});
  return new Lino.checkdata.AllProblems.GridPanel(p);
});
Lino.checkdata.AllProblems.update_problem = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/AllProblems", "GET", pk, "update_problem", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.AllProblems.fix_problem = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/AllProblems", "GET", pk, "fix_problem", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class checkdata.MyProblems
Lino.checkdata.MyProblems.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/checkdata/MyProblems",
  ls_store_fields : [ { "name": "user" }, 'userHidden', { "name": "owner" }, { "name": "message" }, { "name": "checker" }, 'checkerHidden', { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden' ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 14,
  cell_edit : false,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/checkdata/MyProblems','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/MyProblems','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/MyProblems','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/MyProblems','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/checkdata/MyProblems','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "update_problem", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problem", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problem','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Datenkontrollliste",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.MyProblems.detail;
    var ww = this.containing_window;
    var user2797 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/MyProblems/user" }) }) });
    var owner_disp2798 = new Ext.form.DisplayField({ "disabled": true });
    var message2799 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 250, "selectOnFocus": true });
    var checker2800 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.checkdata.Checkers });
    var id2801 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type2802 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/MyProblems/owner_type" }) }) });
    var owner_id2803 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/MyProblems/owner_id" }) }) });
    this.before_row_edit = function(record) {
    };
    this.onRender = function(ct, position) {
      typeof owner_type2802 !== 'undefined' && owner_type2802.on('change',Lino.chooser_handler(owner_id2803,'owner_type'));
      Lino.checkdata.MyProblems.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "user", "editable": true, "editor": user2797, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.MyProblems.user) The user responsible for fixing this\nproblem.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The user responsible for fixing this\nproblem.", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "owner", "editable": false, "header": "Datenobjekt", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.MyProblems.owner) ") }, "sortable": false, "tooltip": "(checkdata.MyProblems.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "message", "editable": true, "editor": message2799, "filter": { "type": "string" }, "header": "Meldung", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.MyProblems.message) The message text. This is a concatenation of all messages that\nwere yielded by the checker.") }, "sortable": true, "tooltip": "The message text. This is a concatenation of all messages that\nwere yielded by the checker.", "width": Lino.chars2width(51) }, { "colIndex": 3, "dataIndex": "checker", "editable": true, "editor": checker2800, "filter": { "options": [ "Adressen pr\u00fcfen", "Auf Termin\u00fcberschneidungen pr\u00fcfen", "Termine ohne Teilnehmer", "Dauer \u00fcberschreitende Kalendereintr\u00e4ge", "Veraltete generierte Kalendereintr\u00e4ge", "Check data of geographical places.", "Check integrity of ledger vouchers", "Check for previewables needing update", "Check for mismatches between contact details and owner", "Check for missing target files", "Find unbleached html content", "Check metadata of upload files", "Find orphaned files in uploads folder" ], "type": "list" }, "header": "Checker", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.MyProblems.checker) The Checker that reported this\nproblem.") }, "sortable": false, "tooltip": "The Checker that reported this\nproblem.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id2801, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.MyProblems.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type2802, "filter": { "type": "string" }, "header": "Datenobjekt (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.MyProblems.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id2803, "filter": { "type": "string" }, "header": "Datenobjekt (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.MyProblems.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) } ];
    Lino.checkdata.MyProblems.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.MyProblems.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/MyProblems", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.MyProblems.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/MyProblems", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.MyProblems.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/MyProblems", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.MyProblems.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/MyProblems", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.checkdata.MyProblems.detailPanel = Ext.extend(Lino.checkdata.Problems.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "update_problem", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problem", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problem','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": null, "xtype": "splitbutton" } ],
  ls_url: "/checkdata/MyProblems",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.MyProblems.detail;
    Lino.checkdata.MyProblems.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.MyProblems.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/MyProblems" };
  return new Lino.checkdata.MyProblems.detailPanel(p);
});
Lino.checkdata.MyProblems.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/MyProblems" };
  p.params_panel = new Lino.checkdata.Problems.ParamsPanel({});
  return new Lino.checkdata.MyProblems.GridPanel(p);
});
Lino.checkdata.MyProblems.update_problem = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/MyProblems", "GET", pk, "update_problem", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.MyProblems.fix_problem = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/MyProblems", "GET", pk, "fix_problem", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.RemoteCalendars
Lino.cal.RemoteCalendars.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/RemoteCalendars",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "seqno", "type": "int", "useNull": true }, { "name": "type" }, 'typeHidden', { "name": "url_template" }, { "name": "username" }, { "name": "password" }, { "name": "readonly", "type": "boolean" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 15,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/RemoteCalendars','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/RemoteCalendars','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/RemoteCalendars','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/RemoteCalendars','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/RemoteCalendars','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Externe Kalender",
  disabled_fields_index : 8,
  initComponent : function() {
    var ww = this.containing_window;
    var id2805 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var seqno2806 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var type2807 = new Lino.ChoicesFieldElement({ "allowBlank": false, "selectOnFocus": true, "store": [ [ "local", "Local Calendar" ], [ "google", "Google Calendar" ] ], "value": "local" });
    var url_template2808 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var username2809 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var password2810 = new Ext.form.TextField({ "allowBlank": true, "inputType": "password", "maxLength": 200, "selectOnFocus": true });
    var readonly2811 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id2805, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.RemoteCalendars.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 1, "dataIndex": "seqno", "editable": true, "editor": seqno2806, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(cal.RemoteCalendars.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 2, "dataIndex": "type", "editable": true, "editor": type2807, "filter": { "type": "string" }, "header": "Art", "listeners": { "render": Lino.quicktip_renderer("","(cal.RemoteCalendars.type) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "url_template", "editable": true, "editor": url_template2808, "filter": { "type": "string" }, "header": "URL-Vorlage", "listeners": { "render": Lino.quicktip_renderer("","(cal.RemoteCalendars.url_template) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "username", "editable": true, "editor": username2809, "filter": { "type": "string" }, "header": "Benutzername", "listeners": { "render": Lino.quicktip_renderer("","(cal.RemoteCalendars.username) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "password", "editable": true, "editor": password2810, "filter": { "type": "string" }, "header": "Passwort", "listeners": { "render": Lino.quicktip_renderer("","(cal.RemoteCalendars.password) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "readonly", "editable": true, "filter": { "type": "boolean" }, "header": "schreibgesch\u00fctzt", "listeners": { "render": Lino.quicktip_renderer("","(cal.RemoteCalendars.readonly) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" } ];
    Lino.cal.RemoteCalendars.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.RemoteCalendars.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RemoteCalendars", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RemoteCalendars.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RemoteCalendars", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RemoteCalendars.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RemoteCalendars", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RemoteCalendars.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RemoteCalendars", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RemoteCalendars.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RemoteCalendars", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RemoteCalendars.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RemoteCalendars", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RemoteCalendars.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/RemoteCalendars" };
  return new Lino.cal.RemoteCalendars.GridPanel(p);
});
Lino.cal.RemoteCalendars.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RemoteCalendars", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RemoteCalendars.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RemoteCalendars", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RemoteCalendars.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RemoteCalendars", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.Rooms
Lino.cal.Rooms.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/Rooms",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "company" }, 'companyHidden', { "name": "contact_person" }, 'contact_personHidden', { "name": "contact_role" }, 'contact_roleHidden', { "name": "display_color" }, 'display_colorHidden', { "name": "description" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 16,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/Rooms','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Rooms','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Rooms','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Rooms','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/Rooms','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Raum) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "R\u00e4ume",
  disabled_fields_index : 13,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Rooms.detail;
    this.ls_insert_handler = Lino.cal.Rooms.insert;
    var ww = this.containing_window;
    var id2813 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var name2814 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de2815 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr2816 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var company2817 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Rooms/company" }) }) });
    var contact_person2818 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Rooms/contact_person" }) }) });
    var contact_role2819 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Rooms/contact_role" }) }) });
    var display_color2820 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.cal.DisplayColors });
    var description2821 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Beschreibung" });
    this.before_row_edit = function(record) {
      contact_person2818.setContextValue('company', record ? record.data['companyHidden'] : undefined);
      description2821.refresh();
    };
    this.onRender = function(ct, position) {
      typeof company2817 !== 'undefined' && company2817.on('change',Lino.chooser_handler(contact_person2818,'company'));
      Lino.cal.Rooms.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id2813, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.Rooms.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name2814, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(cal.Rooms.name) The designation of the room. This is not required to be unique.") }, "sortable": true, "tooltip": "The designation of the room. This is not required to be unique.", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de2815, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(cal.Rooms.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr2816, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(cal.Rooms.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "company", "editable": true, "editor": company2817, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.Rooms.company) Pointer to Company.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "Pointer to Company.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "contact_person", "editable": true, "editor": contact_person2818, "filter": { "type": "string" }, "header": "Kontaktperson", "listeners": { "render": Lino.quicktip_renderer("","(cal.Rooms.contact_person) Pointer to Person.") }, "renderer": Lino.fk_renderer('contact_personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "Pointer to Person.", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "contact_role", "editable": true, "editor": contact_role2819, "filter": { "type": "string" }, "header": "in seiner Eigenschaft als", "listeners": { "render": Lino.quicktip_renderer("","(cal.Rooms.contact_role) The optional Role\nof the contact_person within company.") }, "sortable": false, "tooltip": "The optional Role\nof the contact_person within company.", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "display_color", "editable": true, "editor": display_color2820, "filter": { "options": [ "White", "Silver", "Gray", "Black", "Red", "Maroon", "Yellow", "Olive", "Lime", "Green", "Aqua", "Teal", "Blue", "Navy", "Fuchsia", "Purple" ], "type": "list" }, "header": "Color", "listeners": { "render": Lino.quicktip_renderer("","(cal.Rooms.display_color) The color to use when displaying entries in this room in the calendar\nview.") }, "sortable": false, "tooltip": "The color to use when displaying entries in this room in the calendar\nview.", "width": Lino.chars2width(11) }, { "colIndex": 8, "dataIndex": "description", "editable": true, "editor": description2821, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.Rooms.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.cal.Rooms.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Rooms.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Rooms", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Rooms.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Rooms", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Rooms.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Rooms", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Rooms.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Rooms", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.Rooms.insertPanel = Ext.extend(Lino.cal.Rooms.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/Rooms",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Rooms.detail;
    this.ls_insert_handler = Lino.cal.Rooms.insert;
    Lino.cal.Rooms.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Rooms.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/Rooms" };
  return new Lino.cal.Rooms.insertPanel(p);
});
Lino.cal.Rooms.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Rooms", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.Rooms.detailPanel = Ext.extend(Lino.cal.Rooms.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Raum) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/Rooms",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Rooms.detail;
    this.ls_insert_handler = Lino.cal.Rooms.insert;
    Lino.cal.Rooms.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Rooms.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Rooms" };
  return new Lino.cal.Rooms.detailPanel(p);
});
Lino.cal.Rooms.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Rooms", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Rooms.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Rooms" };
  return new Lino.cal.Rooms.GridPanel(p);
});
Lino.cal.Rooms.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Rooms", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.AllRooms
Lino.cal.AllRooms.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/AllRooms",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "company" }, 'companyHidden', { "name": "contact_person" }, 'contact_personHidden', { "name": "contact_role" }, 'contact_roleHidden', { "name": "display_color" }, 'display_colorHidden', { "name": "description" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 16,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/AllRooms','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AllRooms','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AllRooms','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AllRooms','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/AllRooms','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Raum) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "R\u00e4ume",
  disabled_fields_index : 13,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.AllRooms.detail;
    this.ls_insert_handler = Lino.cal.AllRooms.insert;
    var ww = this.containing_window;
    var id2823 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var name2824 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de2825 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr2826 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var company2827 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllRooms/company" }) }) });
    var contact_person2828 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllRooms/contact_person" }) }) });
    var contact_role2829 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllRooms/contact_role" }) }) });
    var display_color2830 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.cal.DisplayColors });
    var description2831 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Beschreibung" });
    this.before_row_edit = function(record) {
      contact_person2828.setContextValue('company', record ? record.data['companyHidden'] : undefined);
      description2831.refresh();
    };
    this.onRender = function(ct, position) {
      typeof company2827 !== 'undefined' && company2827.on('change',Lino.chooser_handler(contact_person2828,'company'));
      Lino.cal.AllRooms.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id2823, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllRooms.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name2824, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllRooms.name) The designation of the room. This is not required to be unique.") }, "sortable": true, "tooltip": "The designation of the room. This is not required to be unique.", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de2825, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllRooms.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr2826, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllRooms.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "company", "editable": true, "editor": company2827, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllRooms.company) Pointer to Company.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "Pointer to Company.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "contact_person", "editable": true, "editor": contact_person2828, "filter": { "type": "string" }, "header": "Kontaktperson", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllRooms.contact_person) Pointer to Person.") }, "renderer": Lino.fk_renderer('contact_personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "Pointer to Person.", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "contact_role", "editable": true, "editor": contact_role2829, "filter": { "type": "string" }, "header": "in seiner Eigenschaft als", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllRooms.contact_role) The optional Role\nof the contact_person within company.") }, "sortable": false, "tooltip": "The optional Role\nof the contact_person within company.", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "display_color", "editable": true, "editor": display_color2830, "filter": { "options": [ "White", "Silver", "Gray", "Black", "Red", "Maroon", "Yellow", "Olive", "Lime", "Green", "Aqua", "Teal", "Blue", "Navy", "Fuchsia", "Purple" ], "type": "list" }, "header": "Color", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllRooms.display_color) The color to use when displaying entries in this room in the calendar\nview.") }, "sortable": false, "tooltip": "The color to use when displaying entries in this room in the calendar\nview.", "width": Lino.chars2width(11) }, { "colIndex": 8, "dataIndex": "description", "editable": true, "editor": description2831, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllRooms.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.cal.AllRooms.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.AllRooms.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllRooms", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllRooms.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllRooms", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllRooms.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllRooms", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllRooms.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllRooms", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.AllRooms.insertPanel = Ext.extend(Lino.cal.Rooms.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/AllRooms",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.AllRooms.detail;
    this.ls_insert_handler = Lino.cal.AllRooms.insert;
    Lino.cal.AllRooms.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.AllRooms.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/AllRooms" };
  return new Lino.cal.AllRooms.insertPanel(p);
});
Lino.cal.AllRooms.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllRooms", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.AllRooms.detailPanel = Ext.extend(Lino.cal.Rooms.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Raum) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/AllRooms",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.AllRooms.detail;
    this.ls_insert_handler = Lino.cal.AllRooms.insert;
    Lino.cal.AllRooms.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.AllRooms.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/AllRooms" };
  return new Lino.cal.AllRooms.detailPanel(p);
});
Lino.cal.AllRooms.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllRooms", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllRooms.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/AllRooms" };
  return new Lino.cal.AllRooms.GridPanel(p);
});
Lino.cal.AllRooms.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllRooms", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.Calendars
Lino.cal.Calendars.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/Calendars",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "description" }, { "name": "color", "type": "int", "useNull": true }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 19,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/Calendars','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Calendars','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Calendars','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Calendars','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/Calendars','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalender) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalenderliste",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Calendars.detail;
    this.ls_insert_handler = Lino.cal.Calendars.insert;
    var ww = this.containing_window;
    var id2833 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var name2834 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de2835 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr2836 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var description2837 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Beschreibung" });
    var color2838 = new Ext.form.NumberField({ "allowBlank": false, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      description2837.refresh();
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id2833, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.Calendars.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name2834, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(cal.Calendars.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de2835, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(cal.Calendars.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr2836, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(cal.Calendars.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "description", "editable": true, "editor": description2837, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.Calendars.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "align": "right", "colIndex": 5, "dataIndex": "color", "editable": true, "editor": color2838, "filter": { "type": "numeric" }, "format": "0", "header": "Farbe", "listeners": { "render": Lino.quicktip_renderer("","(cal.Calendars.color) The color to use for entries of this calendar (in\nlino_xl.lib.extensible).") }, "sortable": true, "tooltip": "The color to use for entries of this calendar (in\nlino_xl.lib.extensible).", "width": Lino.chars2width(6), "xtype": "numbercolumn" } ];
    Lino.cal.Calendars.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Calendars.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Calendars", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Calendars.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Calendars", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Calendars.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Calendars", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Calendars.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Calendars", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.Calendars.insertPanel = Ext.extend(Lino.cal.Calendars.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/Calendars",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Calendars.detail;
    this.ls_insert_handler = Lino.cal.Calendars.insert;
    Lino.cal.Calendars.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Calendars.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/Calendars" };
  return new Lino.cal.Calendars.insertPanel(p);
});
Lino.cal.Calendars.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Calendars", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.Calendars.detailPanel = Ext.extend(Lino.cal.Calendars.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalender) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/Calendars",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Calendars.detail;
    this.ls_insert_handler = Lino.cal.Calendars.insert;
    Lino.cal.Calendars.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Calendars.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Calendars" };
  return new Lino.cal.Calendars.detailPanel(p);
});
Lino.cal.Calendars.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Calendars", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Calendars.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Calendars" };
  return new Lino.cal.Calendars.GridPanel(p);
});
Lino.cal.Calendars.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Calendars", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.Subscriptions
Lino.cal.Subscriptions.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/Subscriptions",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "user" }, 'userHidden', { "name": "calendar" }, 'calendarHidden', { "name": "is_hidden", "type": "boolean" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 20,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/Subscriptions','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Subscriptions','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Subscriptions','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Subscriptions','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/Subscriptions','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Abonnements",
  disabled_fields_index : 6,
  initComponent : function() {
    var ww = this.containing_window;
    var id2840 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var user2841 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Subscriptions/user" }) }) });
    var calendar2842 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kalender ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Calendars", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Subscriptions/calendar" }) }) });
    var is_hidden2843 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id2840, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.Subscriptions.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user2841, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(cal.Subscriptions.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "calendar", "editable": true, "editor": calendar2842, "filter": { "type": "string" }, "header": "Kalender", "listeners": { "render": Lino.quicktip_renderer("","(cal.Subscriptions.calendar) The calendar you want to subscribe to.") }, "renderer": Lino.fk_renderer('calendarHidden','Lino.cal.Calendars.detail'), "sortable": false, "tooltip": "The calendar you want to subscribe to.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "is_hidden", "editable": true, "filter": { "type": "boolean" }, "header": "versteckt", "listeners": { "render": Lino.quicktip_renderer("","(cal.Subscriptions.is_hidden) Whether this subscription should \"\n        \"initially be displayed as a hidden calendar.") }, "sortable": false, "tooltip": "Whether this subscription should \"\n        \"initially be displayed as a hidden calendar.", "width": Lino.chars2width(11), "xtype": "checkcolumn" } ];
    Lino.cal.Subscriptions.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Subscriptions.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Subscriptions", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Subscriptions.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Subscriptions", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Subscriptions.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Subscriptions", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Subscriptions.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Subscriptions", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Subscriptions.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Subscriptions", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Subscriptions.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Subscriptions" };
  p.params_panel = new Lino.cal.Subscriptions.ParamsPanel({});
  return new Lino.cal.Subscriptions.GridPanel(p);
});

// js_render_GridPanel_class cal.Tasks
Lino.cal.Tasks.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/Tasks",
  ls_store_fields : [ { "name": "priority" }, 'priorityHidden', { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "summary" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "name": "start_time" }, { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "due_date", "type": "date" }, { "name": "due_time" }, { "name": "percent", "type": "int", "useNull": true }, { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 21,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/Tasks','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Tasks','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Tasks','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Tasks','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/Tasks','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Task) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aufgaben",
  disabled_fields_index : 26,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Tasks.detail;
    this.ls_insert_handler = Lino.cal.Tasks.insert;
    var ww = this.containing_window;
    var priority2845 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var start_date2846 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var summary2847 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp2848 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id2849 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified2850 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created2851 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_time2852 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user2853 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Tasks/user" }) }) });
    var owner_type2854 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Tasks/owner_type" }) }) });
    var owner_id2855 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Tasks/owner_id" }) }) });
    var description2856 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class2857 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence2858 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type2859 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var due_date2860 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var due_time2861 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var percent2862 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var state2863 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.TaskStates });
    var owner_disp2864 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id2855.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type2854 !== 'undefined' && owner_type2854.on('change',Lino.chooser_handler(owner_id2855,'owner_type'));
      Lino.cal.Tasks.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "priority", "editable": true, "editor": priority2845, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.priority) How urgent this task is.") }, "sortable": false, "tooltip": "How urgent this task is.", "width": Lino.chars2width(12) }, { "colIndex": 1, "dataIndex": "start_date", "editable": true, "editor": start_date2846, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.start_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "summary", "editable": true, "editor": summary2847, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.summary) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id2849, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 7, "dataIndex": "start_time", "editable": true, "editor": start_time2852, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 8, "dataIndex": "user", "editable": true, "editor": user2853, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "owner_type", "editable": true, "editor": owner_type2854, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "owner_id", "editable": true, "editor": owner_id2855, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 11, "dataIndex": "description", "editable": true, "editor": description2856, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 12, "dataIndex": "access_class", "editable": true, "editor": access_class2857, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 13, "dataIndex": "sequence", "editable": true, "editor": sequence2858, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 14, "dataIndex": "auto_type", "editable": true, "editor": auto_type2859, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 15, "dataIndex": "due_date", "editable": true, "editor": due_date2860, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Zahlungsziel", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.due_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 16, "dataIndex": "due_time", "editable": true, "editor": due_time2861, "header": "F\u00e4llig um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.due_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "align": "right", "colIndex": 17, "dataIndex": "percent", "editable": true, "editor": percent2862, "filter": { "type": "numeric" }, "format": "0", "header": "Dauer (Anzahl)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.percent) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 18, "dataIndex": "state", "editable": true, "editor": state2863, "filter": { "options": [ "Zu tun", "Wichtig", "Begonnen", "Erledigt", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.state) The state of this Task. one of TaskStates.") }, "sortable": false, "tooltip": "The state of this Task. one of TaskStates.", "width": Lino.chars2width(13) }, { "colIndex": 19, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Tasks.owner) ") }, "sortable": false, "tooltip": "(cal.Tasks.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.Tasks.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Tasks.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Tasks.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Tasks.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Tasks.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.Tasks.insertPanel = Ext.extend(Lino.cal.Tasks.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/Tasks",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Tasks.detail;
    this.ls_insert_handler = Lino.cal.Tasks.insert;
    Lino.cal.Tasks.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Tasks.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/Tasks" };
  return new Lino.cal.Tasks.insertPanel(p);
});
Lino.cal.Tasks.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.Tasks.detailPanel = Ext.extend(Lino.cal.Tasks.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Task) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/Tasks",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Tasks.detail;
    this.ls_insert_handler = Lino.cal.Tasks.insert;
    Lino.cal.Tasks.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Tasks.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Tasks" };
  return new Lino.cal.Tasks.detailPanel(p);
});
Lino.cal.Tasks.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Tasks.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Tasks.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Tasks" };
  p.params_panel = new Lino.cal.Tasks.ParamsPanel({});
  return new Lino.cal.Tasks.GridPanel(p);
});
Lino.cal.Tasks.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Tasks.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Tasks.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Tasks.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Tasks.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Tasks", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.MyTasks
Lino.cal.MyTasks.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/MyTasks",
  ls_store_fields : [ { "name": "priority" }, 'priorityHidden', { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "summary" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 21,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/MyTasks','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyTasks','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyTasks','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyTasks','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/MyTasks','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Task) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Aufgaben",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyTasks.detail;
    this.ls_insert_handler = Lino.cal.MyTasks.insert;
    var ww = this.containing_window;
    var priority2866 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var start_date2867 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var summary2868 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp2869 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "priority", "editable": true, "editor": priority2866, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyTasks.priority) How urgent this task is.") }, "sortable": false, "tooltip": "How urgent this task is.", "width": Lino.chars2width(12) }, { "colIndex": 1, "dataIndex": "start_date", "editable": true, "editor": start_date2867, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyTasks.start_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "summary", "editable": true, "editor": summary2868, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyTasks.summary) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyTasks.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) } ];
    Lino.cal.MyTasks.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyTasks.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyTasks.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyTasks.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyTasks.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyTasks.insertPanel = Ext.extend(Lino.cal.Tasks.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/MyTasks",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyTasks.detail;
    this.ls_insert_handler = Lino.cal.MyTasks.insert;
    Lino.cal.MyTasks.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyTasks.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/MyTasks" };
  return new Lino.cal.MyTasks.insertPanel(p);
});
Lino.cal.MyTasks.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyTasks.detailPanel = Ext.extend(Lino.cal.Tasks.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Task) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/MyTasks",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyTasks.detail;
    this.ls_insert_handler = Lino.cal.MyTasks.insert;
    Lino.cal.MyTasks.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyTasks.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyTasks" };
  return new Lino.cal.MyTasks.detailPanel(p);
});
Lino.cal.MyTasks.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyTasks.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyTasks.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyTasks" };
  p.params_panel = new Lino.cal.Tasks.ParamsPanel({});
  return new Lino.cal.MyTasks.GridPanel(p);
});
Lino.cal.MyTasks.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyTasks.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyTasks.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyTasks.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyTasks.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyTasks", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.GuestRoles
Lino.cal.GuestRoles.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/GuestRoles",
  ls_store_fields : [ { "name": "ref" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 18,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/GuestRoles','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestRoles','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestRoles','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestRoles','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/GuestRoles','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.cal.GuestRoles.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Gastrollen",
  disabled_fields_index : 5,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestRoles.detail;
    var ww = this.containing_window;
    var ref2871 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name2872 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de2873 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr2874 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id2875 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "ref", "editable": true, "editor": ref2871, "filter": { "type": "string" }, "header": "Referenz", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestRoles.ref) Die Referenz. Muss entweder leer oder einzig sein.") }, "sortable": true, "tooltip": "Die Referenz. Muss entweder leer oder einzig sein.", "width": Lino.chars2width(5) }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name2872, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestRoles.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de2873, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestRoles.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr2874, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestRoles.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id2875, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestRoles.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" } ];
    Lino.cal.GuestRoles.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestRoles.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestRoles", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestRoles.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestRoles", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestRoles.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestRoles", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestRoles.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestRoles", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.GuestRoles.detailPanel = Ext.extend(Lino.cal.GuestRoles.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.cal.GuestRoles.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/GuestRoles",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestRoles.detail;
    Lino.cal.GuestRoles.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestRoles.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/GuestRoles" };
  return new Lino.cal.GuestRoles.detailPanel(p);
});
Lino.cal.GuestRoles.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestRoles", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestRoles.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/GuestRoles" };
  return new Lino.cal.GuestRoles.GridPanel(p);
});
Lino.cal.GuestRoles.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestRoles", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.Guests
Lino.cal.Guests.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/Guests",
  ls_store_fields : [ { "name": "partner" }, 'partnerHidden', { "name": "role" }, 'roleHidden', { "name": "workflow_buttons" }, { "name": "remark" }, { "name": "event" }, 'eventHidden', { "name": "id", "type": "int" }, { "name": "state" }, 'stateHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 8,
  content_type : 25,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/Guests','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Guests','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Guests','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Guests','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/Guests','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Anwesenheiten",
  disabled_fields_index : 11,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Guests.detail;
    this.ls_insert_handler = Lino.cal.Guests.insert;
    var ww = this.containing_window;
    var partner2877 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/partner" }) }) });
    var role2878 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Gastrolle ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/role" }) }) });
    var workflow_buttons_disp2879 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var remark2880 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var event2881 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kalendereintrag ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.OneEvent", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Guests/event" }) }) });
    var id2882 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var state2883 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.GuestStates });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "partner", "editable": true, "editor": partner2877, "filter": { "type": "string" }, "header": "Person", "listeners": { "render": Lino.quicktip_renderer("","(cal.Guests.partner) The partner to which this presence applies.") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The partner to which this presence applies.", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "role", "editable": true, "editor": role2878, "filter": { "type": "string" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(cal.Guests.role) The role of this partner in this presence.") }, "renderer": Lino.fk_renderer('roleHidden','Lino.cal.GuestRoles.detail'), "sortable": false, "tooltip": "The role of this partner in this presence.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.Guests.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "colIndex": 3, "dataIndex": "remark", "editable": true, "editor": remark2880, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(cal.Guests.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "event", "editable": true, "editor": event2881, "filter": { "type": "string" }, "header": "Kalendereintrag", "listeners": { "render": Lino.quicktip_renderer("","(cal.Guests.event) The calendar event to which this presence applies.") }, "renderer": Lino.fk_renderer('eventHidden','Lino.cal.OneEvent.detail'), "sortable": false, "tooltip": "The calendar event to which this presence applies.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id2882, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Guests.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "state", "editable": true, "editor": state2883, "filter": { "options": [ "Eingeladen", "Anwesend", "Fehlt", "Entschuldigt" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Guests.state) The state of this presence.  See GuestStates.") }, "sortable": false, "tooltip": "The state of this presence.  See GuestStates.", "width": Lino.chars2width(11) } ];
    Lino.cal.Guests.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Guests.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Guests.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Guests.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Guests.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.Guests.insertPanel = Ext.extend(Lino.cal.Guests.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/Guests",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Guests.detail;
    this.ls_insert_handler = Lino.cal.Guests.insert;
    Lino.cal.Guests.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Guests.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/Guests" };
  return new Lino.cal.Guests.insertPanel(p);
});
Lino.cal.Guests.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.Guests.detailPanel = Ext.extend(Lino.cal.Guests.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/Guests",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Guests.detail;
    this.ls_insert_handler = Lino.cal.Guests.insert;
    Lino.cal.Guests.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Guests.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Guests" };
  return new Lino.cal.Guests.detailPanel(p);
});
Lino.cal.Guests.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Guests.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Guests" };
  p.params_panel = new Lino.cal.Guests.ParamsPanel({});
  return new Lino.cal.Guests.GridPanel(p);
});
Lino.cal.Guests.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Guests.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Guests.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Guests.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Guests.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Guests", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.AllGuests
Lino.cal.AllGuests.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/AllGuests",
  ls_store_fields : [ { "name": "partner" }, 'partnerHidden', { "name": "role" }, 'roleHidden', { "name": "workflow_buttons" }, { "name": "remark" }, { "name": "event" }, 'eventHidden', { "name": "id", "type": "int" }, { "name": "state" }, 'stateHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 8,
  content_type : 25,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/AllGuests','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AllGuests','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AllGuests','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AllGuests','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/AllGuests','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Anwesenheiten",
  disabled_fields_index : 11,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.AllGuests.detail;
    this.ls_insert_handler = Lino.cal.AllGuests.insert;
    var ww = this.containing_window;
    var partner2885 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllGuests/partner" }) }) });
    var role2886 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Gastrolle ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllGuests/role" }) }) });
    var workflow_buttons_disp2887 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var remark2888 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var event2889 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kalendereintrag ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.OneEvent", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllGuests/event" }) }) });
    var id2890 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var state2891 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.GuestStates });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "partner", "editable": true, "editor": partner2885, "filter": { "type": "string" }, "header": "Person", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllGuests.partner) The partner to which this presence applies.") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The partner to which this presence applies.", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "role", "editable": true, "editor": role2886, "filter": { "type": "string" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllGuests.role) The role of this partner in this presence.") }, "renderer": Lino.fk_renderer('roleHidden','Lino.cal.GuestRoles.detail'), "sortable": false, "tooltip": "The role of this partner in this presence.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllGuests.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "colIndex": 3, "dataIndex": "remark", "editable": true, "editor": remark2888, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllGuests.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "event", "editable": true, "editor": event2889, "filter": { "type": "string" }, "header": "Kalendereintrag", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllGuests.event) The calendar event to which this presence applies.") }, "renderer": Lino.fk_renderer('eventHidden','Lino.cal.OneEvent.detail'), "sortable": false, "tooltip": "The calendar event to which this presence applies.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id2890, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllGuests.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "state", "editable": true, "editor": state2891, "filter": { "options": [ "Eingeladen", "Anwesend", "Fehlt", "Entschuldigt" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllGuests.state) The state of this presence.  See GuestStates.") }, "sortable": false, "tooltip": "The state of this presence.  See GuestStates.", "width": Lino.chars2width(11) } ];
    Lino.cal.AllGuests.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.AllGuests.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllGuests.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllGuests.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllGuests.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.AllGuests.insertPanel = Ext.extend(Lino.cal.Guests.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/AllGuests",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.AllGuests.detail;
    this.ls_insert_handler = Lino.cal.AllGuests.insert;
    Lino.cal.AllGuests.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.AllGuests.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/AllGuests" };
  return new Lino.cal.AllGuests.insertPanel(p);
});
Lino.cal.AllGuests.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.AllGuests.detailPanel = Ext.extend(Lino.cal.Guests.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/AllGuests",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.AllGuests.detail;
    this.ls_insert_handler = Lino.cal.AllGuests.insert;
    Lino.cal.AllGuests.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.AllGuests.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/AllGuests" };
  return new Lino.cal.AllGuests.detailPanel(p);
});
Lino.cal.AllGuests.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllGuests.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/AllGuests" };
  p.params_panel = new Lino.cal.Guests.ParamsPanel({});
  return new Lino.cal.AllGuests.GridPanel(p);
});
Lino.cal.AllGuests.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllGuests.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllGuests.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllGuests.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllGuests.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllGuests", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.MyPresences
Lino.cal.MyPresences.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/MyPresences",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "event__start_date", "type": "date" }, { "name": "event__start_time" }, { "name": "event_summary" }, { "name": "role" }, 'roleHidden', { "name": "workflow_buttons" }, { "name": "remark" }, { "name": "id", "type": "int" }, { "name": "event" }, 'eventHidden', { "name": "partner" }, 'partnerHidden', { "name": "state" }, 'stateHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 25,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/MyPresences','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyPresences','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyPresences','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyPresences','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/MyPresences','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Anwesenheiten",
  disabled_fields_index : 14,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyPresences.detail;
    this.ls_insert_handler = Lino.cal.MyPresences.insert;
    var ww = this.containing_window;
    var event__start_date2893 = new Lino.DateField({ "disabled": true, "sortable": false, "value": null });
    var event__start_time2894 = new Lino.TimeField({ "disabled": true, "maxValue": "9:00 PM", "minValue": "7:00", "sortable": false, "value": null });
    var event_summary_disp2895 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var role2896 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Gastrolle ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyPresences/role" }) }) });
    var workflow_buttons_disp2897 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var remark2898 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id2899 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var event2900 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kalendereintrag ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.OneEvent", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyPresences/event" }) }) });
    var partner2901 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyPresences/partner" }) }) });
    var state2902 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.GuestStates });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "event__start_date", "editable": false, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPresences.event__start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "event__start_time", "editable": false, "header": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPresences.event__start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 2, "dataIndex": "event_summary", "editable": false, "header": "Kalendereintrag", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPresences.event_summary) ") }, "sortable": false, "tooltip": "(cal.MyPresences.event_summary) ", "width": Lino.chars2width(31) }, { "colIndex": 3, "dataIndex": "role", "editable": true, "editor": role2896, "filter": { "type": "string" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPresences.role) The role of this partner in this presence.") }, "renderer": Lino.fk_renderer('roleHidden','Lino.cal.GuestRoles.detail'), "sortable": false, "tooltip": "The role of this partner in this presence.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPresences.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "colIndex": 5, "dataIndex": "remark", "editable": true, "editor": remark2898, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPresences.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id2899, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPresences.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "event", "editable": true, "editor": event2900, "filter": { "type": "string" }, "header": "Kalendereintrag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPresences.event) The calendar event to which this presence applies.") }, "renderer": Lino.fk_renderer('eventHidden','Lino.cal.OneEvent.detail'), "sortable": false, "tooltip": "The calendar event to which this presence applies.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "partner", "editable": true, "editor": partner2901, "filter": { "type": "string" }, "header": "Person", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPresences.partner) The partner to which this presence applies.") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The partner to which this presence applies.", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "state", "editable": true, "editor": state2902, "filter": { "options": [ "Eingeladen", "Anwesend", "Fehlt", "Entschuldigt" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPresences.state) The state of this presence.  See GuestStates.") }, "sortable": false, "tooltip": "The state of this presence.  See GuestStates.", "width": Lino.chars2width(11) } ];
    Lino.cal.MyPresences.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyPresences.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPresences.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPresences.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPresences.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyPresences.insertPanel = Ext.extend(Lino.cal.Guests.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/MyPresences",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyPresences.detail;
    this.ls_insert_handler = Lino.cal.MyPresences.insert;
    Lino.cal.MyPresences.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyPresences.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/MyPresences" };
  return new Lino.cal.MyPresences.insertPanel(p);
});
Lino.cal.MyPresences.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyPresences.detailPanel = Ext.extend(Lino.cal.Guests.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/MyPresences",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyPresences.detail;
    this.ls_insert_handler = Lino.cal.MyPresences.insert;
    Lino.cal.MyPresences.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyPresences.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyPresences" };
  return new Lino.cal.MyPresences.detailPanel(p);
});
Lino.cal.MyPresences.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPresences.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyPresences" };
  p.params_panel = new Lino.cal.Guests.ParamsPanel({});
  return new Lino.cal.MyPresences.GridPanel(p);
});
Lino.cal.MyPresences.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPresences.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPresences.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPresences.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPresences.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPresences", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.MyPendingPresences
Lino.cal.MyPendingPresences.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/MyPendingPresences",
  ls_store_fields : [ { "name": "event__when_text" }, { "name": "role" }, 'roleHidden', { "name": "workflow_buttons" }, { "name": "remark" }, { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 25,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/MyPendingPresences','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyPendingPresences','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyPendingPresences','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyPendingPresences','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/MyPendingPresences','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "My pending invitations",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyPendingPresences.detail;
    this.ls_insert_handler = Lino.cal.MyPendingPresences.insert;
    var ww = this.containing_window;
    var event__when_text_disp2904 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "sortable": false, "value": null });
    var role2905 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Gastrolle ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyPendingPresences/role" }) }) });
    var workflow_buttons_disp2906 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var remark2907 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "event__when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPendingPresences.event__when_text) ") }, "sortable": true, "tooltip": "(cal.MyPendingPresences.event__when_text) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "role", "editable": true, "editor": role2905, "filter": { "type": "string" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPendingPresences.role) The role of this partner in this presence.") }, "renderer": Lino.fk_renderer('roleHidden','Lino.cal.GuestRoles.detail'), "sortable": false, "tooltip": "The role of this partner in this presence.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPendingPresences.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "colIndex": 3, "dataIndex": "remark", "editable": true, "editor": remark2907, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyPendingPresences.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) } ];
    Lino.cal.MyPendingPresences.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyPendingPresences.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPendingPresences.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPendingPresences.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPendingPresences.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyPendingPresences.insertPanel = Ext.extend(Lino.cal.Guests.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/MyPendingPresences",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyPendingPresences.detail;
    this.ls_insert_handler = Lino.cal.MyPendingPresences.insert;
    Lino.cal.MyPendingPresences.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyPendingPresences.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/MyPendingPresences" };
  return new Lino.cal.MyPendingPresences.insertPanel(p);
});
Lino.cal.MyPendingPresences.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyPendingPresences.detailPanel = Ext.extend(Lino.cal.Guests.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/MyPendingPresences",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyPendingPresences.detail;
    this.ls_insert_handler = Lino.cal.MyPendingPresences.insert;
    Lino.cal.MyPendingPresences.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyPendingPresences.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyPendingPresences" };
  return new Lino.cal.MyPendingPresences.detailPanel(p);
});
Lino.cal.MyPendingPresences.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPendingPresences.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyPendingPresences" };
  p.params_panel = new Lino.cal.Guests.ParamsPanel({});
  return new Lino.cal.MyPendingPresences.GridPanel(p);
});
Lino.cal.MyPendingPresences.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPendingPresences.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPendingPresences.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPendingPresences.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyPendingPresences.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyPendingPresences", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.MyGuests
Lino.cal.MyGuests.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/MyGuests",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "event__start_date", "type": "date" }, { "name": "event__start_time" }, { "name": "event_summary" }, { "name": "role" }, 'roleHidden', { "name": "workflow_buttons" }, { "name": "remark" }, { "name": "id", "type": "int" }, { "name": "event" }, 'eventHidden', { "name": "partner" }, 'partnerHidden', { "name": "state" }, 'stateHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 25,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/MyGuests','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyGuests','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyGuests','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyGuests','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/MyGuests','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine G\u00e4ste",
  disabled_fields_index : 14,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyGuests.detail;
    this.ls_insert_handler = Lino.cal.MyGuests.insert;
    var ww = this.containing_window;
    var event__start_date2909 = new Lino.DateField({ "disabled": true, "sortable": false, "value": null });
    var event__start_time2910 = new Lino.TimeField({ "disabled": true, "maxValue": "9:00 PM", "minValue": "7:00", "sortable": false, "value": null });
    var event_summary_disp2911 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var role2912 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Gastrolle ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyGuests/role" }) }) });
    var workflow_buttons_disp2913 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var remark2914 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id2915 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var event2916 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kalendereintrag ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.OneEvent", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyGuests/event" }) }) });
    var partner2917 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyGuests/partner" }) }) });
    var state2918 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.GuestStates });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "event__start_date", "editable": false, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyGuests.event__start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "event__start_time", "editable": false, "header": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyGuests.event__start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 2, "dataIndex": "event_summary", "editable": false, "header": "Kalendereintrag", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyGuests.event_summary) ") }, "sortable": false, "tooltip": "(cal.MyGuests.event_summary) ", "width": Lino.chars2width(31) }, { "colIndex": 3, "dataIndex": "role", "editable": true, "editor": role2912, "filter": { "type": "string" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyGuests.role) The role of this partner in this presence.") }, "renderer": Lino.fk_renderer('roleHidden','Lino.cal.GuestRoles.detail'), "sortable": false, "tooltip": "The role of this partner in this presence.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyGuests.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "colIndex": 5, "dataIndex": "remark", "editable": true, "editor": remark2914, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyGuests.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id2915, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyGuests.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "event", "editable": true, "editor": event2916, "filter": { "type": "string" }, "header": "Kalendereintrag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyGuests.event) The calendar event to which this presence applies.") }, "renderer": Lino.fk_renderer('eventHidden','Lino.cal.OneEvent.detail'), "sortable": false, "tooltip": "The calendar event to which this presence applies.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "partner", "editable": true, "editor": partner2917, "filter": { "type": "string" }, "header": "Person", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyGuests.partner) The partner to which this presence applies.") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The partner to which this presence applies.", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "state", "editable": true, "editor": state2918, "filter": { "options": [ "Eingeladen", "Anwesend", "Fehlt", "Entschuldigt" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyGuests.state) The state of this presence.  See GuestStates.") }, "sortable": false, "tooltip": "The state of this presence.  See GuestStates.", "width": Lino.chars2width(11) } ];
    Lino.cal.MyGuests.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyGuests.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyGuests.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyGuests.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyGuests.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyGuests.insertPanel = Ext.extend(Lino.cal.Guests.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/MyGuests",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyGuests.detail;
    this.ls_insert_handler = Lino.cal.MyGuests.insert;
    Lino.cal.MyGuests.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyGuests.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/MyGuests" };
  return new Lino.cal.MyGuests.insertPanel(p);
});
Lino.cal.MyGuests.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyGuests.detailPanel = Ext.extend(Lino.cal.Guests.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/MyGuests",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyGuests.detail;
    this.ls_insert_handler = Lino.cal.MyGuests.insert;
    Lino.cal.MyGuests.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyGuests.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyGuests" };
  return new Lino.cal.MyGuests.detailPanel(p);
});
Lino.cal.MyGuests.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyGuests.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyGuests" };
  p.params_panel = new Lino.cal.Guests.ParamsPanel({});
  return new Lino.cal.MyGuests.GridPanel(p);
});
Lino.cal.MyGuests.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyGuests.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyGuests.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyGuests.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyGuests.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyGuests", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.EventTypes
Lino.cal.EventTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/EventTypes",
  ls_store_fields : [ { "name": "ref" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "planner_column" }, 'planner_columnHidden', { "name": "is_appointment", "type": "boolean" }, { "name": "force_guest_states", "type": "boolean" }, { "name": "all_rooms", "type": "boolean" }, { "name": "id", "type": "int" }, { "name": "seqno", "type": "int", "useNull": true }, { "name": "attach_to_email", "type": "boolean" }, { "name": "email_template" }, { "name": "description" }, { "name": "locks_user", "type": "boolean" }, { "name": "fill_presences", "type": "boolean" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "event_label" }, { "name": "event_label_de" }, { "name": "event_label_fr" }, { "name": "max_conflicting", "type": "int", "useNull": true }, { "name": "max_days", "type": "int", "useNull": true }, { "name": "transparent", "type": "boolean" }, { "name": "default_duration" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 9,
  content_type : 17,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/EventTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EventTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EventTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EventTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/EventTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintragsart) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.cal.EventTypes.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalendereintragsarten",
  disabled_fields_index : 24,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EventTypes.detail;
    this.ls_insert_handler = Lino.cal.EventTypes.insert;
    var ww = this.containing_window;
    var ref2920 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name2921 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de2922 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr2923 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var planner_column2924 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.PlannerColumns) });
    var is_appointment2925 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "selectOnFocus": true });
    var force_guest_states2926 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var all_rooms2927 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var id2928 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var seqno2929 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var attach_to_email2930 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var email_template2931 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EventTypes/email_template" }) }) });
    var description2932 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var locks_user2933 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var fill_presences2934 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var start_date2935 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var event_label2936 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var event_label_de2937 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var event_label_fr2938 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var max_conflicting2939 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 1 });
    var max_days2940 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 1 });
    var transparent2941 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var default_duration2942 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(6), "hidden": true, "maxLength": 6, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      description2932.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "ref", "editable": true, "editor": ref2920, "filter": { "type": "string" }, "header": "Referenz", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.ref) Die Referenz. Muss entweder leer oder einzig sein.") }, "sortable": true, "tooltip": "Die Referenz. Muss entweder leer oder einzig sein.", "width": Lino.chars2width(5) }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name2921, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de2922, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr2923, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "planner_column", "editable": true, "editor": planner_column2924, "filter": { "options": [ "Extern", "Intern" ], "type": "list" }, "header": "Tagesplanerkolonne", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.planner_column) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 5, "dataIndex": "is_appointment", "editable": true, "filter": { "type": "boolean" }, "header": "Termin", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.is_appointment) Whether entries of this type are considered \"appointments\" (i.e. whose\ntime and place have been agreed upon with other users or external\nparties).") }, "sortable": false, "tooltip": "Whether entries of this type are considered \"appointments\" (i.e. whose\ntime and place have been agreed upon with other users or external\nparties).", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 6, "dataIndex": "force_guest_states", "editable": true, "filter": { "type": "boolean" }, "header": "Anwesenheiten automatisch", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.force_guest_states) Whether presence states should be forced to those defined by the\nentry state.") }, "sortable": false, "tooltip": "Whether presence states should be forced to those defined by the\nentry state.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 7, "dataIndex": "all_rooms", "editable": true, "filter": { "type": "boolean" }, "header": "Blockiert alle R\u00e4ume", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.all_rooms) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 8, "dataIndex": "id", "editable": true, "editor": id2928, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 9, "dataIndex": "seqno", "editable": true, "editor": seqno2929, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 10, "dataIndex": "attach_to_email", "editable": true, "filter": { "type": "boolean" }, "header": "als Anhang per E-Mail", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.attach_to_email) Whether the printable file should be attached to the email\nwhen creating an email from a mailable of this type.\n") }, "sortable": false, "tooltip": "Whether the printable file should be attached to the email\nwhen creating an email from a mailable of this type.\n", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 11, "dataIndex": "email_template", "editable": true, "editor": email_template2931, "filter": { "type": "string" }, "header": "E-Mail-Vorlage", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.email_template) The name of the file to be used as template when creating an email from a mailable of this type.") }, "sortable": false, "tooltip": "The name of the file to be used as template when creating an email from a mailable of this type.", "width": Lino.chars2width(11) }, { "colIndex": 12, "dataIndex": "description", "editable": true, "editor": description2932, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 13, "dataIndex": "locks_user", "editable": true, "filter": { "type": "boolean" }, "header": "Blockiert den Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.locks_user) Whether calendar entries of this type make the user\nunavailable for other locking events at the same time.") }, "sortable": false, "tooltip": "Whether calendar entries of this type make the user\nunavailable for other locking events at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 14, "dataIndex": "fill_presences", "editable": true, "filter": { "type": "boolean" }, "header": "G\u00e4ste ausf\u00fcllen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.fill_presences) Whether guests should be automatically filled for calendar entries of\nthis type.") }, "sortable": false, "tooltip": "Whether guests should be automatically filled for calendar entries of\nthis type.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "start_date", "editable": true, "editor": start_date2935, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.start_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 16, "dataIndex": "event_label", "editable": true, "editor": event_label2936, "filter": { "type": "string" }, "header": "Bezeichnung Termin", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.event_label) Default text for summary of new entries.") }, "sortable": true, "tooltip": "Default text for summary of new entries.", "width": Lino.chars2width(22) }, { "colIndex": 17, "dataIndex": "event_label_de", "editable": true, "editor": event_label_de2937, "filter": { "type": "string" }, "header": "Bezeichnung Termin (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.event_label_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 18, "dataIndex": "event_label_fr", "editable": true, "editor": event_label_fr2938, "filter": { "type": "string" }, "header": "Bezeichnung Termin (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.event_label_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 19, "dataIndex": "max_conflicting", "editable": true, "editor": max_conflicting2939, "filter": { "type": "numeric" }, "format": "0", "header": "Gleichzeitige Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.max_conflicting) How many conflicting events should be tolerated.") }, "sortable": true, "tooltip": "How many conflicting events should be tolerated.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 20, "dataIndex": "max_days", "editable": true, "editor": max_days2940, "filter": { "type": "numeric" }, "format": "0", "header": "Tage maximal", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.max_days) The maximal number of days allowed as duration. 0 means no limit.") }, "sortable": true, "tooltip": "The maximal number of days allowed as duration. 0 means no limit.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 21, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.transparent) Allow entries of this type to conflict with other events.") }, "sortable": false, "tooltip": "Allow entries of this type to conflict with other events.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 22, "dataIndex": "default_duration", "editable": true, "editor": default_duration2942, "filter": { "type": "string" }, "format": "", "header": "Vorschlag Dauer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventTypes.default_duration) An optional default duration for calendar entries of this type.") }, "sortable": true, "tooltip": "An optional default duration for calendar entries of this type.", "width": Lino.chars2width(8) } ];
    Lino.cal.EventTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EventTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EventTypes.insertPanel = Ext.extend(Lino.cal.EventTypes.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/EventTypes",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EventTypes.detail;
    this.ls_insert_handler = Lino.cal.EventTypes.insert;
    Lino.cal.EventTypes.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EventTypes.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/EventTypes" };
  return new Lino.cal.EventTypes.insertPanel(p);
});
Lino.cal.EventTypes.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventTypes.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EventTypes.detailPanel = Ext.extend(Lino.cal.EventTypes.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintragsart) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.cal.EventTypes.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/EventTypes",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EventTypes.detail;
    this.ls_insert_handler = Lino.cal.EventTypes.insert;
    Lino.cal.EventTypes.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EventTypes.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EventTypes" };
  return new Lino.cal.EventTypes.detailPanel(p);
});
Lino.cal.EventTypes.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EventTypes" };
  return new Lino.cal.EventTypes.GridPanel(p);
});
Lino.cal.EventTypes.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventTypes.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventTypes.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventTypes.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventTypes", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.RecurrentEvents
Lino.cal.RecurrentEvents.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/RecurrentEvents",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "every_unit" }, 'every_unitHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "id", "type": "int" }, { "name": "start_time" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "name": "description" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 9,
  content_type : 23,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/RecurrentEvents','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/RecurrentEvents','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/RecurrentEvents','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/RecurrentEvents','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/RecurrentEvents','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Regelm\u00e4\u00dfiges Ereignis) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Regelm\u00e4\u00dfige Ereignisse",
  disabled_fields_index : 25,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.RecurrentEvents.detail;
    this.ls_insert_handler = Lino.cal.RecurrentEvents.insert;
    var ww = this.containing_window;
    var start_date2944 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var end_date2945 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var name2946 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de2947 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr2948 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var every_unit2949 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.cal.Recurrencies });
    var event_type2950 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/RecurrentEvents/event_type" }) }) });
    var id2951 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time2952 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_time2953 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user2954 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/RecurrentEvents/user" }) }) });
    var every2955 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 1 });
    var positions2956 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday2957 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday2958 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday2959 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday2960 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday2961 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday2962 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday2963 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events2964 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var description2965 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    this.before_row_edit = function(record) {
      description2965.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "start_date", "editable": true, "editor": start_date2944, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "end_date", "editable": true, "editor": end_date2945, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "name", "editable": true, "editor": name2946, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.name) See lino.utils.mldbc.mixins.BabelNamed.name.") }, "sortable": true, "tooltip": "See lino.utils.mldbc.mixins.BabelNamed.name.", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_de", "editable": true, "editor": name_de2947, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "name_fr", "editable": true, "editor": name_fr2948, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "every_unit", "editable": true, "editor": every_unit2949, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.every_unit) Inherited from RecurrentSet.every_unit.") }, "sortable": false, "tooltip": "Inherited from RecurrentSet.every_unit.", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "event_type", "editable": true, "editor": event_type2950, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.event_type) ") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 7, "dataIndex": "id", "editable": true, "editor": id2951, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 8, "dataIndex": "start_time", "editable": true, "editor": start_time2952, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "end_time", "editable": true, "editor": end_time2953, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "user", "editable": true, "editor": user2954, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 11, "dataIndex": "every", "editable": true, "editor": every2955, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 12, "dataIndex": "positions", "editable": true, "editor": positions2956, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 13, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 14, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 19, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 20, "dataIndex": "max_events", "editable": true, "editor": max_events2964, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 21, "dataIndex": "description", "editable": true, "editor": description2965, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.RecurrentEvents.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.cal.RecurrentEvents.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.RecurrentEvents.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RecurrentEvents", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RecurrentEvents.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RecurrentEvents", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RecurrentEvents.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RecurrentEvents", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RecurrentEvents.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RecurrentEvents", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.RecurrentEvents.insertPanel = Ext.extend(Lino.cal.RecurrentEvents.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/RecurrentEvents",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.RecurrentEvents.detail;
    this.ls_insert_handler = Lino.cal.RecurrentEvents.insert;
    Lino.cal.RecurrentEvents.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.RecurrentEvents.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/RecurrentEvents" };
  return new Lino.cal.RecurrentEvents.insertPanel(p);
});
Lino.cal.RecurrentEvents.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RecurrentEvents", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.RecurrentEvents.detailPanel = Ext.extend(Lino.cal.RecurrentEvents.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Regelm\u00e4\u00dfiges Ereignis) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/RecurrentEvents",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.RecurrentEvents.detail;
    this.ls_insert_handler = Lino.cal.RecurrentEvents.insert;
    Lino.cal.RecurrentEvents.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.RecurrentEvents.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/RecurrentEvents" };
  return new Lino.cal.RecurrentEvents.detailPanel(p);
});
Lino.cal.RecurrentEvents.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RecurrentEvents", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RecurrentEvents.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RecurrentEvents", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RecurrentEvents.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/RecurrentEvents" };
  p.params_panel = new Lino.cal.RecurrentEvents.ParamsPanel({});
  return new Lino.cal.RecurrentEvents.GridPanel(p);
});
Lino.cal.RecurrentEvents.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RecurrentEvents", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.RecurrentEvents.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/RecurrentEvents", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.Events
Lino.cal.Events.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/Events",
  ls_store_fields : [ { "name": "when_text" }, { "name": "user" }, 'userHidden', { "name": "summary" }, { "name": "event_type" }, 'event_typeHidden', { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/Events','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Events','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Events','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Events','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/Events','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalendereintr\u00e4ge",
  disabled_fields_index : 35,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Events.detail;
    this.ls_insert_handler = Lino.cal.Events.insert;
    var ww = this.containing_window;
    var when_text_disp2967 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var user2968 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/user" }) }) });
    var summary2969 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var event_type2970 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/event_type" }) }) });
    var id2971 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified2972 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created2973 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date2974 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time2975 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date2976 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time2977 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time2978 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method2979 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var assigned_to2980 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/assigned_to" }) }) });
    var owner_type2981 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/owner_type" }) }) });
    var owner_id2982 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/owner_id" }) }) });
    var description2983 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class2984 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence2985 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type2986 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority2987 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var transparent2988 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room2989 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/Events/room" }) }) });
    var state2990 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp2991 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id2982.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type2981 !== 'undefined' && owner_type2981.on('change',Lino.chooser_handler(owner_id2982,'owner_type'));
      Lino.cal.Events.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.when_text) ") }, "sortable": true, "tooltip": "(cal.Events.when_text) ", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user2968, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "summary", "editable": true, "editor": summary2969, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "event_type", "editable": true, "editor": event_type2970, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id2971, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 7, "dataIndex": "start_date", "editable": true, "editor": start_date2974, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "start_time", "editable": true, "editor": start_time2975, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "end_date", "editable": true, "editor": end_date2976, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "end_time", "editable": true, "editor": end_time2977, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 11, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 12, "dataIndex": "build_method", "editable": true, "editor": build_method2979, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 13, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to2980, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "owner_type", "editable": true, "editor": owner_type2981, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 15, "dataIndex": "owner_id", "editable": true, "editor": owner_id2982, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 16, "dataIndex": "description", "editable": true, "editor": description2983, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 17, "dataIndex": "access_class", "editable": true, "editor": access_class2984, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 18, "dataIndex": "sequence", "editable": true, "editor": sequence2985, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 19, "dataIndex": "auto_type", "editable": true, "editor": auto_type2986, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 20, "dataIndex": "priority", "editable": true, "editor": priority2987, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 21, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 22, "dataIndex": "room", "editable": true, "editor": room2989, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "state", "editable": true, "editor": state2990, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 24, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Events.owner) ") }, "sortable": false, "tooltip": "(cal.Events.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.Events.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Events.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.Events.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/Events",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Events.detail;
    this.ls_insert_handler = Lino.cal.Events.insert;
    Lino.cal.Events.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Events.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/Events" };
  return new Lino.cal.Events.insertPanel(p);
});
Lino.cal.Events.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.Events.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/Events",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.Events.detail;
    this.ls_insert_handler = Lino.cal.Events.insert;
    Lino.cal.Events.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Events.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Events" };
  return new Lino.cal.Events.detailPanel(p);
});
Lino.cal.Events.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Events" };
  p.params_panel = new Lino.cal.Events.ParamsPanel({});
  return new Lino.cal.Events.GridPanel(p);
});
Lino.cal.Events.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Events.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Events", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.AllEntries
Lino.cal.AllEntries.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/AllEntries",
  ls_store_fields : [ { "name": "when_text" }, { "name": "user" }, 'userHidden', { "name": "summary" }, { "name": "event_type" }, 'event_typeHidden', { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/AllEntries','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AllEntries','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AllEntries','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AllEntries','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/AllEntries','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalendereintr\u00e4ge",
  disabled_fields_index : 35,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.AllEntries.detail;
    this.ls_insert_handler = Lino.cal.AllEntries.insert;
    var ww = this.containing_window;
    var when_text_disp2993 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var user2994 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllEntries/user" }) }) });
    var summary2995 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var event_type2996 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllEntries/event_type" }) }) });
    var id2997 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified2998 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created2999 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3000 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3001 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3002 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3003 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time3004 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method3005 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var assigned_to3006 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllEntries/assigned_to" }) }) });
    var owner_type3007 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllEntries/owner_type" }) }) });
    var owner_id3008 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllEntries/owner_id" }) }) });
    var description3009 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class3010 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence3011 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type3012 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority3013 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var transparent3014 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room3015 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/AllEntries/room" }) }) });
    var state3016 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp3017 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id3008.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type3007 !== 'undefined' && owner_type3007.on('change',Lino.chooser_handler(owner_id3008,'owner_type'));
      Lino.cal.AllEntries.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.when_text) ") }, "sortable": true, "tooltip": "(cal.AllEntries.when_text) ", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user2994, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "summary", "editable": true, "editor": summary2995, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "event_type", "editable": true, "editor": event_type2996, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id2997, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 7, "dataIndex": "start_date", "editable": true, "editor": start_date3000, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "start_time", "editable": true, "editor": start_time3001, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "end_date", "editable": true, "editor": end_date3002, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "end_time", "editable": true, "editor": end_time3003, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 11, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 12, "dataIndex": "build_method", "editable": true, "editor": build_method3005, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 13, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to3006, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "owner_type", "editable": true, "editor": owner_type3007, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 15, "dataIndex": "owner_id", "editable": true, "editor": owner_id3008, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 16, "dataIndex": "description", "editable": true, "editor": description3009, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 17, "dataIndex": "access_class", "editable": true, "editor": access_class3010, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 18, "dataIndex": "sequence", "editable": true, "editor": sequence3011, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 19, "dataIndex": "auto_type", "editable": true, "editor": auto_type3012, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 20, "dataIndex": "priority", "editable": true, "editor": priority3013, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 21, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 22, "dataIndex": "room", "editable": true, "editor": room3015, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "state", "editable": true, "editor": state3016, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 24, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AllEntries.owner) ") }, "sortable": false, "tooltip": "(cal.AllEntries.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.AllEntries.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.AllEntries.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.AllEntries.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/AllEntries",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.AllEntries.detail;
    this.ls_insert_handler = Lino.cal.AllEntries.insert;
    Lino.cal.AllEntries.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.AllEntries.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/AllEntries" };
  return new Lino.cal.AllEntries.insertPanel(p);
});
Lino.cal.AllEntries.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.AllEntries.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/AllEntries",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.AllEntries.detail;
    this.ls_insert_handler = Lino.cal.AllEntries.insert;
    Lino.cal.AllEntries.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.AllEntries.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/AllEntries" };
  return new Lino.cal.AllEntries.detailPanel(p);
});
Lino.cal.AllEntries.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/AllEntries" };
  p.params_panel = new Lino.cal.AllEntries.ParamsPanel({});
  return new Lino.cal.AllEntries.GridPanel(p);
});
Lino.cal.AllEntries.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AllEntries.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AllEntries", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.EntriesByDay
Lino.cal.EntriesByDay.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/EntriesByDay",
  ls_store_fields : [ { "name": "start_time" }, { "name": "end_time" }, { "name": "duration" }, { "name": "room" }, 'roomHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "summary" }, { "name": "owner" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "user" }, 'userHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "transparent", "type": "boolean" }, { "name": "state" }, 'stateHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 10,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByDay','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByDay','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByDay','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByDay','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByDay','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  page_length : 20,
  stripeRows : true,
  title : "Termine heute",
  disabled_fields_index : 36,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByDay.detail;
    this.ls_insert_handler = Lino.cal.EntriesByDay.insert;
    var ww = this.containing_window;
    var start_time3019 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_time3020 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var duration3021 = new Ext.form.TextField({ "boxMinWidth": Lino.chars2width(6), "disabled": true, "maxLength": 6 });
    var room3022 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByDay/room" }) }) });
    var event_type3023 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByDay/event_type" }) }) });
    var summary3024 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var owner_disp3025 = new Ext.form.DisplayField({ "disabled": true });
    var workflow_buttons_disp3026 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3027 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified3028 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created3029 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3030 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date3031 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var build_time3032 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method3033 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var user3034 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByDay/user" }) }) });
    var assigned_to3035 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByDay/assigned_to" }) }) });
    var owner_type3036 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByDay/owner_type" }) }) });
    var owner_id3037 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByDay/owner_id" }) }) });
    var description3038 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class3039 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence3040 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type3041 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority3042 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var transparent3043 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var state3044 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    this.before_row_edit = function(record) {
      owner_id3037.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type3036 !== 'undefined' && owner_type3036.on('change',Lino.chooser_handler(owner_id3037,'owner_type'));
      Lino.cal.EntriesByDay.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "start_time", "editable": true, "editor": start_time3019, "header": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 1, "dataIndex": "end_time", "editable": true, "editor": end_time3020, "header": "Endet um", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "align": "right", "colIndex": 2, "dataIndex": "duration", "editable": false, "format": "", "header": "Dauer", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.duration) ") }, "sortable": true, "tooltip": "(cal.EntriesByDay.duration) ", "width": Lino.chars2width(8) }, { "colIndex": 3, "dataIndex": "room", "editable": true, "editor": room3022, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "event_type", "editable": true, "editor": event_type3023, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "summary", "editable": true, "editor": summary3024, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.owner) ") }, "sortable": false, "tooltip": "(cal.EntriesByDay.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 7, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 8, "dataIndex": "id", "editable": true, "editor": id3027, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 9, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 10, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 11, "dataIndex": "start_date", "editable": true, "editor": start_date3030, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 12, "dataIndex": "end_date", "editable": true, "editor": end_date3031, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 13, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 14, "dataIndex": "build_method", "editable": true, "editor": build_method3033, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 15, "dataIndex": "user", "editable": true, "editor": user3034, "filter": { "type": "string" }, "header": "Verantwortlicher", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 16, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to3035, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 17, "dataIndex": "owner_type", "editable": true, "editor": owner_type3036, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 18, "dataIndex": "owner_id", "editable": true, "editor": owner_id3037, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 19, "dataIndex": "description", "editable": true, "editor": description3038, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 20, "dataIndex": "access_class", "editable": true, "editor": access_class3039, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 21, "dataIndex": "sequence", "editable": true, "editor": sequence3040, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 22, "dataIndex": "auto_type", "editable": true, "editor": auto_type3041, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 23, "dataIndex": "priority", "editable": true, "editor": priority3042, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 24, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 25, "dataIndex": "state", "editable": true, "editor": state3044, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByDay.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) } ];
    Lino.cal.EntriesByDay.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByDay.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EntriesByDay.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/EntriesByDay",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByDay.detail;
    this.ls_insert_handler = Lino.cal.EntriesByDay.insert;
    Lino.cal.EntriesByDay.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByDay.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/EntriesByDay" };
  return new Lino.cal.EntriesByDay.insertPanel(p);
});
Lino.cal.EntriesByDay.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EntriesByDay.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/EntriesByDay",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByDay.detail;
    this.ls_insert_handler = Lino.cal.EntriesByDay.insert;
    Lino.cal.EntriesByDay.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByDay.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntriesByDay" };
  return new Lino.cal.EntriesByDay.detailPanel(p);
});
Lino.cal.EntriesByDay.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntriesByDay" };
  p.params_panel = new Lino.cal.Events.ParamsPanel({});
  return new Lino.cal.EntriesByDay.GridPanel(p);
});
Lino.cal.EntriesByDay.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByDay.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByDay", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.OneEvent
Lino.cal.OneEvent.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/OneEvent",
  ls_store_fields : [ { "name": "when_text" }, { "name": "user" }, 'userHidden', { "name": "summary" }, { "name": "event_type" }, 'event_typeHidden', { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/OneEvent','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/OneEvent','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/OneEvent','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/OneEvent','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/OneEvent','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalendereintr\u00e4ge",
  disabled_fields_index : 35,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.OneEvent.detail;
    this.ls_insert_handler = Lino.cal.OneEvent.insert;
    var ww = this.containing_window;
    var when_text_disp3046 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var user3047 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OneEvent/user" }) }) });
    var summary3048 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var event_type3049 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OneEvent/event_type" }) }) });
    var id3050 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified3051 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created3052 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3053 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3054 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3055 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3056 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time3057 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method3058 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var assigned_to3059 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OneEvent/assigned_to" }) }) });
    var owner_type3060 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OneEvent/owner_type" }) }) });
    var owner_id3061 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OneEvent/owner_id" }) }) });
    var description3062 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class3063 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence3064 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type3065 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority3066 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var transparent3067 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room3068 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OneEvent/room" }) }) });
    var state3069 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp3070 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id3061.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type3060 !== 'undefined' && owner_type3060.on('change',Lino.chooser_handler(owner_id3061,'owner_type'));
      Lino.cal.OneEvent.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.when_text) ") }, "sortable": true, "tooltip": "(cal.OneEvent.when_text) ", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user3047, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "summary", "editable": true, "editor": summary3048, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "event_type", "editable": true, "editor": event_type3049, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id3050, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 7, "dataIndex": "start_date", "editable": true, "editor": start_date3053, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "start_time", "editable": true, "editor": start_time3054, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "end_date", "editable": true, "editor": end_date3055, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "end_time", "editable": true, "editor": end_time3056, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 11, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 12, "dataIndex": "build_method", "editable": true, "editor": build_method3058, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 13, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to3059, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "owner_type", "editable": true, "editor": owner_type3060, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 15, "dataIndex": "owner_id", "editable": true, "editor": owner_id3061, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 16, "dataIndex": "description", "editable": true, "editor": description3062, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 17, "dataIndex": "access_class", "editable": true, "editor": access_class3063, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 18, "dataIndex": "sequence", "editable": true, "editor": sequence3064, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 19, "dataIndex": "auto_type", "editable": true, "editor": auto_type3065, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 20, "dataIndex": "priority", "editable": true, "editor": priority3066, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 21, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 22, "dataIndex": "room", "editable": true, "editor": room3068, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "state", "editable": true, "editor": state3069, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 24, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OneEvent.owner) ") }, "sortable": false, "tooltip": "(cal.OneEvent.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.OneEvent.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.OneEvent.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.OneEvent.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/OneEvent",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.OneEvent.detail;
    this.ls_insert_handler = Lino.cal.OneEvent.insert;
    Lino.cal.OneEvent.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.OneEvent.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/OneEvent" };
  return new Lino.cal.OneEvent.insertPanel(p);
});
Lino.cal.OneEvent.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.OneEvent.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/OneEvent",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.OneEvent.detail;
    this.ls_insert_handler = Lino.cal.OneEvent.insert;
    Lino.cal.OneEvent.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.OneEvent.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/OneEvent" };
  return new Lino.cal.OneEvent.detailPanel(p);
});
Lino.cal.OneEvent.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/OneEvent" };
  p.params_panel = new Lino.cal.OneEvent.ParamsPanel({});
  return new Lino.cal.OneEvent.GridPanel(p);
});
Lino.cal.OneEvent.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OneEvent.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OneEvent", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.MyEntries
Lino.cal.MyEntries.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/MyEntries",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "user" }, 'userHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "summary" }, { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 2,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/MyEntries','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyEntries','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyEntries','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyEntries','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/MyEntries','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Termine",
  disabled_fields_index : 36,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyEntries.detail;
    this.ls_insert_handler = Lino.cal.MyEntries.insert;
    var ww = this.containing_window;
    var detail_link_disp3072 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var workflow_buttons_disp3073 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3074 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified3075 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created3076 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3077 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3078 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3079 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3080 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time3081 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method3082 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var user3083 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntries/user" }) }) });
    var assigned_to3084 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntries/assigned_to" }) }) });
    var owner_type3085 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntries/owner_type" }) }) });
    var owner_id3086 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntries/owner_id" }) }) });
    var summary3087 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var description3088 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class3089 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence3090 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type3091 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority3092 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var event_type3093 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntries/event_type" }) }) });
    var transparent3094 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room3095 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntries/room" }) }) });
    var state3096 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp3097 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id3086.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type3085 !== 'undefined' && owner_type3085.on('change',Lino.chooser_handler(owner_id3086,'owner_type'));
      Lino.cal.MyEntries.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Kalendereintrag", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.detail_link) ") }, "sortable": false, "tooltip": "(cal.MyEntries.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 2, "dataIndex": "id", "editable": true, "editor": id3074, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 4, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 5, "dataIndex": "start_date", "editable": true, "editor": start_date3077, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 6, "dataIndex": "start_time", "editable": true, "editor": start_time3078, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 7, "dataIndex": "end_date", "editable": true, "editor": end_date3079, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "end_time", "editable": true, "editor": end_time3080, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 10, "dataIndex": "build_method", "editable": true, "editor": build_method3082, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 11, "dataIndex": "user", "editable": true, "editor": user3083, "filter": { "type": "string" }, "header": "Verantwortlicher", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to3084, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "owner_type", "editable": true, "editor": owner_type3085, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "owner_id", "editable": true, "editor": owner_id3086, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 15, "dataIndex": "summary", "editable": true, "editor": summary3087, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 16, "dataIndex": "description", "editable": true, "editor": description3088, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 17, "dataIndex": "access_class", "editable": true, "editor": access_class3089, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 18, "dataIndex": "sequence", "editable": true, "editor": sequence3090, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 19, "dataIndex": "auto_type", "editable": true, "editor": auto_type3091, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 20, "dataIndex": "priority", "editable": true, "editor": priority3092, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 21, "dataIndex": "event_type", "editable": true, "editor": event_type3093, "filter": { "type": "string" }, "header": "Kalendereintragsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "colIndex": 22, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 23, "dataIndex": "room", "editable": true, "editor": room3095, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "state", "editable": true, "editor": state3096, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 25, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntries.owner) ") }, "sortable": false, "tooltip": "(cal.MyEntries.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.MyEntries.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyEntries.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyEntries.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/MyEntries",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyEntries.detail;
    this.ls_insert_handler = Lino.cal.MyEntries.insert;
    Lino.cal.MyEntries.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyEntries.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/MyEntries" };
  return new Lino.cal.MyEntries.insertPanel(p);
});
Lino.cal.MyEntries.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyEntries.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/MyEntries",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyEntries.detail;
    this.ls_insert_handler = Lino.cal.MyEntries.insert;
    Lino.cal.MyEntries.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyEntries.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyEntries" };
  return new Lino.cal.MyEntries.detailPanel(p);
});
Lino.cal.MyEntries.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyEntries" };
  p.params_panel = new Lino.cal.MyEntries.ParamsPanel({});
  return new Lino.cal.MyEntries.GridPanel(p);
});
Lino.cal.MyEntries.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntries.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntries", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.MyEntriesToday
Lino.cal.MyEntriesToday.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/MyEntriesToday",
  ls_store_fields : [ { "name": "start_time" }, { "name": "end_time" }, { "name": "event_type" }, 'event_typeHidden', { "name": "summary" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "user" }, 'userHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/MyEntriesToday','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyEntriesToday','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyEntriesToday','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyEntriesToday','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/MyEntriesToday','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Termine heute",
  disabled_fields_index : 35,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyEntriesToday.detail;
    this.ls_insert_handler = Lino.cal.MyEntriesToday.insert;
    var ww = this.containing_window;
    var start_time3099 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_time3100 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var event_type3101 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntriesToday/event_type" }) }) });
    var summary3102 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp3103 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3104 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified3105 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created3106 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3107 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date3108 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var build_time3109 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method3110 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var user3111 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntriesToday/user" }) }) });
    var assigned_to3112 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntriesToday/assigned_to" }) }) });
    var owner_type3113 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntriesToday/owner_type" }) }) });
    var owner_id3114 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntriesToday/owner_id" }) }) });
    var description3115 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class3116 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence3117 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type3118 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority3119 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var transparent3120 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room3121 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyEntriesToday/room" }) }) });
    var state3122 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp3123 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id3114.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type3113 !== 'undefined' && owner_type3113.on('change',Lino.chooser_handler(owner_id3114,'owner_type'));
      Lino.cal.MyEntriesToday.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "start_time", "editable": true, "editor": start_time3099, "header": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 1, "dataIndex": "end_time", "editable": true, "editor": end_time3100, "header": "Endet um", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 2, "dataIndex": "event_type", "editable": true, "editor": event_type3101, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "summary", "editable": true, "editor": summary3102, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id3104, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 7, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 8, "dataIndex": "start_date", "editable": true, "editor": start_date3107, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "end_date", "editable": true, "editor": end_date3108, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 11, "dataIndex": "build_method", "editable": true, "editor": build_method3110, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 12, "dataIndex": "user", "editable": true, "editor": user3111, "filter": { "type": "string" }, "header": "Verantwortlicher", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to3112, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "owner_type", "editable": true, "editor": owner_type3113, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 15, "dataIndex": "owner_id", "editable": true, "editor": owner_id3114, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 16, "dataIndex": "description", "editable": true, "editor": description3115, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 17, "dataIndex": "access_class", "editable": true, "editor": access_class3116, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 18, "dataIndex": "sequence", "editable": true, "editor": sequence3117, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 19, "dataIndex": "auto_type", "editable": true, "editor": auto_type3118, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 20, "dataIndex": "priority", "editable": true, "editor": priority3119, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 21, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 22, "dataIndex": "room", "editable": true, "editor": room3121, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "state", "editable": true, "editor": state3122, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 24, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyEntriesToday.owner) ") }, "sortable": false, "tooltip": "(cal.MyEntriesToday.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.MyEntriesToday.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyEntriesToday.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyEntriesToday.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/MyEntriesToday",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyEntriesToday.detail;
    this.ls_insert_handler = Lino.cal.MyEntriesToday.insert;
    Lino.cal.MyEntriesToday.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyEntriesToday.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/MyEntriesToday" };
  return new Lino.cal.MyEntriesToday.insertPanel(p);
});
Lino.cal.MyEntriesToday.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyEntriesToday.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/MyEntriesToday",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyEntriesToday.detail;
    this.ls_insert_handler = Lino.cal.MyEntriesToday.insert;
    Lino.cal.MyEntriesToday.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyEntriesToday.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyEntriesToday" };
  return new Lino.cal.MyEntriesToday.detailPanel(p);
});
Lino.cal.MyEntriesToday.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyEntriesToday" };
  p.params_panel = new Lino.cal.MyEntries.ParamsPanel({});
  return new Lino.cal.MyEntriesToday.GridPanel(p);
});
Lino.cal.MyEntriesToday.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyEntriesToday.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyEntriesToday", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.MyAssignedEvents
Lino.cal.MyAssignedEvents.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/MyAssignedEvents",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "user" }, 'userHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "summary" }, { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 2,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/MyAssignedEvents','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyAssignedEvents','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyAssignedEvents','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyAssignedEvents','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/MyAssignedEvents','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Mir zugewiesene Termine",
  disabled_fields_index : 36,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyAssignedEvents.detail;
    this.ls_insert_handler = Lino.cal.MyAssignedEvents.insert;
    var ww = this.containing_window;
    var detail_link_disp3125 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var workflow_buttons_disp3126 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3127 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified3128 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created3129 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3130 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3131 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3132 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3133 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time3134 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method3135 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var user3136 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyAssignedEvents/user" }) }) });
    var assigned_to3137 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyAssignedEvents/assigned_to" }) }) });
    var owner_type3138 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyAssignedEvents/owner_type" }) }) });
    var owner_id3139 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyAssignedEvents/owner_id" }) }) });
    var summary3140 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var description3141 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class3142 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence3143 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type3144 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority3145 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var event_type3146 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyAssignedEvents/event_type" }) }) });
    var transparent3147 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room3148 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyAssignedEvents/room" }) }) });
    var state3149 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp3150 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id3139.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type3138 !== 'undefined' && owner_type3138.on('change',Lino.chooser_handler(owner_id3139,'owner_type'));
      Lino.cal.MyAssignedEvents.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Kalendereintrag", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.detail_link) ") }, "sortable": false, "tooltip": "(cal.MyAssignedEvents.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 2, "dataIndex": "id", "editable": true, "editor": id3127, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 4, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 5, "dataIndex": "start_date", "editable": true, "editor": start_date3130, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 6, "dataIndex": "start_time", "editable": true, "editor": start_time3131, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 7, "dataIndex": "end_date", "editable": true, "editor": end_date3132, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "end_time", "editable": true, "editor": end_time3133, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 10, "dataIndex": "build_method", "editable": true, "editor": build_method3135, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 11, "dataIndex": "user", "editable": true, "editor": user3136, "filter": { "type": "string" }, "header": "Verantwortlicher", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to3137, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "owner_type", "editable": true, "editor": owner_type3138, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "owner_id", "editable": true, "editor": owner_id3139, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 15, "dataIndex": "summary", "editable": true, "editor": summary3140, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 16, "dataIndex": "description", "editable": true, "editor": description3141, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 17, "dataIndex": "access_class", "editable": true, "editor": access_class3142, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 18, "dataIndex": "sequence", "editable": true, "editor": sequence3143, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 19, "dataIndex": "auto_type", "editable": true, "editor": auto_type3144, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 20, "dataIndex": "priority", "editable": true, "editor": priority3145, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 21, "dataIndex": "event_type", "editable": true, "editor": event_type3146, "filter": { "type": "string" }, "header": "Kalendereintragsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "colIndex": 22, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 23, "dataIndex": "room", "editable": true, "editor": room3148, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "state", "editable": true, "editor": state3149, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 25, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyAssignedEvents.owner) ") }, "sortable": false, "tooltip": "(cal.MyAssignedEvents.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.MyAssignedEvents.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyAssignedEvents.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyAssignedEvents.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/MyAssignedEvents",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyAssignedEvents.detail;
    this.ls_insert_handler = Lino.cal.MyAssignedEvents.insert;
    Lino.cal.MyAssignedEvents.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyAssignedEvents.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/MyAssignedEvents" };
  return new Lino.cal.MyAssignedEvents.insertPanel(p);
});
Lino.cal.MyAssignedEvents.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyAssignedEvents.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/MyAssignedEvents",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyAssignedEvents.detail;
    this.ls_insert_handler = Lino.cal.MyAssignedEvents.insert;
    Lino.cal.MyAssignedEvents.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyAssignedEvents.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyAssignedEvents" };
  return new Lino.cal.MyAssignedEvents.detailPanel(p);
});
Lino.cal.MyAssignedEvents.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyAssignedEvents" };
  p.params_panel = new Lino.cal.MyEntries.ParamsPanel({});
  return new Lino.cal.MyAssignedEvents.GridPanel(p);
});
Lino.cal.MyAssignedEvents.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyAssignedEvents.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyAssignedEvents", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.OverdueAppointments
Lino.cal.OverdueAppointments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/OverdueAppointments",
  ls_store_fields : [ { "name": "when_text" }, { "name": "user" }, 'userHidden', { "name": "owner" }, { "name": "event_type" }, 'event_typeHidden', { "name": "summary" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 8,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/OverdueAppointments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/OverdueAppointments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/OverdueAppointments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/OverdueAppointments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/OverdueAppointments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  page_length : 20,
  stripeRows : true,
  title : "\u00dcberf\u00e4llige Termine",
  disabled_fields_index : 36,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.OverdueAppointments.detail;
    this.ls_insert_handler = Lino.cal.OverdueAppointments.insert;
    var ww = this.containing_window;
    var when_text_disp3152 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var user3153 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OverdueAppointments/user" }) }) });
    var owner_disp3154 = new Ext.form.DisplayField({ "disabled": true });
    var event_type3155 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OverdueAppointments/event_type" }) }) });
    var summary3156 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp3157 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3158 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified3159 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created3160 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3161 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3162 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3163 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3164 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time3165 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method3166 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var assigned_to3167 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OverdueAppointments/assigned_to" }) }) });
    var owner_type3168 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OverdueAppointments/owner_type" }) }) });
    var owner_id3169 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OverdueAppointments/owner_id" }) }) });
    var description3170 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class3171 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence3172 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type3173 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority3174 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var transparent3175 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room3176 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/OverdueAppointments/room" }) }) });
    var state3177 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    this.before_row_edit = function(record) {
      owner_id3169.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type3168 !== 'undefined' && owner_type3168.on('change',Lino.chooser_handler(owner_id3169,'owner_type'));
      Lino.cal.OverdueAppointments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.when_text) ") }, "sortable": true, "tooltip": "(cal.OverdueAppointments.when_text) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user3153, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.owner) ") }, "sortable": false, "tooltip": "(cal.OverdueAppointments.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 3, "dataIndex": "event_type", "editable": true, "editor": event_type3155, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "summary", "editable": true, "editor": summary3156, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id3158, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 8, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 9, "dataIndex": "start_date", "editable": true, "editor": start_date3161, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "start_time", "editable": true, "editor": start_time3162, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 11, "dataIndex": "end_date", "editable": true, "editor": end_date3163, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 12, "dataIndex": "end_time", "editable": true, "editor": end_time3164, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 13, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 14, "dataIndex": "build_method", "editable": true, "editor": build_method3166, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 15, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to3167, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 16, "dataIndex": "owner_type", "editable": true, "editor": owner_type3168, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 17, "dataIndex": "owner_id", "editable": true, "editor": owner_id3169, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 18, "dataIndex": "description", "editable": true, "editor": description3170, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 19, "dataIndex": "access_class", "editable": true, "editor": access_class3171, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 20, "dataIndex": "sequence", "editable": true, "editor": sequence3172, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 21, "dataIndex": "auto_type", "editable": true, "editor": auto_type3173, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 22, "dataIndex": "priority", "editable": true, "editor": priority3174, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 23, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 24, "dataIndex": "room", "editable": true, "editor": room3176, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 25, "dataIndex": "state", "editable": true, "editor": state3177, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.OverdueAppointments.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) } ];
    Lino.cal.OverdueAppointments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.OverdueAppointments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.OverdueAppointments.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/OverdueAppointments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.OverdueAppointments.detail;
    this.ls_insert_handler = Lino.cal.OverdueAppointments.insert;
    Lino.cal.OverdueAppointments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.OverdueAppointments.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/OverdueAppointments" };
  return new Lino.cal.OverdueAppointments.insertPanel(p);
});
Lino.cal.OverdueAppointments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.OverdueAppointments.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/OverdueAppointments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.OverdueAppointments.detail;
    this.ls_insert_handler = Lino.cal.OverdueAppointments.insert;
    Lino.cal.OverdueAppointments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.OverdueAppointments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/OverdueAppointments" };
  return new Lino.cal.OverdueAppointments.detailPanel(p);
});
Lino.cal.OverdueAppointments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/OverdueAppointments" };
  p.params_panel = new Lino.cal.Events.ParamsPanel({});
  return new Lino.cal.OverdueAppointments.GridPanel(p);
});
Lino.cal.OverdueAppointments.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.OverdueAppointments.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/OverdueAppointments", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.MyOverdueAppointments
Lino.cal.MyOverdueAppointments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/MyOverdueAppointments",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "owner" }, { "name": "event_type" }, 'event_typeHidden', { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "user" }, 'userHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "summary" }, { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/MyOverdueAppointments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyOverdueAppointments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyOverdueAppointments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyOverdueAppointments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/MyOverdueAppointments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  page_length : 20,
  stripeRows : true,
  title : "Meine \u00fcberf\u00e4lligen Termine",
  disabled_fields_index : 36,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyOverdueAppointments.detail;
    this.ls_insert_handler = Lino.cal.MyOverdueAppointments.insert;
    var ww = this.containing_window;
    var detail_link_disp3179 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var owner_disp3180 = new Ext.form.DisplayField({ "disabled": true });
    var event_type3181 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyOverdueAppointments/event_type" }) }) });
    var workflow_buttons_disp3182 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3183 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified3184 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created3185 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3186 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3187 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3188 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3189 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time3190 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method3191 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var user3192 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyOverdueAppointments/user" }) }) });
    var assigned_to3193 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyOverdueAppointments/assigned_to" }) }) });
    var owner_type3194 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyOverdueAppointments/owner_type" }) }) });
    var owner_id3195 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyOverdueAppointments/owner_id" }) }) });
    var summary3196 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var description3197 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class3198 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence3199 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type3200 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority3201 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var transparent3202 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room3203 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyOverdueAppointments/room" }) }) });
    var state3204 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    this.before_row_edit = function(record) {
      owner_id3195.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type3194 !== 'undefined' && owner_type3194.on('change',Lino.chooser_handler(owner_id3195,'owner_type'));
      Lino.cal.MyOverdueAppointments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Kalendereintrag", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.detail_link) ") }, "sortable": false, "tooltip": "(cal.MyOverdueAppointments.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.owner) ") }, "sortable": false, "tooltip": "(cal.MyOverdueAppointments.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "event_type", "editable": true, "editor": event_type3181, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id3183, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 7, "dataIndex": "start_date", "editable": true, "editor": start_date3186, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "start_time", "editable": true, "editor": start_time3187, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "end_date", "editable": true, "editor": end_date3188, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "end_time", "editable": true, "editor": end_time3189, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 11, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 12, "dataIndex": "build_method", "editable": true, "editor": build_method3191, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 13, "dataIndex": "user", "editable": true, "editor": user3192, "filter": { "type": "string" }, "header": "Verantwortlicher", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to3193, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 15, "dataIndex": "owner_type", "editable": true, "editor": owner_type3194, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 16, "dataIndex": "owner_id", "editable": true, "editor": owner_id3195, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 17, "dataIndex": "summary", "editable": true, "editor": summary3196, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 18, "dataIndex": "description", "editable": true, "editor": description3197, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 19, "dataIndex": "access_class", "editable": true, "editor": access_class3198, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 20, "dataIndex": "sequence", "editable": true, "editor": sequence3199, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 21, "dataIndex": "auto_type", "editable": true, "editor": auto_type3200, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 22, "dataIndex": "priority", "editable": true, "editor": priority3201, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 23, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 24, "dataIndex": "room", "editable": true, "editor": room3203, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 25, "dataIndex": "state", "editable": true, "editor": state3204, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyOverdueAppointments.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) } ];
    Lino.cal.MyOverdueAppointments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyOverdueAppointments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyOverdueAppointments.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/MyOverdueAppointments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyOverdueAppointments.detail;
    this.ls_insert_handler = Lino.cal.MyOverdueAppointments.insert;
    Lino.cal.MyOverdueAppointments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyOverdueAppointments.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/MyOverdueAppointments" };
  return new Lino.cal.MyOverdueAppointments.insertPanel(p);
});
Lino.cal.MyOverdueAppointments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyOverdueAppointments.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/MyOverdueAppointments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyOverdueAppointments.detail;
    this.ls_insert_handler = Lino.cal.MyOverdueAppointments.insert;
    Lino.cal.MyOverdueAppointments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyOverdueAppointments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyOverdueAppointments" };
  return new Lino.cal.MyOverdueAppointments.detailPanel(p);
});
Lino.cal.MyOverdueAppointments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyOverdueAppointments" };
  p.params_panel = new Lino.cal.Events.ParamsPanel({});
  return new Lino.cal.MyOverdueAppointments.GridPanel(p);
});
Lino.cal.MyOverdueAppointments.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyOverdueAppointments.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyOverdueAppointments", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.MyUnconfirmedAppointments
Lino.cal.MyUnconfirmedAppointments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/MyUnconfirmedAppointments",
  ls_store_fields : [ { "name": "when_html" }, { "name": "summary" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "user" }, 'userHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/MyUnconfirmedAppointments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyUnconfirmedAppointments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyUnconfirmedAppointments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/MyUnconfirmedAppointments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/MyUnconfirmedAppointments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  page_length : 20,
  stripeRows : true,
  title : "Meine unbest\u00e4tigten Termine",
  disabled_fields_index : 36,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyUnconfirmedAppointments.detail;
    this.ls_insert_handler = Lino.cal.MyUnconfirmedAppointments.insert;
    var ww = this.containing_window;
    var when_html_disp3206 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var summary3207 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp3208 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3209 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified3210 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created3211 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3212 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3213 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3214 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3215 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time3216 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method3217 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var user3218 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyUnconfirmedAppointments/user" }) }) });
    var assigned_to3219 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyUnconfirmedAppointments/assigned_to" }) }) });
    var owner_type3220 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyUnconfirmedAppointments/owner_type" }) }) });
    var owner_id3221 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyUnconfirmedAppointments/owner_id" }) }) });
    var description3222 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class3223 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence3224 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type3225 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority3226 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var event_type3227 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyUnconfirmedAppointments/event_type" }) }) });
    var transparent3228 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room3229 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/MyUnconfirmedAppointments/room" }) }) });
    var state3230 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp3231 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id3221.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type3220 !== 'undefined' && owner_type3220.on('change',Lino.chooser_handler(owner_id3221,'owner_type'));
      Lino.cal.MyUnconfirmedAppointments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "when_html", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.when_html) Shows the date and time of the entry with a link that opens\nall entries on that day.") }, "sortable": true, "tooltip": "Shows the date and time of the entry with a link that opens\nall entries on that day.", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "summary", "editable": true, "editor": summary3207, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id3209, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 5, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "start_date", "editable": true, "editor": start_date3212, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 7, "dataIndex": "start_time", "editable": true, "editor": start_time3213, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 8, "dataIndex": "end_date", "editable": true, "editor": end_date3214, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "end_time", "editable": true, "editor": end_time3215, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 11, "dataIndex": "build_method", "editable": true, "editor": build_method3217, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 12, "dataIndex": "user", "editable": true, "editor": user3218, "filter": { "type": "string" }, "header": "Verantwortlicher", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to3219, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "owner_type", "editable": true, "editor": owner_type3220, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 15, "dataIndex": "owner_id", "editable": true, "editor": owner_id3221, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 16, "dataIndex": "description", "editable": true, "editor": description3222, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 17, "dataIndex": "access_class", "editable": true, "editor": access_class3223, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 18, "dataIndex": "sequence", "editable": true, "editor": sequence3224, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 19, "dataIndex": "auto_type", "editable": true, "editor": auto_type3225, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 20, "dataIndex": "priority", "editable": true, "editor": priority3226, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 21, "dataIndex": "event_type", "editable": true, "editor": event_type3227, "filter": { "type": "string" }, "header": "Kalendereintragsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "colIndex": 22, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 23, "dataIndex": "room", "editable": true, "editor": room3229, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "state", "editable": true, "editor": state3230, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 25, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.MyUnconfirmedAppointments.owner) ") }, "sortable": false, "tooltip": "(cal.MyUnconfirmedAppointments.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.MyUnconfirmedAppointments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyUnconfirmedAppointments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyUnconfirmedAppointments.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/MyUnconfirmedAppointments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyUnconfirmedAppointments.detail;
    this.ls_insert_handler = Lino.cal.MyUnconfirmedAppointments.insert;
    Lino.cal.MyUnconfirmedAppointments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyUnconfirmedAppointments.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/MyUnconfirmedAppointments" };
  return new Lino.cal.MyUnconfirmedAppointments.insertPanel(p);
});
Lino.cal.MyUnconfirmedAppointments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.MyUnconfirmedAppointments.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/MyUnconfirmedAppointments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.MyUnconfirmedAppointments.detail;
    this.ls_insert_handler = Lino.cal.MyUnconfirmedAppointments.insert;
    Lino.cal.MyUnconfirmedAppointments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.MyUnconfirmedAppointments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyUnconfirmedAppointments" };
  return new Lino.cal.MyUnconfirmedAppointments.detailPanel(p);
});
Lino.cal.MyUnconfirmedAppointments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/MyUnconfirmedAppointments" };
  p.params_panel = new Lino.cal.MyEntries.ParamsPanel({});
  return new Lino.cal.MyUnconfirmedAppointments.GridPanel(p);
});
Lino.cal.MyUnconfirmedAppointments.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.MyUnconfirmedAppointments.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/MyUnconfirmedAppointments", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.EventPolicies
Lino.cal.EventPolicies.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/EventPolicies",
  ls_store_fields : [ { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "event_type" }, 'event_typeHidden', { "name": "max_events", "type": "int", "useNull": true }, { "name": "every", "type": "int", "useNull": true }, { "name": "every_unit" }, 'every_unitHidden', { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "positions" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 16,
  content_type : 22,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/EventPolicies','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EventPolicies','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EventPolicies','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EventPolicies','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/EventPolicies','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Wiederholungsregeln",
  disabled_fields_index : 22,
  initComponent : function() {
    var ww = this.containing_window;
    var name3233 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de3234 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr3235 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var event_type3236 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EventPolicies/event_type" }) }) });
    var max_events3237 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var every3238 = new Ext.form.NumberField({ "allowBlank": false, "selectOnFocus": true, "value": 1 });
    var every_unit3239 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var monday3240 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var tuesday3241 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var wednesday3242 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var thursday3243 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var friday3244 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var saturday3245 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var sunday3246 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var id3247 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date3248 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3249 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3250 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3251 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var positions3252 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name", "editable": true, "editor": name3233, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name_de", "editable": true, "editor": name_de3234, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_fr", "editable": true, "editor": name_fr3235, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "event_type", "editable": true, "editor": event_type3236, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.event_type) Generated calendar entries will have this type.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "Generated calendar entries will have this type.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 4, "dataIndex": "max_events", "editable": true, "editor": max_events3237, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 5, "dataIndex": "every", "editable": true, "editor": every3238, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "every_unit", "editable": true, "editor": every_unit3239, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 8, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 9, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 10, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 11, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 12, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 13, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 14, "dataIndex": "id", "editable": true, "editor": id3247, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 15, "dataIndex": "start_date", "editable": true, "editor": start_date3248, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 16, "dataIndex": "start_time", "editable": true, "editor": start_time3249, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 17, "dataIndex": "end_date", "editable": true, "editor": end_date3250, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 18, "dataIndex": "end_time", "editable": true, "editor": end_time3251, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 19, "dataIndex": "positions", "editable": true, "editor": positions3252, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventPolicies.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) } ];
    Lino.cal.EventPolicies.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EventPolicies.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventPolicies", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventPolicies.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventPolicies", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventPolicies.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventPolicies", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventPolicies.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventPolicies", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventPolicies.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventPolicies", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventPolicies.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EventPolicies" };
  return new Lino.cal.EventPolicies.GridPanel(p);
});

// js_render_GridPanel_class calview.DailyPlannerRows
Lino.calview.DailyPlannerRows.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/calview/DailyPlannerRows",
  ls_store_fields : [ { "name": "seqno", "type": "int", "useNull": true }, { "name": "designation" }, { "name": "designation_de" }, { "name": "designation_fr" }, { "name": "start_time" }, { "name": "end_time" }, { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 26,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/calview/DailyPlannerRows','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/DailyPlannerRows','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/calview/DailyPlannerRows','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/DailyPlannerRows','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/calview/DailyPlannerRows','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Tagesplanerzeilen",
  disabled_fields_index : 7,
  initComponent : function() {
    var ww = this.containing_window;
    var seqno3254 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var designation3255 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var designation_de3256 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var designation_fr3257 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var start_time3258 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_time3259 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "seqno", "editable": true, "editor": seqno3254, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyPlannerRows.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "designation", "editable": true, "editor": designation3255, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyPlannerRows.designation) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "designation_de", "editable": true, "editor": designation_de3256, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyPlannerRows.designation_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "designation_fr", "editable": true, "editor": designation_fr3257, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyPlannerRows.designation_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "start_time", "editable": true, "editor": start_time3258, "header": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyPlannerRows.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 5, "dataIndex": "end_time", "editable": true, "editor": end_time3259, "header": "Endet um", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyPlannerRows.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) } ];
    Lino.calview.DailyPlannerRows.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.calview.DailyPlannerRows.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlannerRows", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlannerRows.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlannerRows", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlannerRows.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlannerRows", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlannerRows.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlannerRows", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlannerRows.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlannerRows", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlannerRows.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlannerRows", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlannerRows.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/calview/DailyPlannerRows" };
  return new Lino.calview.DailyPlannerRows.GridPanel(p);
});
Lino.calview.DailyPlannerRows.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlannerRows", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlannerRows.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlannerRows", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlannerRows.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlannerRows", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class uploads.Volumes
Lino.uploads.Volumes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/uploads/Volumes",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "ref" }, { "name": "root_dir" }, { "name": "base_url" }, { "name": "description" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 27,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/uploads/Volumes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/Volumes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/Volumes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/Volumes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/uploads/Volumes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Dateibibliothek) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.uploads.Volumes.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Dateibibliotheken",
  disabled_fields_index : 5,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.Volumes.detail;
    this.ls_insert_handler = Lino.uploads.Volumes.insert;
    var ww = this.containing_window;
    var id3261 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var ref3262 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var root_dir3263 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 255, "selectOnFocus": true });
    var base_url3264 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 255, "selectOnFocus": true });
    var description3265 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 255, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3261, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Volumes.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "ref", "editable": true, "editor": ref3262, "filter": { "type": "string" }, "header": "Referenz", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Volumes.ref) Die Referenz. Muss entweder leer oder einzig sein.") }, "sortable": true, "tooltip": "Die Referenz. Muss entweder leer oder einzig sein.", "width": Lino.chars2width(41) }, { "colIndex": 2, "dataIndex": "root_dir", "editable": true, "editor": root_dir3263, "filter": { "type": "string" }, "header": "Root directory", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Volumes.root_dir) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "base_url", "editable": true, "editor": base_url3264, "filter": { "type": "string" }, "header": "Base URL", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Volumes.base_url) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "description", "editable": true, "editor": description3265, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Volumes.description) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) } ];
    Lino.uploads.Volumes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.Volumes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Volumes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Volumes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Volumes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Volumes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Volumes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Volumes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Volumes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.Volumes.insertPanel = Ext.extend(Lino.uploads.Volumes.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/uploads/Volumes",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.Volumes.detail;
    this.ls_insert_handler = Lino.uploads.Volumes.insert;
    Lino.uploads.Volumes.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.Volumes.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/uploads/Volumes" };
  return new Lino.uploads.Volumes.insertPanel(p);
});
Lino.uploads.Volumes.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Volumes", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.Volumes.detailPanel = Ext.extend(Lino.uploads.Volumes.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Dateibibliothek) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.uploads.Volumes.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/uploads/Volumes",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.Volumes.detail;
    this.ls_insert_handler = Lino.uploads.Volumes.insert;
    Lino.uploads.Volumes.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.Volumes.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/Volumes" };
  return new Lino.uploads.Volumes.detailPanel(p);
});
Lino.uploads.Volumes.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Volumes", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Volumes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/Volumes" };
  return new Lino.uploads.Volumes.GridPanel(p);
});
Lino.uploads.Volumes.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Volumes", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class uploads.UploadTypes
Lino.uploads.UploadTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/uploads/UploadTypes",
  ls_store_fields : [ { "name": "upload_area" }, 'upload_areaHidden', { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "max_number", "type": "int", "useNull": true }, { "name": "wanted", "type": "boolean" }, { "name": "shortcut" }, { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 8,
  content_type : 28,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Art) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Upload-Arten",
  disabled_fields_index : 9,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.UploadTypes.detail;
    this.ls_insert_handler = Lino.uploads.UploadTypes.insert;
    var ww = this.containing_window;
    var upload_area3267 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.uploads.UploadAreas });
    var name3268 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de3269 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr3270 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var max_number3271 = new Ext.form.NumberField({ "allowBlank": false, "selectOnFocus": true, "value": -1 });
    var wanted3272 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var shortcut3273 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 50, "selectOnFocus": true });
    var id3274 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "upload_area", "editable": true, "editor": upload_area3267, "filter": { "options": [ "Uploads" ], "type": "list" }, "header": "Upload-Bereich", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadTypes.upload_area) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name3268, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadTypes.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de3269, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadTypes.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr3270, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadTypes.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 4, "dataIndex": "max_number", "editable": true, "editor": max_number3271, "filter": { "type": "numeric" }, "format": "0", "header": "Max. number", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadTypes.max_number) No need to upload more uploads than N of this type.\n-1 means no limit.") }, "sortable": true, "tooltip": "No need to upload more uploads than N of this type.\n-1 means no limit.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "wanted", "editable": true, "filter": { "type": "boolean" }, "header": "Wanted", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadTypes.wanted) Add a (+) button when there is no upload of this type.") }, "sortable": false, "tooltip": "Add a (+) button when there is no upload of this type.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 6, "dataIndex": "shortcut", "editable": true, "editor": shortcut3273, "filter": { "type": "string" }, "header": "Upload shortcut", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadTypes.shortcut) Optional pointer to a virtual upload shortcut field.  If\nthis is not empty, then the given shortcut field will manage\nuploads of this type.  See also Shortcuts.") }, "sortable": true, "tooltip": "Optional pointer to a virtual upload shortcut field.  If\nthis is not empty, then the given shortcut field will manage\nuploads of this type.  See also Shortcuts.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 7, "dataIndex": "id", "editable": true, "editor": id3274, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadTypes.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" } ];
    Lino.uploads.UploadTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.UploadTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.UploadTypes.insertPanel = Ext.extend(Lino.uploads.UploadTypes.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/uploads/UploadTypes",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.UploadTypes.detail;
    this.ls_insert_handler = Lino.uploads.UploadTypes.insert;
    Lino.uploads.UploadTypes.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.UploadTypes.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/uploads/UploadTypes" };
  return new Lino.uploads.UploadTypes.insertPanel(p);
});
Lino.uploads.UploadTypes.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadTypes", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.UploadTypes.detailPanel = Ext.extend(Lino.uploads.UploadTypes.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Art) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/uploads/UploadTypes",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.UploadTypes.detail;
    this.ls_insert_handler = Lino.uploads.UploadTypes.insert;
    Lino.uploads.UploadTypes.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.UploadTypes.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/UploadTypes" };
  return new Lino.uploads.UploadTypes.detailPanel(p);
});
Lino.uploads.UploadTypes.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadTypes", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/UploadTypes" };
  return new Lino.uploads.UploadTypes.GridPanel(p);
});
Lino.uploads.UploadTypes.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadTypes", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class uploads.Uploads
Lino.uploads.Uploads.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/uploads/Uploads",
  ls_store_fields : [ { "name": "file" }, { "name": "type" }, 'typeHidden', { "name": "user" }, 'userHidden', { "name": "owner" }, { "name": "description" }, { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "mimetype" }, { "name": "upload_area" }, 'upload_areaHidden', { "name": "volume" }, 'volumeHidden', { "name": "library_file" }, { "name": "file_size", "type": "int", "useNull": true }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 29,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/uploads/Uploads','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/Uploads','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/Uploads','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/Uploads','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/uploads/Uploads','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Upload-Dateien",
  disabled_fields_index : 19,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.Uploads.detail;
    this.ls_insert_handler = Lino.uploads.Uploads.insert;
    var ww = this.containing_window;
    var file3276 = Lino.file_field_handler(this,{ "allowBlank": true, "maxLength": 100, "selectOnFocus": true });
    var type3277 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Upload-Art ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "uploads.UploadTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/type" }) }) });
    var user3278 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/user" }) }) });
    var owner_disp3279 = new Ext.form.DisplayField({ "disabled": true });
    var description3280 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id3281 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type3282 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/owner_type" }) }) });
    var owner_id3283 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/owner_id" }) }) });
    var mimetype3284 = new Ext.form.TextField({ "disabled": true, "hidden": true, "maxLength": 255 });
    var upload_area3285 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.uploads.UploadAreas });
    var volume3286 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Dateibibliothek ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/volume" }) }) });
    var library_file3287 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/Uploads/library_file" }) }) });
    var file_size3288 = new Ext.form.NumberField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      type3277.setContextValue('upload_area', record ? record.data['upload_areaHidden'] : undefined);
      owner_id3283.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      library_file3287.setContextValue('volume', record ? record.data['volumeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof upload_area3285 !== 'undefined' && upload_area3285.on('change',Lino.chooser_handler(type3277,'upload_area'));
      typeof owner_type3282 !== 'undefined' && owner_type3282.on('change',Lino.chooser_handler(owner_id3283,'owner_type'));
      typeof volume3286 !== 'undefined' && volume3286.on('change',Lino.chooser_handler(library_file3287,'volume'));
      Lino.uploads.Uploads.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "file", "editable": true, "editor": file3276, "filter": { "type": "string" }, "header": "Datei", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.file) Pointer to the uploaded file itself (a Django FileField).") }, "sortable": true, "tooltip": "Pointer to the uploaded file itself (a Django FileField).", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "type", "editable": true, "editor": type3277, "filter": { "type": "string" }, "header": "Upload-Art", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.type) The type of this upload.") }, "renderer": Lino.fk_renderer('typeHidden','Lino.uploads.UploadTypes.detail'), "sortable": false, "tooltip": "The type of this upload.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user3278, "filter": { "type": "string" }, "header": "Hochgeladen durch", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.owner) ") }, "sortable": false, "tooltip": "(uploads.Uploads.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 4, "dataIndex": "description", "editable": true, "editor": description3280, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.description) A short description entered manually by the user.") }, "sortable": true, "tooltip": "A short description entered manually by the user.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id3281, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "owner_type", "editable": true, "editor": owner_type3282, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "owner_id", "editable": true, "editor": owner_id3283, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 8, "dataIndex": "mimetype", "editable": false, "filter": { "type": "string" }, "header": "MIME-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.mimetype) The media type of the\nuploaded file.") }, "sortable": true, "tooltip": "The media type of the\nuploaded file.", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "upload_area", "editable": true, "editor": upload_area3285, "filter": { "options": [ "Uploads" ], "type": "list" }, "header": "Upload-Bereich", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.upload_area) The upload area this file belongs to.") }, "sortable": false, "tooltip": "The upload area this file belongs to.", "width": Lino.chars2width(11) }, { "colIndex": 10, "dataIndex": "volume", "editable": true, "editor": volume3286, "filter": { "type": "string" }, "header": "Dateibibliothek", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.volume) A pointer to the library volume where this file is stored.") }, "renderer": Lino.fk_renderer('volumeHidden','Lino.uploads.Volumes.detail'), "sortable": false, "tooltip": "A pointer to the library volume where this file is stored.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "library_file", "editable": true, "editor": library_file3287, "filter": { "type": "string" }, "header": "Bibliotheksdatei", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.library_file) The path of this file, relative the volume's root.") }, "sortable": false, "tooltip": "The path of this file, relative the volume's root.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 12, "dataIndex": "file_size", "editable": false, "filter": { "type": "numeric" }, "format": "0", "header": "File size", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Uploads.file_size) The size of the file in bytes. Not yet implemented.") }, "sortable": true, "tooltip": "The size of the file in bytes. Not yet implemented.", "width": Lino.chars2width(6), "xtype": "numbercolumn" } ];
    Lino.uploads.Uploads.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.Uploads.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Uploads", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Uploads.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Uploads", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Uploads.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Uploads", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Uploads.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Uploads", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.Uploads.insertPanel = Ext.extend(Lino.uploads.Uploads.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/uploads/Uploads",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.Uploads.detail;
    this.ls_insert_handler = Lino.uploads.Uploads.insert;
    Lino.uploads.Uploads.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.Uploads.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/uploads/Uploads" };
  return new Lino.uploads.Uploads.insertPanel(p);
});
Lino.uploads.Uploads.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Uploads", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.Uploads.detailPanel = Ext.extend(Lino.uploads.Uploads.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/uploads/Uploads",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.Uploads.detail;
    this.ls_insert_handler = Lino.uploads.Uploads.insert;
    Lino.uploads.Uploads.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.Uploads.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/Uploads" };
  return new Lino.uploads.Uploads.detailPanel(p);
});
Lino.uploads.Uploads.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Uploads", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Uploads.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Uploads", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Uploads.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Uploads", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Uploads.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/Uploads" };
  p.params_panel = new Lino.uploads.Uploads.ParamsPanel({});
  return new Lino.uploads.Uploads.GridPanel(p);
});
Lino.uploads.Uploads.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Uploads", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class uploads.AllUploads
Lino.uploads.AllUploads.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/uploads/AllUploads",
  ls_store_fields : [ { "name": "file" }, { "name": "type" }, 'typeHidden', { "name": "user" }, 'userHidden', { "name": "owner" }, { "name": "description" }, { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "mimetype" }, { "name": "upload_area" }, 'upload_areaHidden', { "name": "volume" }, 'volumeHidden', { "name": "library_file" }, { "name": "file_size", "type": "int", "useNull": true }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 29,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/uploads/AllUploads','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/AllUploads','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/AllUploads','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/AllUploads','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/uploads/AllUploads','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Upload-Dateien",
  disabled_fields_index : 19,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.AllUploads.detail;
    this.ls_insert_handler = Lino.uploads.AllUploads.insert;
    var ww = this.containing_window;
    var file3290 = Lino.file_field_handler(this,{ "allowBlank": true, "maxLength": 100, "selectOnFocus": true });
    var type3291 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Upload-Art ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "uploads.UploadTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AllUploads/type" }) }) });
    var user3292 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AllUploads/user" }) }) });
    var owner_disp3293 = new Ext.form.DisplayField({ "disabled": true });
    var description3294 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id3295 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type3296 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AllUploads/owner_type" }) }) });
    var owner_id3297 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AllUploads/owner_id" }) }) });
    var mimetype3298 = new Ext.form.TextField({ "disabled": true, "hidden": true, "maxLength": 255 });
    var upload_area3299 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.uploads.UploadAreas });
    var volume3300 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Dateibibliothek ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AllUploads/volume" }) }) });
    var library_file3301 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AllUploads/library_file" }) }) });
    var file_size3302 = new Ext.form.NumberField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      type3291.setContextValue('upload_area', record ? record.data['upload_areaHidden'] : undefined);
      owner_id3297.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      library_file3301.setContextValue('volume', record ? record.data['volumeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof upload_area3299 !== 'undefined' && upload_area3299.on('change',Lino.chooser_handler(type3291,'upload_area'));
      typeof owner_type3296 !== 'undefined' && owner_type3296.on('change',Lino.chooser_handler(owner_id3297,'owner_type'));
      typeof volume3300 !== 'undefined' && volume3300.on('change',Lino.chooser_handler(library_file3301,'volume'));
      Lino.uploads.AllUploads.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "file", "editable": true, "editor": file3290, "filter": { "type": "string" }, "header": "Datei", "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.file) Pointer to the uploaded file itself (a Django FileField).") }, "sortable": true, "tooltip": "Pointer to the uploaded file itself (a Django FileField).", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "type", "editable": true, "editor": type3291, "filter": { "type": "string" }, "header": "Upload-Art", "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.type) The type of this upload.") }, "renderer": Lino.fk_renderer('typeHidden','Lino.uploads.UploadTypes.detail'), "sortable": false, "tooltip": "The type of this upload.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user3292, "filter": { "type": "string" }, "header": "Hochgeladen durch", "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.owner) ") }, "sortable": false, "tooltip": "(uploads.AllUploads.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 4, "dataIndex": "description", "editable": true, "editor": description3294, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.description) A short description entered manually by the user.") }, "sortable": true, "tooltip": "A short description entered manually by the user.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id3295, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "owner_type", "editable": true, "editor": owner_type3296, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "owner_id", "editable": true, "editor": owner_id3297, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 8, "dataIndex": "mimetype", "editable": false, "filter": { "type": "string" }, "header": "MIME-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.mimetype) The media type of the\nuploaded file.") }, "sortable": true, "tooltip": "The media type of the\nuploaded file.", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "upload_area", "editable": true, "editor": upload_area3299, "filter": { "options": [ "Uploads" ], "type": "list" }, "header": "Upload-Bereich", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.upload_area) The upload area this file belongs to.") }, "sortable": false, "tooltip": "The upload area this file belongs to.", "width": Lino.chars2width(11) }, { "colIndex": 10, "dataIndex": "volume", "editable": true, "editor": volume3300, "filter": { "type": "string" }, "header": "Dateibibliothek", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.volume) A pointer to the library volume where this file is stored.") }, "renderer": Lino.fk_renderer('volumeHidden','Lino.uploads.Volumes.detail'), "sortable": false, "tooltip": "A pointer to the library volume where this file is stored.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "library_file", "editable": true, "editor": library_file3301, "filter": { "type": "string" }, "header": "Bibliotheksdatei", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.library_file) The path of this file, relative the volume's root.") }, "sortable": false, "tooltip": "The path of this file, relative the volume's root.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 12, "dataIndex": "file_size", "editable": false, "filter": { "type": "numeric" }, "format": "0", "header": "File size", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AllUploads.file_size) The size of the file in bytes. Not yet implemented.") }, "sortable": true, "tooltip": "The size of the file in bytes. Not yet implemented.", "width": Lino.chars2width(6), "xtype": "numbercolumn" } ];
    Lino.uploads.AllUploads.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.AllUploads.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AllUploads", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AllUploads.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AllUploads", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AllUploads.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AllUploads", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AllUploads.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AllUploads", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.AllUploads.insertPanel = Ext.extend(Lino.uploads.Uploads.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/uploads/AllUploads",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.AllUploads.detail;
    this.ls_insert_handler = Lino.uploads.AllUploads.insert;
    Lino.uploads.AllUploads.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.AllUploads.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/uploads/AllUploads" };
  return new Lino.uploads.AllUploads.insertPanel(p);
});
Lino.uploads.AllUploads.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AllUploads", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.AllUploads.detailPanel = Ext.extend(Lino.uploads.Uploads.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/uploads/AllUploads",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.AllUploads.detail;
    this.ls_insert_handler = Lino.uploads.AllUploads.insert;
    Lino.uploads.AllUploads.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.AllUploads.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/AllUploads" };
  return new Lino.uploads.AllUploads.detailPanel(p);
});
Lino.uploads.AllUploads.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AllUploads", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AllUploads.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AllUploads", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AllUploads.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AllUploads", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AllUploads.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/AllUploads" };
  p.params_panel = new Lino.uploads.Uploads.ParamsPanel({});
  return new Lino.uploads.AllUploads.GridPanel(p);
});
Lino.uploads.AllUploads.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AllUploads", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class uploads.MyUploads
Lino.uploads.MyUploads.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/uploads/MyUploads",
  ls_store_fields : [ { "name": "file" }, { "name": "library_file" }, { "name": "description" }, { "name": "user" }, 'userHidden', { "name": "owner" }, { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "mimetype" }, { "name": "upload_area" }, 'upload_areaHidden', { "name": "type" }, 'typeHidden', { "name": "volume" }, 'volumeHidden', { "name": "file_size", "type": "int", "useNull": true }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 29,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/uploads/MyUploads','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/MyUploads','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/MyUploads','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/MyUploads','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/uploads/MyUploads','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Upload-Dateien",
  disabled_fields_index : 19,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.MyUploads.detail;
    this.ls_insert_handler = Lino.uploads.MyUploads.insert;
    var ww = this.containing_window;
    var file3304 = Lino.file_field_handler(this,{ "allowBlank": true, "maxLength": 100, "selectOnFocus": true });
    var library_file3305 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/MyUploads/library_file" }) }) });
    var description3306 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var user3307 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/MyUploads/user" }) }) });
    var owner_disp3308 = new Ext.form.DisplayField({ "disabled": true });
    var id3309 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type3310 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/MyUploads/owner_type" }) }) });
    var owner_id3311 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/MyUploads/owner_id" }) }) });
    var mimetype3312 = new Ext.form.TextField({ "disabled": true, "hidden": true, "maxLength": 255 });
    var upload_area3313 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.uploads.UploadAreas });
    var type3314 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Upload-Art ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "uploads.UploadTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/MyUploads/type" }) }) });
    var volume3315 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Dateibibliothek ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/MyUploads/volume" }) }) });
    var file_size3316 = new Ext.form.NumberField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      library_file3305.setContextValue('volume', record ? record.data['volumeHidden'] : undefined);
      owner_id3311.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      type3314.setContextValue('upload_area', record ? record.data['upload_areaHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof volume3315 !== 'undefined' && volume3315.on('change',Lino.chooser_handler(library_file3305,'volume'));
      typeof owner_type3310 !== 'undefined' && owner_type3310.on('change',Lino.chooser_handler(owner_id3311,'owner_type'));
      typeof upload_area3313 !== 'undefined' && upload_area3313.on('change',Lino.chooser_handler(type3314,'upload_area'));
      Lino.uploads.MyUploads.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "file", "editable": true, "editor": file3304, "filter": { "type": "string" }, "header": "Datei", "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.file) Pointer to the uploaded file itself (a Django FileField).") }, "sortable": true, "tooltip": "Pointer to the uploaded file itself (a Django FileField).", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "library_file", "editable": true, "editor": library_file3305, "filter": { "type": "string" }, "header": "Bibliotheksdatei", "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.library_file) The path of this file, relative the volume's root.") }, "sortable": false, "tooltip": "The path of this file, relative the volume's root.", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "description", "editable": true, "editor": description3306, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.description) A short description entered manually by the user.") }, "sortable": true, "tooltip": "A short description entered manually by the user.", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "user", "editable": true, "editor": user3307, "filter": { "type": "string" }, "header": "Hochgeladen durch", "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.owner) ") }, "sortable": false, "tooltip": "(uploads.MyUploads.owner) ", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id3309, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "owner_type", "editable": true, "editor": owner_type3310, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "owner_id", "editable": true, "editor": owner_id3311, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 8, "dataIndex": "mimetype", "editable": false, "filter": { "type": "string" }, "header": "MIME-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.mimetype) The media type of the\nuploaded file.") }, "sortable": true, "tooltip": "The media type of the\nuploaded file.", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "upload_area", "editable": true, "editor": upload_area3313, "filter": { "options": [ "Uploads" ], "type": "list" }, "header": "Upload-Bereich", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.upload_area) The upload area this file belongs to.") }, "sortable": false, "tooltip": "The upload area this file belongs to.", "width": Lino.chars2width(11) }, { "colIndex": 10, "dataIndex": "type", "editable": true, "editor": type3314, "filter": { "type": "string" }, "header": "Upload-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.type) The type of this upload.") }, "renderer": Lino.fk_renderer('typeHidden','Lino.uploads.UploadTypes.detail'), "sortable": false, "tooltip": "The type of this upload.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "volume", "editable": true, "editor": volume3315, "filter": { "type": "string" }, "header": "Dateibibliothek", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.volume) A pointer to the library volume where this file is stored.") }, "renderer": Lino.fk_renderer('volumeHidden','Lino.uploads.Volumes.detail'), "sortable": false, "tooltip": "A pointer to the library volume where this file is stored.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 12, "dataIndex": "file_size", "editable": false, "filter": { "type": "numeric" }, "format": "0", "header": "File size", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.MyUploads.file_size) The size of the file in bytes. Not yet implemented.") }, "sortable": true, "tooltip": "The size of the file in bytes. Not yet implemented.", "width": Lino.chars2width(6), "xtype": "numbercolumn" } ];
    Lino.uploads.MyUploads.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.MyUploads.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/MyUploads", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.MyUploads.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/MyUploads", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.MyUploads.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/MyUploads", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.MyUploads.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/MyUploads", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.MyUploads.insertPanel = Ext.extend(Lino.uploads.Uploads.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/uploads/MyUploads",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.MyUploads.detail;
    this.ls_insert_handler = Lino.uploads.MyUploads.insert;
    Lino.uploads.MyUploads.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.MyUploads.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/uploads/MyUploads" };
  return new Lino.uploads.MyUploads.insertPanel(p);
});
Lino.uploads.MyUploads.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/MyUploads", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.MyUploads.detailPanel = Ext.extend(Lino.uploads.Uploads.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/uploads/MyUploads",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.MyUploads.detail;
    this.ls_insert_handler = Lino.uploads.MyUploads.insert;
    Lino.uploads.MyUploads.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.MyUploads.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/MyUploads" };
  return new Lino.uploads.MyUploads.detailPanel(p);
});
Lino.uploads.MyUploads.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/MyUploads", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.MyUploads.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/MyUploads", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.MyUploads.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/MyUploads", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.MyUploads.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/MyUploads" };
  p.params_panel = new Lino.uploads.Uploads.ParamsPanel({});
  return new Lino.uploads.MyUploads.GridPanel(p);
});
Lino.uploads.MyUploads.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/MyUploads", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class uploads.AreaUploads
Lino.uploads.AreaUploads.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/uploads/AreaUploads",
  ls_store_fields : [ { "name": "file" }, { "name": "type" }, 'typeHidden', { "name": "user" }, 'userHidden', { "name": "owner" }, { "name": "description" }, { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "mimetype" }, { "name": "upload_area" }, 'upload_areaHidden', { "name": "volume" }, 'volumeHidden', { "name": "library_file" }, { "name": "file_size", "type": "int", "useNull": true }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 29,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/uploads/AreaUploads','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/AreaUploads','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/AreaUploads','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/AreaUploads','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/uploads/AreaUploads','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Upload-Dateien",
  disabled_fields_index : 19,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.AreaUploads.detail;
    this.ls_insert_handler = Lino.uploads.AreaUploads.insert;
    var ww = this.containing_window;
    var file3318 = Lino.file_field_handler(this,{ "allowBlank": true, "maxLength": 100, "selectOnFocus": true });
    var type3319 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Upload-Art ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "uploads.UploadTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AreaUploads/type" }) }) });
    var user3320 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AreaUploads/user" }) }) });
    var owner_disp3321 = new Ext.form.DisplayField({ "disabled": true });
    var description3322 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id3323 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type3324 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AreaUploads/owner_type" }) }) });
    var owner_id3325 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AreaUploads/owner_id" }) }) });
    var mimetype3326 = new Ext.form.TextField({ "disabled": true, "hidden": true, "maxLength": 255 });
    var upload_area3327 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.uploads.UploadAreas });
    var volume3328 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Dateibibliothek ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AreaUploads/volume" }) }) });
    var library_file3329 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/AreaUploads/library_file" }) }) });
    var file_size3330 = new Ext.form.NumberField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      type3319.setContextValue('upload_area', record ? record.data['upload_areaHidden'] : undefined);
      owner_id3325.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      library_file3329.setContextValue('volume', record ? record.data['volumeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof upload_area3327 !== 'undefined' && upload_area3327.on('change',Lino.chooser_handler(type3319,'upload_area'));
      typeof owner_type3324 !== 'undefined' && owner_type3324.on('change',Lino.chooser_handler(owner_id3325,'owner_type'));
      typeof volume3328 !== 'undefined' && volume3328.on('change',Lino.chooser_handler(library_file3329,'volume'));
      Lino.uploads.AreaUploads.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "file", "editable": true, "editor": file3318, "filter": { "type": "string" }, "header": "Datei", "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.file) Pointer to the uploaded file itself (a Django FileField).") }, "sortable": true, "tooltip": "Pointer to the uploaded file itself (a Django FileField).", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "type", "editable": true, "editor": type3319, "filter": { "type": "string" }, "header": "Upload-Art", "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.type) The type of this upload.") }, "renderer": Lino.fk_renderer('typeHidden','Lino.uploads.UploadTypes.detail'), "sortable": false, "tooltip": "The type of this upload.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user3320, "filter": { "type": "string" }, "header": "Hochgeladen durch", "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.owner) ") }, "sortable": false, "tooltip": "(uploads.AreaUploads.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 4, "dataIndex": "description", "editable": true, "editor": description3322, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.description) A short description entered manually by the user.") }, "sortable": true, "tooltip": "A short description entered manually by the user.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id3323, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "owner_type", "editable": true, "editor": owner_type3324, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "owner_id", "editable": true, "editor": owner_id3325, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 8, "dataIndex": "mimetype", "editable": false, "filter": { "type": "string" }, "header": "MIME-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.mimetype) The media type of the\nuploaded file.") }, "sortable": true, "tooltip": "The media type of the\nuploaded file.", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "upload_area", "editable": true, "editor": upload_area3327, "filter": { "options": [ "Uploads" ], "type": "list" }, "header": "Upload-Bereich", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.upload_area) The upload area this file belongs to.") }, "sortable": false, "tooltip": "The upload area this file belongs to.", "width": Lino.chars2width(11) }, { "colIndex": 10, "dataIndex": "volume", "editable": true, "editor": volume3328, "filter": { "type": "string" }, "header": "Dateibibliothek", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.volume) A pointer to the library volume where this file is stored.") }, "renderer": Lino.fk_renderer('volumeHidden','Lino.uploads.Volumes.detail'), "sortable": false, "tooltip": "A pointer to the library volume where this file is stored.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "library_file", "editable": true, "editor": library_file3329, "filter": { "type": "string" }, "header": "Bibliotheksdatei", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.library_file) The path of this file, relative the volume's root.") }, "sortable": false, "tooltip": "The path of this file, relative the volume's root.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 12, "dataIndex": "file_size", "editable": false, "filter": { "type": "numeric" }, "format": "0", "header": "File size", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.AreaUploads.file_size) The size of the file in bytes. Not yet implemented.") }, "sortable": true, "tooltip": "The size of the file in bytes. Not yet implemented.", "width": Lino.chars2width(6), "xtype": "numbercolumn" } ];
    Lino.uploads.AreaUploads.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.AreaUploads.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AreaUploads", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AreaUploads.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AreaUploads", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AreaUploads.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AreaUploads", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AreaUploads.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AreaUploads", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.AreaUploads.insertPanel = Ext.extend(Lino.uploads.Uploads.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/uploads/AreaUploads",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.AreaUploads.detail;
    this.ls_insert_handler = Lino.uploads.AreaUploads.insert;
    Lino.uploads.AreaUploads.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.AreaUploads.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/uploads/AreaUploads" };
  return new Lino.uploads.AreaUploads.insertPanel(p);
});
Lino.uploads.AreaUploads.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AreaUploads", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.AreaUploads.detailPanel = Ext.extend(Lino.uploads.Uploads.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/uploads/AreaUploads",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.AreaUploads.detail;
    this.ls_insert_handler = Lino.uploads.AreaUploads.insert;
    Lino.uploads.AreaUploads.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.AreaUploads.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/AreaUploads" };
  return new Lino.uploads.AreaUploads.detailPanel(p);
});
Lino.uploads.AreaUploads.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AreaUploads", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AreaUploads.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AreaUploads", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AreaUploads.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AreaUploads", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.AreaUploads.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/AreaUploads" };
  p.params_panel = new Lino.uploads.Uploads.ParamsPanel({});
  return new Lino.uploads.AreaUploads.GridPanel(p);
});
Lino.uploads.AreaUploads.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/AreaUploads", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class sepa.Accounts
Lino.sepa.Accounts.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/sepa/Accounts",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "partner" }, 'partnerHidden', { "name": "iban" }, { "name": "bic" }, { "name": "remark" }, { "name": "primary", "type": "boolean" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 40,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/sepa/Accounts','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/sepa/Accounts','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/sepa/Accounts','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/sepa/Accounts','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/sepa/Accounts','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Bankkonten",
  disabled_fields_index : 7,
  initComponent : function() {
    var ww = this.containing_window;
    var id3332 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var partner3333 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Partner ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/sepa/Accounts/partner" }) }) });
    var iban3334 = new Lino.UppercaseTextField({ "allowBlank": false, "maxLength": 34, "selectOnFocus": true });
    var bic3335 = new Lino.UppercaseTextField({ "allowBlank": true, "maxLength": 11, "selectOnFocus": true });
    var remark3336 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var primary3337 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3332, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(sepa.Accounts.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "partner", "editable": true, "editor": partner3333, "filter": { "type": "string" }, "header": "Partner", "listeners": { "render": Lino.quicktip_renderer("","(sepa.Accounts.partner) Partner") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "Partner", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "iban", "editable": true, "editor": iban3334, "filter": { "type": "string" }, "header": "IBAN", "listeners": { "render": Lino.quicktip_renderer("","(sepa.Accounts.iban) ") }, "renderer": Lino.iban_renderer, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "bic", "editable": true, "editor": bic3335, "filter": { "type": "string" }, "header": "BIC", "listeners": { "render": Lino.quicktip_renderer("","(sepa.Accounts.bic) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(13) }, { "colIndex": 4, "dataIndex": "remark", "editable": true, "editor": remark3336, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(sepa.Accounts.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "listeners": { "render": Lino.quicktip_renderer("","(sepa.Accounts.primary) Enabling this field will automatically disable any previous primary account and update the partner's IBAN and BIC") }, "sortable": false, "tooltip": "Enabling this field will automatically disable any previous primary account and update the partner's IBAN and BIC", "width": Lino.chars2width(11), "xtype": "checkcolumn" } ];
    Lino.sepa.Accounts.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.sepa.Accounts.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/Accounts", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.sepa.Accounts.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/Accounts", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.sepa.Accounts.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/Accounts", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.sepa.Accounts.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/Accounts", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.sepa.Accounts.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/Accounts", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.sepa.Accounts.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/sepa/Accounts" };
  return new Lino.sepa.Accounts.GridPanel(p);
});

// js_render_GridPanel_class addresses.Addresses
Lino.addresses.Addresses.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/addresses/Addresses",
  ls_store_fields : [ { "name": "partner" }, 'partnerHidden', { "name": "address_type" }, 'address_typeHidden', { "name": "remark" }, { "name": "address_column" }, { "name": "primary", "type": "boolean" }, { "name": "data_source" }, 'data_sourceHidden', { "name": "id", "type": "int" }, { "name": "country" }, 'countryHidden', { "name": "city" }, 'cityHidden', { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street" }, { "name": "street_no" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 9,
  content_type : 41,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/addresses/Addresses','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/Addresses','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/Addresses','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/addresses/Addresses','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/Addresses','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/addresses/Addresses','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Adresse) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Adressen",
  disabled_fields_index : 23,
  initComponent : function() {
    this.ls_detail_handler = Lino.addresses.Addresses.detail;
    this.ls_insert_handler = Lino.addresses.Addresses.insert;
    var ww = this.containing_window;
    var partner3339 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partner ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/partner" }) }) });
    var address_type3340 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.addresses.AddressTypes });
    var remark3341 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 50, "selectOnFocus": true });
    var address_column_disp3342 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var primary3343 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var data_source3344 = new Lino.ChoicesFieldElement({ "disabled": true, "forceSelection": true, "store": Lino.addresses.DataSources });
    var id3345 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var country3346 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/country" }) }) });
    var city3347 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/city" }) }) });
    var zip_code3348 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region3349 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/Addresses/region" }) }) });
    var addr13350 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix3351 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street3352 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_no3353 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var street_box3354 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr23355 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      city3347.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city3347.setContextValue('region', record ? record.data['regionHidden'] : undefined);
      region3349.setContextValue('country', record ? record.data['countryHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof country3346 !== 'undefined' && country3346.on('change',Lino.chooser_handler(city3347,'country'));
      typeof region3349 !== 'undefined' && region3349.on('change',Lino.chooser_handler(city3347,'region'));
      typeof country3346 !== 'undefined' && country3346.on('change',Lino.chooser_handler(region3349,'country'));
      Lino.addresses.Addresses.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "partner", "editable": true, "editor": partner3339, "filter": { "type": "string" }, "header": "Partner", "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.partner) ") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "address_type", "editable": true, "editor": address_type3340, "filter": { "options": [ "Offizielle Adresse", "Ungepr\u00fcfte Adresse", "Deklarierte Addresse", "Referenzadresse", "Veraltet", "Sonstige" ], "type": "list" }, "header": "Adressenart", "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.address_type) The type of this address record.\nA pointer to AddressTypes.\nThe default value is AddressTypes.official.") }, "sortable": false, "tooltip": "The type of this address record.\nA pointer to AddressTypes.\nThe default value is AddressTypes.official.", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "remark", "editable": true, "editor": remark3341, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 3, "dataIndex": "address_column", "editable": false, "header": "Adresse", "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.address_column) ") }, "sortable": false, "tooltip": "(addresses.Addresses.address_column) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.primary) Whether this address is the primary address of its owner.\nSetting this field will automatically uncheck any previousl\nprimary addresses and update the owner's address fields.") }, "sortable": false, "tooltip": "Whether this address is the primary address of its owner.\nSetting this field will automatically uncheck any previousl\nprimary addresses and update the owner's address fields.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 5, "dataIndex": "data_source", "editable": false, "filter": { "options": [ "Manuell eingegeben", "Eingelesen von eID-Karte" ], "type": "list" }, "header": "Datenquelle", "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.data_source) Pointer to DataSources.") }, "sortable": false, "tooltip": "Pointer to DataSources.", "width": Lino.chars2width(20) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id3345, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "country", "editable": true, "editor": country3346, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "city", "editable": true, "editor": city3347, "filter": { "type": "string" }, "header": "Ortschaft", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "zip_code", "editable": true, "editor": zip_code3348, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 10, "dataIndex": "region", "editable": true, "editor": region3349, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "addr1", "editable": true, "editor": addr13350, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 12, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix3351, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 13, "dataIndex": "street", "editable": true, "editor": street3352, "filter": { "type": "string" }, "header": "Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "street_no", "editable": true, "editor": street_no3353, "filter": { "type": "string" }, "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 15, "dataIndex": "street_box", "editable": true, "editor": street_box3354, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 16, "dataIndex": "addr2", "editable": true, "editor": addr23355, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.Addresses.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) } ];
    Lino.addresses.Addresses.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.Addresses.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/Addresses", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.Addresses.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/Addresses", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.Addresses.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/Addresses", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.Addresses.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/Addresses", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.Addresses.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/Addresses", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.addresses.Addresses.insertPanel = Ext.extend(Lino.addresses.Addresses.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/addresses/Addresses",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.addresses.Addresses.detail;
    this.ls_insert_handler = Lino.addresses.Addresses.insert;
    Lino.addresses.Addresses.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.Addresses.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/addresses/Addresses" };
  return new Lino.addresses.Addresses.insertPanel(p);
});
Lino.addresses.Addresses.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/Addresses", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.addresses.Addresses.detailPanel = Ext.extend(Lino.addresses.Addresses.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Adresse) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/addresses/Addresses",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.addresses.Addresses.detail;
    this.ls_insert_handler = Lino.addresses.Addresses.insert;
    Lino.addresses.Addresses.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.Addresses.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/addresses/Addresses" };
  return new Lino.addresses.Addresses.detailPanel(p);
});
Lino.addresses.Addresses.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/Addresses", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.Addresses.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/addresses/Addresses" };
  p.params_panel = new Lino.addresses.Addresses.ParamsPanel({});
  return new Lino.addresses.Addresses.GridPanel(p);
});
Lino.addresses.Addresses.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/Addresses", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class phones.ContactDetails
Lino.phones.ContactDetails.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/phones/ContactDetails",
  ls_store_fields : [ { "name": "value" }, { "name": "detail_type" }, 'detail_typeHidden', { "name": "remark" }, { "name": "partner" }, 'partnerHidden', { "name": "id", "type": "int" }, { "name": "primary", "type": "boolean" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 42,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetails','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetails','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetails','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetails','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetails','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kontaktangabe) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kontaktangaben",
  disabled_fields_index : 9,
  initComponent : function() {
    this.ls_detail_handler = Lino.phones.ContactDetails.detail;
    this.ls_insert_handler = Lino.phones.ContactDetails.insert;
    var ww = this.containing_window;
    var value3357 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var detail_type3358 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.phones.ContactDetailTypes });
    var remark3359 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var partner3360 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partner ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/phones/ContactDetails/partner" }) }) });
    var id3361 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var primary3362 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var end_date3363 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": true, "editor": value3357, "filter": { "type": "string" }, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetails.value) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "detail_type", "editable": true, "editor": detail_type3358, "filter": { "options": [ "E-Mail", "Handy", "Telefon", "Website", "Fax", "Sonstige" ], "type": "list" }, "header": "Kontaktangabenart", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetails.detail_type) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "remark", "editable": true, "editor": remark3359, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetails.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 3, "dataIndex": "partner", "editable": true, "editor": partner3360, "filter": { "type": "string" }, "header": "Partner", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetails.partner) ") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id3361, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetails.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetails.primary) Whether this item is the primary contact detail for this type\nand this owner.  Setting this field will automatically uncheck\nany previously primary items and update the owner's contact\ndetail fields.") }, "sortable": false, "tooltip": "Whether this item is the primary contact detail for this type\nand this owner.  Setting this field will automatically uncheck\nany previously primary items and update the owner's contact\ndetail fields.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 6, "dataIndex": "end_date", "editable": true, "editor": end_date3363, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetails.end_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.phones.ContactDetails.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.phones.ContactDetails.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetails", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetails.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetails", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetails.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetails", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetails.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetails", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.phones.ContactDetails.insertPanel = Ext.extend(Lino.phones.ContactDetails.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/phones/ContactDetails",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.phones.ContactDetails.detail;
    this.ls_insert_handler = Lino.phones.ContactDetails.insert;
    Lino.phones.ContactDetails.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.phones.ContactDetails.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/phones/ContactDetails" };
  return new Lino.phones.ContactDetails.insertPanel(p);
});
Lino.phones.ContactDetails.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetails", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.phones.ContactDetails.detailPanel = Ext.extend(Lino.phones.ContactDetails.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kontaktangabe) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/phones/ContactDetails",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.phones.ContactDetails.detail;
    this.ls_insert_handler = Lino.phones.ContactDetails.insert;
    Lino.phones.ContactDetails.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.phones.ContactDetails.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/phones/ContactDetails" };
  return new Lino.phones.ContactDetails.detailPanel(p);
});
Lino.phones.ContactDetails.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetails", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetails.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/phones/ContactDetails" };
  p.params_panel = new Lino.phones.ContactDetails.ParamsPanel({});
  return new Lino.phones.ContactDetails.GridPanel(p);
});
Lino.phones.ContactDetails.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetails", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class households.Types
Lino.households.Types.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/households/Types",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 43,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/households/Types','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/Types','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/households/Types','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/Types','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/households/Types','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Haushaltsarten",
  disabled_fields_index : 4,
  initComponent : function() {
    this.ls_detail_handler = Lino.households.Types.detail;
    var ww = this.containing_window;
    var id3365 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var name3366 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de3367 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr3368 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3365, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(households.Types.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name3366, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(households.Types.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de3367, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(households.Types.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr3368, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(households.Types.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) } ];
    Lino.households.Types.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.households.Types.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Types", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Types.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Types", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Types.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Types", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Types.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Types", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.households.Types.detailPanel = Ext.extend(Lino.households.Types.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/households/Types",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.households.Types.detail;
    Lino.households.Types.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.households.Types.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/Types" };
  return new Lino.households.Types.detailPanel(p);
});
Lino.households.Types.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Types", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Types.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/Types" };
  return new Lino.households.Types.GridPanel(p);
});
Lino.households.Types.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Types", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class households.Households
Lino.households.Households.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/households/Households",
  ls_store_fields : [ { "name": "name" }, { "name": "type" }, 'typeHidden', { "name": "address_column" }, { "name": "id", "type": "int" }, { "name": "email" }, { "name": "language" }, 'languageHidden', { "name": "url" }, { "name": "phone" }, { "name": "gsm" }, { "name": "fax" }, { "name": "country" }, 'countryHidden', { "name": "city" }, 'cityHidden', { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street" }, { "name": "street_no" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "prefix" }, { "name": "remarks" }, { "name": "payment_term" }, 'payment_termHidden', { "name": "purchase_account" }, 'purchase_accountHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 6,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/households/Households','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/Households','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/households/Households','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/households/Households','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/Households','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/households/Households','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/households/Households','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Haushalt) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.households.Households.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-lightning", "itemId": "populate_members", "menu_item_text": "Populate", "overflowText": "Populate", "panel_btn_handler": Lino.row_action_handler('populate_members','GET',null), "tooltip": "Populate household members from data in human links.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Haushalte",
  disabled_fields_index : 31,
  initComponent : function() {
    this.ls_detail_handler = Lino.households.Households.detail;
    this.ls_insert_handler = Lino.households.Households.insert;
    var ww = this.containing_window;
    var name3370 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var type3371 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Haushaltsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "households.Types", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/Households/type" }) }) });
    var address_column_disp3372 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3373 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var email3374 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 254, "selectOnFocus": true });
    var language3375 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var url3376 = new Lino.URLField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var phone3377 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var gsm3378 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var fax3379 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var country3380 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/Households/country" }) }) });
    var city3381 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/Households/city" }) }) });
    var zip_code3382 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region3383 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/Households/region" }) }) });
    var addr13384 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix3385 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street3386 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_no3387 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var street_box3388 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr23389 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var prefix3390 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var remarks3391 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    var payment_term3392 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Zahlungsbedingungen ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.PaymentTerms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/Households/payment_term" }) }) });
    var purchase_account3393 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Konto ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/Households/purchase_account" }) }) });
    this.before_row_edit = function(record) {
      city3381.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city3381.setContextValue('region', record ? record.data['regionHidden'] : undefined);
      region3383.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      remarks3391.refresh();
    };
    this.onRender = function(ct, position) {
      typeof country3380 !== 'undefined' && country3380.on('change',Lino.chooser_handler(city3381,'country'));
      typeof region3383 !== 'undefined' && region3383.on('change',Lino.chooser_handler(city3381,'region'));
      typeof country3380 !== 'undefined' && country3380.on('change',Lino.chooser_handler(region3383,'country'));
      Lino.households.Households.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name", "editable": true, "editor": name3370, "filter": { "type": "string" }, "header": "Name", "listeners": { "render": Lino.quicktip_renderer("","(households.Households.name) The full name of this partner. Used for alphabetic sorting.") }, "sortable": true, "tooltip": "The full name of this partner. Used for alphabetic sorting.", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "type", "editable": true, "editor": type3371, "filter": { "type": "string" }, "header": "Haushaltsart", "listeners": { "render": Lino.quicktip_renderer("","(households.Households.type) The type of this household.  See household types") }, "renderer": Lino.fk_renderer('typeHidden','Lino.households.Types.detail'), "sortable": false, "tooltip": "The type of this household.  See household types", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "address_column", "editable": false, "header": "Adresse", "listeners": { "render": Lino.quicktip_renderer("","(households.Households.address_column) ") }, "sortable": false, "tooltip": "(households.Households.address_column) ", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id3373, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "email", "editable": true, "editor": email3374, "filter": { "type": "string" }, "header": "E-Mail-Adresse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.email) The primary email address.") }, "sortable": true, "tooltip": "The primary email address.", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "language", "editable": true, "editor": language3375, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.language) The language to use when communicating with this partner.") }, "sortable": false, "tooltip": "The language to use when communicating with this partner.", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "url", "editable": true, "editor": url3376, "filter": { "type": "string" }, "header": "Adresse (URL)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.url) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "phone", "editable": true, "editor": phone3377, "filter": { "type": "string" }, "header": "Telefon", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.phone) The primary phone number.") }, "sortable": true, "tooltip": "The primary phone number.", "width": Lino.chars2width(22) }, { "colIndex": 8, "dataIndex": "gsm", "editable": true, "editor": gsm3378, "filter": { "type": "string" }, "header": "GSM", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.gsm) The primary mobile phone number.") }, "sortable": true, "tooltip": "The primary mobile phone number.", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "fax", "editable": true, "editor": fax3379, "filter": { "type": "string" }, "header": "Fax", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.fax) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 10, "dataIndex": "country", "editable": true, "editor": country3380, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "city", "editable": true, "editor": city3381, "filter": { "type": "string" }, "header": "Ortschaft", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "zip_code", "editable": true, "editor": zip_code3382, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 13, "dataIndex": "region", "editable": true, "editor": region3383, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "addr1", "editable": true, "editor": addr13384, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix3385, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 16, "dataIndex": "street", "editable": true, "editor": street3386, "filter": { "type": "string" }, "header": "Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 17, "dataIndex": "street_no", "editable": true, "editor": street_no3387, "filter": { "type": "string" }, "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 18, "dataIndex": "street_box", "editable": true, "editor": street_box3388, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 19, "dataIndex": "addr2", "editable": true, "editor": addr23389, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 20, "dataIndex": "prefix", "editable": true, "editor": prefix3390, "filter": { "type": "string" }, "header": "Name prefix", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.prefix) An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.") }, "sortable": true, "tooltip": "An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.", "width": Lino.chars2width(22) }, { "colIndex": 21, "dataIndex": "remarks", "editable": true, "editor": remarks3391, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 22, "dataIndex": "payment_term", "editable": true, "editor": payment_term3392, "filter": { "type": "string" }, "header": "Zahlungsbedingungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.payment_term) The default payment term for sales invoices to this customer.") }, "sortable": false, "tooltip": "The default payment term for sales invoices to this customer.", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "purchase_account", "editable": true, "editor": purchase_account3393, "filter": { "type": "string" }, "header": "Konto Einkauf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.Households.purchase_account) The general account to suggest as default value in purchase\ninvoices from this partner.") }, "sortable": false, "tooltip": "The general account to suggest as default value in purchase\ninvoices from this partner.", "width": Lino.chars2width(21) } ];
    Lino.households.Households.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.households.Households.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.export_vcf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "export_vcf", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.households.Households.insertPanel = Ext.extend(Lino.households.Households.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/households/Households",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.households.Households.detail;
    this.ls_insert_handler = Lino.households.Households.insert;
    Lino.households.Households.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.households.Households.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/households/Households" };
  return new Lino.households.Households.insertPanel(p);
});
Lino.households.Households.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.households.Households.detailPanel = Ext.extend(Lino.households.Households.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/households/Households','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Haushalt) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.households.Households.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-lightning", "itemId": "populate_members", "menu_item_text": "Populate", "overflowText": "Populate", "panel_btn_handler": Lino.row_action_handler('populate_members','GET',null), "tooltip": "Populate household members from data in human links.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/households/Households",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.households.Households.detail;
    this.ls_insert_handler = Lino.households.Households.insert;
    Lino.households.Households.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.households.Households.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/Households" };
  return new Lino.households.Households.detailPanel(p);
});
Lino.households.Households.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.create_excerpt2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "create_excerpt2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.due = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "due", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.show_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "show_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.del_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "del_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.del_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "del_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.del_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "del_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.del_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "del_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/Households" };
  p.params_panel = new Lino.contacts.Partners.ParamsPanel({});
  return new Lino.households.Households.GridPanel(p);
});
Lino.households.Households.ins_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "ins_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.ins_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "ins_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.ins_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "ins_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.ins_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "ins_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.populate_members = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "GET", pk, "populate_members", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Households.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Households", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class households.Members
Lino.households.Members.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/households/Members",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "title" }, { "name": "first_name" }, { "name": "middle_name" }, { "name": "last_name" }, { "name": "gender" }, 'genderHidden', { "name": "birth_date" }, { "name": "role" }, 'roleHidden', { "name": "person" }, 'personHidden', { "name": "household" }, 'householdHidden', { "name": "dependency" }, 'dependencyHidden', { "name": "primary", "type": "boolean" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 44,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/households/Members','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/Members','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/households/Members','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/Members','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/households/Members','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "set_primary", "menu_item_text": "set_primary", "overflowText": "set_primary", "panel_btn_handler": Lino.row_action_handler('set_primary','GET',null), "text": "set_primary", "tooltip": "Diesen Haushalt als prim\u00e4r markieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Mitglieder",
  disabled_fields_index : 19,
  initComponent : function() {
    var ww = this.containing_window;
    var id3395 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var start_date3396 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var end_date3397 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var title3398 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var first_name3399 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var middle_name3400 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var last_name3401 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var gender3402 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.Genders) });
    var birth_date3403 = new Lino.IncompleteDateField({ "allowBlank": true, "selectOnFocus": true });
    var role3404 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.households.MemberRoles) });
    var person3405 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/Members/person" }) }) });
    var household3406 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Haushalt ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "households.Households", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/Members/household" }) }) });
    var dependency3407 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.households.MemberDependencies });
    var primary3408 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3395, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "start_date", "editable": true, "editor": start_date3396, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.start_date) Since when this membership exists. This is usually empty.") }, "sortable": true, "tooltip": "Since when this membership exists. This is usually empty.", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "end_date", "editable": true, "editor": end_date3397, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.end_date) Until when this membership exists.") }, "sortable": true, "tooltip": "Until when this membership exists.", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 3, "dataIndex": "title", "editable": true, "editor": title3398, "filter": { "type": "string" }, "header": "Titel", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.title) Eventuelle berufliche Position oder akademischer Titel, z.B. \"Dr.\" oder \"Prof.\"") }, "sortable": true, "tooltip": "Eventuelle berufliche Position oder akademischer Titel, z.B. \"Dr.\" oder \"Prof.\"", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "first_name", "editable": true, "editor": first_name3399, "filter": { "type": "string" }, "header": "Vorname", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.first_name) The first name, also known as given name.") }, "sortable": true, "tooltip": "The first name, also known as given name.", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "middle_name", "editable": true, "editor": middle_name3400, "filter": { "type": "string" }, "header": "Zwischenname", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.middle_name) A space-separated list of all middle names.") }, "sortable": true, "tooltip": "A space-separated list of all middle names.", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "last_name", "editable": true, "editor": last_name3401, "filter": { "type": "string" }, "header": "Familienname", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.last_name) The last name, also known as family name.") }, "sortable": true, "tooltip": "The last name, also known as family name.", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "gender", "editable": true, "editor": gender3402, "filter": { "options": [ "M\u00e4nnlich", "Weiblich" ], "type": "list" }, "header": "Geschlecht", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.gender) The sex of this person (male or female).") }, "sortable": false, "tooltip": "The sex of this person (male or female).", "width": Lino.chars2width(10) }, { "colIndex": 8, "dataIndex": "birth_date", "editable": true, "editor": birth_date3403, "filter": { "type": "string" }, "header": "Geburtsdatum", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.birth_date) Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".") }, "sortable": true, "tooltip": "Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".", "width": Lino.chars2width(13) }, { "colIndex": 9, "dataIndex": "role", "editable": true, "editor": role3404, "filter": { "options": [ "Vorstand", "Ehepartner", "Partner", "Mitbewohner", "Kind", "Verwandt", "Adoptivkind", "Pflegekind", "Sonstige" ], "type": "list" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.role) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "person", "editable": true, "editor": person3405, "filter": { "type": "string" }, "header": "Person", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.person) ") }, "renderer": Lino.fk_renderer('personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "household", "editable": true, "editor": household3406, "filter": { "type": "string" }, "header": "Haushalt", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.household) ") }, "renderer": Lino.fk_renderer('householdHidden','Lino.households.Households.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "dependency", "editable": true, "editor": dependency3407, "filter": { "options": [ "Zu Lasten", "Nicht zu Lasten", "Lasten geteilt" ], "type": "list" }, "header": "Abh\u00e4ngigkeit", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.dependency) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(20) }, { "colIndex": 13, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "listeners": { "render": Lino.quicktip_renderer("","(households.Members.primary) Whether this is the primary household of this person.\nChecking this field will automatically disable any other primary memberships.") }, "sortable": false, "tooltip": "Whether this is the primary household of this person.\nChecking this field will automatically disable any other primary memberships.", "width": Lino.chars2width(11), "xtype": "checkcolumn" } ];
    Lino.households.Members.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.households.Members.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Members", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Members.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Members", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Members.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Members", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Members.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Members", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Members.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Members", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.Members.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/Members" };
  p.params_panel = new Lino.households.Members.ParamsPanel({});
  return new Lino.households.Members.GridPanel(p);
});
Lino.households.Members.set_primary = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/Members", "GET", pk, "set_primary", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class humanlinks.Links
Lino.humanlinks.Links.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/humanlinks/Links",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "type" }, 'typeHidden', { "name": "parent" }, 'parentHidden', { "name": "child" }, 'childHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 46,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/humanlinks/Links','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/humanlinks/Links','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/humanlinks/Links','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/humanlinks/Links','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/humanlinks/Links','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Verwandtschaftsbeziehung) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Verwandtschaftsbeziehungen",
  disabled_fields_index : 7,
  initComponent : function() {
    this.ls_detail_handler = Lino.humanlinks.Links.detail;
    this.ls_insert_handler = Lino.humanlinks.Links.insert;
    var ww = this.containing_window;
    var id3410 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var type3411 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.humanlinks.LinkTypes });
    var parent3412 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/humanlinks/Links/parent" }) }) });
    var child3413 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/humanlinks/Links/child" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3410, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.Links.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "type", "editable": true, "editor": type3411, "filter": { "options": [ "Vater(Mutter)", "Adoptivvater(Adoptivmutter)", "Gro\u00dfvater(Gro\u00dfmutter)", "Ehemann(Ehefrau)", "Freund(Freundin)", "Partner(Partnerin)", "Stiefvater(Stiefmutter)", "Pflegevater(Pflegemutter)", "Bruder(Schwester)", "Vetter(Kusine)", "Onkel(Tante)", "Verwandter(Verwandte)", "Sonstiger(Sonstige)" ], "type": "list" }, "header": "Verwandschaftsart", "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.Links.type) The type of link.  Pointer to LinkTypes.") }, "sortable": false, "tooltip": "The type of link.  Pointer to LinkTypes.", "width": Lino.chars2width(36) }, { "colIndex": 2, "dataIndex": "parent", "editable": true, "editor": parent3412, "filter": { "type": "string" }, "header": "Wer ist...", "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.Links.parent) Pointer to the person who is \"parent\".") }, "renderer": Lino.fk_renderer('parentHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "Pointer to the person who is \"parent\".", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "child", "editable": true, "editor": child3413, "filter": { "type": "string" }, "header": "Von wem...", "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.Links.child) Pointer to the person who is \"child\".") }, "renderer": Lino.fk_renderer('childHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "Pointer to the person who is \"child\".", "width": Lino.chars2width(21) } ];
    Lino.humanlinks.Links.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.humanlinks.Links.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/Links", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.Links.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/Links", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.Links.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/Links", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.Links.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/Links", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.humanlinks.Links.insertPanel = Ext.extend(Lino.humanlinks.Links.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/humanlinks/Links",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.humanlinks.Links.detail;
    this.ls_insert_handler = Lino.humanlinks.Links.insert;
    Lino.humanlinks.Links.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.humanlinks.Links.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/humanlinks/Links" };
  return new Lino.humanlinks.Links.insertPanel(p);
});
Lino.humanlinks.Links.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/Links", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.humanlinks.Links.detailPanel = Ext.extend(Lino.humanlinks.Links.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Verwandtschaftsbeziehung) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/humanlinks/Links",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.humanlinks.Links.detail;
    this.ls_insert_handler = Lino.humanlinks.Links.insert;
    Lino.humanlinks.Links.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.humanlinks.Links.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(40) }, function(){
  var p = { "is_main_window": true, "ls_url": "/humanlinks/Links" };
  return new Lino.humanlinks.Links.detailPanel(p);
});
Lino.humanlinks.Links.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/Links", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.Links.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/humanlinks/Links" };
  return new Lino.humanlinks.Links.GridPanel(p);
});
Lino.humanlinks.Links.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/Links", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class topics.AllTopics
Lino.topics.AllTopics.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/topics/AllTopics",
  ls_store_fields : [ { "name": "ref" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "id", "type": "int" }, { "name": "description_text" }, { "name": "description_text_de" }, { "name": "description_text_fr" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 53,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/topics/AllTopics','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/topics/AllTopics','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/topics/AllTopics','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/topics/AllTopics','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/topics/AllTopics','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Thema) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.topics.Topics.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Themen",
  disabled_fields_index : 8,
  initComponent : function() {
    this.ls_detail_handler = Lino.topics.AllTopics.detail;
    this.ls_insert_handler = Lino.topics.AllTopics.insert;
    var ww = this.containing_window;
    var ref3415 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name3416 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de3417 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr3418 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id3419 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var description_text3420 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Long description" });
    var description_text_de3421 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Long description (de)" });
    var description_text_fr3422 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Long description (fr)" });
    this.before_row_edit = function(record) {
      description_text3420.refresh();
      description_text_de3421.refresh();
      description_text_fr3422.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "ref", "editable": true, "editor": ref3415, "filter": { "type": "string" }, "header": "Referenz", "listeners": { "render": Lino.quicktip_renderer("","(topics.AllTopics.ref) The reference.") }, "sortable": true, "tooltip": "The reference.", "width": Lino.chars2width(6) }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name3416, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(topics.AllTopics.name) The designation in different languages.") }, "sortable": true, "tooltip": "The designation in different languages.", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de3417, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(topics.AllTopics.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr3418, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(topics.AllTopics.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id3419, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(topics.AllTopics.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "description_text", "editable": true, "editor": description_text3420, "filter": { "type": "string" }, "header": "Long description", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(topics.AllTopics.description_text) Rich text field for a longer multi-line description.") }, "sortable": false, "tooltip": "Rich text field for a longer multi-line description.", "width": Lino.chars2width(61) }, { "colIndex": 6, "dataIndex": "description_text_de", "editable": true, "editor": description_text_de3421, "filter": { "type": "string" }, "header": "Long description (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(topics.AllTopics.description_text_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 7, "dataIndex": "description_text_fr", "editable": true, "editor": description_text_fr3422, "filter": { "type": "string" }, "header": "Long description (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(topics.AllTopics.description_text_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.topics.AllTopics.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.topics.AllTopics.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllTopics", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.topics.AllTopics.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllTopics", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.topics.AllTopics.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllTopics", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.topics.AllTopics.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllTopics", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.topics.AllTopics.insertPanel = Ext.extend(Lino.topics.Topics.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/topics/AllTopics",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.topics.AllTopics.detail;
    this.ls_insert_handler = Lino.topics.AllTopics.insert;
    Lino.topics.AllTopics.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.topics.AllTopics.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/topics/AllTopics" };
  return new Lino.topics.AllTopics.insertPanel(p);
});
Lino.topics.AllTopics.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllTopics", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.topics.AllTopics.detailPanel = Ext.extend(Lino.topics.Topics.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Thema) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.topics.Topics.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/topics/AllTopics",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.topics.AllTopics.detail;
    this.ls_insert_handler = Lino.topics.AllTopics.insert;
    Lino.topics.AllTopics.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.topics.AllTopics.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/topics/AllTopics" };
  return new Lino.topics.AllTopics.detailPanel(p);
});
Lino.topics.AllTopics.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllTopics", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.topics.AllTopics.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/topics/AllTopics" };
  return new Lino.topics.AllTopics.GridPanel(p);
});
Lino.topics.AllTopics.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllTopics", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class topics.AllInterests
Lino.topics.AllInterests.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/topics/AllInterests",
  ls_store_fields : [ { "name": "partner" }, 'partnerHidden', { "name": "topic" }, 'topicHidden', { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "remark" }, { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 52,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/topics/AllInterests','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/topics/AllInterests','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/topics/AllInterests','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/topics/AllInterests','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/topics/AllInterests','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Interessen",
  disabled_fields_index : 11,
  initComponent : function() {
    this.ls_detail_handler = Lino.topics.AllInterests.detail;
    var ww = this.containing_window;
    var partner3424 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Partner ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/topics/AllInterests/partner" }) }) });
    var topic3425 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Thema ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "topics.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/topics/AllInterests/topic" }) }) });
    var id3426 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type3427 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/topics/AllInterests/owner_type" }) }) });
    var owner_id3428 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/topics/AllInterests/owner_id" }) }) });
    var remark3429 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var owner_disp3430 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id3428.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type3427 !== 'undefined' && owner_type3427.on('change',Lino.chooser_handler(owner_id3428,'owner_type'));
      Lino.topics.AllInterests.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "partner", "editable": true, "editor": partner3424, "filter": { "type": "string" }, "header": "Partner", "listeners": { "render": Lino.quicktip_renderer("","(topics.AllInterests.partner) ") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "topic", "editable": true, "editor": topic3425, "filter": { "type": "string" }, "header": "Thema", "listeners": { "render": Lino.quicktip_renderer("","(topics.AllInterests.topic) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 2, "dataIndex": "id", "editable": true, "editor": id3426, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(topics.AllInterests.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "owner_type", "editable": true, "editor": owner_type3427, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(topics.AllInterests.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "owner_id", "editable": true, "editor": owner_id3428, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(topics.AllInterests.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 5, "dataIndex": "remark", "editable": true, "editor": remark3429, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(topics.AllInterests.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 6, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(topics.AllInterests.owner) ") }, "sortable": false, "tooltip": "(topics.AllInterests.owner) ", "width": Lino.chars2width(11) } ];
    Lino.topics.AllInterests.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.topics.AllInterests.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllInterests", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.topics.AllInterests.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllInterests", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.topics.AllInterests.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllInterests", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.topics.AllInterests.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllInterests", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.topics.AllInterests.detailPanel = Ext.extend(Lino.topics.Interests.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/topics/AllInterests",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.topics.AllInterests.detail;
    Lino.topics.AllInterests.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.topics.AllInterests.detail = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(15), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/topics/AllInterests" };
  return new Lino.topics.AllInterests.detailPanel(p);
});
Lino.topics.AllInterests.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllInterests", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.topics.AllInterests.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/topics/AllInterests" };
  return new Lino.topics.AllInterests.GridPanel(p);
});
Lino.topics.AllInterests.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/topics/AllInterests", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class lists.ListTypes
Lino.lists.ListTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/lists/ListTypes",
  ls_store_fields : [ { "name": "designation" }, { "name": "designation_de" }, { "name": "designation_fr" }, { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 54,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/lists/ListTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/ListTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/lists/ListTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/ListTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/lists/ListTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Listenarten",
  disabled_fields_index : 4,
  initComponent : function() {
    var ww = this.containing_window;
    var designation3432 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var designation_de3433 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var designation_fr3434 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id3435 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "designation", "editable": true, "editor": designation3432, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(lists.ListTypes.designation) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "designation_de", "editable": true, "editor": designation_de3433, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(lists.ListTypes.designation_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "designation_fr", "editable": true, "editor": designation_fr3434, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(lists.ListTypes.designation_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id3435, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.ListTypes.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" } ];
    Lino.lists.ListTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.ListTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/ListTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.ListTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/ListTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.ListTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/ListTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.ListTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/ListTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.ListTypes.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/ListTypes", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.ListTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/ListTypes" };
  return new Lino.lists.ListTypes.GridPanel(p);
});

// js_render_GridPanel_class lists.Lists
Lino.lists.Lists.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/lists/Lists",
  ls_store_fields : [ { "name": "ref" }, { "name": "overview" }, { "name": "list_type" }, 'list_typeHidden', { "name": "id", "type": "int" }, { "name": "designation" }, { "name": "designation_de" }, { "name": "designation_fr" }, { "name": "remarks" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 55,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/lists/Lists','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/Lists','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/lists/Lists','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/lists/Lists','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/Lists','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/lists/Lists','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Partnerliste) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.lists.Lists.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Partnerlisten",
  disabled_fields_index : 9,
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.Lists.detail;
    this.ls_insert_handler = Lino.lists.Lists.insert;
    var ww = this.containing_window;
    var ref3437 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var overview_htmlbox3438 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "overview", "value": "<br/>" });
    var list_type3439 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Listenart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "lists.ListTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/Lists/list_type" }) }) });
    var id3440 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var designation3441 = new Ext.form.TextField({ "allowBlank": false, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var designation_de3442 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var designation_fr3443 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var remarks3444 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    this.before_row_edit = function(record) {
      overview_htmlbox3438.refresh();
      remarks3444.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "ref", "editable": true, "editor": ref3437, "filter": { "type": "string" }, "header": "Referenz", "listeners": { "render": Lino.quicktip_renderer("","(lists.Lists.ref) Die Referenz. Muss entweder leer oder einzig sein.") }, "sortable": true, "tooltip": "Die Referenz. Muss entweder leer oder einzig sein.", "width": Lino.chars2width(41) }, { "colIndex": 1, "dataIndex": "overview", "editable": false, "header": "overview", "listeners": { "render": Lino.quicktip_renderer("","(lists.Lists.overview) ") }, "sortable": false, "tooltip": "(lists.Lists.overview) ", "width": Lino.chars2width(31) }, { "colIndex": 2, "dataIndex": "list_type", "editable": true, "editor": list_type3439, "filter": { "type": "string" }, "header": "Listenart", "listeners": { "render": Lino.quicktip_renderer("","(lists.Lists.list_type) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id3440, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.Lists.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "designation", "editable": true, "editor": designation3441, "filter": { "type": "string" }, "header": "Bezeichnung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.Lists.designation) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "designation_de", "editable": true, "editor": designation_de3442, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.Lists.designation_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "designation_fr", "editable": true, "editor": designation_fr3443, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.Lists.designation_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "remarks", "editable": true, "editor": remarks3444, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.Lists.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.lists.Lists.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.Lists.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Lists", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Lists.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Lists", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Lists.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Lists", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Lists.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Lists", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Lists.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Lists", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.lists.Lists.insertPanel = Ext.extend(Lino.lists.Lists.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/lists/Lists",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.Lists.detail;
    this.ls_insert_handler = Lino.lists.Lists.insert;
    Lino.lists.Lists.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.Lists.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(12), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/lists/Lists" };
  return new Lino.lists.Lists.insertPanel(p);
});
Lino.lists.Lists.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Lists", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.lists.Lists.detailPanel = Ext.extend(Lino.lists.Lists.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Partnerliste) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.lists.Lists.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/lists/Lists",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.Lists.detail;
    this.ls_insert_handler = Lino.lists.Lists.insert;
    Lino.lists.Lists.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.Lists.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/Lists" };
  return new Lino.lists.Lists.detailPanel(p);
});
Lino.lists.Lists.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Lists", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Lists.print_members = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Lists", "GET", pk, "print_members", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Lists.print_members_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Lists", "GET", pk, "print_members_html", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Lists.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/Lists" };
  return new Lino.lists.Lists.GridPanel(p);
});
Lino.lists.Lists.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Lists", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class lists.Members
Lino.lists.Members.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/lists/Members",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "seqno", "type": "int", "useNull": true }, { "name": "list" }, 'listHidden', { "name": "partner" }, 'partnerHidden', { "name": "remark" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 56,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/lists/Members','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/Members','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/lists/Members','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/Members','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/lists/Members','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Listenmitgliedschaften",
  disabled_fields_index : 7,
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.Members.detail;
    var ww = this.containing_window;
    var id3446 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var seqno3447 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var list3448 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partnerliste ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "lists.Lists", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/Members/list" }) }) });
    var partner3449 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partner ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/Members/partner" }) }) });
    var remark3450 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3446, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(lists.Members.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 1, "dataIndex": "seqno", "editable": true, "editor": seqno3447, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(lists.Members.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 2, "dataIndex": "list", "editable": true, "editor": list3448, "filter": { "type": "string" }, "header": "Partnerliste", "listeners": { "render": Lino.quicktip_renderer("","(lists.Members.list) ") }, "renderer": Lino.fk_renderer('listHidden','Lino.lists.Lists.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "partner", "editable": true, "editor": partner3449, "filter": { "type": "string" }, "header": "Partner", "listeners": { "render": Lino.quicktip_renderer("","(lists.Members.partner) ") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "remark", "editable": true, "editor": remark3450, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(lists.Members.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) } ];
    Lino.lists.Members.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.Members.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Members", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Members.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Members", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Members.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Members", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Members.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Members", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Members.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Members", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.lists.Members.detailPanel = Ext.extend(Lino.lists.Members.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/lists/Members",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.Members.detail;
    Lino.lists.Members.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.Members.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/Members" };
  return new Lino.lists.Members.detailPanel(p);
});
Lino.lists.Members.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Members", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Members.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/Members" };
  return new Lino.lists.Members.GridPanel(p);
});
Lino.lists.Members.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Members", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Members.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Members", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Members.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Members", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.Members.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/Members", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class lists.AllMembers
Lino.lists.AllMembers.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/lists/AllMembers",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "seqno", "type": "int", "useNull": true }, { "name": "list" }, 'listHidden', { "name": "partner" }, 'partnerHidden', { "name": "remark" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 56,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/lists/AllMembers','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/AllMembers','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/lists/AllMembers','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/AllMembers','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/lists/AllMembers','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Listenmitgliedschaften",
  disabled_fields_index : 7,
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.AllMembers.detail;
    var ww = this.containing_window;
    var id3452 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var seqno3453 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var list3454 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partnerliste ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "lists.Lists", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/AllMembers/list" }) }) });
    var partner3455 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partner ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/AllMembers/partner" }) }) });
    var remark3456 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3452, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(lists.AllMembers.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 1, "dataIndex": "seqno", "editable": true, "editor": seqno3453, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(lists.AllMembers.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 2, "dataIndex": "list", "editable": true, "editor": list3454, "filter": { "type": "string" }, "header": "Partnerliste", "listeners": { "render": Lino.quicktip_renderer("","(lists.AllMembers.list) ") }, "renderer": Lino.fk_renderer('listHidden','Lino.lists.Lists.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "partner", "editable": true, "editor": partner3455, "filter": { "type": "string" }, "header": "Partner", "listeners": { "render": Lino.quicktip_renderer("","(lists.AllMembers.partner) ") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "remark", "editable": true, "editor": remark3456, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(lists.AllMembers.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) } ];
    Lino.lists.AllMembers.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.AllMembers.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/AllMembers", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.AllMembers.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/AllMembers", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.AllMembers.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/AllMembers", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.AllMembers.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/AllMembers", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.AllMembers.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/AllMembers", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.lists.AllMembers.detailPanel = Ext.extend(Lino.lists.Members.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/lists/AllMembers",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.AllMembers.detail;
    Lino.lists.AllMembers.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.AllMembers.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/AllMembers" };
  return new Lino.lists.AllMembers.detailPanel(p);
});
Lino.lists.AllMembers.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/AllMembers", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.AllMembers.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/AllMembers" };
  return new Lino.lists.AllMembers.GridPanel(p);
});
Lino.lists.AllMembers.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/AllMembers", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.AllMembers.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/AllMembers", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.AllMembers.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/AllMembers", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.AllMembers.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/AllMembers", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class blogs.EntryTypes
Lino.blogs.EntryTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/blogs/EntryTypes",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "important", "type": "boolean" }, { "name": "remark" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 57,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/blogs/EntryTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/EntryTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/EntryTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/EntryTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/blogs/EntryTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Blog-Eintrags-Arten",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.EntryTypes.detail;
    var ww = this.containing_window;
    var id3458 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var name3459 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de3460 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr3461 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var important3462 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var remark3463 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Bemerkung" });
    this.before_row_edit = function(record) {
      remark3463.refresh();
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3458, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntryTypes.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name3459, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntryTypes.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de3460, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntryTypes.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr3461, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntryTypes.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "important", "editable": true, "filter": { "type": "boolean" }, "header": "wichtig", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntryTypes.important) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 5, "dataIndex": "remark", "editable": true, "editor": remark3463, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntryTypes.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.blogs.EntryTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.EntryTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntryTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntryTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntryTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntryTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntryTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntryTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntryTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.EntryTypes.detailPanel = Ext.extend(Lino.blogs.EntryTypes.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/blogs/EntryTypes",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.EntryTypes.detail;
    Lino.blogs.EntryTypes.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.EntryTypes.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/EntryTypes" };
  return new Lino.blogs.EntryTypes.detailPanel(p);
});
Lino.blogs.EntryTypes.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntryTypes", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntryTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/EntryTypes" };
  return new Lino.blogs.EntryTypes.GridPanel(p);
});
Lino.blogs.EntryTypes.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntryTypes", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class blogs.Entries
Lino.blogs.Entries.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/blogs/Entries",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "pub_date", "type": "date" }, { "name": "user" }, 'userHidden', { "name": "entry_type" }, 'entry_typeHidden', { "name": "title" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "short_preview" }, { "name": "full_preview" }, { "name": "pub_time" }, { "name": "language" }, 'languageHidden', { "name": "owner" }, { "name": "body" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 58,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/blogs/Entries','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/Entries','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/Entries','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/Entries','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/blogs/Entries','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Blog-Eintr\u00e4ge",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.Entries.detail;
    this.ls_insert_handler = Lino.blogs.Entries.insert;
    var ww = this.containing_window;
    var id3465 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var pub_date3466 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var user3467 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/Entries/user" }) }) });
    var entry_type3468 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Blog Entry Type ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "blogs.EntryTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/Entries/entry_type" }) }) });
    var title3469 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var owner_type3470 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/Entries/owner_type" }) }) });
    var owner_id3471 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/Entries/owner_id" }) }) });
    var short_preview3472 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau" });
    var full_preview3473 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau (komplett)" });
    var pub_time3474 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var language3475 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var owner_disp3476 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    var body3477 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Inhalt" });
    this.before_row_edit = function(record) {
      owner_id3471.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      short_preview3472.refresh();
      full_preview3473.refresh();
      body3477.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type3470 !== 'undefined' && owner_type3470.on('change',Lino.chooser_handler(owner_id3471,'owner_type'));
      Lino.blogs.Entries.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3465, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "pub_date", "editable": true, "editor": pub_date3466, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Bildungsart", "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.pub_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user3467, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "entry_type", "editable": true, "editor": entry_type3468, "filter": { "type": "string" }, "header": "Blog Entry Type", "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.entry_type) ") }, "renderer": Lino.fk_renderer('entry_typeHidden','Lino.blogs.EntryTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "title", "editable": true, "editor": title3469, "filter": { "type": "string" }, "header": "\u00dcberschrift", "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.title) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type3470, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id3471, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.short_preview) A read-only short preview of body.") }, "sortable": false, "tooltip": "A read-only short preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "pub_time", "editable": true, "editor": pub_time3474, "header": "Bildungsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.pub_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "language", "editable": true, "editor": language3475, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.language) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.owner) ") }, "sortable": false, "tooltip": "(blogs.Entries.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 12, "dataIndex": "body", "editable": true, "editor": body3477, "filter": { "type": "string" }, "header": "Inhalt", "listeners": { "render": Lino.quicktip_renderer("","(blogs.Entries.body) An editable text body.") }, "sortable": false, "tooltip": "An editable text body.", "width": Lino.chars2width(61) } ];
    Lino.blogs.Entries.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.Entries.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/Entries", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.Entries.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/Entries", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.Entries.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/Entries", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.Entries.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/Entries", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.Entries.insertPanel = Ext.extend(Lino.blogs.Entries.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/blogs/Entries",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.Entries.detail;
    this.ls_insert_handler = Lino.blogs.Entries.insert;
    Lino.blogs.Entries.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.Entries.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/blogs/Entries" };
  return new Lino.blogs.Entries.insertPanel(p);
});
Lino.blogs.Entries.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/Entries", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.Entries.detailPanel = Ext.extend(Lino.blogs.Entries.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/blogs/Entries",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.Entries.detail;
    this.ls_insert_handler = Lino.blogs.Entries.insert;
    Lino.blogs.Entries.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.Entries.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/Entries" };
  return new Lino.blogs.Entries.detailPanel(p);
});
Lino.blogs.Entries.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/Entries", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.Entries.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/Entries", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.Entries.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/Entries", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.Entries.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/Entries" };
  p.params_panel = new Lino.blogs.Entries.ParamsPanel({});
  return new Lino.blogs.Entries.GridPanel(p);
});
Lino.blogs.Entries.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/Entries", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.Entries.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/Entries", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class blogs.MyEntries
Lino.blogs.MyEntries.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/blogs/MyEntries",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "pub_date", "type": "date" }, { "name": "entry_type" }, 'entry_typeHidden', { "name": "title" }, { "name": "body" }, { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "short_preview" }, { "name": "full_preview" }, { "name": "pub_time" }, { "name": "language" }, 'languageHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 58,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/blogs/MyEntries','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/MyEntries','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/MyEntries','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/MyEntries','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/blogs/MyEntries','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Blog-Eintr\u00e4ge",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.MyEntries.detail;
    this.ls_insert_handler = Lino.blogs.MyEntries.insert;
    var ww = this.containing_window;
    var id3479 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var pub_date3480 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var entry_type3481 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Blog Entry Type ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "blogs.EntryTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/MyEntries/entry_type" }) }) });
    var title3482 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var body3483 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Inhalt" });
    var user3484 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/MyEntries/user" }) }) });
    var owner_type3485 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/MyEntries/owner_type" }) }) });
    var owner_id3486 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/MyEntries/owner_id" }) }) });
    var short_preview3487 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau" });
    var full_preview3488 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau (komplett)" });
    var pub_time3489 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var language3490 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var owner_disp3491 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      body3483.refresh();
      owner_id3486.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      short_preview3487.refresh();
      full_preview3488.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type3485 !== 'undefined' && owner_type3485.on('change',Lino.chooser_handler(owner_id3486,'owner_type'));
      Lino.blogs.MyEntries.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3479, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "pub_date", "editable": true, "editor": pub_date3480, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Bildungsart", "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.pub_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "entry_type", "editable": true, "editor": entry_type3481, "filter": { "type": "string" }, "header": "Blog Entry Type", "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.entry_type) ") }, "renderer": Lino.fk_renderer('entry_typeHidden','Lino.blogs.EntryTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "title", "editable": true, "editor": title3482, "filter": { "type": "string" }, "header": "\u00dcberschrift", "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.title) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "body", "editable": true, "editor": body3483, "filter": { "type": "string" }, "header": "Inhalt", "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.body) An editable text body.") }, "sortable": false, "tooltip": "An editable text body.", "width": Lino.chars2width(61) }, { "colIndex": 5, "dataIndex": "user", "editable": true, "editor": user3484, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_type", "editable": true, "editor": owner_type3485, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "owner_id", "editable": true, "editor": owner_id3486, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 8, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.short_preview) A read-only short preview of body.") }, "sortable": false, "tooltip": "A read-only short preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 10, "dataIndex": "pub_time", "editable": true, "editor": pub_time3489, "header": "Bildungsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.pub_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 11, "dataIndex": "language", "editable": true, "editor": language3490, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.language) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.MyEntries.owner) ") }, "sortable": false, "tooltip": "(blogs.MyEntries.owner) ", "width": Lino.chars2width(11) } ];
    Lino.blogs.MyEntries.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.MyEntries.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/MyEntries", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.MyEntries.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/MyEntries", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.MyEntries.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/MyEntries", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.MyEntries.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/MyEntries", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.MyEntries.insertPanel = Ext.extend(Lino.blogs.Entries.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/blogs/MyEntries",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.MyEntries.detail;
    this.ls_insert_handler = Lino.blogs.MyEntries.insert;
    Lino.blogs.MyEntries.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.MyEntries.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/blogs/MyEntries" };
  return new Lino.blogs.MyEntries.insertPanel(p);
});
Lino.blogs.MyEntries.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/MyEntries", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.MyEntries.detailPanel = Ext.extend(Lino.blogs.Entries.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/blogs/MyEntries",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.MyEntries.detail;
    this.ls_insert_handler = Lino.blogs.MyEntries.insert;
    Lino.blogs.MyEntries.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.MyEntries.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/MyEntries" };
  return new Lino.blogs.MyEntries.detailPanel(p);
});
Lino.blogs.MyEntries.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/MyEntries", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.MyEntries.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/MyEntries", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.MyEntries.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/MyEntries", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.MyEntries.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/MyEntries" };
  p.params_panel = new Lino.blogs.Entries.ParamsPanel({});
  return new Lino.blogs.MyEntries.GridPanel(p);
});
Lino.blogs.MyEntries.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/MyEntries", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.MyEntries.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/MyEntries", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class blogs.AllEntries
Lino.blogs.AllEntries.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/blogs/AllEntries",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "pub_date", "type": "date" }, { "name": "user" }, 'userHidden', { "name": "entry_type" }, 'entry_typeHidden', { "name": "title" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "short_preview" }, { "name": "full_preview" }, { "name": "pub_time" }, { "name": "language" }, 'languageHidden', { "name": "owner" }, { "name": "body" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 58,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/blogs/AllEntries','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/AllEntries','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/AllEntries','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/AllEntries','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/blogs/AllEntries','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Blog-Eintr\u00e4ge",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.AllEntries.detail;
    this.ls_insert_handler = Lino.blogs.AllEntries.insert;
    var ww = this.containing_window;
    var id3493 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var pub_date3494 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var user3495 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/AllEntries/user" }) }) });
    var entry_type3496 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Blog Entry Type ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "blogs.EntryTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/AllEntries/entry_type" }) }) });
    var title3497 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var owner_type3498 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/AllEntries/owner_type" }) }) });
    var owner_id3499 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/AllEntries/owner_id" }) }) });
    var short_preview3500 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau" });
    var full_preview3501 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau (komplett)" });
    var pub_time3502 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var language3503 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var owner_disp3504 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    var body3505 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Inhalt" });
    this.before_row_edit = function(record) {
      owner_id3499.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      short_preview3500.refresh();
      full_preview3501.refresh();
      body3505.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type3498 !== 'undefined' && owner_type3498.on('change',Lino.chooser_handler(owner_id3499,'owner_type'));
      Lino.blogs.AllEntries.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3493, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "pub_date", "editable": true, "editor": pub_date3494, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Bildungsart", "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.pub_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user3495, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "entry_type", "editable": true, "editor": entry_type3496, "filter": { "type": "string" }, "header": "Blog Entry Type", "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.entry_type) ") }, "renderer": Lino.fk_renderer('entry_typeHidden','Lino.blogs.EntryTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "title", "editable": true, "editor": title3497, "filter": { "type": "string" }, "header": "\u00dcberschrift", "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.title) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type3498, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id3499, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.short_preview) A read-only short preview of body.") }, "sortable": false, "tooltip": "A read-only short preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "pub_time", "editable": true, "editor": pub_time3502, "header": "Bildungsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.pub_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "language", "editable": true, "editor": language3503, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.language) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.owner) ") }, "sortable": false, "tooltip": "(blogs.AllEntries.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 12, "dataIndex": "body", "editable": true, "editor": body3505, "filter": { "type": "string" }, "header": "Inhalt", "listeners": { "render": Lino.quicktip_renderer("","(blogs.AllEntries.body) An editable text body.") }, "sortable": false, "tooltip": "An editable text body.", "width": Lino.chars2width(61) } ];
    Lino.blogs.AllEntries.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.AllEntries.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/AllEntries", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.AllEntries.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/AllEntries", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.AllEntries.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/AllEntries", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.AllEntries.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/AllEntries", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.AllEntries.insertPanel = Ext.extend(Lino.blogs.Entries.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/blogs/AllEntries",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.AllEntries.detail;
    this.ls_insert_handler = Lino.blogs.AllEntries.insert;
    Lino.blogs.AllEntries.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.AllEntries.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/blogs/AllEntries" };
  return new Lino.blogs.AllEntries.insertPanel(p);
});
Lino.blogs.AllEntries.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/AllEntries", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.AllEntries.detailPanel = Ext.extend(Lino.blogs.Entries.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/blogs/AllEntries",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.AllEntries.detail;
    this.ls_insert_handler = Lino.blogs.AllEntries.insert;
    Lino.blogs.AllEntries.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.AllEntries.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/AllEntries" };
  return new Lino.blogs.AllEntries.detailPanel(p);
});
Lino.blogs.AllEntries.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/AllEntries", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.AllEntries.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/AllEntries", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.AllEntries.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/AllEntries", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.AllEntries.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/AllEntries" };
  p.params_panel = new Lino.blogs.Entries.ParamsPanel({});
  return new Lino.blogs.AllEntries.GridPanel(p);
});
Lino.blogs.AllEntries.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/AllEntries", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.AllEntries.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/AllEntries", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class blogs.LatestEntries
Lino.blogs.LatestEntries.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/blogs/LatestEntries",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "pub_date", "type": "date" }, { "name": "title" }, { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "body" }, { "name": "short_preview" }, { "name": "full_preview" }, { "name": "pub_time" }, { "name": "entry_type" }, 'entry_typeHidden', { "name": "language" }, 'languageHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 58,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/blogs/LatestEntries','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/LatestEntries','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/LatestEntries','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/LatestEntries','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/blogs/LatestEntries','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Blog-Eintr\u00e4ge",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.LatestEntries.detail;
    this.ls_insert_handler = Lino.blogs.LatestEntries.insert;
    var ww = this.containing_window;
    var pub_date3507 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var title3508 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var user3509 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/LatestEntries/user" }) }) });
    var id3510 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type3511 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/LatestEntries/owner_type" }) }) });
    var owner_id3512 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/LatestEntries/owner_id" }) }) });
    var body3513 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Inhalt" });
    var short_preview3514 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau" });
    var full_preview3515 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau (komplett)" });
    var pub_time3516 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var entry_type3517 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Blog Entry Type ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "blogs.EntryTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/LatestEntries/entry_type" }) }) });
    var language3518 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var owner_disp3519 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id3512.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      body3513.refresh();
      short_preview3514.refresh();
      full_preview3515.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type3511 !== 'undefined' && owner_type3511.on('change',Lino.chooser_handler(owner_id3512,'owner_type'));
      Lino.blogs.LatestEntries.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "pub_date", "editable": true, "editor": pub_date3507, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Bildungsart", "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.pub_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "title", "editable": true, "editor": title3508, "filter": { "type": "string" }, "header": "\u00dcberschrift", "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.title) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user3509, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id3510, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "owner_type", "editable": true, "editor": owner_type3511, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_id", "editable": true, "editor": owner_id3512, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "body", "editable": true, "editor": body3513, "filter": { "type": "string" }, "header": "Inhalt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.body) An editable text body.") }, "sortable": false, "tooltip": "An editable text body.", "width": Lino.chars2width(61) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.short_preview) A read-only short preview of body.") }, "sortable": false, "tooltip": "A read-only short preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "pub_time", "editable": true, "editor": pub_time3516, "header": "Bildungsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.pub_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "entry_type", "editable": true, "editor": entry_type3517, "filter": { "type": "string" }, "header": "Blog Entry Type", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.entry_type) ") }, "renderer": Lino.fk_renderer('entry_typeHidden','Lino.blogs.EntryTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "language", "editable": true, "editor": language3518, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.language) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.LatestEntries.owner) ") }, "sortable": false, "tooltip": "(blogs.LatestEntries.owner) ", "width": Lino.chars2width(11) } ];
    Lino.blogs.LatestEntries.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.LatestEntries.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/LatestEntries", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.LatestEntries.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/LatestEntries", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.LatestEntries.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/LatestEntries", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.LatestEntries.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/LatestEntries", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.LatestEntries.insertPanel = Ext.extend(Lino.blogs.Entries.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/blogs/LatestEntries",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.LatestEntries.detail;
    this.ls_insert_handler = Lino.blogs.LatestEntries.insert;
    Lino.blogs.LatestEntries.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.LatestEntries.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/blogs/LatestEntries" };
  return new Lino.blogs.LatestEntries.insertPanel(p);
});
Lino.blogs.LatestEntries.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/LatestEntries", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.LatestEntries.detailPanel = Ext.extend(Lino.blogs.Entries.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/blogs/LatestEntries",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.LatestEntries.detail;
    this.ls_insert_handler = Lino.blogs.LatestEntries.insert;
    Lino.blogs.LatestEntries.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.LatestEntries.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/LatestEntries" };
  return new Lino.blogs.LatestEntries.detailPanel(p);
});
Lino.blogs.LatestEntries.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/LatestEntries", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.LatestEntries.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/LatestEntries", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.LatestEntries.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/LatestEntries", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.LatestEntries.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/LatestEntries" };
  p.params_panel = new Lino.blogs.Entries.ParamsPanel({});
  return new Lino.blogs.LatestEntries.GridPanel(p);
});
Lino.blogs.LatestEntries.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/LatestEntries", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.LatestEntries.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/LatestEntries", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class excerpts.ExcerptTypes
Lino.excerpts.ExcerptTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/excerpts/ExcerptTypes",
  ls_store_fields : [ { "name": "content_type_display" }, { "name": "primary", "type": "boolean" }, { "name": "certifying", "type": "boolean" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "build_method" }, 'build_methodHidden', { "name": "template" }, { "name": "body_template" }, { "name": "id", "type": "int" }, { "name": "attach_to_email", "type": "boolean" }, { "name": "email_template" }, { "name": "remark" }, { "name": "content_type" }, 'content_typeHidden', { "name": "backward_compat", "type": "boolean" }, { "name": "print_recipient", "type": "boolean" }, { "name": "print_directly", "type": "boolean" }, { "name": "shortcut" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 10,
  content_type : 59,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Auszugsart) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Auszugsarten",
  disabled_fields_index : 20,
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.ExcerptTypes.detail;
    this.ls_insert_handler = Lino.excerpts.ExcerptTypes.insert;
    var ww = this.containing_window;
    var content_type_display_disp3521 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var primary3522 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var certifying3523 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var name3524 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de3525 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr3526 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var build_method3527 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var template3528 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/template" }) }) });
    var body_template3529 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/body_template" }) }) });
    var id3530 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var attach_to_email3531 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var email_template3532 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/email_template" }) }) });
    var remark3533 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var content_type3534 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptTypes/content_type" }) }) });
    var backward_compat3535 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var print_recipient3536 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "hidden": true, "selectOnFocus": true });
    var print_directly3537 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "hidden": true, "selectOnFocus": true });
    var shortcut3538 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      template3528.setContextValue('build_method', record ? record.data['build_methodHidden'] : undefined);
      template3528.setContextValue('content_type', record ? record.data['content_typeHidden'] : undefined);
      body_template3529.setContextValue('content_type', record ? record.data['content_typeHidden'] : undefined);
      email_template3532.setContextValue('content_type', record ? record.data['content_typeHidden'] : undefined);
      remark3533.refresh();
    };
    this.onRender = function(ct, position) {
      typeof build_method3527 !== 'undefined' && build_method3527.on('change',Lino.chooser_handler(template3528,'build_method'));
      typeof content_type3534 !== 'undefined' && content_type3534.on('change',Lino.chooser_handler(template3528,'content_type'));
      typeof content_type3534 !== 'undefined' && content_type3534.on('change',Lino.chooser_handler(body_template3529,'content_type'));
      typeof content_type3534 !== 'undefined' && content_type3534.on('change',Lino.chooser_handler(email_template3532,'content_type'));
      Lino.excerpts.ExcerptTypes.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "content_type_display", "editable": false, "header": "Modell", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.content_type_display) ") }, "sortable": false, "tooltip": "(excerpts.ExcerptTypes.content_type_display) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.primary) Whether this is the default type to use for this model. There's at most one primary type per model. Enabling this field will automatically make the other types non-primary.") }, "sortable": false, "tooltip": "Whether this is the default type to use for this model. There's at most one primary type per model. Enabling this field will automatically make the other types non-primary.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 2, "dataIndex": "certifying", "editable": true, "filter": { "type": "boolean" }, "header": "Bescheinigend", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.certifying) Ob Ausz\u00fcge dieser Art als einmalige Ausdrucke behandelt werden sollen.") }, "sortable": false, "tooltip": "Ob Ausz\u00fcge dieser Art als einmalige Ausdrucke behandelt werden sollen.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 3, "dataIndex": "name", "editable": true, "editor": name3524, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.name) The designation of this excerpt type.\nOne field for every language.") }, "sortable": true, "tooltip": "The designation of this excerpt type.\nOne field for every language.", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "name_de", "editable": true, "editor": name_de3525, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "name_fr", "editable": true, "editor": name_fr3526, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "build_method", "editable": true, "editor": build_method3527, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.build_method) See lino.modlib.printing.mixins.PrintableType.build_method.") }, "sortable": false, "tooltip": "See lino.modlib.printing.mixins.PrintableType.build_method.", "width": Lino.chars2width(24) }, { "colIndex": 7, "dataIndex": "template", "editable": true, "editor": template3528, "filter": { "type": "string" }, "header": "Vorlage", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.template) The main template to be used when printing an excerpt of this type.") }, "sortable": false, "tooltip": "The main template to be used when printing an excerpt of this type.", "width": Lino.chars2width(11) }, { "colIndex": 8, "dataIndex": "body_template", "editable": true, "editor": body_template3529, "filter": { "type": "string" }, "header": "Textk\u00f6rper-Vorlage", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.body_template) The body template to use when printing an excerpt of this type.") }, "sortable": false, "tooltip": "The body template to use when printing an excerpt of this type.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 9, "dataIndex": "id", "editable": true, "editor": id3530, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 10, "dataIndex": "attach_to_email", "editable": true, "filter": { "type": "boolean" }, "header": "als Anhang per E-Mail", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.attach_to_email) Whether the printable file should be attached to the email\nwhen creating an email from a mailable of this type.\n") }, "sortable": false, "tooltip": "Whether the printable file should be attached to the email\nwhen creating an email from a mailable of this type.\n", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 11, "dataIndex": "email_template", "editable": true, "editor": email_template3532, "filter": { "type": "string" }, "header": "E-Mail-Vorlage", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.email_template) The template to use when sending this an excerpt of this type\nby email.") }, "sortable": false, "tooltip": "The template to use when sending this an excerpt of this type\nby email.", "width": Lino.chars2width(11) }, { "colIndex": 12, "dataIndex": "remark", "editable": true, "editor": remark3533, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 13, "dataIndex": "content_type", "editable": true, "editor": content_type3534, "filter": { "type": "string" }, "header": "Modell", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.content_type) The database model for which this excerpt type is to be used.") }, "renderer": Lino.fk_renderer('content_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "The database model for which this excerpt type is to be used.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "backward_compat", "editable": true, "filter": { "type": "boolean" }, "header": "Backward compatible", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.backward_compat) Check this to have `this` in template context point to owner instead of excerpt.") }, "sortable": false, "tooltip": "Check this to have `this` in template context point to owner instead of excerpt.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "print_recipient", "editable": true, "filter": { "type": "boolean" }, "header": "Empf\u00e4nger drucken", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.print_recipient) Whether to print a recipient field in document.") }, "sortable": false, "tooltip": "Whether to print a recipient field in document.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "print_directly", "editable": true, "filter": { "type": "boolean" }, "header": "Print directly", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.print_directly) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "shortcut", "editable": true, "editor": shortcut3538, "filter": { "type": "string" }, "header": "Excerpt shortcut", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptTypes.shortcut) Optional pointer to a shortcut field.  If this is not empty, then\nthe given shortcut field will manage excerpts of this type.") }, "sortable": true, "tooltip": "Optional pointer to a shortcut field.  If this is not empty, then\nthe given shortcut field will manage excerpts of this type.", "width": Lino.chars2width(22) } ];
    Lino.excerpts.ExcerptTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.ExcerptTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.excerpts.ExcerptTypes.insertPanel = Ext.extend(Lino.excerpts.ExcerptTypes.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/excerpts/ExcerptTypes",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.ExcerptTypes.detail;
    this.ls_insert_handler = Lino.excerpts.ExcerptTypes.insert;
    Lino.excerpts.ExcerptTypes.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.ExcerptTypes.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/excerpts/ExcerptTypes" };
  return new Lino.excerpts.ExcerptTypes.insertPanel(p);
});
Lino.excerpts.ExcerptTypes.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptTypes", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.excerpts.ExcerptTypes.detailPanel = Ext.extend(Lino.excerpts.ExcerptTypes.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Auszugsart) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/excerpts/ExcerptTypes",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.ExcerptTypes.detail;
    this.ls_insert_handler = Lino.excerpts.ExcerptTypes.insert;
    Lino.excerpts.ExcerptTypes.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.ExcerptTypes.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/ExcerptTypes" };
  return new Lino.excerpts.ExcerptTypes.detailPanel(p);
});
Lino.excerpts.ExcerptTypes.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptTypes", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/ExcerptTypes" };
  return new Lino.excerpts.ExcerptTypes.GridPanel(p);
});
Lino.excerpts.ExcerptTypes.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptTypes", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class excerpts.Excerpts
Lino.excerpts.Excerpts.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/excerpts/Excerpts",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "excerpt_type" }, 'excerpt_typeHidden', { "name": "owner" }, { "name": "company" }, 'companyHidden', { "name": "language" }, 'languageHidden', { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "contact_person" }, 'contact_personHidden', { "name": "contact_role" }, 'contact_roleHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 60,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/excerpts/Excerpts','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/Excerpts','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/Excerpts','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/Excerpts','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/excerpts/Excerpts','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Ausz\u00fcge",
  disabled_fields_index : 21,
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.Excerpts.detail;
    var ww = this.containing_window;
    var id3540 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var excerpt_type3541 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "emptyText": "Auszugsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "excerpts.ExcerptTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/excerpt_type" }) }) });
    var owner_disp3542 = new Ext.form.DisplayField({ "disabled": true });
    var company3543 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/company" }) }) });
    var language3544 = new Lino.ChoicesFieldElement({ "allowBlank": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var build_time3545 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var build_method3546 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var user3547 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/user" }) }) });
    var owner_type3548 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/owner_type" }) }) });
    var owner_id3549 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/owner_id" }) }) });
    var contact_person3550 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/contact_person" }) }) });
    var contact_role3551 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/Excerpts/contact_role" }) }) });
    this.before_row_edit = function(record) {
      excerpt_type3541.setContextValue('owner', record ? record.data['owner'] : undefined);
      owner_id3549.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      contact_person3550.setContextValue('company', record ? record.data['companyHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_disp3542 !== 'undefined' && owner_disp3542.on('change',Lino.chooser_handler(excerpt_type3541,'owner'));
      typeof owner_type3548 !== 'undefined' && owner_type3548.on('change',Lino.chooser_handler(owner_id3549,'owner_type'));
      typeof company3543 !== 'undefined' && company3543.on('change',Lino.chooser_handler(contact_person3550,'company'));
      Lino.excerpts.Excerpts.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3540, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "excerpt_type", "editable": true, "editor": excerpt_type3541, "filter": { "type": "string" }, "header": "Auszugsart", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.excerpt_type) The type of this excerpt (ForeignKey to ExcerptType).") }, "renderer": Lino.fk_renderer('excerpt_typeHidden','Lino.excerpts.ExcerptTypes.detail'), "sortable": false, "tooltip": "The type of this excerpt (ForeignKey to ExcerptType).", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.owner) The object being printed by this excerpt.\nSee Controllable.owner.") }, "sortable": false, "tooltip": "The object being printed by this excerpt.\nSee Controllable.owner.", "width": Lino.chars2width(11) }, { "colIndex": 3, "dataIndex": "company", "editable": true, "editor": company3543, "filter": { "type": "string" }, "header": "Empf\u00e4nger (Organisation)", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.company) The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "language", "editable": true, "editor": language3544, "filter": { "type": "string" }, "header": "Sprache", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.language) The language used for printing this excerpt.") }, "sortable": false, "tooltip": "The language used for printing this excerpt.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "build_method", "editable": true, "editor": build_method3546, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 7, "dataIndex": "user", "editable": true, "editor": user3547, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "owner_type", "editable": true, "editor": owner_type3548, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "owner_id", "editable": true, "editor": owner_id3549, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 10, "dataIndex": "contact_person", "editable": true, "editor": contact_person3550, "filter": { "type": "string" }, "header": "Empf\u00e4nger (Person)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.contact_person) The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.") }, "renderer": Lino.fk_renderer('contact_personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "contact_role", "editable": true, "editor": contact_role3551, "filter": { "type": "string" }, "header": "in seiner Eigenschaft als", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Excerpts.contact_role) The optional Role\nof the contact_person within company.") }, "sortable": false, "tooltip": "The optional Role\nof the contact_person within company.", "width": Lino.chars2width(21) } ];
    Lino.excerpts.Excerpts.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.Excerpts.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Excerpts.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Excerpts.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Excerpts.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Excerpts.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.excerpts.Excerpts.detailPanel = Ext.extend(Lino.excerpts.Excerpts.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/excerpts/Excerpts",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.Excerpts.detail;
    Lino.excerpts.Excerpts.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.Excerpts.detail = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(13), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/Excerpts" };
  return new Lino.excerpts.Excerpts.detailPanel(p);
});
Lino.excerpts.Excerpts.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Excerpts.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Excerpts.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Excerpts.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Excerpts.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Excerpts.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/Excerpts" };
  p.params_panel = new Lino.excerpts.Excerpts.ParamsPanel({});
  return new Lino.excerpts.Excerpts.GridPanel(p);
});
Lino.excerpts.Excerpts.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Excerpts", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class excerpts.AllExcerpts
Lino.excerpts.AllExcerpts.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/excerpts/AllExcerpts",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "excerpt_type" }, 'excerpt_typeHidden', { "name": "owner" }, { "name": "company" }, 'companyHidden', { "name": "language" }, 'languageHidden', { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "contact_person" }, 'contact_personHidden', { "name": "contact_role" }, 'contact_roleHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 60,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/excerpts/AllExcerpts','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/AllExcerpts','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/AllExcerpts','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/AllExcerpts','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/excerpts/AllExcerpts','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Ausz\u00fcge",
  disabled_fields_index : 21,
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.AllExcerpts.detail;
    var ww = this.containing_window;
    var id3553 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var excerpt_type3554 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "emptyText": "Auszugsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "excerpts.ExcerptTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/AllExcerpts/excerpt_type" }) }) });
    var owner_disp3555 = new Ext.form.DisplayField({ "disabled": true });
    var company3556 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/AllExcerpts/company" }) }) });
    var language3557 = new Lino.ChoicesFieldElement({ "allowBlank": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var build_time3558 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var build_method3559 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var user3560 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/AllExcerpts/user" }) }) });
    var owner_type3561 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/AllExcerpts/owner_type" }) }) });
    var owner_id3562 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/AllExcerpts/owner_id" }) }) });
    var contact_person3563 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/AllExcerpts/contact_person" }) }) });
    var contact_role3564 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/AllExcerpts/contact_role" }) }) });
    this.before_row_edit = function(record) {
      excerpt_type3554.setContextValue('owner', record ? record.data['owner'] : undefined);
      owner_id3562.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      contact_person3563.setContextValue('company', record ? record.data['companyHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_disp3555 !== 'undefined' && owner_disp3555.on('change',Lino.chooser_handler(excerpt_type3554,'owner'));
      typeof owner_type3561 !== 'undefined' && owner_type3561.on('change',Lino.chooser_handler(owner_id3562,'owner_type'));
      typeof company3556 !== 'undefined' && company3556.on('change',Lino.chooser_handler(contact_person3563,'company'));
      Lino.excerpts.AllExcerpts.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3553, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "excerpt_type", "editable": true, "editor": excerpt_type3554, "filter": { "type": "string" }, "header": "Auszugsart", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.excerpt_type) The type of this excerpt (ForeignKey to ExcerptType).") }, "renderer": Lino.fk_renderer('excerpt_typeHidden','Lino.excerpts.ExcerptTypes.detail'), "sortable": false, "tooltip": "The type of this excerpt (ForeignKey to ExcerptType).", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.owner) The object being printed by this excerpt.\nSee Controllable.owner.") }, "sortable": false, "tooltip": "The object being printed by this excerpt.\nSee Controllable.owner.", "width": Lino.chars2width(11) }, { "colIndex": 3, "dataIndex": "company", "editable": true, "editor": company3556, "filter": { "type": "string" }, "header": "Empf\u00e4nger (Organisation)", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.company) The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "language", "editable": true, "editor": language3557, "filter": { "type": "string" }, "header": "Sprache", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.language) The language used for printing this excerpt.") }, "sortable": false, "tooltip": "The language used for printing this excerpt.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "build_method", "editable": true, "editor": build_method3559, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 7, "dataIndex": "user", "editable": true, "editor": user3560, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "owner_type", "editable": true, "editor": owner_type3561, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "owner_id", "editable": true, "editor": owner_id3562, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 10, "dataIndex": "contact_person", "editable": true, "editor": contact_person3563, "filter": { "type": "string" }, "header": "Empf\u00e4nger (Person)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.contact_person) The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.") }, "renderer": Lino.fk_renderer('contact_personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "contact_role", "editable": true, "editor": contact_role3564, "filter": { "type": "string" }, "header": "in seiner Eigenschaft als", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.AllExcerpts.contact_role) The optional Role\nof the contact_person within company.") }, "sortable": false, "tooltip": "The optional Role\nof the contact_person within company.", "width": Lino.chars2width(21) } ];
    Lino.excerpts.AllExcerpts.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.AllExcerpts.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.AllExcerpts.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.AllExcerpts.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.AllExcerpts.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.AllExcerpts.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.excerpts.AllExcerpts.detailPanel = Ext.extend(Lino.excerpts.Excerpts.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/excerpts/AllExcerpts",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.AllExcerpts.detail;
    Lino.excerpts.AllExcerpts.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.AllExcerpts.detail = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(13), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/AllExcerpts" };
  return new Lino.excerpts.AllExcerpts.detailPanel(p);
});
Lino.excerpts.AllExcerpts.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.AllExcerpts.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.AllExcerpts.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.AllExcerpts.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.AllExcerpts.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.AllExcerpts.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/AllExcerpts" };
  p.params_panel = new Lino.excerpts.Excerpts.ParamsPanel({});
  return new Lino.excerpts.AllExcerpts.GridPanel(p);
});
Lino.excerpts.AllExcerpts.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/AllExcerpts", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class excerpts.MyExcerpts
Lino.excerpts.MyExcerpts.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/excerpts/MyExcerpts",
  ls_store_fields : [ { "name": "build_time" }, { "name": "excerpt_type" }, 'excerpt_typeHidden', { "name": "id", "type": "int" }, { "name": "build_method" }, 'build_methodHidden', { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "company" }, 'companyHidden', { "name": "contact_person" }, 'contact_personHidden', { "name": "contact_role" }, 'contact_roleHidden', { "name": "language" }, 'languageHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 60,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/excerpts/MyExcerpts','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/MyExcerpts','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/MyExcerpts','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/MyExcerpts','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/excerpts/MyExcerpts','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Ausz\u00fcge",
  disabled_fields_index : 21,
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.MyExcerpts.detail;
    var ww = this.containing_window;
    var build_time3566 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var excerpt_type3567 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "emptyText": "Auszugsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "excerpts.ExcerptTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/MyExcerpts/excerpt_type" }) }) });
    var id3568 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var build_method3569 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var user3570 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/MyExcerpts/user" }) }) });
    var owner_type3571 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/MyExcerpts/owner_type" }) }) });
    var owner_id3572 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/MyExcerpts/owner_id" }) }) });
    var company3573 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/MyExcerpts/company" }) }) });
    var contact_person3574 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/MyExcerpts/contact_person" }) }) });
    var contact_role3575 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/MyExcerpts/contact_role" }) }) });
    var language3576 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var owner_disp3577 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      excerpt_type3567.setContextValue('owner', record ? record.data['owner'] : undefined);
      owner_id3572.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      contact_person3574.setContextValue('company', record ? record.data['companyHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_disp3577 !== 'undefined' && owner_disp3577.on('change',Lino.chooser_handler(excerpt_type3567,'owner'));
      typeof owner_type3571 !== 'undefined' && owner_type3571.on('change',Lino.chooser_handler(owner_id3572,'owner_type'));
      typeof company3573 !== 'undefined' && company3573.on('change',Lino.chooser_handler(contact_person3574,'company'));
      Lino.excerpts.MyExcerpts.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 1, "dataIndex": "excerpt_type", "editable": true, "editor": excerpt_type3567, "filter": { "type": "string" }, "header": "Auszugsart", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.excerpt_type) The type of this excerpt (ForeignKey to ExcerptType).") }, "renderer": Lino.fk_renderer('excerpt_typeHidden','Lino.excerpts.ExcerptTypes.detail'), "sortable": false, "tooltip": "The type of this excerpt (ForeignKey to ExcerptType).", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 2, "dataIndex": "id", "editable": true, "editor": id3568, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "build_method", "editable": true, "editor": build_method3569, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 4, "dataIndex": "user", "editable": true, "editor": user3570, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type3571, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id3572, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 7, "dataIndex": "company", "editable": true, "editor": company3573, "filter": { "type": "string" }, "header": "Empf\u00e4nger (Organisation)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.company) The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "contact_person", "editable": true, "editor": contact_person3574, "filter": { "type": "string" }, "header": "Empf\u00e4nger (Person)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.contact_person) The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.") }, "renderer": Lino.fk_renderer('contact_personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "contact_role", "editable": true, "editor": contact_role3575, "filter": { "type": "string" }, "header": "in seiner Eigenschaft als", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.contact_role) The optional Role\nof the contact_person within company.") }, "sortable": false, "tooltip": "The optional Role\nof the contact_person within company.", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "language", "editable": true, "editor": language3576, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.language) The language used for printing this excerpt.") }, "sortable": false, "tooltip": "The language used for printing this excerpt.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.MyExcerpts.owner) The object being printed by this excerpt.\nSee Controllable.owner.") }, "sortable": false, "tooltip": "The object being printed by this excerpt.\nSee Controllable.owner.", "width": Lino.chars2width(11) } ];
    Lino.excerpts.MyExcerpts.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.MyExcerpts.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.MyExcerpts.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.MyExcerpts.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.MyExcerpts.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.MyExcerpts.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.excerpts.MyExcerpts.detailPanel = Ext.extend(Lino.excerpts.Excerpts.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/excerpts/MyExcerpts",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.MyExcerpts.detail;
    Lino.excerpts.MyExcerpts.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.MyExcerpts.detail = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(13), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/MyExcerpts" };
  return new Lino.excerpts.MyExcerpts.detailPanel(p);
});
Lino.excerpts.MyExcerpts.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.MyExcerpts.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.MyExcerpts.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.MyExcerpts.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.MyExcerpts.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.MyExcerpts.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/MyExcerpts" };
  p.params_panel = new Lino.excerpts.Excerpts.ParamsPanel({});
  return new Lino.excerpts.MyExcerpts.GridPanel(p);
});
Lino.excerpts.MyExcerpts.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/MyExcerpts", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class tinymce.TextFieldTemplates
Lino.tinymce.TextFieldTemplates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/tinymce/TextFieldTemplates",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "user" }, 'userHidden', { "name": "name" }, { "name": "description" }, { "name": "text" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 61,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/tinymce/TextFieldTemplates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/tinymce/TextFieldTemplates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/tinymce/TextFieldTemplates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/tinymce/TextFieldTemplates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/tinymce/TextFieldTemplates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einf\u00fcgetext) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Einf\u00fcgetexte",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.tinymce.TextFieldTemplates.detail;
    this.ls_insert_handler = Lino.tinymce.TextFieldTemplates.insert;
    var ww = this.containing_window;
    var id3579 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var user3580 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/tinymce/TextFieldTemplates/user" }) }) });
    var name3581 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var description3582 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "selectOnFocus": true });
    var text3583 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Vorlagentext" });
    this.before_row_edit = function(record) {
      text3583.refresh();
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3579, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(tinymce.TextFieldTemplates.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user3580, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(tinymce.TextFieldTemplates.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "name", "editable": true, "editor": name3581, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(tinymce.TextFieldTemplates.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "description", "editable": true, "editor": description3582, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(tinymce.TextFieldTemplates.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 4, "dataIndex": "text", "editable": true, "editor": text3583, "filter": { "type": "string" }, "header": "Vorlagentext", "listeners": { "render": Lino.quicktip_renderer("","(tinymce.TextFieldTemplates.text) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.tinymce.TextFieldTemplates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.tinymce.TextFieldTemplates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/TextFieldTemplates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.tinymce.TextFieldTemplates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/TextFieldTemplates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.tinymce.TextFieldTemplates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/TextFieldTemplates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.tinymce.TextFieldTemplates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/TextFieldTemplates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.tinymce.TextFieldTemplates.insertPanel = Ext.extend(Lino.tinymce.TextFieldTemplates.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/tinymce/TextFieldTemplates",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.tinymce.TextFieldTemplates.detail;
    this.ls_insert_handler = Lino.tinymce.TextFieldTemplates.insert;
    Lino.tinymce.TextFieldTemplates.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.tinymce.TextFieldTemplates.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/tinymce/TextFieldTemplates" };
  return new Lino.tinymce.TextFieldTemplates.insertPanel(p);
});
Lino.tinymce.TextFieldTemplates.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/TextFieldTemplates", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.tinymce.TextFieldTemplates.detailPanel = Ext.extend(Lino.tinymce.TextFieldTemplates.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einf\u00fcgetext) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/tinymce/TextFieldTemplates",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.tinymce.TextFieldTemplates.detail;
    this.ls_insert_handler = Lino.tinymce.TextFieldTemplates.insert;
    Lino.tinymce.TextFieldTemplates.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.tinymce.TextFieldTemplates.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/tinymce/TextFieldTemplates" };
  return new Lino.tinymce.TextFieldTemplates.detailPanel(p);
});
Lino.tinymce.TextFieldTemplates.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/TextFieldTemplates", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.tinymce.TextFieldTemplates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/tinymce/TextFieldTemplates" };
  p.params_panel = new Lino.tinymce.TextFieldTemplates.ParamsPanel({});
  return new Lino.tinymce.TextFieldTemplates.GridPanel(p);
});
Lino.tinymce.TextFieldTemplates.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/TextFieldTemplates", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class tinymce.MyTextFieldTemplates
Lino.tinymce.MyTextFieldTemplates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/tinymce/MyTextFieldTemplates",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "user" }, 'userHidden', { "name": "name" }, { "name": "description" }, { "name": "text" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 61,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/tinymce/MyTextFieldTemplates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/tinymce/MyTextFieldTemplates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/tinymce/MyTextFieldTemplates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/tinymce/MyTextFieldTemplates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/tinymce/MyTextFieldTemplates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einf\u00fcgetext) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Einf\u00fcgetexte",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.tinymce.MyTextFieldTemplates.detail;
    this.ls_insert_handler = Lino.tinymce.MyTextFieldTemplates.insert;
    var ww = this.containing_window;
    var id3585 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var user3586 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/tinymce/MyTextFieldTemplates/user" }) }) });
    var name3587 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var description3588 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "selectOnFocus": true });
    var text3589 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Vorlagentext" });
    this.before_row_edit = function(record) {
      text3589.refresh();
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3585, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(tinymce.MyTextFieldTemplates.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user3586, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(tinymce.MyTextFieldTemplates.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "name", "editable": true, "editor": name3587, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(tinymce.MyTextFieldTemplates.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "description", "editable": true, "editor": description3588, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(tinymce.MyTextFieldTemplates.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 4, "dataIndex": "text", "editable": true, "editor": text3589, "filter": { "type": "string" }, "header": "Vorlagentext", "listeners": { "render": Lino.quicktip_renderer("","(tinymce.MyTextFieldTemplates.text) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.tinymce.MyTextFieldTemplates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.tinymce.MyTextFieldTemplates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/MyTextFieldTemplates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.tinymce.MyTextFieldTemplates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/MyTextFieldTemplates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.tinymce.MyTextFieldTemplates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/MyTextFieldTemplates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.tinymce.MyTextFieldTemplates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/MyTextFieldTemplates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.tinymce.MyTextFieldTemplates.insertPanel = Ext.extend(Lino.tinymce.TextFieldTemplates.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/tinymce/MyTextFieldTemplates",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.tinymce.MyTextFieldTemplates.detail;
    this.ls_insert_handler = Lino.tinymce.MyTextFieldTemplates.insert;
    Lino.tinymce.MyTextFieldTemplates.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.tinymce.MyTextFieldTemplates.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/tinymce/MyTextFieldTemplates" };
  return new Lino.tinymce.MyTextFieldTemplates.insertPanel(p);
});
Lino.tinymce.MyTextFieldTemplates.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/MyTextFieldTemplates", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.tinymce.MyTextFieldTemplates.detailPanel = Ext.extend(Lino.tinymce.TextFieldTemplates.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einf\u00fcgetext) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/tinymce/MyTextFieldTemplates",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.tinymce.MyTextFieldTemplates.detail;
    this.ls_insert_handler = Lino.tinymce.MyTextFieldTemplates.insert;
    Lino.tinymce.MyTextFieldTemplates.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.tinymce.MyTextFieldTemplates.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/tinymce/MyTextFieldTemplates" };
  return new Lino.tinymce.MyTextFieldTemplates.detailPanel(p);
});
Lino.tinymce.MyTextFieldTemplates.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/MyTextFieldTemplates", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.tinymce.MyTextFieldTemplates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/tinymce/MyTextFieldTemplates" };
  p.params_panel = new Lino.tinymce.TextFieldTemplates.ParamsPanel({});
  return new Lino.tinymce.MyTextFieldTemplates.GridPanel(p);
});
Lino.tinymce.MyTextFieldTemplates.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/tinymce/MyTextFieldTemplates", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.CommentTypes
Lino.comments.CommentTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/CommentTypes",
  ls_store_fields : [ { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 62,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/CommentTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/CommentTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar-Art) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kommentar-Arten",
  disabled_fields_index : 4,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentTypes.detail;
    this.ls_insert_handler = Lino.comments.CommentTypes.insert;
    var ww = this.containing_window;
    var name3591 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de3592 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr3593 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id3594 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name", "editable": true, "editor": name3591, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentTypes.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name_de", "editable": true, "editor": name_de3592, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentTypes.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_fr", "editable": true, "editor": name_fr3593, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentTypes.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id3594, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentTypes.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" } ];
    Lino.comments.CommentTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.CommentTypes.insertPanel = Ext.extend(Lino.comments.CommentTypes.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/comments/CommentTypes",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentTypes.detail;
    this.ls_insert_handler = Lino.comments.CommentTypes.insert;
    Lino.comments.CommentTypes.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentTypes.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/comments/CommentTypes" };
  return new Lino.comments.CommentTypes.insertPanel(p);
});
Lino.comments.CommentTypes.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentTypes", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.CommentTypes.detailPanel = Ext.extend(Lino.comments.CommentTypes.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar-Art) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/comments/CommentTypes",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentTypes.detail;
    this.ls_insert_handler = Lino.comments.CommentTypes.insert;
    Lino.comments.CommentTypes.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentTypes.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentTypes" };
  return new Lino.comments.CommentTypes.detailPanel(p);
});
Lino.comments.CommentTypes.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentTypes", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentTypes" };
  return new Lino.comments.CommentTypes.GridPanel(p);
});
Lino.comments.CommentTypes.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentTypes", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.Comments
Lino.comments.Comments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/Comments",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "body" }, { "name": "short_preview" }, { "name": "full_preview" }, { "name": "reply_to" }, 'reply_toHidden', { "name": "private", "type": "boolean" }, { "name": "comment_type" }, 'comment_typeHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 63,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/Comments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Comments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Comments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Comments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/Comments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kommentare",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.Comments.detail;
    this.ls_insert_handler = Lino.comments.Comments.insert;
    var ww = this.containing_window;
    var id3596 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified3597 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var created3598 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var user3599 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers" });
    var owner_type3600 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/owner_type" }) }) });
    var owner_id3601 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/owner_id" }) }) });
    var body3602 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Inhalt" });
    var short_preview3603 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau" });
    var full_preview3604 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau (komplett)" });
    var reply_to3605 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/reply_to" }) }) });
    var private3606 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "selectOnFocus": true });
    var comment_type3607 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar-Art ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.CommentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Comments/comment_type" }) }) });
    var owner_disp3608 = new Ext.form.DisplayField({ "disabled": true });
    this.before_row_edit = function(record) {
      owner_id3601.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      body3602.refresh();
      short_preview3603.refresh();
      full_preview3604.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type3600 !== 'undefined' && owner_type3600.on('change',Lino.chooser_handler(owner_id3601,'owner_type'));
      Lino.comments.Comments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3596, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 2, "dataIndex": "created", "editable": false, "header": "Erstellt", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 3, "dataIndex": "user", "editable": false, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.user) The author of the comment.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of the comment.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "owner_type", "editable": true, "editor": owner_type3600, "filter": { "type": "string" }, "header": "Thema (Modell)", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_id", "editable": true, "editor": owner_id3601, "filter": { "type": "string" }, "header": "Thema (Objekt)", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "body", "editable": true, "editor": body3602, "filter": { "type": "string" }, "header": "Inhalt", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.body) The full body text of your comment.") }, "sortable": false, "tooltip": "The full body text of your comment.", "width": Lino.chars2width(61) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.short_preview) The first paragraph of your body.") }, "sortable": false, "tooltip": "The first paragraph of your body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "reply_to", "editable": true, "editor": reply_to3605, "filter": { "type": "string" }, "header": "Antwort auf", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.reply_to) ") }, "renderer": Lino.fk_renderer('reply_toHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "private", "editable": true, "filter": { "type": "boolean" }, "header": "Privat", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.private) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 11, "dataIndex": "comment_type", "editable": true, "editor": comment_type3607, "filter": { "type": "string" }, "header": "Kommentar-Art", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.comment_type) ") }, "renderer": Lino.fk_renderer('comment_typeHidden','Lino.comments.CommentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "owner", "editable": false, "header": "Thema", "listeners": { "render": Lino.quicktip_renderer("","(comments.Comments.owner) The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.") }, "sortable": false, "tooltip": "The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.", "width": Lino.chars2width(11) } ];
    Lino.comments.Comments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.Comments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Comments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Comments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Comments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.Comments.insertPanel = Ext.extend(Lino.comments.Comments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/comments/Comments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.Comments.detail;
    this.ls_insert_handler = Lino.comments.Comments.insert;
    Lino.comments.Comments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.Comments.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(15), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/comments/Comments" };
  return new Lino.comments.Comments.insertPanel(p);
});
Lino.comments.Comments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.Comments.detailPanel = Ext.extend(Lino.comments.Comments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/comments/Comments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.Comments.detail;
    this.ls_insert_handler = Lino.comments.Comments.insert;
    Lino.comments.Comments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.Comments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/Comments" };
  return new Lino.comments.Comments.detailPanel(p);
});
Lino.comments.Comments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Comments.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Comments.do_pick_my_emotion = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "GET", pk, "do_pick_my_emotion", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Comments.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Comments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/Comments" };
  p.params_panel = new Lino.comments.Comments.ParamsPanel({});
  return new Lino.comments.Comments.GridPanel(p);
});
Lino.comments.Comments.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Comments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Comments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.MyComments
Lino.comments.MyComments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/MyComments",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "short_preview" }, { "name": "owner" }, { "name": "workflow_buttons" }, { "name": "created" }, { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "body" }, { "name": "full_preview" }, { "name": "reply_to" }, 'reply_toHidden', { "name": "private", "type": "boolean" }, { "name": "comment_type" }, 'comment_typeHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 63,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/MyComments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/MyComments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/MyComments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/MyComments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/MyComments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Kommentare",
  disabled_fields_index : 19,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.MyComments.detail;
    this.ls_insert_handler = Lino.comments.MyComments.insert;
    var ww = this.containing_window;
    var id3610 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified3611 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var short_preview3612 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau" });
    var owner_disp3613 = new Ext.form.DisplayField({ "disabled": true });
    var workflow_buttons_disp3614 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var created3615 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var user3616 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers" });
    var owner_type3617 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/MyComments/owner_type" }) }) });
    var owner_id3618 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/MyComments/owner_id" }) }) });
    var body3619 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Inhalt" });
    var full_preview3620 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau (komplett)" });
    var reply_to3621 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/MyComments/reply_to" }) }) });
    var private3622 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "hidden": true, "selectOnFocus": true });
    var comment_type3623 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar-Art ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "comments.CommentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/MyComments/comment_type" }) }) });
    this.before_row_edit = function(record) {
      short_preview3612.refresh();
      owner_id3618.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      body3619.refresh();
      full_preview3620.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type3617 !== 'undefined' && owner_type3617.on('change',Lino.chooser_handler(owner_id3618,'owner_type'));
      Lino.comments.MyComments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3610, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 2, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.short_preview) The first paragraph of your body.") }, "sortable": false, "tooltip": "The first paragraph of your body.", "width": Lino.chars2width(61) }, { "colIndex": 3, "dataIndex": "owner", "editable": false, "header": "Thema", "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.owner) The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.") }, "sortable": false, "tooltip": "The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.", "width": Lino.chars2width(11) }, { "colIndex": 4, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "colIndex": 5, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "user", "editable": false, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.user) The author of the comment.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of the comment.", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "owner_type", "editable": true, "editor": owner_type3617, "filter": { "type": "string" }, "header": "Thema (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "owner_id", "editable": true, "editor": owner_id3618, "filter": { "type": "string" }, "header": "Thema (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 9, "dataIndex": "body", "editable": true, "editor": body3619, "filter": { "type": "string" }, "header": "Inhalt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.body) The full body text of your comment.") }, "sortable": false, "tooltip": "The full body text of your comment.", "width": Lino.chars2width(61) }, { "colIndex": 10, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 11, "dataIndex": "reply_to", "editable": true, "editor": reply_to3621, "filter": { "type": "string" }, "header": "Antwort auf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.reply_to) ") }, "renderer": Lino.fk_renderer('reply_toHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "private", "editable": true, "filter": { "type": "boolean" }, "header": "Privat", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.private) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 13, "dataIndex": "comment_type", "editable": true, "editor": comment_type3623, "filter": { "type": "string" }, "header": "Kommentar-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MyComments.comment_type) ") }, "renderer": Lino.fk_renderer('comment_typeHidden','Lino.comments.CommentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.comments.MyComments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.MyComments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MyComments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MyComments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MyComments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.MyComments.insertPanel = Ext.extend(Lino.comments.Comments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/comments/MyComments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.MyComments.detail;
    this.ls_insert_handler = Lino.comments.MyComments.insert;
    Lino.comments.MyComments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.MyComments.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(15), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/comments/MyComments" };
  return new Lino.comments.MyComments.insertPanel(p);
});
Lino.comments.MyComments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.MyComments.detailPanel = Ext.extend(Lino.comments.Comments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/comments/MyComments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.MyComments.detail;
    this.ls_insert_handler = Lino.comments.MyComments.insert;
    Lino.comments.MyComments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.MyComments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/MyComments" };
  return new Lino.comments.MyComments.detailPanel(p);
});
Lino.comments.MyComments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MyComments.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MyComments.do_pick_my_emotion = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "GET", pk, "do_pick_my_emotion", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MyComments.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MyComments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/MyComments" };
  p.params_panel = new Lino.comments.Comments.ParamsPanel({});
  return new Lino.comments.MyComments.GridPanel(p);
});
Lino.comments.MyComments.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MyComments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MyComments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.AllComments
Lino.comments.AllComments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/AllComments",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "body" }, { "name": "short_preview" }, { "name": "full_preview" }, { "name": "reply_to" }, 'reply_toHidden', { "name": "private", "type": "boolean" }, { "name": "comment_type" }, 'comment_typeHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 63,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/AllComments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/AllComments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/AllComments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/AllComments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/AllComments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kommentare",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.AllComments.detail;
    this.ls_insert_handler = Lino.comments.AllComments.insert;
    var ww = this.containing_window;
    var id3625 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified3626 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var created3627 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var user3628 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers" });
    var owner_type3629 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/AllComments/owner_type" }) }) });
    var owner_id3630 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/AllComments/owner_id" }) }) });
    var body3631 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Inhalt" });
    var short_preview3632 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau" });
    var full_preview3633 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau (komplett)" });
    var reply_to3634 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/AllComments/reply_to" }) }) });
    var private3635 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "selectOnFocus": true });
    var comment_type3636 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar-Art ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.CommentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/AllComments/comment_type" }) }) });
    var owner_disp3637 = new Ext.form.DisplayField({ "disabled": true });
    this.before_row_edit = function(record) {
      owner_id3630.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      body3631.refresh();
      short_preview3632.refresh();
      full_preview3633.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type3629 !== 'undefined' && owner_type3629.on('change',Lino.chooser_handler(owner_id3630,'owner_type'));
      Lino.comments.AllComments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3625, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 2, "dataIndex": "created", "editable": false, "header": "Erstellt", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 3, "dataIndex": "user", "editable": false, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.user) The author of the comment.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of the comment.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "owner_type", "editable": true, "editor": owner_type3629, "filter": { "type": "string" }, "header": "Thema (Modell)", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_id", "editable": true, "editor": owner_id3630, "filter": { "type": "string" }, "header": "Thema (Objekt)", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "body", "editable": true, "editor": body3631, "filter": { "type": "string" }, "header": "Inhalt", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.body) The full body text of your comment.") }, "sortable": false, "tooltip": "The full body text of your comment.", "width": Lino.chars2width(61) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.short_preview) The first paragraph of your body.") }, "sortable": false, "tooltip": "The first paragraph of your body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "reply_to", "editable": true, "editor": reply_to3634, "filter": { "type": "string" }, "header": "Antwort auf", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.reply_to) ") }, "renderer": Lino.fk_renderer('reply_toHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "private", "editable": true, "filter": { "type": "boolean" }, "header": "Privat", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.private) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 11, "dataIndex": "comment_type", "editable": true, "editor": comment_type3636, "filter": { "type": "string" }, "header": "Kommentar-Art", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.comment_type) ") }, "renderer": Lino.fk_renderer('comment_typeHidden','Lino.comments.CommentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "owner", "editable": false, "header": "Thema", "listeners": { "render": Lino.quicktip_renderer("","(comments.AllComments.owner) The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.") }, "sortable": false, "tooltip": "The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.", "width": Lino.chars2width(11) } ];
    Lino.comments.AllComments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.AllComments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.AllComments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.AllComments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.AllComments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.AllComments.insertPanel = Ext.extend(Lino.comments.Comments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/comments/AllComments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.AllComments.detail;
    this.ls_insert_handler = Lino.comments.AllComments.insert;
    Lino.comments.AllComments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.AllComments.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(15), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/comments/AllComments" };
  return new Lino.comments.AllComments.insertPanel(p);
});
Lino.comments.AllComments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.AllComments.detailPanel = Ext.extend(Lino.comments.Comments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/comments/AllComments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.AllComments.detail;
    this.ls_insert_handler = Lino.comments.AllComments.insert;
    Lino.comments.AllComments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.AllComments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/AllComments" };
  return new Lino.comments.AllComments.detailPanel(p);
});
Lino.comments.AllComments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.AllComments.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.AllComments.do_pick_my_emotion = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "GET", pk, "do_pick_my_emotion", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.AllComments.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.AllComments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/AllComments" };
  p.params_panel = new Lino.comments.Comments.ParamsPanel({});
  return new Lino.comments.AllComments.GridPanel(p);
});
Lino.comments.AllComments.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.AllComments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/AllComments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.CommentsByX
Lino.comments.CommentsByX.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/CommentsByX",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "body" }, { "name": "short_preview" }, { "name": "full_preview" }, { "name": "reply_to" }, 'reply_toHidden', { "name": "private", "type": "boolean" }, { "name": "comment_type" }, 'comment_typeHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 63,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByX','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByX','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByX','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByX','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByX','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kommentare",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByX.detail;
    this.ls_insert_handler = Lino.comments.CommentsByX.insert;
    var ww = this.containing_window;
    var id3639 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified3640 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var created3641 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var user3642 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers" });
    var owner_type3643 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByX/owner_type" }) }) });
    var owner_id3644 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByX/owner_id" }) }) });
    var body3645 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Inhalt" });
    var short_preview3646 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau" });
    var full_preview3647 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau (komplett)" });
    var reply_to3648 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByX/reply_to" }) }) });
    var private3649 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "selectOnFocus": true });
    var comment_type3650 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar-Art ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.CommentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByX/comment_type" }) }) });
    var owner_disp3651 = new Ext.form.DisplayField({ "disabled": true });
    this.before_row_edit = function(record) {
      owner_id3644.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      body3645.refresh();
      short_preview3646.refresh();
      full_preview3647.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type3643 !== 'undefined' && owner_type3643.on('change',Lino.chooser_handler(owner_id3644,'owner_type'));
      Lino.comments.CommentsByX.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3639, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 2, "dataIndex": "created", "editable": false, "header": "Erstellt", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 3, "dataIndex": "user", "editable": false, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.user) The author of the comment.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of the comment.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "owner_type", "editable": true, "editor": owner_type3643, "filter": { "type": "string" }, "header": "Thema (Modell)", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_id", "editable": true, "editor": owner_id3644, "filter": { "type": "string" }, "header": "Thema (Objekt)", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "body", "editable": true, "editor": body3645, "filter": { "type": "string" }, "header": "Inhalt", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.body) The full body text of your comment.") }, "sortable": false, "tooltip": "The full body text of your comment.", "width": Lino.chars2width(61) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.short_preview) The first paragraph of your body.") }, "sortable": false, "tooltip": "The first paragraph of your body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "reply_to", "editable": true, "editor": reply_to3648, "filter": { "type": "string" }, "header": "Antwort auf", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.reply_to) ") }, "renderer": Lino.fk_renderer('reply_toHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "private", "editable": true, "filter": { "type": "boolean" }, "header": "Privat", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.private) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 11, "dataIndex": "comment_type", "editable": true, "editor": comment_type3650, "filter": { "type": "string" }, "header": "Kommentar-Art", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.comment_type) ") }, "renderer": Lino.fk_renderer('comment_typeHidden','Lino.comments.CommentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "owner", "editable": false, "header": "Thema", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByX.owner) The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.") }, "sortable": false, "tooltip": "The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.", "width": Lino.chars2width(11) } ];
    Lino.comments.CommentsByX.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByX.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByX.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByX.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByX.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.CommentsByX.insertPanel = Ext.extend(Lino.comments.Comments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/comments/CommentsByX",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByX.detail;
    this.ls_insert_handler = Lino.comments.CommentsByX.insert;
    Lino.comments.CommentsByX.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByX.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(15), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/comments/CommentsByX" };
  return new Lino.comments.CommentsByX.insertPanel(p);
});
Lino.comments.CommentsByX.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.CommentsByX.detailPanel = Ext.extend(Lino.comments.Comments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/comments/CommentsByX",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByX.detail;
    this.ls_insert_handler = Lino.comments.CommentsByX.insert;
    Lino.comments.CommentsByX.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByX.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentsByX" };
  return new Lino.comments.CommentsByX.detailPanel(p);
});
Lino.comments.CommentsByX.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByX.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByX.do_pick_my_emotion = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "GET", pk, "do_pick_my_emotion", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByX.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByX.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentsByX" };
  p.params_panel = new Lino.comments.Comments.ParamsPanel({});
  return new Lino.comments.CommentsByX.GridPanel(p);
});
Lino.comments.CommentsByX.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByX.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByX", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.RecentComments
Lino.comments.RecentComments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/RecentComments",
  ls_store_fields : [ { "name": "short_preview" }, { "name": "modified" }, { "name": "user" }, 'userHidden', { "name": "owner" }, { "name": "id", "type": "int" }, { "name": "created" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "body" }, { "name": "full_preview" }, { "name": "reply_to" }, 'reply_toHidden', { "name": "private", "type": "boolean" }, { "name": "comment_type" }, 'comment_typeHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 63,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/RecentComments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/RecentComments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/RecentComments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/RecentComments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/RecentComments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Recent comments",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.RecentComments.detail;
    this.ls_insert_handler = Lino.comments.RecentComments.insert;
    var ww = this.containing_window;
    var short_preview3656 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau" });
    var modified3657 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var user3658 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers" });
    var owner_disp3659 = new Ext.form.DisplayField({ "disabled": true });
    var id3660 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var created3661 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var owner_type3662 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/RecentComments/owner_type" }) }) });
    var owner_id3663 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/RecentComments/owner_id" }) }) });
    var body3664 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Inhalt" });
    var full_preview3665 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau (komplett)" });
    var reply_to3666 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/RecentComments/reply_to" }) }) });
    var private3667 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "hidden": true, "selectOnFocus": true });
    var comment_type3668 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar-Art ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "comments.CommentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/RecentComments/comment_type" }) }) });
    this.before_row_edit = function(record) {
      short_preview3656.refresh();
      owner_id3663.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      body3664.refresh();
      full_preview3665.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type3662 !== 'undefined' && owner_type3662.on('change',Lino.chooser_handler(owner_id3663,'owner_type'));
      Lino.comments.RecentComments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.short_preview) The first paragraph of your body.") }, "sortable": false, "tooltip": "The first paragraph of your body.", "width": Lino.chars2width(61) }, { "colIndex": 1, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 2, "dataIndex": "user", "editable": false, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.user) The author of the comment.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of the comment.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "owner", "editable": false, "header": "Thema", "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.owner) The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.") }, "sortable": false, "tooltip": "The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id3660, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "owner_type", "editable": true, "editor": owner_type3662, "filter": { "type": "string" }, "header": "Thema (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "owner_id", "editable": true, "editor": owner_id3663, "filter": { "type": "string" }, "header": "Thema (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 8, "dataIndex": "body", "editable": true, "editor": body3664, "filter": { "type": "string" }, "header": "Inhalt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.body) The full body text of your comment.") }, "sortable": false, "tooltip": "The full body text of your comment.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 10, "dataIndex": "reply_to", "editable": true, "editor": reply_to3666, "filter": { "type": "string" }, "header": "Antwort auf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.reply_to) ") }, "renderer": Lino.fk_renderer('reply_toHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "private", "editable": true, "filter": { "type": "boolean" }, "header": "Privat", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.private) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 12, "dataIndex": "comment_type", "editable": true, "editor": comment_type3668, "filter": { "type": "string" }, "header": "Kommentar-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.RecentComments.comment_type) ") }, "renderer": Lino.fk_renderer('comment_typeHidden','Lino.comments.CommentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.comments.RecentComments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.RecentComments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RecentComments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RecentComments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RecentComments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.RecentComments.insertPanel = Ext.extend(Lino.comments.Comments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/comments/RecentComments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.RecentComments.detail;
    this.ls_insert_handler = Lino.comments.RecentComments.insert;
    Lino.comments.RecentComments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.RecentComments.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(15), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/comments/RecentComments" };
  return new Lino.comments.RecentComments.insertPanel(p);
});
Lino.comments.RecentComments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.RecentComments.detailPanel = Ext.extend(Lino.comments.Comments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/comments/RecentComments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.RecentComments.detail;
    this.ls_insert_handler = Lino.comments.RecentComments.insert;
    Lino.comments.RecentComments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.RecentComments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/RecentComments" };
  return new Lino.comments.RecentComments.detailPanel(p);
});
Lino.comments.RecentComments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RecentComments.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RecentComments.do_pick_my_emotion = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "GET", pk, "do_pick_my_emotion", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RecentComments.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RecentComments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/RecentComments" };
  p.params_panel = new Lino.comments.Comments.ParamsPanel({});
  return new Lino.comments.RecentComments.GridPanel(p);
});
Lino.comments.RecentComments.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RecentComments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RecentComments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.Mentions
Lino.comments.Mentions.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/Mentions",
  ls_store_fields : [ { "name": "comment" }, 'commentHidden', { "name": "owner" }, { "name": "created" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden' ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 64,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/Mentions','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Mentions','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Mentions','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Mentions','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/Mentions','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Erw\u00e4hnungen",
  initComponent : function() {
    var ww = this.containing_window;
    var comment3670 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Mentions/comment" }) }) });
    var owner_disp3671 = new Ext.form.DisplayField({ "disabled": true });
    var created3672 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var id3673 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified3674 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var user3675 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Mentions/user" }) }) });
    var owner_type3676 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Mentions/owner_type" }) }) });
    var owner_id3677 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Mentions/owner_id" }) }) });
    this.before_row_edit = function(record) {
    };
    this.onRender = function(ct, position) {
      typeof owner_type3676 !== 'undefined' && owner_type3676.on('change',Lino.chooser_handler(owner_id3677,'owner_type'));
      Lino.comments.Mentions.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "comment", "editable": true, "editor": comment3670, "filter": { "type": "string" }, "header": "Kommentar", "listeners": { "render": Lino.quicktip_renderer("","(comments.Mentions.comment) ") }, "renderer": Lino.fk_renderer('commentHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(comments.Mentions.owner) ") }, "sortable": false, "tooltip": "(comments.Mentions.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "created", "editable": false, "header": "Erstellt", "listeners": { "render": Lino.quicktip_renderer("","(comments.Mentions.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id3673, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.Mentions.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.Mentions.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 5, "dataIndex": "user", "editable": true, "editor": user3675, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.Mentions.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_type", "editable": true, "editor": owner_type3676, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.Mentions.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "owner_id", "editable": true, "editor": owner_id3677, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.Mentions.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) } ];
    Lino.comments.Mentions.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.Mentions.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Mentions", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Mentions.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Mentions", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Mentions.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Mentions", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Mentions.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Mentions", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Mentions.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/Mentions" };
  p.params_panel = new Lino.comments.Mentions.ParamsPanel({});
  return new Lino.comments.Mentions.GridPanel(p);
});

// js_render_GridPanel_class comments.Reactions
Lino.comments.Reactions.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/Reactions",
  ls_store_fields : [ { "name": "comment" }, 'commentHidden', { "name": "user" }, 'userHidden', { "name": "emotion" }, 'emotionHidden', { "name": "created" }, { "name": "id", "type": "int" }, { "name": "modified" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 65,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/Reactions','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Reactions','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Reactions','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Reactions','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/Reactions','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Reaktionen",
  initComponent : function() {
    var ww = this.containing_window;
    var comment3679 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kommentar ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Reactions/comment" }) }) });
    var user3680 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/Reactions/user" }) }) });
    var emotion3681 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.comments.Emotions });
    var created3682 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var id3683 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified3684 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "comment", "editable": true, "editor": comment3679, "filter": { "type": "string" }, "header": "Kommentar", "listeners": { "render": Lino.quicktip_renderer("","(comments.Reactions.comment) ") }, "renderer": Lino.fk_renderer('commentHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user3680, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(comments.Reactions.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "emotion", "editable": true, "editor": emotion3681, "filter": { "options": [ "Okay", "Einverstanden", "Disagree" ], "type": "list" }, "header": "Emotion", "listeners": { "render": Lino.quicktip_renderer("","(comments.Reactions.emotion) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 3, "dataIndex": "created", "editable": false, "header": "Erstellt", "listeners": { "render": Lino.quicktip_renderer("","(comments.Reactions.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id3683, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.Reactions.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.Reactions.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) } ];
    Lino.comments.Reactions.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.Reactions.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Reactions", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Reactions.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Reactions", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Reactions.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Reactions", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Reactions.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Reactions", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Reactions.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/Reactions" };
  p.params_panel = new Lino.comments.Reactions.ParamsPanel({});
  return new Lino.comments.Reactions.GridPanel(p);
});

// js_render_GridPanel_class dashboard.Widgets
Lino.dashboard.Widgets.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/dashboard/Widgets",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "seqno", "type": "int", "useNull": true }, { "name": "user" }, 'userHidden', { "name": "item_name" }, { "name": "visible", "type": "boolean" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 66,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/dashboard/Widgets','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/dashboard/Widgets','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/dashboard/Widgets','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/dashboard/Widgets','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/dashboard/Widgets','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Widgets",
  disabled_fields_index : 6,
  initComponent : function() {
    var ww = this.containing_window;
    var id3686 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var seqno3687 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var user3688 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/dashboard/Widgets/user" }) }) });
    var item_name3689 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/dashboard/Widgets/item_name" }) }) });
    var visible3690 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      item_name3689.setContextValue('user', record ? record.data['userHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof user3688 !== 'undefined' && user3688.on('change',Lino.chooser_handler(item_name3689,'user'));
      Lino.dashboard.Widgets.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3686, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.Widgets.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 1, "dataIndex": "seqno", "editable": true, "editor": seqno3687, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.Widgets.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user3688, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.Widgets.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "item_name", "editable": true, "editor": item_name3689, "filter": { "type": "string" }, "header": "Resource", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.Widgets.item_name) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 4, "dataIndex": "visible", "editable": true, "filter": { "type": "boolean" }, "header": "Sichtbar", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.Widgets.visible) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" } ];
    Lino.dashboard.Widgets.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.dashboard.Widgets.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/Widgets", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.Widgets.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/Widgets", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.Widgets.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/Widgets", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.Widgets.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/Widgets", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.Widgets.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/Widgets", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.Widgets.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/Widgets", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.Widgets.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/dashboard/Widgets" };
  p.params_panel = new Lino.dashboard.Widgets.ParamsPanel({});
  return new Lino.dashboard.Widgets.GridPanel(p);
});
Lino.dashboard.Widgets.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/Widgets", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.Widgets.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/Widgets", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.Widgets.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/Widgets", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class dashboard.AllWidgets
Lino.dashboard.AllWidgets.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/dashboard/AllWidgets",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "user" }, 'userHidden', { "name": "seqno", "type": "int", "useNull": true }, { "name": "move_buttons" }, { "name": "title" }, { "name": "visible", "type": "boolean" }, { "name": "item_name" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 66,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/dashboard/AllWidgets','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/dashboard/AllWidgets','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/dashboard/AllWidgets','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/dashboard/AllWidgets','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/dashboard/AllWidgets','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "All dashboard widgets",
  disabled_fields_index : 8,
  initComponent : function() {
    var ww = this.containing_window;
    var id3692 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var user3693 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/dashboard/AllWidgets/user" }) }) });
    var seqno3694 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var move_buttons_disp3695 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var title_disp3696 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var visible3697 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "selectOnFocus": true });
    var item_name3698 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/dashboard/AllWidgets/item_name" }) }) });
    this.before_row_edit = function(record) {
      item_name3698.setContextValue('user', record ? record.data['userHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof user3693 !== 'undefined' && user3693.on('change',Lino.chooser_handler(item_name3698,'user'));
      Lino.dashboard.AllWidgets.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3692, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.AllWidgets.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user3693, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.AllWidgets.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 2, "dataIndex": "seqno", "editable": true, "editor": seqno3694, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.AllWidgets.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "move_buttons", "editable": false, "header": "Bearbeiten", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.AllWidgets.move_buttons) Displays buttons for certain actions on this row:") }, "sortable": false, "tooltip": "Displays buttons for certain actions on this row:", "width": Lino.chars2width(6) }, { "colIndex": 4, "dataIndex": "title", "editable": false, "header": "Label", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.AllWidgets.title) ") }, "sortable": false, "tooltip": "(dashboard.AllWidgets.title) ", "width": Lino.chars2width(31) }, { "colIndex": 5, "dataIndex": "visible", "editable": true, "filter": { "type": "boolean" }, "header": "Sichtbar", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.AllWidgets.visible) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 6, "dataIndex": "item_name", "editable": true, "editor": item_name3698, "filter": { "type": "string" }, "header": "Resource", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(dashboard.AllWidgets.item_name) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) } ];
    Lino.dashboard.AllWidgets.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.dashboard.AllWidgets.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/AllWidgets", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.AllWidgets.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/AllWidgets", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.AllWidgets.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/AllWidgets", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.AllWidgets.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/AllWidgets", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.AllWidgets.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/AllWidgets", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.AllWidgets.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/AllWidgets", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.AllWidgets.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/dashboard/AllWidgets" };
  p.params_panel = new Lino.dashboard.Widgets.ParamsPanel({});
  return new Lino.dashboard.AllWidgets.GridPanel(p);
});
Lino.dashboard.AllWidgets.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/AllWidgets", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.AllWidgets.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/AllWidgets", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.AllWidgets.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/AllWidgets", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class users.AllUsers
Lino.users.AllUsers.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/users/AllUsers",
  ls_store_fields : [ { "name": "username" }, { "name": "user_type" }, 'user_typeHidden', { "name": "first_name" }, { "name": "last_name" }, { "name": "id", "type": "int" }, { "name": "email" }, { "name": "language" }, 'languageHidden', { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "password" }, { "name": "last_login" }, { "name": "initials" }, { "name": "remarks" }, { "name": "time_zone" }, 'time_zoneHidden', { "name": "access_class" }, 'access_classHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "partner" }, 'partnerHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 2,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/users/AllUsers','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/AllUsers','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/users/AllUsers','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/AllUsers','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/users/AllUsers','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Benutzer) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "change_password", "menu_item_text": "Passwort \u00e4ndern", "overflowText": "Passwort \u00e4ndern", "panel_btn_handler": Lino.param_action_handler(Lino.users.AllUsers.change_password), "text": " <font size=\"4\">\u2731</font>", "tooltip": "Change the password of this user.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_widgets", "menu_item_text": "Update widgets", "overflowText": "Update widgets", "panel_btn_handler": Lino.row_action_handler('update_widgets','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the dashboard widgets for this user.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Benutzer",
  disabled_fields_index : 25,
  initComponent : function() {
    this.ls_detail_handler = Lino.users.AllUsers.detail;
    this.ls_insert_handler = Lino.users.AllUsers.insert;
    var ww = this.containing_window;
    var username3700 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 30, "selectOnFocus": true });
    var user_type3701 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.users.UserTypes) });
    var first_name3702 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 30, "selectOnFocus": true });
    var last_name3703 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 30, "selectOnFocus": true });
    var id3704 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var email3705 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 254, "selectOnFocus": true });
    var language3706 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var modified3707 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created3708 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3709 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date3710 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var password3711 = new Ext.form.TextField({ "allowBlank": false, "hidden": true, "maxLength": 128, "selectOnFocus": true });
    var last_login3712 = new Ext.form.DisplayField({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "value": "<br>" });
    var initials3713 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var remarks3714 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    var time_zone3715 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.about.TimeZones });
    var access_class3716 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.AccessClasses });
    var event_type3717 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/AllUsers/event_type" }) }) });
    var partner3718 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Partner ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/AllUsers/partner" }) }) });
    this.before_row_edit = function(record) {
      remarks3714.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "username", "editable": true, "editor": username3700, "filter": { "type": "string" }, "header": "Benutzername", "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.username) Must be unique and cannot be empty.") }, "sortable": true, "tooltip": "Must be unique and cannot be empty.", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "user_type", "editable": true, "editor": user_type3701, "filter": { "options": [ "000 (000 (Anonym))", "100 (100 (Benutzer))", "200 (200 (Collector))", "300 (300 (Project manager))", "800 (800 (Staff))", "900 (900 (Verwalter))" ], "type": "list" }, "header": "Benutzerart", "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.user_type) The user type given to this user. Users having this field empty\nare considered inactive and cannot log in.") }, "sortable": false, "tooltip": "The user type given to this user. Users having this field empty\nare considered inactive and cannot log in.", "width": Lino.chars2width(31) }, { "colIndex": 2, "dataIndex": "first_name", "editable": true, "editor": first_name3702, "filter": { "type": "string" }, "header": "Vorname", "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.first_name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "last_name", "editable": true, "editor": last_name3703, "filter": { "type": "string" }, "header": "Familienname", "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.last_name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id3704, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "email", "editable": true, "editor": email3705, "filter": { "type": "string" }, "header": "E-Mail-Adresse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.email) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "language", "editable": true, "editor": language3706, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.language) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 8, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 9, "dataIndex": "start_date", "editable": true, "editor": start_date3709, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.start_date) If start_date is given, then the user cannot sign in\nbefore that date.  If end_date is given, then the user\ncannot sign in after that date.") }, "sortable": true, "tooltip": "If start_date is given, then the user cannot sign in\nbefore that date.  If end_date is given, then the user\ncannot sign in after that date.", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "end_date", "editable": true, "editor": end_date3710, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.end_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 11, "dataIndex": "password", "editable": true, "editor": password3711, "filter": { "type": "string" }, "header": "password", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.password) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 12, "dataIndex": "last_login", "editable": true, "editor": last_login3712, "header": "last login", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.last_login) Not used in Lino.") }, "sortable": true, "tooltip": "Not used in Lino.", "width": Lino.chars2width(17) }, { "colIndex": 13, "dataIndex": "initials", "editable": true, "editor": initials3713, "filter": { "type": "string" }, "header": "Initialien", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.initials) The nickname or initials of this user. This does not need to\nbe unique but should provide a reasonably identifying\nfunction.") }, "sortable": true, "tooltip": "The nickname or initials of this user. This does not need to\nbe unique but should provide a reasonably identifying\nfunction.", "width": Lino.chars2width(12) }, { "colIndex": 14, "dataIndex": "remarks", "editable": true, "editor": remarks3714, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 15, "dataIndex": "time_zone", "editable": true, "editor": time_zone3715, "filter": { "options": [ "UTC" ], "type": "list" }, "header": "Zeitzone", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.time_zone) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(8) }, { "colIndex": 16, "dataIndex": "access_class", "editable": true, "editor": access_class3716, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Standardm\u00e4\u00dfige Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.access_class) Die standardm\u00e4\u00dfige Zugriffsklasse f\u00fcr Ihre Termine und Aufgaben") }, "sortable": false, "tooltip": "Die standardm\u00e4\u00dfige Zugriffsklasse f\u00fcr Ihre Termine und Aufgaben", "width": Lino.chars2width(13) }, { "colIndex": 17, "dataIndex": "event_type", "editable": true, "editor": event_type3717, "filter": { "type": "string" }, "header": "Standard-Kalenderintragsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.event_type) The default event type for your calendar events.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The default event type for your calendar events.", "width": Lino.chars2width(21) }, { "colIndex": 18, "dataIndex": "partner", "editable": true, "editor": partner3718, "filter": { "type": "string" }, "header": "Partner", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.AllUsers.partner) Pointer to the Partner instance related to\nthis user.") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "Pointer to the Partner instance related to\nthis user.", "width": Lino.chars2width(21) } ];
    Lino.users.AllUsers.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.users.AllUsers.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AllUsers", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AllUsers.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AllUsers", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AllUsers.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AllUsers", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AllUsers.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AllUsers", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.users.AllUsers.insertPanel = Ext.extend(Lino.users.AllUsers.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/users/AllUsers",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.users.AllUsers.detail;
    this.ls_insert_handler = Lino.users.AllUsers.insert;
    Lino.users.AllUsers.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.users.AllUsers.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/users/AllUsers" };
  return new Lino.users.AllUsers.insertPanel(p);
});
Lino.users.AllUsers.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AllUsers", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.users.AllUsers.detailPanel = Ext.extend(Lino.users.AllUsers.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Benutzer) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "change_password", "menu_item_text": "Passwort \u00e4ndern", "overflowText": "Passwort \u00e4ndern", "panel_btn_handler": Lino.param_action_handler(Lino.users.AllUsers.change_password), "text": " <font size=\"4\">\u2731</font>", "tooltip": "Change the password of this user.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_widgets", "menu_item_text": "Update widgets", "overflowText": "Update widgets", "panel_btn_handler": Lino.row_action_handler('update_widgets','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the dashboard widgets for this user.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/users/AllUsers",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.users.AllUsers.detail;
    this.ls_insert_handler = Lino.users.AllUsers.insert;
    Lino.users.AllUsers.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.users.AllUsers.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/AllUsers" };
  return new Lino.users.AllUsers.detailPanel(p);
});
Lino.users.AllUsers.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AllUsers", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AllUsers.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/AllUsers" };
  p.params_panel = new Lino.users.AllUsers.ParamsPanel({});
  return new Lino.users.AllUsers.GridPanel(p);
});
Lino.users.AllUsers.sign_out = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AllUsers", "GET", pk, "sign_out", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AllUsers.update_widgets = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AllUsers", "GET", pk, "update_widgets", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AllUsers.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AllUsers", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class users.UsersOverview
Lino.users.UsersOverview.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/users/UsersOverview",
  ls_store_fields : [ { "name": "username" }, { "name": "user_type" }, 'user_typeHidden', { "name": "language" }, 'languageHidden', { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 2,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/users/UsersOverview','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/UsersOverview','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/users/UsersOverview','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/UsersOverview','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/users/UsersOverview','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Benutzer) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "change_password", "menu_item_text": "Passwort \u00e4ndern", "overflowText": "Passwort \u00e4ndern", "panel_btn_handler": Lino.param_action_handler(Lino.users.AllUsers.change_password), "text": " <font size=\"4\">\u2731</font>", "tooltip": "Change the password of this user.", "tooltipType": "title" }, { "auto_save": true, "itemId": "sign_in", "menu_item_text": "Anmelden", "overflowText": "Anmelden", "panel_btn_handler": Lino.param_action_handler(Lino.users.UsersOverview.sign_in), "text": "Anmelden", "tooltip": "Open a window which asks for username and password and which\nauthenticates as this user when submitted.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_widgets", "menu_item_text": "Update widgets", "overflowText": "Update widgets", "panel_btn_handler": Lino.row_action_handler('update_widgets','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the dashboard widgets for this user.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Benutzer",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.users.UsersOverview.detail;
    this.ls_insert_handler = Lino.users.UsersOverview.insert;
    var ww = this.containing_window;
    var username2636 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 30, "selectOnFocus": true });
    var user_type2637 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.users.UserTypes) });
    var language2638 = new Lino.ChoicesFieldElement({ "allowBlank": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "username", "editable": true, "editor": username2636, "filter": { "type": "string" }, "header": "Benutzername", "listeners": { "render": Lino.quicktip_renderer("","(users.UsersOverview.username) Must be unique and cannot be empty.") }, "sortable": true, "tooltip": "Must be unique and cannot be empty.", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "user_type", "editable": true, "editor": user_type2637, "filter": { "options": [ "000 (000 (Anonym))", "100 (100 (Benutzer))", "200 (200 (Collector))", "300 (300 (Project manager))", "800 (800 (Staff))", "900 (900 (Verwalter))" ], "type": "list" }, "header": "Benutzerart", "listeners": { "render": Lino.quicktip_renderer("","(users.UsersOverview.user_type) The user type given to this user. Users having this field empty\nare considered inactive and cannot log in.") }, "sortable": false, "tooltip": "The user type given to this user. Users having this field empty\nare considered inactive and cannot log in.", "width": Lino.chars2width(31) }, { "colIndex": 2, "dataIndex": "language", "editable": true, "editor": language2638, "filter": { "type": "string" }, "header": "Sprache", "listeners": { "render": Lino.quicktip_renderer("","(users.UsersOverview.language) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.users.UsersOverview.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.users.UsersOverview.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UsersOverview", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UsersOverview.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UsersOverview", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UsersOverview.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UsersOverview", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UsersOverview.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UsersOverview", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.users.UsersOverview.insertPanel = Ext.extend(Lino.users.AllUsers.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/users/UsersOverview",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.users.UsersOverview.detail;
    this.ls_insert_handler = Lino.users.UsersOverview.insert;
    Lino.users.UsersOverview.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.users.UsersOverview.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/users/UsersOverview" };
  return new Lino.users.UsersOverview.insertPanel(p);
});
Lino.users.UsersOverview.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UsersOverview", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.users.UsersOverview.detailPanel = Ext.extend(Lino.users.AllUsers.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Benutzer) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "change_password", "menu_item_text": "Passwort \u00e4ndern", "overflowText": "Passwort \u00e4ndern", "panel_btn_handler": Lino.param_action_handler(Lino.users.AllUsers.change_password), "text": " <font size=\"4\">\u2731</font>", "tooltip": "Change the password of this user.", "tooltipType": "title" }, { "auto_save": true, "itemId": "sign_in", "menu_item_text": "Anmelden", "overflowText": "Anmelden", "panel_btn_handler": Lino.param_action_handler(Lino.users.UsersOverview.sign_in), "text": "Anmelden", "tooltip": "Open a window which asks for username and password and which\nauthenticates as this user when submitted.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_widgets", "menu_item_text": "Update widgets", "overflowText": "Update widgets", "panel_btn_handler": Lino.row_action_handler('update_widgets','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the dashboard widgets for this user.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/users/UsersOverview",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.users.UsersOverview.detail;
    this.ls_insert_handler = Lino.users.UsersOverview.insert;
    Lino.users.UsersOverview.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.users.UsersOverview.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/UsersOverview" };
  return new Lino.users.UsersOverview.detailPanel(p);
});
Lino.users.UsersOverview.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UsersOverview", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UsersOverview.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/UsersOverview" };
  p.params_panel = new Lino.users.UsersOverview.ParamsPanel({});
  return new Lino.users.UsersOverview.GridPanel(p);
});
Lino.users.UsersOverview.sign_out = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UsersOverview", "GET", pk, "sign_out", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UsersOverview.update_widgets = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UsersOverview", "GET", pk, "update_widgets", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UsersOverview.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UsersOverview", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class users.MySettings
Lino.users.MySettings.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/users/MySettings",
  ls_store_fields : [ { "name": "username" }, { "name": "user_type" }, 'user_typeHidden', { "name": "first_name" }, { "name": "last_name" }, { "name": "id", "type": "int" }, { "name": "email" }, { "name": "language" }, 'languageHidden', { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "password" }, { "name": "last_login" }, { "name": "initials" }, { "name": "remarks" }, { "name": "time_zone" }, 'time_zoneHidden', { "name": "access_class" }, 'access_classHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "partner" }, 'partnerHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 2,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Benutzer) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "change_password", "menu_item_text": "Passwort \u00e4ndern", "overflowText": "Passwort \u00e4ndern", "panel_btn_handler": Lino.param_action_handler(Lino.users.AllUsers.change_password), "text": " <font size=\"4\">\u2731</font>", "tooltip": "Change the password of this user.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_widgets", "menu_item_text": "Update widgets", "overflowText": "Update widgets", "panel_btn_handler": Lino.row_action_handler('update_widgets','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the dashboard widgets for this user.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Benutzer",
  disabled_fields_index : 25,
  initComponent : function() {
    this.ls_detail_handler = Lino.users.MySettings.detail;
    this.ls_insert_handler = Lino.users.MySettings.insert;
    var ww = this.containing_window;
    var username3720 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 30, "selectOnFocus": true });
    var user_type3721 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.users.UserTypes) });
    var first_name3722 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 30, "selectOnFocus": true });
    var last_name3723 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 30, "selectOnFocus": true });
    var id3724 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var email3725 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 254, "selectOnFocus": true });
    var language3726 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var modified3727 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created3728 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date3729 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date3730 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var password3731 = new Ext.form.TextField({ "allowBlank": false, "hidden": true, "maxLength": 128, "selectOnFocus": true });
    var last_login3732 = new Ext.form.DisplayField({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "value": "<br>" });
    var initials3733 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var remarks3734 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    var time_zone3735 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.about.TimeZones });
    var access_class3736 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.AccessClasses });
    var event_type3737 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/MySettings/event_type" }) }) });
    var partner3738 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Partner ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/MySettings/partner" }) }) });
    this.before_row_edit = function(record) {
      remarks3734.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "username", "editable": true, "editor": username3720, "filter": { "type": "string" }, "header": "Benutzername", "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.username) Must be unique and cannot be empty.") }, "sortable": true, "tooltip": "Must be unique and cannot be empty.", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "user_type", "editable": true, "editor": user_type3721, "filter": { "options": [ "000 (000 (Anonym))", "100 (100 (Benutzer))", "200 (200 (Collector))", "300 (300 (Project manager))", "800 (800 (Staff))", "900 (900 (Verwalter))" ], "type": "list" }, "header": "Benutzerart", "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.user_type) The user type given to this user. Users having this field empty\nare considered inactive and cannot log in.") }, "sortable": false, "tooltip": "The user type given to this user. Users having this field empty\nare considered inactive and cannot log in.", "width": Lino.chars2width(31) }, { "colIndex": 2, "dataIndex": "first_name", "editable": true, "editor": first_name3722, "filter": { "type": "string" }, "header": "Vorname", "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.first_name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "last_name", "editable": true, "editor": last_name3723, "filter": { "type": "string" }, "header": "Familienname", "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.last_name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id3724, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "email", "editable": true, "editor": email3725, "filter": { "type": "string" }, "header": "E-Mail-Adresse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.email) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "language", "editable": true, "editor": language3726, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.language) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 8, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 9, "dataIndex": "start_date", "editable": true, "editor": start_date3729, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.start_date) If start_date is given, then the user cannot sign in\nbefore that date.  If end_date is given, then the user\ncannot sign in after that date.") }, "sortable": true, "tooltip": "If start_date is given, then the user cannot sign in\nbefore that date.  If end_date is given, then the user\ncannot sign in after that date.", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "end_date", "editable": true, "editor": end_date3730, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.end_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 11, "dataIndex": "password", "editable": true, "editor": password3731, "filter": { "type": "string" }, "header": "password", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.password) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 12, "dataIndex": "last_login", "editable": true, "editor": last_login3732, "header": "last login", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.last_login) Not used in Lino.") }, "sortable": true, "tooltip": "Not used in Lino.", "width": Lino.chars2width(17) }, { "colIndex": 13, "dataIndex": "initials", "editable": true, "editor": initials3733, "filter": { "type": "string" }, "header": "Initialien", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.initials) The nickname or initials of this user. This does not need to\nbe unique but should provide a reasonably identifying\nfunction.") }, "sortable": true, "tooltip": "The nickname or initials of this user. This does not need to\nbe unique but should provide a reasonably identifying\nfunction.", "width": Lino.chars2width(12) }, { "colIndex": 14, "dataIndex": "remarks", "editable": true, "editor": remarks3734, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 15, "dataIndex": "time_zone", "editable": true, "editor": time_zone3735, "filter": { "options": [ "UTC" ], "type": "list" }, "header": "Zeitzone", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.time_zone) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(8) }, { "colIndex": 16, "dataIndex": "access_class", "editable": true, "editor": access_class3736, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Standardm\u00e4\u00dfige Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.access_class) Die standardm\u00e4\u00dfige Zugriffsklasse f\u00fcr Ihre Termine und Aufgaben") }, "sortable": false, "tooltip": "Die standardm\u00e4\u00dfige Zugriffsklasse f\u00fcr Ihre Termine und Aufgaben", "width": Lino.chars2width(13) }, { "colIndex": 17, "dataIndex": "event_type", "editable": true, "editor": event_type3737, "filter": { "type": "string" }, "header": "Standard-Kalenderintragsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.event_type) The default event type for your calendar events.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The default event type for your calendar events.", "width": Lino.chars2width(21) }, { "colIndex": 18, "dataIndex": "partner", "editable": true, "editor": partner3738, "filter": { "type": "string" }, "header": "Partner", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(users.MySettings.partner) Pointer to the Partner instance related to\nthis user.") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "Pointer to the Partner instance related to\nthis user.", "width": Lino.chars2width(21) } ];
    Lino.users.MySettings.GridPanel.superclass.initComponent.call(this);
  }
});


Lino.users.MySettings.insertPanel = Ext.extend(Lino.users.AllUsers.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/users/MySettings",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.users.MySettings.detail;
    this.ls_insert_handler = Lino.users.MySettings.insert;
    Lino.users.MySettings.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.users.MySettings.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/users/MySettings" };
  return new Lino.users.MySettings.insertPanel(p);
});
Lino.users.MySettings.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/MySettings", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.users.MySettings.detailPanel = Ext.extend(Lino.users.AllUsers.DetailFormPanel,{
  empty_title: "Benutzer",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Benutzer) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "change_password", "menu_item_text": "Passwort \u00e4ndern", "overflowText": "Passwort \u00e4ndern", "panel_btn_handler": Lino.param_action_handler(Lino.users.AllUsers.change_password), "text": " <font size=\"4\">\u2731</font>", "tooltip": "Change the password of this user.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_widgets", "menu_item_text": "Update widgets", "overflowText": "Update widgets", "panel_btn_handler": Lino.row_action_handler('update_widgets','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the dashboard widgets for this user.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/users/MySettings",
  initComponent : function() {
    this.ls_detail_handler = Lino.users.MySettings.detail;
    this.ls_insert_handler = Lino.users.MySettings.insert;
    Lino.users.MySettings.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.users.MySettings.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/MySettings" };
  return new Lino.users.MySettings.detailPanel(p);
});
Lino.users.MySettings.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/MySettings", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.MySettings.sign_out = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/MySettings", "GET", pk, "sign_out", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.MySettings.update_widgets = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/MySettings", "GET", pk, "update_widgets", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.MySettings.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/MySettings", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class users.Authorities
Lino.users.Authorities.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/users/Authorities",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "user" }, 'userHidden', { "name": "authorized" }, 'authorizedHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 3,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/users/Authorities','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/Authorities','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/users/Authorities','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/Authorities','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/users/Authorities','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Vollmachten",
  disabled_fields_index : 5,
  initComponent : function() {
    var ww = this.containing_window;
    var id3740 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var user3741 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/Authorities/user" }) }) });
    var authorized3742 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/Authorities/authorized" }) }) });
    this.before_row_edit = function(record) {
      authorized3742.setContextValue('user', record ? record.data['userHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof user3741 !== 'undefined' && user3741.on('change',Lino.chooser_handler(authorized3742,'user'));
      Lino.users.Authorities.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3740, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(users.Authorities.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user3741, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(users.Authorities.user) The user who gives the right of representation. author of this\nauthority") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The user who gives the right of representation. author of this\nauthority", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "authorized", "editable": true, "editor": authorized3742, "filter": { "type": "string" }, "header": "Benutzer", "listeners": { "render": Lino.quicktip_renderer("","(users.Authorities.authorized) The user who gets the right to represent the author") }, "renderer": Lino.fk_renderer('authorizedHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The user who gets the right to represent the author", "width": Lino.chars2width(21) } ];
    Lino.users.Authorities.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.users.Authorities.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/Authorities", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.Authorities.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/Authorities", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.Authorities.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/Authorities", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.Authorities.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/Authorities", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.Authorities.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/Authorities", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.Authorities.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/Authorities" };
  p.params_panel = new Lino.users.Authorities.ParamsPanel({});
  return new Lino.users.Authorities.GridPanel(p);
});

// js_render_GridPanel_class users.Sessions
Lino.users.Sessions.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/users/Sessions",
  ls_store_fields : [ { "name": "last_activity" }, { "name": "last_ip_addr" }, { "name": "username" }, { "name": "session_key" }, { "name": "expire_date" }, { "name": "workflow_buttons" }, { "name": "session_key" } ],
  ls_id_property : "session_key",
  pk_index : 6,
  content_type : 67,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/users/Sessions','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/Sessions','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/users/Sessions','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/Sessions','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/users/Sessions','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Benutzersitzungen",
  initComponent : function() {
    var ww = this.containing_window;
    var last_activity_disp3744 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var last_ip_addr_disp3745 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var username_disp3746 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var session_key_disp3747 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var expire_date_disp3748 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var workflow_buttons_disp3749 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "last_activity", "editable": false, "header": "Last activity", "listeners": { "render": Lino.quicktip_renderer("","(users.Sessions.last_activity) ") }, "sortable": false, "tooltip": "(users.Sessions.last_activity) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "last_ip_addr", "editable": false, "header": "IP-Adresse", "listeners": { "render": Lino.quicktip_renderer("","(users.Sessions.last_ip_addr) ") }, "sortable": false, "tooltip": "(users.Sessions.last_ip_addr) ", "width": Lino.chars2width(13) }, { "colIndex": 2, "dataIndex": "username", "editable": false, "header": "Benutzername", "listeners": { "render": Lino.quicktip_renderer("","(users.Sessions.username) ") }, "sortable": false, "tooltip": "(users.Sessions.username) ", "width": Lino.chars2width(13) }, { "colIndex": 3, "dataIndex": "session_key", "editable": false, "header": "Sitzungs-ID", "listeners": { "render": Lino.quicktip_renderer("","(users.Sessions.session_key) ") }, "sortable": false, "tooltip": "(users.Sessions.session_key) ", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "expire_date", "editable": false, "header": "Expires", "listeners": { "render": Lino.quicktip_renderer("","(users.Sessions.expire_date) ") }, "sortable": false, "tooltip": "(users.Sessions.expire_date) ", "width": Lino.chars2width(31) }, { "colIndex": 5, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(users.Sessions.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) } ];
    Lino.users.Sessions.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.users.Sessions.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/Sessions", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.Sessions.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/Sessions", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.Sessions.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/Sessions", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.Sessions.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/Sessions", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.Sessions.grid = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(12), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(90) }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/Sessions" };
  return new Lino.users.Sessions.GridPanel(p);
});
Lino.users.Sessions.kill_session = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/Sessions", "GET", pk, "kill_session", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.Slots
Lino.courses.Slots.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/Slots",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "seqno", "type": "int", "useNull": true }, { "name": "start_time" }, { "name": "end_time" }, { "name": "name" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 47,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/Slots','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Slots','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Slots','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Slots','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/Slots','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Timetable Slot) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Timetable Slots",
  disabled_fields_index : 5,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Slots.detail;
    this.ls_insert_handler = Lino.courses.Slots.insert;
    var ww = this.containing_window;
    var id3751 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var seqno3752 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var start_time3753 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_time3754 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var name3755 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3751, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(courses.Slots.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 1, "dataIndex": "seqno", "editable": true, "editor": seqno3752, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(courses.Slots.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 2, "dataIndex": "start_time", "editable": true, "editor": start_time3753, "header": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("","(courses.Slots.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 3, "dataIndex": "end_time", "editable": true, "editor": end_time3754, "header": "Endet um", "listeners": { "render": Lino.quicktip_renderer("","(courses.Slots.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 4, "dataIndex": "name", "editable": true, "editor": name3755, "filter": { "type": "string" }, "header": "Name", "listeners": { "render": Lino.quicktip_renderer("","(courses.Slots.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) } ];
    Lino.courses.Slots.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Slots.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Slots.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Slots.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Slots.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.Slots.insertPanel = Ext.extend(Lino.courses.Slots.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/Slots",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Slots.detail;
    this.ls_insert_handler = Lino.courses.Slots.insert;
    Lino.courses.Slots.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Slots.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/Slots" };
  return new Lino.courses.Slots.insertPanel(p);
});
Lino.courses.Slots.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Slots.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.Slots.detailPanel = Ext.extend(Lino.courses.Slots.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Timetable Slot) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/Slots",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Slots.detail;
    this.ls_insert_handler = Lino.courses.Slots.insert;
    Lino.courses.Slots.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Slots.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/Slots" };
  return new Lino.courses.Slots.detailPanel(p);
});
Lino.courses.Slots.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Slots.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/Slots" };
  return new Lino.courses.Slots.GridPanel(p);
});
Lino.courses.Slots.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Slots.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Slots.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Slots.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Slots", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.Topics
Lino.courses.Topics.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/Topics",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 48,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/Topics','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Topics','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Topics','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Topics','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/Topics','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Themen",
  disabled_fields_index : 4,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Topics.detail;
    var ww = this.containing_window;
    var id3757 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var name3758 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de3759 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr3760 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id3757, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(courses.Topics.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name3758, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(courses.Topics.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de3759, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(courses.Topics.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr3760, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(courses.Topics.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) } ];
    Lino.courses.Topics.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Topics.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Topics", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Topics.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Topics", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Topics.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Topics", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Topics.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Topics", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Topics.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Topics", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.Topics.detailPanel = Ext.extend(Lino.courses.Topics.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/Topics",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Topics.detail;
    Lino.courses.Topics.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Topics.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/Topics" };
  return new Lino.courses.Topics.detailPanel(p);
});
Lino.courses.Topics.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Topics", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Topics.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/Topics" };
  return new Lino.courses.Topics.GridPanel(p);
});
Lino.courses.Topics.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Topics", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.Lines
Lino.courses.Lines.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/Lines",
  ls_store_fields : [ { "name": "ref" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "topic" }, 'topicHidden', { "name": "course_area" }, 'course_areaHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "guest_role" }, 'guest_roleHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "id", "type": "int" }, { "name": "company" }, 'companyHidden', { "name": "contact_person" }, 'contact_personHidden', { "name": "contact_role" }, 'contact_roleHidden', { "name": "excerpt_title" }, { "name": "excerpt_title_de" }, { "name": "excerpt_title_fr" }, { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "body_template" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 15,
  content_type : 49,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/Lines','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Lines','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Lines','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Lines','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/Lines','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4tenreihe) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.courses.Lines.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aktivit\u00e4tenreihen",
  disabled_fields_index : 29,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Lines.detail;
    this.ls_insert_handler = Lino.courses.Lines.insert;
    var ww = this.containing_window;
    var ref3762 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name3763 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de3764 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr3765 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var topic3766 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Thema ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/topic" }) }) });
    var course_area3767 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.courses.ActivityLayouts });
    var event_type3768 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/event_type" }) }) });
    var guest_role3769 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Gastrolle ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/guest_role" }) }) });
    var every_unit3770 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every3771 = new Ext.form.NumberField({ "allowBlank": false, "selectOnFocus": true, "value": 1 });
    var id3772 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var company3773 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/company" }) }) });
    var contact_person3774 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/contact_person" }) }) });
    var contact_role3775 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/contact_role" }) }) });
    var excerpt_title3776 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var excerpt_title_de3777 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var excerpt_title_fr3778 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var description3779 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de3780 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr3781 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var body_template3782 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Lines/body_template" }) }) });
    this.before_row_edit = function(record) {
      contact_person3774.setContextValue('company', record ? record.data['companyHidden'] : undefined);
      description3779.refresh();
      description_de3780.refresh();
      description_fr3781.refresh();
    };
    this.onRender = function(ct, position) {
      typeof company3773 !== 'undefined' && company3773.on('change',Lino.chooser_handler(contact_person3774,'company'));
      Lino.courses.Lines.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "ref", "editable": true, "editor": ref3762, "filter": { "type": "string" }, "header": "Referenz", "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.ref) Die Referenz. Muss entweder leer oder einzig sein.") }, "sortable": true, "tooltip": "Die Referenz. Muss entweder leer oder einzig sein.", "width": Lino.chars2width(41) }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name3763, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.name) The designation of this activity line as seen by the user\ne.g. when selecting the line.") }, "sortable": true, "tooltip": "The designation of this activity line as seen by the user\ne.g. when selecting the line.", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de3764, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr3765, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "topic", "editable": true, "editor": topic3766, "filter": { "type": "string" }, "header": "Thema", "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.topic) ") }, "renderer": Lino.fk_renderer('topicHidden','Lino.courses.Topics.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "course_area", "editable": true, "editor": course_area3767, "filter": { "options": [ "Aktivit\u00e4ten" ], "type": "list" }, "header": "Layout", "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.course_area) Pointer to ActivityLayouts.  This is used only when an\napplication defines several variants of\nEnrolmentsByPupil.") }, "sortable": false, "tooltip": "Pointer to ActivityLayouts.  This is used only when an\napplication defines several variants of\nEnrolmentsByPupil.", "width": Lino.chars2width(14) }, { "colIndex": 6, "dataIndex": "event_type", "editable": true, "editor": event_type3768, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.event_type) The type of calendar entries to be generated. If this is empty, no calendar entries will be generated.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of calendar entries to be generated. If this is empty, no calendar entries will be generated.", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "guest_role", "editable": true, "editor": guest_role3769, "filter": { "type": "string" }, "header": "Anwesenheiten erfassen als", "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.guest_role) The default guest role for particpants of calendar entries for activities in this series. Leave empty if you don't want any presences management.") }, "renderer": Lino.fk_renderer('guest_roleHidden','Lino.cal.GuestRoles.detail'), "sortable": false, "tooltip": "The default guest role for particpants of calendar entries for activities in this series. Leave empty if you don't want any presences management.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "every_unit", "editable": true, "editor": every_unit3770, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.every_unit) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 9, "dataIndex": "every", "editable": true, "editor": every3771, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.every) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 10, "dataIndex": "id", "editable": true, "editor": id3772, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 11, "dataIndex": "company", "editable": true, "editor": company3773, "filter": { "type": "string" }, "header": "Organisation", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.company) Pointer to Company.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "Pointer to Company.", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "contact_person", "editable": true, "editor": contact_person3774, "filter": { "type": "string" }, "header": "Vertreten durch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.contact_person) Pointer to Person.") }, "renderer": Lino.fk_renderer('contact_personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "Pointer to Person.", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "contact_role", "editable": true, "editor": contact_role3775, "filter": { "type": "string" }, "header": "in seiner Eigenschaft als", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.contact_role) The optional Role\nof the contact_person within company.") }, "sortable": false, "tooltip": "The optional Role\nof the contact_person within company.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "excerpt_title", "editable": true, "editor": excerpt_title3776, "filter": { "type": "string" }, "header": "Excerpt title", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.excerpt_title) The text to print as title in enrolments.") }, "sortable": true, "tooltip": "The text to print as title in enrolments.", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "excerpt_title_de", "editable": true, "editor": excerpt_title_de3777, "filter": { "type": "string" }, "header": "Excerpt title (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.excerpt_title_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 16, "dataIndex": "excerpt_title_fr", "editable": true, "editor": excerpt_title_fr3778, "filter": { "type": "string" }, "header": "Excerpt title (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.excerpt_title_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 17, "dataIndex": "description", "editable": true, "editor": description3779, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 18, "dataIndex": "description_de", "editable": true, "editor": description_de3780, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 19, "dataIndex": "description_fr", "editable": true, "editor": description_fr3781, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 20, "dataIndex": "body_template", "editable": true, "editor": body_template3782, "filter": { "type": "string" }, "header": "Textk\u00f6rper-Vorlage", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Lines.body_template) The body template to use when printing an activity of this\nline.  Leave empty to use the site's default (defined by\nbody_template on the\nlino_xl.lib.excerpts.models.ExcerptType for\nCourse)") }, "sortable": false, "tooltip": "The body template to use when printing an activity of this\nline.  Leave empty to use the site's default (defined by\nbody_template on the\nlino_xl.lib.excerpts.models.ExcerptType for\nCourse)", "width": Lino.chars2width(11) } ];
    Lino.courses.Lines.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Lines.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Lines", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Lines.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Lines", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Lines.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Lines", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Lines.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Lines", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.Lines.insertPanel = Ext.extend(Lino.courses.Lines.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/Lines",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Lines.detail;
    this.ls_insert_handler = Lino.courses.Lines.insert;
    Lino.courses.Lines.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Lines.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(16), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/Lines" };
  return new Lino.courses.Lines.insertPanel(p);
});
Lino.courses.Lines.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Lines", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Lines.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Lines", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.Lines.detailPanel = Ext.extend(Lino.courses.Lines.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4tenreihe) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.courses.Lines.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/Lines",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Lines.detail;
    this.ls_insert_handler = Lino.courses.Lines.insert;
    Lino.courses.Lines.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Lines.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/Lines" };
  return new Lino.courses.Lines.detailPanel(p);
});
Lino.courses.Lines.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Lines", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Lines.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/Lines" };
  return new Lino.courses.Lines.GridPanel(p);
});
Lino.courses.Lines.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Lines", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.Activities
Lino.courses.Activities.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/Activities",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "name" }, { "name": "line" }, 'lineHidden', { "name": "teacher" }, 'teacherHidden', { "name": "room" }, 'roomHidden', { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 9,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/Activities','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Activities','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Activities','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Activities','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/Activities','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aktivit\u00e4ten",
  disabled_fields_index : 38,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Activities.detail;
    this.ls_insert_handler = Lino.courses.Activities.insert;
    var ww = this.containing_window;
    var start_date3784 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var name3785 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 100, "selectOnFocus": true });
    var line3786 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/line" }) }) });
    var teacher3787 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/teacher" }) }) });
    var room3788 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/room" }) }) });
    var workflow_buttons_disp3789 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3790 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3791 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3792 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3793 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user3794 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/user" }) }) });
    var every_unit3795 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every3796 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions3797 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday3798 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday3799 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday3800 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday3801 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday3802 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday3803 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday3804 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events3805 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var max_date3806 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var slot3807 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Activities/slot" }) }) });
    var description3808 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de3809 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr3810 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark3811 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state3812 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places3813 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var enrolments_until3814 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      description3808.refresh();
      description_de3809.refresh();
      description_fr3810.refresh();
      remark3811.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "start_date", "editable": true, "editor": start_date3784, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name3785, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "line", "editable": true, "editor": line3786, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "teacher", "editable": true, "editor": teacher3787, "filter": { "type": "string" }, "header": "Kursleiter", "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "room", "editable": true, "editor": room3788, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id3790, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "start_time", "editable": true, "editor": start_time3791, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 8, "dataIndex": "end_date", "editable": true, "editor": end_date3792, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "end_time", "editable": true, "editor": end_time3793, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "user", "editable": true, "editor": user3794, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "every_unit", "editable": true, "editor": every_unit3795, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 12, "dataIndex": "every", "editable": true, "editor": every3796, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 13, "dataIndex": "positions", "editable": true, "editor": positions3797, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 19, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 20, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 21, "dataIndex": "max_events", "editable": true, "editor": max_events3805, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 22, "dataIndex": "max_date", "editable": true, "editor": max_date3806, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 23, "dataIndex": "slot", "editable": true, "editor": slot3807, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "description", "editable": true, "editor": description3808, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 25, "dataIndex": "description_de", "editable": true, "editor": description_de3809, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 26, "dataIndex": "description_fr", "editable": true, "editor": description_fr3810, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 27, "dataIndex": "remark", "editable": true, "editor": remark3811, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 28, "dataIndex": "state", "editable": true, "editor": state3812, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 29, "dataIndex": "max_places", "editable": true, "editor": max_places3813, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 30, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until3814, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Activities.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.courses.Activities.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Activities.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Activities.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Activities.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Activities.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.Activities.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/Activities",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Activities.detail;
    this.ls_insert_handler = Lino.courses.Activities.insert;
    Lino.courses.Activities.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Activities.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/Activities" };
  return new Lino.courses.Activities.insertPanel(p);
});
Lino.courses.Activities.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Activities.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.Activities.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/Activities",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Activities.detail;
    this.ls_insert_handler = Lino.courses.Activities.insert;
    Lino.courses.Activities.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Activities.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/Activities" };
  return new Lino.courses.Activities.detailPanel(p);
});
Lino.courses.Activities.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Activities.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Activities.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Activities.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/Activities" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.Activities.GridPanel(p);
});
Lino.courses.Activities.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Activities.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Activities", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.ActivitiesByLayout
Lino.courses.ActivitiesByLayout.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/ActivitiesByLayout",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "name" }, { "name": "line" }, 'lineHidden', { "name": "teacher" }, 'teacherHidden', { "name": "room" }, 'roomHidden', { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 9,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByLayout','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByLayout','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByLayout','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByLayout','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByLayout','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aktivit\u00e4ten",
  disabled_fields_index : 38,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByLayout.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesByLayout.insert;
    var ww = this.containing_window;
    var start_date3816 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var name3817 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 100, "selectOnFocus": true });
    var line3818 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByLayout/line" }) }) });
    var teacher3819 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByLayout/teacher" }) }) });
    var room3820 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByLayout/room" }) }) });
    var workflow_buttons_disp3821 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3822 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3823 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3824 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3825 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user3826 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByLayout/user" }) }) });
    var every_unit3827 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every3828 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions3829 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday3830 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday3831 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday3832 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday3833 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday3834 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday3835 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday3836 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events3837 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var max_date3838 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var slot3839 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByLayout/slot" }) }) });
    var description3840 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de3841 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr3842 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark3843 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state3844 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places3845 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var enrolments_until3846 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      description3840.refresh();
      description_de3841.refresh();
      description_fr3842.refresh();
      remark3843.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "start_date", "editable": true, "editor": start_date3816, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name3817, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "line", "editable": true, "editor": line3818, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "teacher", "editable": true, "editor": teacher3819, "filter": { "type": "string" }, "header": "Kursleiter", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "room", "editable": true, "editor": room3820, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id3822, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "start_time", "editable": true, "editor": start_time3823, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 8, "dataIndex": "end_date", "editable": true, "editor": end_date3824, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "end_time", "editable": true, "editor": end_time3825, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "user", "editable": true, "editor": user3826, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "every_unit", "editable": true, "editor": every_unit3827, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 12, "dataIndex": "every", "editable": true, "editor": every3828, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 13, "dataIndex": "positions", "editable": true, "editor": positions3829, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 19, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 20, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 21, "dataIndex": "max_events", "editable": true, "editor": max_events3837, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 22, "dataIndex": "max_date", "editable": true, "editor": max_date3838, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 23, "dataIndex": "slot", "editable": true, "editor": slot3839, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "description", "editable": true, "editor": description3840, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 25, "dataIndex": "description_de", "editable": true, "editor": description_de3841, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 26, "dataIndex": "description_fr", "editable": true, "editor": description_fr3842, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 27, "dataIndex": "remark", "editable": true, "editor": remark3843, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 28, "dataIndex": "state", "editable": true, "editor": state3844, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 29, "dataIndex": "max_places", "editable": true, "editor": max_places3845, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 30, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until3846, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLayout.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.courses.ActivitiesByLayout.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByLayout.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLayout.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLayout.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLayout.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActivitiesByLayout.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/ActivitiesByLayout",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByLayout.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesByLayout.insert;
    Lino.courses.ActivitiesByLayout.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByLayout.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/ActivitiesByLayout" };
  return new Lino.courses.ActivitiesByLayout.insertPanel(p);
});
Lino.courses.ActivitiesByLayout.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLayout.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActivitiesByLayout.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/ActivitiesByLayout",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByLayout.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesByLayout.insert;
    Lino.courses.ActivitiesByLayout.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByLayout.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivitiesByLayout" };
  return new Lino.courses.ActivitiesByLayout.detailPanel(p);
});
Lino.courses.ActivitiesByLayout.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLayout.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLayout.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLayout.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivitiesByLayout" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.ActivitiesByLayout.GridPanel(p);
});
Lino.courses.ActivitiesByLayout.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLayout.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLayout", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.AllActivities
Lino.courses.AllActivities.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/AllActivities",
  ls_store_fields : [ { "name": "line" }, 'lineHidden', { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "teacher" }, 'teacherHidden', { "name": "user" }, 'userHidden', { "name": "weekdays_text" }, { "name": "times_text" }, { "name": "id", "type": "int" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "name": "room" }, 'roomHidden', { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "name": "name" }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 9,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/AllActivities','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/AllActivities','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/AllActivities','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/AllActivities','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/AllActivities','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aktivit\u00e4ten",
  disabled_fields_index : 39,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.AllActivities.detail;
    this.ls_insert_handler = Lino.courses.AllActivities.insert;
    var ww = this.containing_window;
    var line3848 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/AllActivities/line" }) }) });
    var start_date3849 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var teacher3850 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/AllActivities/teacher" }) }) });
    var user3851 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/AllActivities/user" }) }) });
    var weekdays_text_disp3852 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var times_text_disp3853 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3854 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3855 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3856 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3857 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var every_unit3858 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every3859 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions3860 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday3861 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday3862 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday3863 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday3864 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday3865 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday3866 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday3867 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events3868 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var room3869 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/AllActivities/room" }) }) });
    var max_date3870 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var slot3871 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/AllActivities/slot" }) }) });
    var description3872 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de3873 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr3874 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark3875 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state3876 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places3877 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var name3878 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 100, "selectOnFocus": true });
    var enrolments_until3879 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      description3872.refresh();
      description_de3873.refresh();
      description_fr3874.refresh();
      remark3875.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "line", "editable": true, "editor": line3848, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "start_date", "editable": true, "editor": start_date3849, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(9), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "teacher", "editable": true, "editor": teacher3850, "filter": { "type": "string" }, "header": "Kursleiter", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "user", "editable": true, "editor": user3851, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "weekdays_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.weekdays_text) A virtual field returning the textual formulation of the\nweekdays where the recurrence occurs.") }, "sortable": false, "tooltip": "A virtual field returning the textual formulation of the\nweekdays where the recurrence occurs.", "width": Lino.chars2width(11) }, { "colIndex": 5, "dataIndex": "times_text", "editable": false, "header": "Uhrzeiten", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.times_text) ") }, "sortable": false, "tooltip": "(courses.AllActivities.times_text) ", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id3854, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "start_time", "editable": true, "editor": start_time3855, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 8, "dataIndex": "end_date", "editable": true, "editor": end_date3856, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "end_time", "editable": true, "editor": end_time3857, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "every_unit", "editable": true, "editor": every_unit3858, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 11, "dataIndex": "every", "editable": true, "editor": every3859, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 12, "dataIndex": "positions", "editable": true, "editor": positions3860, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 13, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 14, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 19, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 20, "dataIndex": "max_events", "editable": true, "editor": max_events3868, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 21, "dataIndex": "room", "editable": true, "editor": room3869, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 22, "dataIndex": "max_date", "editable": true, "editor": max_date3870, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 23, "dataIndex": "slot", "editable": true, "editor": slot3871, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "description", "editable": true, "editor": description3872, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 25, "dataIndex": "description_de", "editable": true, "editor": description_de3873, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 26, "dataIndex": "description_fr", "editable": true, "editor": description_fr3874, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 27, "dataIndex": "remark", "editable": true, "editor": remark3875, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 28, "dataIndex": "state", "editable": true, "editor": state3876, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 29, "dataIndex": "max_places", "editable": true, "editor": max_places3877, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 30, "dataIndex": "name", "editable": true, "editor": name3878, "filter": { "type": "string" }, "header": "Bezeichnung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 31, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until3879, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllActivities.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.courses.AllActivities.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.AllActivities.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllActivities.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllActivities.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllActivities.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.AllActivities.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/AllActivities",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.AllActivities.detail;
    this.ls_insert_handler = Lino.courses.AllActivities.insert;
    Lino.courses.AllActivities.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.AllActivities.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/AllActivities" };
  return new Lino.courses.AllActivities.insertPanel(p);
});
Lino.courses.AllActivities.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllActivities.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.AllActivities.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/AllActivities",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.AllActivities.detail;
    this.ls_insert_handler = Lino.courses.AllActivities.insert;
    Lino.courses.AllActivities.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.AllActivities.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/AllActivities" };
  return new Lino.courses.AllActivities.detailPanel(p);
});
Lino.courses.AllActivities.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllActivities.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllActivities.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllActivities.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/AllActivities" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.AllActivities.GridPanel(p);
});
Lino.courses.AllActivities.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllActivities.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllActivities", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.MyActivities
Lino.courses.MyActivities.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/MyActivities",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "room" }, 'roomHidden', { "name": "name" }, { "name": "line" }, 'lineHidden', { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "teacher" }, 'teacherHidden', { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/MyActivities','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/MyActivities','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/MyActivities','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/MyActivities','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/MyActivities','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Meine Aktivit\u00e4ten",
  disabled_fields_index : 38,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.MyActivities.detail;
    this.ls_insert_handler = Lino.courses.MyActivities.insert;
    var ww = this.containing_window;
    var start_date3881 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var room3882 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/MyActivities/room" }) }) });
    var name3883 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 100, "selectOnFocus": true });
    var line3884 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/MyActivities/line" }) }) });
    var workflow_buttons_disp3885 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id3886 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3887 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3888 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3889 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user3890 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/MyActivities/user" }) }) });
    var every_unit3891 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every3892 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions3893 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday3894 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday3895 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday3896 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday3897 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday3898 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday3899 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday3900 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events3901 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var max_date3902 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var teacher3903 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/MyActivities/teacher" }) }) });
    var slot3904 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/MyActivities/slot" }) }) });
    var description3905 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de3906 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr3907 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark3908 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state3909 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places3910 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var enrolments_until3911 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      description3905.refresh();
      description_de3906.refresh();
      description_fr3907.refresh();
      remark3908.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "start_date", "editable": true, "editor": start_date3881, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(9), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "room", "editable": true, "editor": room3882, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "name", "editable": true, "editor": name3883, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "line", "editable": true, "editor": line3884, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id3886, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "start_time", "editable": true, "editor": start_time3887, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 7, "dataIndex": "end_date", "editable": true, "editor": end_date3888, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "end_time", "editable": true, "editor": end_time3889, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "user", "editable": true, "editor": user3890, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "every_unit", "editable": true, "editor": every_unit3891, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 11, "dataIndex": "every", "editable": true, "editor": every3892, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 12, "dataIndex": "positions", "editable": true, "editor": positions3893, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 13, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 14, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 19, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 20, "dataIndex": "max_events", "editable": true, "editor": max_events3901, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 21, "dataIndex": "max_date", "editable": true, "editor": max_date3902, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 22, "dataIndex": "teacher", "editable": true, "editor": teacher3903, "filter": { "type": "string" }, "header": "Kursleiter", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "slot", "editable": true, "editor": slot3904, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "description", "editable": true, "editor": description3905, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 25, "dataIndex": "description_de", "editable": true, "editor": description_de3906, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 26, "dataIndex": "description_fr", "editable": true, "editor": description_fr3907, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 27, "dataIndex": "remark", "editable": true, "editor": remark3908, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 28, "dataIndex": "state", "editable": true, "editor": state3909, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 29, "dataIndex": "max_places", "editable": true, "editor": max_places3910, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 30, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until3911, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.MyActivities.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.courses.MyActivities.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.MyActivities.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.MyActivities.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.MyActivities.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.MyActivities.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.MyActivities.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/MyActivities",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.MyActivities.detail;
    this.ls_insert_handler = Lino.courses.MyActivities.insert;
    Lino.courses.MyActivities.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.MyActivities.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/MyActivities" };
  return new Lino.courses.MyActivities.insertPanel(p);
});
Lino.courses.MyActivities.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.MyActivities.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.MyActivities.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/MyActivities",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.MyActivities.detail;
    this.ls_insert_handler = Lino.courses.MyActivities.insert;
    Lino.courses.MyActivities.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.MyActivities.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/MyActivities" };
  return new Lino.courses.MyActivities.detailPanel(p);
});
Lino.courses.MyActivities.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.MyActivities.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.MyActivities.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.MyActivities.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/MyActivities" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.MyActivities.GridPanel(p);
});
Lino.courses.MyActivities.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.MyActivities.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/MyActivities", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.DraftActivities
Lino.courses.DraftActivities.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/DraftActivities",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "room" }, 'roomHidden', { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "line" }, 'lineHidden', { "name": "teacher" }, 'teacherHidden', { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "name": "name" }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/DraftActivities','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/DraftActivities','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/DraftActivities','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/DraftActivities','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/DraftActivities','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Draft activities",
  disabled_fields_index : 38,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.DraftActivities.detail;
    this.ls_insert_handler = Lino.courses.DraftActivities.insert;
    var ww = this.containing_window;
    var detail_link_disp3913 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var room3914 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/DraftActivities/room" }) }) });
    var id3915 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date3916 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3917 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3918 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3919 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user3920 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/DraftActivities/user" }) }) });
    var every_unit3921 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every3922 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions3923 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday3924 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday3925 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday3926 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday3927 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday3928 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday3929 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday3930 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events3931 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var max_date3932 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var line3933 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/DraftActivities/line" }) }) });
    var teacher3934 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/DraftActivities/teacher" }) }) });
    var slot3935 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/DraftActivities/slot" }) }) });
    var description3936 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de3937 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr3938 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark3939 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state3940 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places3941 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var name3942 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 100, "selectOnFocus": true });
    var enrolments_until3943 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      description3936.refresh();
      description_de3937.refresh();
      description_fr3938.refresh();
      remark3939.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.detail_link) ") }, "sortable": false, "tooltip": "(courses.DraftActivities.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "room", "editable": true, "editor": room3914, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 2, "dataIndex": "id", "editable": true, "editor": id3915, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "start_date", "editable": true, "editor": start_date3916, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 4, "dataIndex": "start_time", "editable": true, "editor": start_time3917, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 5, "dataIndex": "end_date", "editable": true, "editor": end_date3918, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 6, "dataIndex": "end_time", "editable": true, "editor": end_time3919, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 7, "dataIndex": "user", "editable": true, "editor": user3920, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "every_unit", "editable": true, "editor": every_unit3921, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 9, "dataIndex": "every", "editable": true, "editor": every3922, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 10, "dataIndex": "positions", "editable": true, "editor": positions3923, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 11, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 12, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 13, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 14, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 18, "dataIndex": "max_events", "editable": true, "editor": max_events3931, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 19, "dataIndex": "max_date", "editable": true, "editor": max_date3932, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 20, "dataIndex": "line", "editable": true, "editor": line3933, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 21, "dataIndex": "teacher", "editable": true, "editor": teacher3934, "filter": { "type": "string" }, "header": "Kursleiter", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 22, "dataIndex": "slot", "editable": true, "editor": slot3935, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "description", "editable": true, "editor": description3936, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 24, "dataIndex": "description_de", "editable": true, "editor": description_de3937, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 25, "dataIndex": "description_fr", "editable": true, "editor": description_fr3938, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 26, "dataIndex": "remark", "editable": true, "editor": remark3939, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 27, "dataIndex": "state", "editable": true, "editor": state3940, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 28, "dataIndex": "max_places", "editable": true, "editor": max_places3941, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 29, "dataIndex": "name", "editable": true, "editor": name3942, "filter": { "type": "string" }, "header": "Bezeichnung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 30, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until3943, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.DraftActivities.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.courses.DraftActivities.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.DraftActivities.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.DraftActivities.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.DraftActivities.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.DraftActivities.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.DraftActivities.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/DraftActivities",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.DraftActivities.detail;
    this.ls_insert_handler = Lino.courses.DraftActivities.insert;
    Lino.courses.DraftActivities.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.DraftActivities.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/DraftActivities" };
  return new Lino.courses.DraftActivities.insertPanel(p);
});
Lino.courses.DraftActivities.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.DraftActivities.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.DraftActivities.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/DraftActivities",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.DraftActivities.detail;
    this.ls_insert_handler = Lino.courses.DraftActivities.insert;
    Lino.courses.DraftActivities.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.DraftActivities.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/DraftActivities" };
  return new Lino.courses.DraftActivities.detailPanel(p);
});
Lino.courses.DraftActivities.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.DraftActivities.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.DraftActivities.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.DraftActivities.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/DraftActivities" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.DraftActivities.GridPanel(p);
});
Lino.courses.DraftActivities.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.DraftActivities.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/DraftActivities", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.ActiveActivities
Lino.courses.ActiveActivities.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/ActiveActivities",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "enrolments" }, { "name": "free_places", "type": "int", "useNull": true }, { "name": "teacher" }, 'teacherHidden', { "name": "room" }, 'roomHidden', { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "line" }, 'lineHidden', { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "name": "name" }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/ActiveActivities','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActiveActivities','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActiveActivities','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActiveActivities','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/ActiveActivities','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Current activities",
  disabled_fields_index : 40,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActiveActivities.detail;
    this.ls_insert_handler = Lino.courses.ActiveActivities.insert;
    var ww = this.containing_window;
    var detail_link_disp3945 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var enrolments3946 = new Ext.form.NumberField({ "disabled": true });
    var free_places3947 = new Ext.form.NumberField({ "disabled": true });
    var teacher3948 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActiveActivities/teacher" }) }) });
    var room3949 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActiveActivities/room" }) }) });
    var id3950 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date3951 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3952 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3953 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3954 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user3955 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActiveActivities/user" }) }) });
    var every_unit3956 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every3957 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions3958 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday3959 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday3960 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday3961 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday3962 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday3963 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday3964 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday3965 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events3966 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var max_date3967 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var line3968 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActiveActivities/line" }) }) });
    var slot3969 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActiveActivities/slot" }) }) });
    var description3970 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de3971 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr3972 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark3973 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state3974 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places3975 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var name3976 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 100, "selectOnFocus": true });
    var enrolments_until3977 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      description3970.refresh();
      description_de3971.refresh();
      description_fr3972.refresh();
      remark3973.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.detail_link) ") }, "sortable": false, "tooltip": "(courses.ActiveActivities.detail_link) ", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 1, "dataIndex": "enrolments", "editable": false, "format": "0", "header": "Einschreibungen", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.enrolments) ") }, "sortable": true, "tooltip": "(courses.ActiveActivities.enrolments) ", "width": Lino.chars2width(9), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 2, "dataIndex": "free_places", "editable": false, "format": "0", "header": "Freie Pl\u00e4tze", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.free_places) Number of free places.") }, "sortable": true, "tooltip": "Number of free places.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "teacher", "editable": true, "editor": teacher3948, "filter": { "type": "string" }, "header": "Kursleiter", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "room", "editable": true, "editor": room3949, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id3950, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "start_date", "editable": true, "editor": start_date3951, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 7, "dataIndex": "start_time", "editable": true, "editor": start_time3952, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 8, "dataIndex": "end_date", "editable": true, "editor": end_date3953, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "end_time", "editable": true, "editor": end_time3954, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "user", "editable": true, "editor": user3955, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "every_unit", "editable": true, "editor": every_unit3956, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 12, "dataIndex": "every", "editable": true, "editor": every3957, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 13, "dataIndex": "positions", "editable": true, "editor": positions3958, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 19, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 20, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 21, "dataIndex": "max_events", "editable": true, "editor": max_events3966, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 22, "dataIndex": "max_date", "editable": true, "editor": max_date3967, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 23, "dataIndex": "line", "editable": true, "editor": line3968, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "slot", "editable": true, "editor": slot3969, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 25, "dataIndex": "description", "editable": true, "editor": description3970, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 26, "dataIndex": "description_de", "editable": true, "editor": description_de3971, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 27, "dataIndex": "description_fr", "editable": true, "editor": description_fr3972, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 28, "dataIndex": "remark", "editable": true, "editor": remark3973, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 29, "dataIndex": "state", "editable": true, "editor": state3974, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 30, "dataIndex": "max_places", "editable": true, "editor": max_places3975, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 31, "dataIndex": "name", "editable": true, "editor": name3976, "filter": { "type": "string" }, "header": "Bezeichnung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 32, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until3977, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActiveActivities.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.courses.ActiveActivities.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActiveActivities.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActiveActivities.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActiveActivities.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActiveActivities.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActiveActivities.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/ActiveActivities",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActiveActivities.detail;
    this.ls_insert_handler = Lino.courses.ActiveActivities.insert;
    Lino.courses.ActiveActivities.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActiveActivities.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/ActiveActivities" };
  return new Lino.courses.ActiveActivities.insertPanel(p);
});
Lino.courses.ActiveActivities.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActiveActivities.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActiveActivities.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/ActiveActivities",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActiveActivities.detail;
    this.ls_insert_handler = Lino.courses.ActiveActivities.insert;
    Lino.courses.ActiveActivities.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActiveActivities.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActiveActivities" };
  return new Lino.courses.ActiveActivities.detailPanel(p);
});
Lino.courses.ActiveActivities.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActiveActivities.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActiveActivities.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActiveActivities.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActiveActivities" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.ActiveActivities.GridPanel(p);
});
Lino.courses.ActiveActivities.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActiveActivities.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActiveActivities", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.InactiveActivities
Lino.courses.InactiveActivities.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/InactiveActivities",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "enrolments" }, { "name": "free_places", "type": "int", "useNull": true }, { "name": "room" }, 'roomHidden', { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "line" }, 'lineHidden', { "name": "teacher" }, 'teacherHidden', { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "name": "name" }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/InactiveActivities','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/InactiveActivities','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/InactiveActivities','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/InactiveActivities','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/InactiveActivities','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Inaktive Kurse",
  disabled_fields_index : 40,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.InactiveActivities.detail;
    this.ls_insert_handler = Lino.courses.InactiveActivities.insert;
    var ww = this.containing_window;
    var detail_link_disp3979 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var enrolments3980 = new Ext.form.NumberField({ "disabled": true });
    var free_places3981 = new Ext.form.NumberField({ "disabled": true });
    var room3982 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/InactiveActivities/room" }) }) });
    var id3983 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date3984 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time3985 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date3986 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time3987 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user3988 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/InactiveActivities/user" }) }) });
    var every_unit3989 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every3990 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions3991 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday3992 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday3993 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday3994 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday3995 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday3996 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday3997 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday3998 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events3999 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var max_date4000 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var line4001 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/InactiveActivities/line" }) }) });
    var teacher4002 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/InactiveActivities/teacher" }) }) });
    var slot4003 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/InactiveActivities/slot" }) }) });
    var description4004 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de4005 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr4006 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark4007 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state4008 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places4009 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var name4010 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 100, "selectOnFocus": true });
    var enrolments_until4011 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      description4004.refresh();
      description_de4005.refresh();
      description_fr4006.refresh();
      remark4007.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.detail_link) ") }, "sortable": false, "tooltip": "(courses.InactiveActivities.detail_link) ", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 1, "dataIndex": "enrolments", "editable": false, "format": "0", "header": "Einschreibungen", "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.enrolments) ") }, "sortable": true, "tooltip": "(courses.InactiveActivities.enrolments) ", "width": Lino.chars2width(9), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 2, "dataIndex": "free_places", "editable": false, "format": "0", "header": "Freie Pl\u00e4tze", "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.free_places) Number of free places.") }, "sortable": true, "tooltip": "Number of free places.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "room", "editable": true, "editor": room3982, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id3983, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "start_date", "editable": true, "editor": start_date3984, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 6, "dataIndex": "start_time", "editable": true, "editor": start_time3985, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 7, "dataIndex": "end_date", "editable": true, "editor": end_date3986, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "end_time", "editable": true, "editor": end_time3987, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "user", "editable": true, "editor": user3988, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "every_unit", "editable": true, "editor": every_unit3989, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 11, "dataIndex": "every", "editable": true, "editor": every3990, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 12, "dataIndex": "positions", "editable": true, "editor": positions3991, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 13, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 14, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 19, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 20, "dataIndex": "max_events", "editable": true, "editor": max_events3999, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 21, "dataIndex": "max_date", "editable": true, "editor": max_date4000, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 22, "dataIndex": "line", "editable": true, "editor": line4001, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "teacher", "editable": true, "editor": teacher4002, "filter": { "type": "string" }, "header": "Kursleiter", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "slot", "editable": true, "editor": slot4003, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 25, "dataIndex": "description", "editable": true, "editor": description4004, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 26, "dataIndex": "description_de", "editable": true, "editor": description_de4005, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 27, "dataIndex": "description_fr", "editable": true, "editor": description_fr4006, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 28, "dataIndex": "remark", "editable": true, "editor": remark4007, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 29, "dataIndex": "state", "editable": true, "editor": state4008, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 30, "dataIndex": "max_places", "editable": true, "editor": max_places4009, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 31, "dataIndex": "name", "editable": true, "editor": name4010, "filter": { "type": "string" }, "header": "Bezeichnung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 32, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until4011, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.InactiveActivities.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.courses.InactiveActivities.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.InactiveActivities.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.InactiveActivities.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.InactiveActivities.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.InactiveActivities.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.InactiveActivities.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/InactiveActivities",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.InactiveActivities.detail;
    this.ls_insert_handler = Lino.courses.InactiveActivities.insert;
    Lino.courses.InactiveActivities.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.InactiveActivities.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/InactiveActivities" };
  return new Lino.courses.InactiveActivities.insertPanel(p);
});
Lino.courses.InactiveActivities.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.InactiveActivities.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.InactiveActivities.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/InactiveActivities",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.InactiveActivities.detail;
    this.ls_insert_handler = Lino.courses.InactiveActivities.insert;
    Lino.courses.InactiveActivities.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.InactiveActivities.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/InactiveActivities" };
  return new Lino.courses.InactiveActivities.detailPanel(p);
});
Lino.courses.InactiveActivities.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.InactiveActivities.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.InactiveActivities.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.InactiveActivities.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/InactiveActivities" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.InactiveActivities.GridPanel(p);
});
Lino.courses.InactiveActivities.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.InactiveActivities.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/InactiveActivities", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.ClosedActivities
Lino.courses.ClosedActivities.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/ClosedActivities",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "enrolments" }, { "name": "room" }, 'roomHidden', { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "line" }, 'lineHidden', { "name": "teacher" }, 'teacherHidden', { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "name": "name" }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/ClosedActivities','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ClosedActivities','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ClosedActivities','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ClosedActivities','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/ClosedActivities','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Abgeschlossene Kurse",
  disabled_fields_index : 39,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ClosedActivities.detail;
    this.ls_insert_handler = Lino.courses.ClosedActivities.insert;
    var ww = this.containing_window;
    var detail_link_disp4013 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var enrolments4014 = new Ext.form.NumberField({ "disabled": true });
    var room4015 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ClosedActivities/room" }) }) });
    var id4016 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date4017 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time4018 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date4019 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time4020 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user4021 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ClosedActivities/user" }) }) });
    var every_unit4022 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every4023 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions4024 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday4025 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday4026 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday4027 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday4028 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday4029 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday4030 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday4031 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events4032 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var max_date4033 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var line4034 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ClosedActivities/line" }) }) });
    var teacher4035 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ClosedActivities/teacher" }) }) });
    var slot4036 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ClosedActivities/slot" }) }) });
    var description4037 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de4038 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr4039 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark4040 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state4041 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places4042 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var name4043 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 100, "selectOnFocus": true });
    var enrolments_until4044 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
      description4037.refresh();
      description_de4038.refresh();
      description_fr4039.refresh();
      remark4040.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.detail_link) ") }, "sortable": false, "tooltip": "(courses.ClosedActivities.detail_link) ", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 1, "dataIndex": "enrolments", "editable": false, "format": "0", "header": "Einschreibungen", "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.enrolments) ") }, "sortable": true, "tooltip": "(courses.ClosedActivities.enrolments) ", "width": Lino.chars2width(9), "xtype": "numbercolumn" }, { "colIndex": 2, "dataIndex": "room", "editable": true, "editor": room4015, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id4016, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "start_date", "editable": true, "editor": start_date4017, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 5, "dataIndex": "start_time", "editable": true, "editor": start_time4018, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 6, "dataIndex": "end_date", "editable": true, "editor": end_date4019, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 7, "dataIndex": "end_time", "editable": true, "editor": end_time4020, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 8, "dataIndex": "user", "editable": true, "editor": user4021, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "every_unit", "editable": true, "editor": every_unit4022, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 10, "dataIndex": "every", "editable": true, "editor": every4023, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 11, "dataIndex": "positions", "editable": true, "editor": positions4024, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 12, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 13, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 14, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 19, "dataIndex": "max_events", "editable": true, "editor": max_events4032, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 20, "dataIndex": "max_date", "editable": true, "editor": max_date4033, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 21, "dataIndex": "line", "editable": true, "editor": line4034, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 22, "dataIndex": "teacher", "editable": true, "editor": teacher4035, "filter": { "type": "string" }, "header": "Kursleiter", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "slot", "editable": true, "editor": slot4036, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "description", "editable": true, "editor": description4037, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 25, "dataIndex": "description_de", "editable": true, "editor": description_de4038, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 26, "dataIndex": "description_fr", "editable": true, "editor": description_fr4039, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 27, "dataIndex": "remark", "editable": true, "editor": remark4040, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 28, "dataIndex": "state", "editable": true, "editor": state4041, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 29, "dataIndex": "max_places", "editable": true, "editor": max_places4042, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 30, "dataIndex": "name", "editable": true, "editor": name4043, "filter": { "type": "string" }, "header": "Bezeichnung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 31, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until4044, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ClosedActivities.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.courses.ClosedActivities.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ClosedActivities.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ClosedActivities.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ClosedActivities.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ClosedActivities.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ClosedActivities.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/ClosedActivities",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ClosedActivities.detail;
    this.ls_insert_handler = Lino.courses.ClosedActivities.insert;
    Lino.courses.ClosedActivities.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ClosedActivities.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/ClosedActivities" };
  return new Lino.courses.ClosedActivities.insertPanel(p);
});
Lino.courses.ClosedActivities.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ClosedActivities.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ClosedActivities.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/ClosedActivities",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ClosedActivities.detail;
    this.ls_insert_handler = Lino.courses.ClosedActivities.insert;
    Lino.courses.ClosedActivities.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ClosedActivities.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ClosedActivities" };
  return new Lino.courses.ClosedActivities.detailPanel(p);
});
Lino.courses.ClosedActivities.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ClosedActivities.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ClosedActivities.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ClosedActivities.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ClosedActivities" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.ClosedActivities.GridPanel(p);
});
Lino.courses.ClosedActivities.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ClosedActivities.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ClosedActivities", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.Enrolments
Lino.courses.Enrolments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/Enrolments",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "request_date", "type": "date" }, { "name": "course" }, 'courseHidden', { "name": "course__state" }, 'course__stateHidden', { "name": "pupil" }, 'pupilHidden', { "name": "workflow_buttons" }, { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "printed_by" }, 'printed_byHidden', { "name": "course_area" }, 'course_areaHidden', { "name": "state" }, 'stateHidden', { "name": "places", "type": "int", "useNull": true }, { "name": "remark" }, { "name": "confirmation_details" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 10,
  content_type : 51,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/Enrolments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Enrolments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Enrolments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/Enrolments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/Enrolments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Einschreibungen",
  disabled_fields_index : 22,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Enrolments.detail;
    this.ls_insert_handler = Lino.courses.Enrolments.insert;
    var ww = this.containing_window;
    var request_date4046 = new Lino.DateField({ "allowBlank": false, "selectOnFocus": true });
    var course4047 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Aktivit\u00e4t ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Activities", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Enrolments/course" }) }) });
    var course__state4048 = new Ext.form.TextField({ "boxMinWidth": Lino.chars2width(10), "disabled": true, "maxLength": 10, "sortable": false, "value": null });
    var pupil4049 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Enrolments/pupil" }) }) });
    var workflow_buttons_disp4050 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var user4051 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/Enrolments/user" }) }) });
    var id4052 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date4053 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date4054 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var printed_by4055 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Auszug ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "excerpts.Excerpts" });
    var course_area4056 = new Lino.ChoicesFieldElement({ "disabled": true, "forceSelection": true, "hidden": true, "store": [['','<br>']].concat(Lino.courses.ActivityLayouts) });
    var state4057 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.EnrolmentStates });
    var places4058 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 1 });
    var remark4059 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var confirmation_details4060 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Details Best\u00e4tigung" });
    this.before_row_edit = function(record) {
      course4047.setContextValue('course_area', record ? record.data['course_areaHidden'] : undefined);
      course4047.setContextValue('request_date', record ? record.data['request_date'] : undefined);
      pupil4049.setContextValue('course', record ? record.data['courseHidden'] : undefined);
      confirmation_details4060.refresh();
    };
    this.onRender = function(ct, position) {
      typeof course_area4056 !== 'undefined' && course_area4056.on('change',Lino.chooser_handler(course4047,'course_area'));
      typeof request_date4046 !== 'undefined' && request_date4046.on('change',Lino.chooser_handler(course4047,'request_date'));
      typeof course4047 !== 'undefined' && course4047.on('change',Lino.chooser_handler(pupil4049,'course'));
      Lino.courses.Enrolments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "request_date", "editable": true, "editor": request_date4046, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Datum der Anfrage", "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.request_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "course", "editable": true, "editor": course4047, "filter": { "type": "string" }, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.course) ") }, "renderer": Lino.fk_renderer('courseHidden','Lino.courses.Activities.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "course__state", "editable": false, "filter": { "type": "string" }, "header": "Zustand", "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.course__state) The workflow state field.") }, "sortable": true, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "colIndex": 3, "dataIndex": "pupil", "editable": true, "editor": pupil4049, "filter": { "type": "string" }, "header": "Teilnehmer", "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.pupil) ") }, "renderer": Lino.fk_renderer('pupilHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "colIndex": 5, "dataIndex": "user", "editable": true, "editor": user4051, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id4052, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "start_date", "editable": true, "editor": start_date4053, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.start_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "end_date", "editable": true, "editor": end_date4054, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.end_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "printed_by", "editable": false, "filter": { "type": "string" }, "header": "Ausgedruckt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.printed_by) ForeignKey to the Excerpt which certifies this instance.") }, "renderer": Lino.fk_renderer('printed_byHidden','Lino.excerpts.Excerpts.detail'), "sortable": false, "tooltip": "ForeignKey to the Excerpt which certifies this instance.", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "course_area", "editable": false, "filter": { "options": [ "Aktivit\u00e4ten" ], "type": "list" }, "header": "Layout", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.course_area) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(14) }, { "colIndex": 11, "dataIndex": "state", "editable": true, "editor": state4057, "filter": { "options": [ "Angefragt", "Test", "Best\u00e4tigt", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.state) One of lino_xl.lib.courses.EnrolmentStates.") }, "sortable": false, "tooltip": "One of lino_xl.lib.courses.EnrolmentStates.", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 12, "dataIndex": "places", "editable": true, "editor": places4058, "filter": { "type": "numeric" }, "format": "0", "header": "Anz. Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.places) The number of participants in this enrolment.") }, "sortable": true, "tooltip": "The number of participants in this enrolment.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 13, "dataIndex": "remark", "editable": true, "editor": remark4059, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "confirmation_details", "editable": true, "editor": confirmation_details4060, "filter": { "type": "string" }, "header": "Details Best\u00e4tigung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.Enrolments.confirmation_details) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.courses.Enrolments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Enrolments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Enrolments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Enrolments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Enrolments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Enrolments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Enrolments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Enrolments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Enrolments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.Enrolments.insertPanel = Ext.extend(Lino.courses.Enrolments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/Enrolments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Enrolments.detail;
    this.ls_insert_handler = Lino.courses.Enrolments.insert;
    Lino.courses.Enrolments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Enrolments.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/Enrolments" };
  return new Lino.courses.Enrolments.insertPanel(p);
});
Lino.courses.Enrolments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Enrolments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.Enrolments.detailPanel = Ext.extend(Lino.courses.Enrolments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/Enrolments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.Enrolments.detail;
    this.ls_insert_handler = Lino.courses.Enrolments.insert;
    Lino.courses.Enrolments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.Enrolments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/Enrolments" };
  return new Lino.courses.Enrolments.detailPanel(p);
});
Lino.courses.Enrolments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Enrolments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Enrolments.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Enrolments", "GET", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Enrolments.clear_printed = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Enrolments", "GET", pk, "clear_printed", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.Enrolments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/Enrolments" };
  p.params_panel = new Lino.courses.Enrolments.ParamsPanel({});
  return new Lino.courses.Enrolments.GridPanel(p);
});
Lino.courses.Enrolments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/Enrolments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.AllEnrolments
Lino.courses.AllEnrolments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/AllEnrolments",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "request_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "user" }, 'userHidden', { "name": "course" }, 'courseHidden', { "name": "pupil" }, 'pupilHidden', { "name": "pupil__birth_date" }, { "name": "pupil__age" }, { "name": "pupil__country" }, 'pupil__countryHidden', { "name": "pupil__city" }, 'pupil__cityHidden', { "name": "pupil__gender" }, 'pupil__genderHidden', { "name": "printed_by" }, 'printed_byHidden', { "name": "course_area" }, 'course_areaHidden', { "name": "state" }, 'stateHidden', { "name": "places", "type": "int", "useNull": true }, { "name": "remark" }, { "name": "confirmation_details" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 51,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/AllEnrolments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/AllEnrolments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/AllEnrolments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/AllEnrolments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/AllEnrolments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Einschreibungen",
  disabled_fields_index : 27,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.AllEnrolments.detail;
    this.ls_insert_handler = Lino.courses.AllEnrolments.insert;
    var ww = this.containing_window;
    var id4062 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var request_date4063 = new Lino.DateField({ "allowBlank": false, "selectOnFocus": true });
    var start_date4064 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var end_date4065 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var user4066 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/AllEnrolments/user" }) }) });
    var course4067 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Aktivit\u00e4t ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Activities", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/AllEnrolments/course" }) }) });
    var pupil4068 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/AllEnrolments/pupil" }) }) });
    var pupil__birth_date4069 = new Lino.IncompleteDateField({ "disabled": true, "sortable": false, "value": null });
    var pupil__age_disp4070 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "sortable": false, "value": null });
    var pupil__country4071 = new Lino.RemoteComboFieldElement({ "can_create_choice": false, "disabled": true, "value": null });
    var pupil__city4072 = new Lino.RemoteComboFieldElement({ "can_create_choice": true, "disabled": true, "forceSelection": false, "value": null });
    var pupil__gender4073 = new Ext.form.TextField({ "boxMinWidth": Lino.chars2width(10), "disabled": true, "maxLength": 10, "sortable": false, "value": null });
    var printed_by4074 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Auszug ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "excerpts.Excerpts" });
    var course_area4075 = new Lino.ChoicesFieldElement({ "disabled": true, "forceSelection": true, "hidden": true, "store": [['','<br>']].concat(Lino.courses.ActivityLayouts) });
    var state4076 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.EnrolmentStates });
    var places4077 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 1 });
    var remark4078 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var confirmation_details4079 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Details Best\u00e4tigung" });
    this.before_row_edit = function(record) {
      course4067.setContextValue('course_area', record ? record.data['course_areaHidden'] : undefined);
      course4067.setContextValue('request_date', record ? record.data['request_date'] : undefined);
      pupil4068.setContextValue('course', record ? record.data['courseHidden'] : undefined);
      pupil__city4072.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      pupil__city4072.setContextValue('region', record ? record.data['regionHidden'] : undefined);
      confirmation_details4079.refresh();
    };
    this.onRender = function(ct, position) {
      typeof course_area4075 !== 'undefined' && course_area4075.on('change',Lino.chooser_handler(course4067,'course_area'));
      typeof request_date4063 !== 'undefined' && request_date4063.on('change',Lino.chooser_handler(course4067,'request_date'));
      typeof course4067 !== 'undefined' && course4067.on('change',Lino.chooser_handler(pupil4068,'course'));
      Lino.courses.AllEnrolments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id4062, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "request_date", "editable": true, "editor": request_date4063, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Datum der Anfrage", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.request_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "start_date", "editable": true, "editor": start_date4064, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.start_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 3, "dataIndex": "end_date", "editable": true, "editor": end_date4065, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.end_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 4, "dataIndex": "user", "editable": true, "editor": user4066, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "course", "editable": true, "editor": course4067, "filter": { "type": "string" }, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.course) ") }, "renderer": Lino.fk_renderer('courseHidden','Lino.courses.Activities.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "pupil", "editable": true, "editor": pupil4068, "filter": { "type": "string" }, "header": "Teilnehmer", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.pupil) ") }, "renderer": Lino.fk_renderer('pupilHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "pupil__birth_date", "editable": false, "filter": { "type": "string" }, "header": "Geburtsdatum", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.pupil__birth_date) Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".") }, "sortable": true, "tooltip": "Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".", "width": Lino.chars2width(13) }, { "colIndex": 8, "dataIndex": "pupil__age", "editable": false, "header": "Alter", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.pupil__age) Virtual field displaying the age in years.") }, "sortable": true, "tooltip": "Virtual field displaying the age in years.", "width": Lino.chars2width(31) }, { "colIndex": 9, "dataIndex": "pupil__country", "editable": false, "filter": { "type": "string" }, "header": "Land", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.pupil__country) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 10, "dataIndex": "pupil__city", "editable": false, "filter": { "type": "string" }, "header": "Ortschaft", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.pupil__city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "sortable": true, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(11) }, { "colIndex": 11, "dataIndex": "pupil__gender", "editable": false, "filter": { "type": "string" }, "header": "Geschlecht", "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.pupil__gender) The sex of this person (male or female).") }, "sortable": true, "tooltip": "The sex of this person (male or female).", "width": Lino.chars2width(12) }, { "colIndex": 12, "dataIndex": "printed_by", "editable": false, "filter": { "type": "string" }, "header": "Ausgedruckt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.printed_by) ForeignKey to the Excerpt which certifies this instance.") }, "renderer": Lino.fk_renderer('printed_byHidden','Lino.excerpts.Excerpts.detail'), "sortable": false, "tooltip": "ForeignKey to the Excerpt which certifies this instance.", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "course_area", "editable": false, "filter": { "options": [ "Aktivit\u00e4ten" ], "type": "list" }, "header": "Layout", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.course_area) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(14) }, { "colIndex": 14, "dataIndex": "state", "editable": true, "editor": state4076, "filter": { "options": [ "Angefragt", "Test", "Best\u00e4tigt", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.state) One of lino_xl.lib.courses.EnrolmentStates.") }, "sortable": false, "tooltip": "One of lino_xl.lib.courses.EnrolmentStates.", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 15, "dataIndex": "places", "editable": true, "editor": places4077, "filter": { "type": "numeric" }, "format": "0", "header": "Anz. Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.places) The number of participants in this enrolment.") }, "sortable": true, "tooltip": "The number of participants in this enrolment.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 16, "dataIndex": "remark", "editable": true, "editor": remark4078, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 17, "dataIndex": "confirmation_details", "editable": true, "editor": confirmation_details4079, "filter": { "type": "string" }, "header": "Details Best\u00e4tigung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.AllEnrolments.confirmation_details) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.courses.AllEnrolments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.AllEnrolments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllEnrolments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllEnrolments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllEnrolments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllEnrolments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllEnrolments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllEnrolments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllEnrolments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.AllEnrolments.insertPanel = Ext.extend(Lino.courses.Enrolments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/AllEnrolments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.AllEnrolments.detail;
    this.ls_insert_handler = Lino.courses.AllEnrolments.insert;
    Lino.courses.AllEnrolments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.AllEnrolments.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/AllEnrolments" };
  return new Lino.courses.AllEnrolments.insertPanel(p);
});
Lino.courses.AllEnrolments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllEnrolments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.AllEnrolments.detailPanel = Ext.extend(Lino.courses.Enrolments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/AllEnrolments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.AllEnrolments.detail;
    this.ls_insert_handler = Lino.courses.AllEnrolments.insert;
    Lino.courses.AllEnrolments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.AllEnrolments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/AllEnrolments" };
  return new Lino.courses.AllEnrolments.detailPanel(p);
});
Lino.courses.AllEnrolments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllEnrolments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllEnrolments.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllEnrolments", "GET", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllEnrolments.clear_printed = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllEnrolments", "GET", pk, "clear_printed", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.AllEnrolments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/AllEnrolments" };
  p.params_panel = new Lino.courses.Enrolments.ParamsPanel({});
  return new Lino.courses.AllEnrolments.GridPanel(p);
});
Lino.courses.AllEnrolments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/AllEnrolments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.PendingRequestedEnrolments
Lino.courses.PendingRequestedEnrolments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/PendingRequestedEnrolments",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "request_date", "type": "date" }, { "name": "course" }, 'courseHidden', { "name": "pupil" }, 'pupilHidden', { "name": "remark" }, { "name": "user" }, 'userHidden', { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 9,
  content_type : 51,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/PendingRequestedEnrolments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/PendingRequestedEnrolments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/PendingRequestedEnrolments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/PendingRequestedEnrolments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/PendingRequestedEnrolments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Offene Einschreibungsanfragen",
  disabled_fields_index : 10,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.PendingRequestedEnrolments.detail;
    this.ls_insert_handler = Lino.courses.PendingRequestedEnrolments.insert;
    var ww = this.containing_window;
    var request_date4081 = new Lino.DateField({ "allowBlank": false, "selectOnFocus": true });
    var course4082 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Aktivit\u00e4t ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Activities", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/PendingRequestedEnrolments/course" }) }) });
    var pupil4083 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/PendingRequestedEnrolments/pupil" }) }) });
    var remark4084 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var user4085 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/PendingRequestedEnrolments/user" }) }) });
    var workflow_buttons_disp4086 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
      course4082.setContextValue('course_area', record ? record.data['course_areaHidden'] : undefined);
      course4082.setContextValue('request_date', record ? record.data['request_date'] : undefined);
      pupil4083.setContextValue('course', record ? record.data['courseHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof request_date4081 !== 'undefined' && request_date4081.on('change',Lino.chooser_handler(course4082,'request_date'));
      typeof course4082 !== 'undefined' && course4082.on('change',Lino.chooser_handler(pupil4083,'course'));
      Lino.courses.PendingRequestedEnrolments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "request_date", "editable": true, "editor": request_date4081, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Datum der Anfrage", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingRequestedEnrolments.request_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "course", "editable": true, "editor": course4082, "filter": { "type": "string" }, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingRequestedEnrolments.course) ") }, "renderer": Lino.fk_renderer('courseHidden','Lino.courses.Activities.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "pupil", "editable": true, "editor": pupil4083, "filter": { "type": "string" }, "header": "Teilnehmer", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingRequestedEnrolments.pupil) ") }, "renderer": Lino.fk_renderer('pupilHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "remark", "editable": true, "editor": remark4084, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingRequestedEnrolments.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "user", "editable": true, "editor": user4085, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingRequestedEnrolments.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingRequestedEnrolments.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) } ];
    Lino.courses.PendingRequestedEnrolments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.PendingRequestedEnrolments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingRequestedEnrolments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingRequestedEnrolments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingRequestedEnrolments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingRequestedEnrolments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingRequestedEnrolments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingRequestedEnrolments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingRequestedEnrolments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.PendingRequestedEnrolments.insertPanel = Ext.extend(Lino.courses.Enrolments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/PendingRequestedEnrolments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.PendingRequestedEnrolments.detail;
    this.ls_insert_handler = Lino.courses.PendingRequestedEnrolments.insert;
    Lino.courses.PendingRequestedEnrolments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.PendingRequestedEnrolments.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/PendingRequestedEnrolments" };
  return new Lino.courses.PendingRequestedEnrolments.insertPanel(p);
});
Lino.courses.PendingRequestedEnrolments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingRequestedEnrolments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.PendingRequestedEnrolments.detailPanel = Ext.extend(Lino.courses.Enrolments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/PendingRequestedEnrolments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.PendingRequestedEnrolments.detail;
    this.ls_insert_handler = Lino.courses.PendingRequestedEnrolments.insert;
    Lino.courses.PendingRequestedEnrolments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.PendingRequestedEnrolments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/PendingRequestedEnrolments" };
  return new Lino.courses.PendingRequestedEnrolments.detailPanel(p);
});
Lino.courses.PendingRequestedEnrolments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingRequestedEnrolments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingRequestedEnrolments.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingRequestedEnrolments", "GET", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingRequestedEnrolments.clear_printed = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingRequestedEnrolments", "GET", pk, "clear_printed", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingRequestedEnrolments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/PendingRequestedEnrolments" };
  p.params_panel = new Lino.courses.Enrolments.ParamsPanel({});
  return new Lino.courses.PendingRequestedEnrolments.GridPanel(p);
});
Lino.courses.PendingRequestedEnrolments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingRequestedEnrolments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.PendingConfirmedEnrolments
Lino.courses.PendingConfirmedEnrolments.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/PendingConfirmedEnrolments",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "request_date", "type": "date" }, { "name": "course" }, 'courseHidden', { "name": "course__state" }, 'course__stateHidden', { "name": "pupil" }, 'pupilHidden', { "name": "workflow_buttons" }, { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "printed_by" }, 'printed_byHidden', { "name": "course_area" }, 'course_areaHidden', { "name": "state" }, 'stateHidden', { "name": "places", "type": "int", "useNull": true }, { "name": "remark" }, { "name": "confirmation_details" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 10,
  content_type : 51,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/PendingConfirmedEnrolments','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/PendingConfirmedEnrolments','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/PendingConfirmedEnrolments','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/PendingConfirmedEnrolments','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/PendingConfirmedEnrolments','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Auszustellende Teilnahmebescheinigungen",
  disabled_fields_index : 22,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.PendingConfirmedEnrolments.detail;
    this.ls_insert_handler = Lino.courses.PendingConfirmedEnrolments.insert;
    var ww = this.containing_window;
    var request_date4088 = new Lino.DateField({ "allowBlank": false, "selectOnFocus": true });
    var course4089 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Aktivit\u00e4t ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Activities", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/PendingConfirmedEnrolments/course" }) }) });
    var course__state4090 = new Ext.form.TextField({ "boxMinWidth": Lino.chars2width(10), "disabled": true, "maxLength": 10, "sortable": false, "value": null });
    var pupil4091 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/PendingConfirmedEnrolments/pupil" }) }) });
    var workflow_buttons_disp4092 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var user4093 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/PendingConfirmedEnrolments/user" }) }) });
    var id4094 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date4095 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date4096 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var printed_by4097 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Auszug ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "excerpts.Excerpts" });
    var course_area4098 = new Lino.ChoicesFieldElement({ "disabled": true, "forceSelection": true, "hidden": true, "store": [['','<br>']].concat(Lino.courses.ActivityLayouts) });
    var state4099 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.EnrolmentStates });
    var places4100 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 1 });
    var remark4101 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var confirmation_details4102 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Details Best\u00e4tigung" });
    this.before_row_edit = function(record) {
      course4089.setContextValue('course_area', record ? record.data['course_areaHidden'] : undefined);
      course4089.setContextValue('request_date', record ? record.data['request_date'] : undefined);
      pupil4091.setContextValue('course', record ? record.data['courseHidden'] : undefined);
      confirmation_details4102.refresh();
    };
    this.onRender = function(ct, position) {
      typeof course_area4098 !== 'undefined' && course_area4098.on('change',Lino.chooser_handler(course4089,'course_area'));
      typeof request_date4088 !== 'undefined' && request_date4088.on('change',Lino.chooser_handler(course4089,'request_date'));
      typeof course4089 !== 'undefined' && course4089.on('change',Lino.chooser_handler(pupil4091,'course'));
      Lino.courses.PendingConfirmedEnrolments.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "request_date", "editable": true, "editor": request_date4088, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Datum der Anfrage", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.request_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "course", "editable": true, "editor": course4089, "filter": { "type": "string" }, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.course) ") }, "renderer": Lino.fk_renderer('courseHidden','Lino.courses.Activities.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "course__state", "editable": false, "filter": { "type": "string" }, "header": "Zustand", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.course__state) The workflow state field.") }, "sortable": true, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "colIndex": 3, "dataIndex": "pupil", "editable": true, "editor": pupil4091, "filter": { "type": "string" }, "header": "Teilnehmer", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.pupil) ") }, "renderer": Lino.fk_renderer('pupilHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "colIndex": 5, "dataIndex": "user", "editable": true, "editor": user4093, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id4094, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "start_date", "editable": true, "editor": start_date4095, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.start_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "end_date", "editable": true, "editor": end_date4096, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.end_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "printed_by", "editable": false, "filter": { "type": "string" }, "header": "Ausgedruckt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.printed_by) ForeignKey to the Excerpt which certifies this instance.") }, "renderer": Lino.fk_renderer('printed_byHidden','Lino.excerpts.Excerpts.detail'), "sortable": false, "tooltip": "ForeignKey to the Excerpt which certifies this instance.", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "course_area", "editable": false, "filter": { "options": [ "Aktivit\u00e4ten" ], "type": "list" }, "header": "Layout", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.course_area) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(14) }, { "colIndex": 11, "dataIndex": "state", "editable": true, "editor": state4099, "filter": { "options": [ "Angefragt", "Test", "Best\u00e4tigt", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.state) One of lino_xl.lib.courses.EnrolmentStates.") }, "sortable": false, "tooltip": "One of lino_xl.lib.courses.EnrolmentStates.", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 12, "dataIndex": "places", "editable": true, "editor": places4100, "filter": { "type": "numeric" }, "format": "0", "header": "Anz. Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.places) The number of participants in this enrolment.") }, "sortable": true, "tooltip": "The number of participants in this enrolment.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 13, "dataIndex": "remark", "editable": true, "editor": remark4101, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "confirmation_details", "editable": true, "editor": confirmation_details4102, "filter": { "type": "string" }, "header": "Details Best\u00e4tigung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.PendingConfirmedEnrolments.confirmation_details) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) } ];
    Lino.courses.PendingConfirmedEnrolments.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.PendingConfirmedEnrolments.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingConfirmedEnrolments", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingConfirmedEnrolments.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingConfirmedEnrolments", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingConfirmedEnrolments.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingConfirmedEnrolments", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingConfirmedEnrolments.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingConfirmedEnrolments", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.PendingConfirmedEnrolments.insertPanel = Ext.extend(Lino.courses.Enrolments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/PendingConfirmedEnrolments",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.PendingConfirmedEnrolments.detail;
    this.ls_insert_handler = Lino.courses.PendingConfirmedEnrolments.insert;
    Lino.courses.PendingConfirmedEnrolments.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.PendingConfirmedEnrolments.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/PendingConfirmedEnrolments" };
  return new Lino.courses.PendingConfirmedEnrolments.insertPanel(p);
});
Lino.courses.PendingConfirmedEnrolments.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingConfirmedEnrolments", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.PendingConfirmedEnrolments.detailPanel = Ext.extend(Lino.courses.Enrolments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/PendingConfirmedEnrolments",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.PendingConfirmedEnrolments.detail;
    this.ls_insert_handler = Lino.courses.PendingConfirmedEnrolments.insert;
    Lino.courses.PendingConfirmedEnrolments.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.PendingConfirmedEnrolments.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/PendingConfirmedEnrolments" };
  return new Lino.courses.PendingConfirmedEnrolments.detailPanel(p);
});
Lino.courses.PendingConfirmedEnrolments.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingConfirmedEnrolments", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingConfirmedEnrolments.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingConfirmedEnrolments", "GET", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingConfirmedEnrolments.clear_printed = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingConfirmedEnrolments", "GET", pk, "clear_printed", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.PendingConfirmedEnrolments.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/PendingConfirmedEnrolments" };
  p.params_panel = new Lino.courses.Enrolments.ParamsPanel({});
  return new Lino.courses.PendingConfirmedEnrolments.GridPanel(p);
});
Lino.courses.PendingConfirmedEnrolments.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/PendingConfirmedEnrolments", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class ledger.LedgerInfoTable
Lino.ledger.LedgerInfoTable.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/ledger/LedgerInfoTable",
  ls_store_fields : [ { "name": "user" }, { "dateFormat": "d.m.Y", "name": "entry_date", "type": "date" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "user",
  pk_index : 0,
  content_type : 30,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/ledger/LedgerInfoTable','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/ledger/LedgerInfoTable','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/ledger/LedgerInfoTable','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/ledger/LedgerInfoTable','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/ledger/LedgerInfoTable','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "ledger infos",
  disabled_fields_index : 2,
  initComponent : function() {
    var ww = this.containing_window;
    var user_disp4104 = new Ext.form.DisplayField({ "disabled": true });
    var entry_date4105 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "user", "editable": false, "header": "Benutzer", "listeners": { "render": Lino.quicktip_renderer("","(ledger.LedgerInfoTable.user) OneToOneField pointing to the user.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "OneToOneField pointing to the user.", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "entry_date", "editable": true, "editor": entry_date4105, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Last entry date", "listeners": { "render": Lino.quicktip_renderer("","(ledger.LedgerInfoTable.entry_date) The last value this user typed as entry_date of a voucher.  It is the default value\nfor every new voucher.") }, "sortable": true, "tooltip": "The last value this user typed as entry_date of a voucher.  It is the default value\nfor every new voucher.", "width": Lino.chars2width(14), "xtype": "datecolumn" } ];
    Lino.ledger.LedgerInfoTable.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.ledger.LedgerInfoTable.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/LedgerInfoTable", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.LedgerInfoTable.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/LedgerInfoTable", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.LedgerInfoTable.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/LedgerInfoTable", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.LedgerInfoTable.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/LedgerInfoTable", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.LedgerInfoTable.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/LedgerInfoTable", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.LedgerInfoTable.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/ledger/LedgerInfoTable" };
  return new Lino.ledger.LedgerInfoTable.GridPanel(p);
});

// js_render_GridPanel_class countries.PlacesByPlace
Lino.countries.PlacesByPlace.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/countries/PlacesByPlace",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "type" }, 'typeHidden', { "name": "zip_code" }, { "name": "id", "type": "int" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "country" }, 'countryHidden', { "name": "show_type", "type": "boolean" }, { "name": "parent" }, 'parentHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 5,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/countries/PlacesByPlace','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/countries/PlacesByPlace','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/countries/PlacesByPlace','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/countries/PlacesByPlace','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/countries/PlacesByPlace','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Ort) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Unterteilungen",
  disabled_fields_index : 13,
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.PlacesByPlace.detail;
    this.ls_insert_handler = Lino.countries.PlacesByPlace.insert;
    var ww = this.containing_window;
    var detail_link_disp1240 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var type1241 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/PlacesByPlace/type" }) }) });
    var zip_code1242 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(8), "maxLength": 8, "selectOnFocus": true });
    var id1243 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var name1244 = new Ext.form.TextField({ "allowBlank": false, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var name_de1245 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr1246 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var country1247 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/PlacesByPlace/country" }) }) });
    var show_type1248 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var parent1249 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/PlacesByPlace/parent" }) }) });
    this.before_row_edit = function(record) {
      type1241.setContextValue('country', record ? record.data['countryHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof country1247 !== 'undefined' && country1247.on('change',Lino.chooser_handler(type1241,'country'));
      Lino.countries.PlacesByPlace.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Ort", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByPlace.detail_link) ") }, "sortable": false, "tooltip": "(countries.PlacesByPlace.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "type", "editable": true, "editor": type1241, "filter": { "type": "string" }, "header": "Ortsart", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByPlace.type) The type of this place (whether it's a city. a village, a province...)") }, "sortable": false, "tooltip": "The type of this place (whether it's a city. a village, a province...)", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "zip_code", "editable": true, "editor": zip_code1242, "filter": { "type": "string" }, "header": "zip code", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByPlace.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(10) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id1243, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByPlace.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "name", "editable": true, "editor": name1244, "filter": { "type": "string" }, "header": "Bezeichnung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByPlace.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "name_de", "editable": true, "editor": name_de1245, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByPlace.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "name_fr", "editable": true, "editor": name_fr1246, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByPlace.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "country", "editable": true, "editor": country1247, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByPlace.country) The country this place is in.") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "The country this place is in.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "show_type", "editable": true, "filter": { "type": "boolean" }, "header": "Show type", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByPlace.show_type) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 9, "dataIndex": "parent", "editable": true, "editor": parent1249, "filter": { "type": "string" }, "header": "Teil von", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByPlace.parent) The superordinate geographic place of which this place is a part.") }, "renderer": Lino.fk_renderer('parentHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "The superordinate geographic place of which this place is a part.", "width": Lino.chars2width(21) } ];
    Lino.countries.PlacesByPlace.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.PlacesByPlace.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByPlace", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByPlace.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByPlace", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByPlace.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByPlace", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByPlace.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByPlace", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.countries.PlacesByPlace.insertPanel = Ext.extend(Lino.countries.Places.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/countries/PlacesByPlace",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.PlacesByPlace.detail;
    this.ls_insert_handler = Lino.countries.PlacesByPlace.insert;
    Lino.countries.PlacesByPlace.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.PlacesByPlace.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/countries/PlacesByPlace" };
  return new Lino.countries.PlacesByPlace.insertPanel(p);
});
Lino.countries.PlacesByPlace.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByPlace", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByPlace.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByPlace", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.countries.PlacesByPlace.detailPanel = Ext.extend(Lino.countries.Places.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Ort) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/countries/PlacesByPlace",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.PlacesByPlace.detail;
    this.ls_insert_handler = Lino.countries.PlacesByPlace.insert;
    Lino.countries.PlacesByPlace.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.PlacesByPlace.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/countries/PlacesByPlace" };
  return new Lino.countries.PlacesByPlace.detailPanel(p);
});
Lino.countries.PlacesByPlace.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByPlace", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByPlace.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByPlace", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByPlace.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByPlace", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByPlace.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/countries/PlacesByPlace" };
  return new Lino.countries.PlacesByPlace.GridPanel(p);
});
Lino.countries.PlacesByPlace.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByPlace", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class countries.PlacesByCountry
Lino.countries.PlacesByCountry.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/countries/PlacesByCountry",
  ls_store_fields : [ { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "type" }, 'typeHidden', { "name": "zip_code" }, { "name": "id", "type": "int" }, { "name": "parent" }, 'parentHidden', { "name": "show_type", "type": "boolean" }, { "name": "country" }, 'countryHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 5,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/countries/PlacesByCountry','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/countries/PlacesByCountry','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/countries/PlacesByCountry','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/countries/PlacesByCountry','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/countries/PlacesByCountry','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Ort) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Orte",
  disabled_fields_index : 12,
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.PlacesByCountry.detail;
    this.ls_insert_handler = Lino.countries.PlacesByCountry.insert;
    var ww = this.containing_window;
    var name1133 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de1134 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr1135 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var type1136 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/PlacesByCountry/type" }) }) });
    var zip_code1137 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(8), "maxLength": 8, "selectOnFocus": true });
    var id1138 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var parent1139 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/PlacesByCountry/parent" }) }) });
    var show_type1140 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var country1141 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/countries/PlacesByCountry/country" }) }) });
    this.before_row_edit = function(record) {
      var bp = this.get_base_params();
      type1136.setContextValue('mk',bp['mk']);
      type1136.setContextValue('mt',bp['mt']);
    };
    this.onRender = function(ct, position) {
      typeof country1141 !== 'undefined' && country1141.on('change',Lino.chooser_handler(type1136,'country'));
      Lino.countries.PlacesByCountry.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name", "editable": true, "editor": name1133, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByCountry.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name_de", "editable": true, "editor": name_de1134, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByCountry.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_fr", "editable": true, "editor": name_fr1135, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByCountry.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "type", "editable": true, "editor": type1136, "filter": { "type": "string" }, "header": "Ortsart", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByCountry.type) The type of this place (whether it's a city. a village, a province...)") }, "sortable": false, "tooltip": "The type of this place (whether it's a city. a village, a province...)", "width": Lino.chars2width(11) }, { "colIndex": 4, "dataIndex": "zip_code", "editable": true, "editor": zip_code1137, "filter": { "type": "string" }, "header": "zip code", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByCountry.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(10) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id1138, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByCountry.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "parent", "editable": true, "editor": parent1139, "filter": { "type": "string" }, "header": "Teil von", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByCountry.parent) The superordinate geographic place of which this place is a part.") }, "renderer": Lino.fk_renderer('parentHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "The superordinate geographic place of which this place is a part.", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "show_type", "editable": true, "filter": { "type": "boolean" }, "header": "Show type", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByCountry.show_type) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 8, "dataIndex": "country", "editable": true, "editor": country1141, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlacesByCountry.country) The country this place is in.") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "The country this place is in.", "width": Lino.chars2width(21) } ];
    Lino.countries.PlacesByCountry.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.PlacesByCountry.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByCountry", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByCountry.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByCountry", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByCountry.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByCountry", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByCountry.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByCountry", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.countries.PlacesByCountry.insertPanel = Ext.extend(Lino.countries.Places.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/countries/PlacesByCountry",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.PlacesByCountry.detail;
    this.ls_insert_handler = Lino.countries.PlacesByCountry.insert;
    Lino.countries.PlacesByCountry.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.PlacesByCountry.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/countries/PlacesByCountry" };
  return new Lino.countries.PlacesByCountry.insertPanel(p);
});
Lino.countries.PlacesByCountry.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByCountry", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByCountry.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByCountry", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.countries.PlacesByCountry.detailPanel = Ext.extend(Lino.countries.Places.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Ort) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/countries/PlacesByCountry",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.countries.PlacesByCountry.detail;
    this.ls_insert_handler = Lino.countries.PlacesByCountry.insert;
    Lino.countries.PlacesByCountry.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.PlacesByCountry.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/countries/PlacesByCountry" };
  return new Lino.countries.PlacesByCountry.detailPanel(p);
});
Lino.countries.PlacesByCountry.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByCountry", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByCountry.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByCountry", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByCountry.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByCountry", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlacesByCountry.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/countries/PlacesByCountry" };
  return new Lino.countries.PlacesByCountry.GridPanel(p);
});
Lino.countries.PlacesByCountry.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlacesByCountry", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class contacts.PartnersByCity
Lino.contacts.PartnersByCity.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/PartnersByCity",
  ls_store_fields : [ { "name": "address_column" }, { "name": "name" }, { "name": "id", "type": "int" }, { "name": "email" }, { "name": "language" }, 'languageHidden', { "name": "url" }, { "name": "phone" }, { "name": "gsm" }, { "name": "fax" }, { "name": "country" }, 'countryHidden', { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street" }, { "name": "street_no" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "prefix" }, { "name": "remarks" }, { "name": "payment_term" }, 'payment_termHidden', { "name": "purchase_account" }, 'purchase_accountHidden', { "name": "city" }, 'cityHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 2,
  content_type : 6,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCity','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCity','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCity','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCity','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCity','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCity','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCity','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Partners.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Partner",
  disabled_fields_index : 29,
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.PartnersByCity.detail;
    var ww = this.containing_window;
    var address_column_disp1197 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var name1198 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var id1199 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var email1200 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 254, "selectOnFocus": true });
    var language1201 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var url1202 = new Lino.URLField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var phone1203 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var gsm1204 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var fax1205 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var country1206 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/PartnersByCity/country" }) }) });
    var zip_code1207 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region1208 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/PartnersByCity/region" }) }) });
    var addr11209 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix1210 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street1211 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_no1212 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var street_box1213 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr21214 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var prefix1215 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var remarks1216 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    var payment_term1217 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Zahlungsbedingungen ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.PaymentTerms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/PartnersByCity/payment_term" }) }) });
    var purchase_account1218 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Konto ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/PartnersByCity/purchase_account" }) }) });
    var city1219 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/PartnersByCity/city" }) }) });
    this.before_row_edit = function(record) {
      region1208.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      remarks1216.refresh();
      city1219.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city1219.setContextValue('region', record ? record.data['regionHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof country1206 !== 'undefined' && country1206.on('change',Lino.chooser_handler(region1208,'country'));
      typeof country1206 !== 'undefined' && country1206.on('change',Lino.chooser_handler(city1219,'country'));
      typeof region1208 !== 'undefined' && region1208.on('change',Lino.chooser_handler(city1219,'region'));
      Lino.contacts.PartnersByCity.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "address_column", "editable": false, "header": "Adresse", "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.address_column) ") }, "sortable": false, "tooltip": "(contacts.PartnersByCity.address_column) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name1198, "filter": { "type": "string" }, "header": "Name", "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.name) The full name of this partner. Used for alphabetic sorting.") }, "sortable": true, "tooltip": "The full name of this partner. Used for alphabetic sorting.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 2, "dataIndex": "id", "editable": true, "editor": id1199, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "email", "editable": true, "editor": email1200, "filter": { "type": "string" }, "header": "E-Mail-Adresse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.email) The primary email address.") }, "sortable": true, "tooltip": "The primary email address.", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "language", "editable": true, "editor": language1201, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.language) The language to use when communicating with this partner.") }, "sortable": false, "tooltip": "The language to use when communicating with this partner.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "url", "editable": true, "editor": url1202, "filter": { "type": "string" }, "header": "Adresse (URL)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.url) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "phone", "editable": true, "editor": phone1203, "filter": { "type": "string" }, "header": "Telefon", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.phone) The primary phone number.") }, "sortable": true, "tooltip": "The primary phone number.", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "gsm", "editable": true, "editor": gsm1204, "filter": { "type": "string" }, "header": "GSM", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.gsm) The primary mobile phone number.") }, "sortable": true, "tooltip": "The primary mobile phone number.", "width": Lino.chars2width(22) }, { "colIndex": 8, "dataIndex": "fax", "editable": true, "editor": fax1205, "filter": { "type": "string" }, "header": "Fax", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.fax) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "country", "editable": true, "editor": country1206, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "zip_code", "editable": true, "editor": zip_code1207, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 11, "dataIndex": "region", "editable": true, "editor": region1208, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "addr1", "editable": true, "editor": addr11209, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 13, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix1210, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "street", "editable": true, "editor": street1211, "filter": { "type": "string" }, "header": "Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "street_no", "editable": true, "editor": street_no1212, "filter": { "type": "string" }, "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 16, "dataIndex": "street_box", "editable": true, "editor": street_box1213, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 17, "dataIndex": "addr2", "editable": true, "editor": addr21214, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 18, "dataIndex": "prefix", "editable": true, "editor": prefix1215, "filter": { "type": "string" }, "header": "Name prefix", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.prefix) An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.") }, "sortable": true, "tooltip": "An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.", "width": Lino.chars2width(22) }, { "colIndex": 19, "dataIndex": "remarks", "editable": true, "editor": remarks1216, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 20, "dataIndex": "payment_term", "editable": true, "editor": payment_term1217, "filter": { "type": "string" }, "header": "Zahlungsbedingungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.payment_term) The default payment term for sales invoices to this customer.") }, "sortable": false, "tooltip": "The default payment term for sales invoices to this customer.", "width": Lino.chars2width(21) }, { "colIndex": 21, "dataIndex": "purchase_account", "editable": true, "editor": purchase_account1218, "filter": { "type": "string" }, "header": "Konto Einkauf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.purchase_account) The general account to suggest as default value in purchase\ninvoices from this partner.") }, "sortable": false, "tooltip": "The general account to suggest as default value in purchase\ninvoices from this partner.", "width": Lino.chars2width(21) }, { "colIndex": 22, "dataIndex": "city", "editable": true, "editor": city1219, "filter": { "type": "string" }, "header": "Ortschaft", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCity.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) } ];
    Lino.contacts.PartnersByCity.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.PartnersByCity.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.export_vcf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "export_vcf", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.contacts.PartnersByCity.detailPanel = Ext.extend(Lino.contacts.Partners.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCity','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Partners.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/contacts/PartnersByCity",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.PartnersByCity.detail;
    Lino.contacts.PartnersByCity.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.PartnersByCity.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/PartnersByCity" };
  return new Lino.contacts.PartnersByCity.detailPanel(p);
});
Lino.contacts.PartnersByCity.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.create_excerpt2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "create_excerpt2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.due = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "due", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.show_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "show_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.del_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "del_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.del_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "del_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.del_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "del_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.del_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "del_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/PartnersByCity" };
  p.params_panel = new Lino.contacts.Partners.ParamsPanel({});
  return new Lino.contacts.PartnersByCity.GridPanel(p);
});
Lino.contacts.PartnersByCity.ins_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "ins_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.ins_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "ins_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.ins_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "ins_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.ins_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "GET", pk, "ins_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCity.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCity", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class contacts.PartnersByCountry
Lino.contacts.PartnersByCountry.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/PartnersByCountry",
  ls_store_fields : [ { "name": "city" }, 'cityHidden', { "name": "street" }, { "name": "street_no" }, { "name": "name" }, { "name": "language" }, 'languageHidden', { "name": "id", "type": "int" }, { "name": "email" }, { "name": "url" }, { "name": "phone" }, { "name": "gsm" }, { "name": "fax" }, { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "prefix" }, { "name": "remarks" }, { "name": "payment_term" }, 'payment_termHidden', { "name": "purchase_account" }, 'purchase_accountHidden', { "name": "country" }, 'countryHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 6,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCountry','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCountry','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCountry','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCountry','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCountry','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCountry','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCountry','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Partners.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Partner",
  disabled_fields_index : 28,
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.PartnersByCountry.detail;
    var ww = this.containing_window;
    var city4107 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/PartnersByCountry/city" }) }) });
    var street4108 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var street_no4109 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "maxLength": 10, "selectOnFocus": true });
    var name4110 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var language4111 = new Lino.ChoicesFieldElement({ "allowBlank": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var id4112 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var email4113 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 254, "selectOnFocus": true });
    var url4114 = new Lino.URLField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var phone4115 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var gsm4116 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var fax4117 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var zip_code4118 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region4119 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/PartnersByCountry/region" }) }) });
    var addr14120 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix4121 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_box4122 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr24123 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var prefix4124 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var remarks4125 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    var payment_term4126 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Zahlungsbedingungen ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.PaymentTerms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/PartnersByCountry/payment_term" }) }) });
    var purchase_account4127 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Konto ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/PartnersByCountry/purchase_account" }) }) });
    var country4128 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/PartnersByCountry/country" }) }) });
    this.before_row_edit = function(record) {
      var bp = this.get_base_params();
      city4107.setContextValue('mk',bp['mk']);
      city4107.setContextValue('mt',bp['mt']);
      city4107.setContextValue('region', record ? record.data['regionHidden'] : undefined);
      var bp = this.get_base_params();
      region4119.setContextValue('mk',bp['mk']);
      region4119.setContextValue('mt',bp['mt']);
      remarks4125.refresh();
    };
    this.onRender = function(ct, position) {
      typeof country4128 !== 'undefined' && country4128.on('change',Lino.chooser_handler(city4107,'country'));
      typeof region4119 !== 'undefined' && region4119.on('change',Lino.chooser_handler(city4107,'region'));
      typeof country4128 !== 'undefined' && country4128.on('change',Lino.chooser_handler(region4119,'country'));
      Lino.contacts.PartnersByCountry.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "city", "editable": true, "editor": city4107, "filter": { "type": "string" }, "header": "Ortschaft", "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "street", "editable": true, "editor": street4108, "filter": { "type": "string" }, "header": "Stra\u00dfe", "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "street_no", "editable": true, "editor": street_no4109, "filter": { "type": "string" }, "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 3, "dataIndex": "name", "editable": true, "editor": name4110, "filter": { "type": "string" }, "header": "Name", "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.name) The full name of this partner. Used for alphabetic sorting.") }, "sortable": true, "tooltip": "The full name of this partner. Used for alphabetic sorting.", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "language", "editable": true, "editor": language4111, "filter": { "type": "string" }, "header": "Sprache", "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.language) The language to use when communicating with this partner.") }, "sortable": false, "tooltip": "The language to use when communicating with this partner.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id4112, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "email", "editable": true, "editor": email4113, "filter": { "type": "string" }, "header": "E-Mail-Adresse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.email) The primary email address.") }, "sortable": true, "tooltip": "The primary email address.", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "url", "editable": true, "editor": url4114, "filter": { "type": "string" }, "header": "Adresse (URL)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.url) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 8, "dataIndex": "phone", "editable": true, "editor": phone4115, "filter": { "type": "string" }, "header": "Telefon", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.phone) The primary phone number.") }, "sortable": true, "tooltip": "The primary phone number.", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "gsm", "editable": true, "editor": gsm4116, "filter": { "type": "string" }, "header": "GSM", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.gsm) The primary mobile phone number.") }, "sortable": true, "tooltip": "The primary mobile phone number.", "width": Lino.chars2width(22) }, { "colIndex": 10, "dataIndex": "fax", "editable": true, "editor": fax4117, "filter": { "type": "string" }, "header": "Fax", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.fax) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 11, "dataIndex": "zip_code", "editable": true, "editor": zip_code4118, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 12, "dataIndex": "region", "editable": true, "editor": region4119, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "addr1", "editable": true, "editor": addr14120, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix4121, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "street_box", "editable": true, "editor": street_box4122, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 16, "dataIndex": "addr2", "editable": true, "editor": addr24123, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 17, "dataIndex": "prefix", "editable": true, "editor": prefix4124, "filter": { "type": "string" }, "header": "Name prefix", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.prefix) An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.") }, "sortable": true, "tooltip": "An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.", "width": Lino.chars2width(22) }, { "colIndex": 18, "dataIndex": "remarks", "editable": true, "editor": remarks4125, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 19, "dataIndex": "payment_term", "editable": true, "editor": payment_term4126, "filter": { "type": "string" }, "header": "Zahlungsbedingungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.payment_term) The default payment term for sales invoices to this customer.") }, "sortable": false, "tooltip": "The default payment term for sales invoices to this customer.", "width": Lino.chars2width(21) }, { "colIndex": 20, "dataIndex": "purchase_account", "editable": true, "editor": purchase_account4127, "filter": { "type": "string" }, "header": "Konto Einkauf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.purchase_account) The general account to suggest as default value in purchase\ninvoices from this partner.") }, "sortable": false, "tooltip": "The general account to suggest as default value in purchase\ninvoices from this partner.", "width": Lino.chars2width(21) }, { "colIndex": 21, "dataIndex": "country", "editable": true, "editor": country4128, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnersByCountry.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.contacts.PartnersByCountry.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.PartnersByCountry.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.export_vcf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "export_vcf", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.contacts.PartnersByCountry.detailPanel = Ext.extend(Lino.contacts.Partners.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnersByCountry','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Partners.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/contacts/PartnersByCountry",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.PartnersByCountry.detail;
    Lino.contacts.PartnersByCountry.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.PartnersByCountry.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/PartnersByCountry" };
  return new Lino.contacts.PartnersByCountry.detailPanel(p);
});
Lino.contacts.PartnersByCountry.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.create_excerpt2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "create_excerpt2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.due = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "due", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.show_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "show_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.del_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "del_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.del_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "del_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.del_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "del_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.del_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "del_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/PartnersByCountry" };
  p.params_panel = new Lino.contacts.Partners.ParamsPanel({});
  return new Lino.contacts.PartnersByCountry.GridPanel(p);
});
Lino.contacts.PartnersByCountry.ins_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "ins_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.ins_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "ins_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.ins_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "ins_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.ins_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "GET", pk, "ins_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnersByCountry.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnersByCountry", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class contacts.RolesByCompany
Lino.contacts.RolesByCompany.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/RolesByCompany",
  ls_store_fields : [ { "name": "person" }, 'personHidden', { "name": "type" }, 'typeHidden', { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "id", "type": "int" }, { "name": "company" }, 'companyHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 9,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByCompany','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByCompany','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByCompany','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByCompany','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByCompany','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByCompany','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kontaktpersonen",
  disabled_fields_index : 9,
  initComponent : function() {
    var ww = this.containing_window;
    var person640 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/RolesByCompany/person" }) }) });
    var type641 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/RolesByCompany/type" }) }) });
    var start_date642 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var end_date643 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var id644 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var company645 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Organisation ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/RolesByCompany/company" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "person", "editable": true, "editor": person640, "filter": { "type": "string" }, "header": "Person", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByCompany.person) The person having this role in this organization.") }, "renderer": Lino.fk_renderer('personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The person having this role in this organization.", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "type", "editable": true, "editor": type641, "filter": { "type": "string" }, "header": "Funktion", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByCompany.type) The function of this person in this organization.") }, "sortable": false, "tooltip": "The function of this person in this organization.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "start_date", "editable": true, "editor": start_date642, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByCompany.start_date) When this person started to exercise this function in this\norganization.") }, "sortable": true, "tooltip": "When this person started to exercise this function in this\norganization.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 3, "dataIndex": "end_date", "editable": true, "editor": end_date643, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByCompany.end_date) When this person stopped to exercise this function in this\norganization.") }, "sortable": true, "tooltip": "When this person stopped to exercise this function in this\norganization.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id644, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByCompany.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "company", "editable": true, "editor": company645, "filter": { "type": "string" }, "header": "Organisation", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByCompany.company) The organization where this person has this role.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "The organization where this person has this role.", "width": Lino.chars2width(21) } ];
    Lino.contacts.RolesByCompany.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.RolesByCompany.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByCompany", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByCompany.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByCompany", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByCompany.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByCompany", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByCompany.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByCompany", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByCompany.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByCompany", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByCompany.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByCompany", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByCompany.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/RolesByCompany" };
  return new Lino.contacts.RolesByCompany.GridPanel(p);
});

// js_render_GridPanel_class contacts.RolesByPerson
Lino.contacts.RolesByPerson.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/RolesByPerson",
  ls_store_fields : [ { "name": "company" }, 'companyHidden', { "name": "type" }, 'typeHidden', { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "id", "type": "int" }, { "name": "person" }, 'personHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 9,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByPerson','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByPerson','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByPerson','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByPerson','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByPerson','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/RolesByPerson','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kontaktperson f\u00fcr",
  disabled_fields_index : 9,
  initComponent : function() {
    var ww = this.containing_window;
    var company1653 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Organisation ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/RolesByPerson/company" }) }) });
    var type1654 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/RolesByPerson/type" }) }) });
    var start_date1655 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var end_date1656 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var id1657 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var person1658 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/RolesByPerson/person" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "company", "editable": true, "editor": company1653, "filter": { "type": "string" }, "header": "Organisation", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByPerson.company) The organization where this person has this role.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "The organization where this person has this role.", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "type", "editable": true, "editor": type1654, "filter": { "type": "string" }, "header": "Funktion", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByPerson.type) The function of this person in this organization.") }, "sortable": false, "tooltip": "The function of this person in this organization.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "start_date", "editable": true, "editor": start_date1655, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByPerson.start_date) When this person started to exercise this function in this\norganization.") }, "sortable": true, "tooltip": "When this person started to exercise this function in this\norganization.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 3, "dataIndex": "end_date", "editable": true, "editor": end_date1656, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByPerson.end_date) When this person stopped to exercise this function in this\norganization.") }, "sortable": true, "tooltip": "When this person stopped to exercise this function in this\norganization.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id1657, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByPerson.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "person", "editable": true, "editor": person1658, "filter": { "type": "string" }, "header": "Person", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.RolesByPerson.person) The person having this role in this organization.") }, "renderer": Lino.fk_renderer('personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The person having this role in this organization.", "width": Lino.chars2width(21) } ];
    Lino.contacts.RolesByPerson.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.RolesByPerson.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByPerson", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByPerson.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByPerson", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByPerson.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByPerson", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByPerson.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByPerson", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByPerson.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByPerson", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByPerson.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/RolesByPerson", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.RolesByPerson.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/RolesByPerson" };
  return new Lino.contacts.RolesByPerson.GridPanel(p);
});

// js_render_GridPanel_class contacts.CompaniesByCompany
Lino.contacts.CompaniesByCompany.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/CompaniesByCompany",
  ls_store_fields : [ { "name": "name_column" }, { "name": "email" }, { "name": "id", "type": "int" }, { "name": "language" }, 'languageHidden', { "name": "url" }, { "name": "phone" }, { "name": "gsm" }, { "name": "fax" }, { "name": "country" }, 'countryHidden', { "name": "city" }, 'cityHidden', { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street" }, { "name": "street_no" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "prefix" }, { "name": "name" }, { "name": "remarks" }, { "name": "payment_term" }, 'payment_termHidden', { "name": "purchase_account" }, 'purchase_accountHidden', { "name": "type" }, 'typeHidden', { "name": "parent" }, 'parentHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 2,
  content_type : 6,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/CompaniesByCompany','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/CompaniesByCompany','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/CompaniesByCompany','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/contacts/CompaniesByCompany','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/CompaniesByCompany','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/CompaniesByCompany','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/CompaniesByCompany','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Organisation) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Companies.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Child organisations",
  disabled_fields_index : 33,
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.CompaniesByCompany.detail;
    this.ls_insert_handler = Lino.contacts.CompaniesByCompany.insert;
    var ww = this.containing_window;
    var name_column_disp666 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var email667 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 254, "selectOnFocus": true });
    var id668 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var language669 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var url670 = new Lino.URLField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var phone671 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var gsm672 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var fax673 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var country674 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/CompaniesByCompany/country" }) }) });
    var city675 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/CompaniesByCompany/city" }) }) });
    var zip_code676 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region677 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/CompaniesByCompany/region" }) }) });
    var addr1678 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix679 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street680 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_no681 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var street_box682 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr2683 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var prefix684 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var name685 = new Ext.form.TextField({ "allowBlank": false, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var remarks686 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    var payment_term687 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Zahlungsbedingungen ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.PaymentTerms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/CompaniesByCompany/payment_term" }) }) });
    var purchase_account688 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Konto ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/CompaniesByCompany/purchase_account" }) }) });
    var type689 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisationsart ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "contacts.CompanyTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/CompaniesByCompany/type" }) }) });
    var parent690 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/contacts/CompaniesByCompany/parent" }) }) });
    this.before_row_edit = function(record) {
      city675.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city675.setContextValue('region', record ? record.data['regionHidden'] : undefined);
      region677.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      remarks686.refresh();
    };
    this.onRender = function(ct, position) {
      typeof country674 !== 'undefined' && country674.on('change',Lino.chooser_handler(city675,'country'));
      typeof region677 !== 'undefined' && region677.on('change',Lino.chooser_handler(city675,'region'));
      typeof country674 !== 'undefined' && country674.on('change',Lino.chooser_handler(region677,'country'));
      Lino.contacts.CompaniesByCompany.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name_column", "editable": false, "header": "Name", "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.name_column) ") }, "sortable": false, "tooltip": "(contacts.CompaniesByCompany.name_column) ", "width": Lino.chars2width(16) }, { "colIndex": 1, "dataIndex": "email", "editable": true, "editor": email667, "filter": { "type": "string" }, "header": "E-Mail-Adresse", "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.email) The primary email address.") }, "sortable": true, "tooltip": "The primary email address.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 2, "dataIndex": "id", "editable": true, "editor": id668, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "language", "editable": true, "editor": language669, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.language) The language to use when communicating with this partner.") }, "sortable": false, "tooltip": "The language to use when communicating with this partner.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "url", "editable": true, "editor": url670, "filter": { "type": "string" }, "header": "Adresse (URL)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.url) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "phone", "editable": true, "editor": phone671, "filter": { "type": "string" }, "header": "Telefon", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.phone) The primary phone number.") }, "sortable": true, "tooltip": "The primary phone number.", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "gsm", "editable": true, "editor": gsm672, "filter": { "type": "string" }, "header": "GSM", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.gsm) The primary mobile phone number.") }, "sortable": true, "tooltip": "The primary mobile phone number.", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "fax", "editable": true, "editor": fax673, "filter": { "type": "string" }, "header": "Fax", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.fax) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 8, "dataIndex": "country", "editable": true, "editor": country674, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "city", "editable": true, "editor": city675, "filter": { "type": "string" }, "header": "Ortschaft", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "zip_code", "editable": true, "editor": zip_code676, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 11, "dataIndex": "region", "editable": true, "editor": region677, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "addr1", "editable": true, "editor": addr1678, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 13, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix679, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "street", "editable": true, "editor": street680, "filter": { "type": "string" }, "header": "Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "street_no", "editable": true, "editor": street_no681, "filter": { "type": "string" }, "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 16, "dataIndex": "street_box", "editable": true, "editor": street_box682, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 17, "dataIndex": "addr2", "editable": true, "editor": addr2683, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 18, "dataIndex": "prefix", "editable": true, "editor": prefix684, "filter": { "type": "string" }, "header": "Name prefix", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.prefix) An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.") }, "sortable": true, "tooltip": "An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.", "width": Lino.chars2width(22) }, { "colIndex": 19, "dataIndex": "name", "editable": true, "editor": name685, "filter": { "type": "string" }, "header": "Name", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.name) The full name of this partner. Used for alphabetic sorting.") }, "sortable": true, "tooltip": "The full name of this partner. Used for alphabetic sorting.", "width": Lino.chars2width(22) }, { "colIndex": 20, "dataIndex": "remarks", "editable": true, "editor": remarks686, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 21, "dataIndex": "payment_term", "editable": true, "editor": payment_term687, "filter": { "type": "string" }, "header": "Zahlungsbedingungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.payment_term) The default payment term for sales invoices to this customer.") }, "sortable": false, "tooltip": "The default payment term for sales invoices to this customer.", "width": Lino.chars2width(21) }, { "colIndex": 22, "dataIndex": "purchase_account", "editable": true, "editor": purchase_account688, "filter": { "type": "string" }, "header": "Konto Einkauf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.purchase_account) The general account to suggest as default value in purchase\ninvoices from this partner.") }, "sortable": false, "tooltip": "The general account to suggest as default value in purchase\ninvoices from this partner.", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "type", "editable": true, "editor": type689, "filter": { "type": "string" }, "header": "Organisationsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.type) Pointer to the CompanyType.") }, "sortable": false, "tooltip": "Pointer to the CompanyType.", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "parent", "editable": true, "editor": parent690, "filter": { "type": "string" }, "header": "Vater/Mutter", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CompaniesByCompany.parent) ") }, "renderer": Lino.fk_renderer('parentHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.contacts.CompaniesByCompany.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.CompaniesByCompany.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.export_vcf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "export_vcf", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.contacts.CompaniesByCompany.insertPanel = Ext.extend(Lino.contacts.Companies.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/contacts/CompaniesByCompany",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.CompaniesByCompany.detail;
    this.ls_insert_handler = Lino.contacts.CompaniesByCompany.insert;
    Lino.contacts.CompaniesByCompany.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.CompaniesByCompany.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/contacts/CompaniesByCompany" };
  return new Lino.contacts.CompaniesByCompany.insertPanel(p);
});
Lino.contacts.CompaniesByCompany.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.contacts.CompaniesByCompany.detailPanel = Ext.extend(Lino.contacts.Companies.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/contacts/CompaniesByCompany','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Organisation) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.contacts.Companies.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/contacts/CompaniesByCompany",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.contacts.CompaniesByCompany.detail;
    this.ls_insert_handler = Lino.contacts.CompaniesByCompany.insert;
    Lino.contacts.CompaniesByCompany.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.CompaniesByCompany.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/CompaniesByCompany" };
  return new Lino.contacts.CompaniesByCompany.detailPanel(p);
});
Lino.contacts.CompaniesByCompany.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.create_excerpt2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "create_excerpt2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.due = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "due", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.show_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "show_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.del_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "del_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.del_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "del_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.del_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "del_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.del_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "del_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/CompaniesByCompany" };
  p.params_panel = new Lino.contacts.Partners.ParamsPanel({});
  return new Lino.contacts.CompaniesByCompany.GridPanel(p);
});
Lino.contacts.CompaniesByCompany.ins_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "ins_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.ins_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "ins_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.ins_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "ins_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.ins_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "GET", pk, "ins_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CompaniesByCompany.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CompaniesByCompany", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class checkdata.ProblemsByChecker
Lino.checkdata.ProblemsByChecker.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/checkdata/ProblemsByChecker",
  ls_store_fields : [ { "name": "user" }, 'userHidden', { "name": "owner" }, { "name": "message" }, { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "checker" }, 'checkerHidden' ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 14,
  cell_edit : false,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/checkdata/ProblemsByChecker','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/ProblemsByChecker','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/ProblemsByChecker','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/ProblemsByChecker','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/checkdata/ProblemsByChecker','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "update_problem", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problem", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problem','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Datenprobleme",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.ProblemsByChecker.detail;
    var ww = this.containing_window;
    var user2062 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/ProblemsByChecker/user" }) }) });
    var owner_disp2063 = new Ext.form.DisplayField({ "disabled": true });
    var message2064 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 250, "selectOnFocus": true });
    var id2065 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type2066 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/ProblemsByChecker/owner_type" }) }) });
    var owner_id2067 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/ProblemsByChecker/owner_id" }) }) });
    var checker2068 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.checkdata.Checkers });
    this.before_row_edit = function(record) {
    };
    this.onRender = function(ct, position) {
      typeof owner_type2066 !== 'undefined' && owner_type2066.on('change',Lino.chooser_handler(owner_id2067,'owner_type'));
      Lino.checkdata.ProblemsByChecker.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "user", "editable": true, "editor": user2062, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByChecker.user) The user responsible for fixing this\nproblem.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The user responsible for fixing this\nproblem.", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "owner", "editable": false, "header": "Datenobjekt", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByChecker.owner) ") }, "sortable": false, "tooltip": "(checkdata.ProblemsByChecker.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "message", "editable": true, "editor": message2064, "filter": { "type": "string" }, "header": "Meldung", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByChecker.message) The message text. This is a concatenation of all messages that\nwere yielded by the checker.") }, "sortable": true, "tooltip": "The message text. This is a concatenation of all messages that\nwere yielded by the checker.", "width": Lino.chars2width(51) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id2065, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByChecker.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "owner_type", "editable": true, "editor": owner_type2066, "filter": { "type": "string" }, "header": "Datenobjekt (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByChecker.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_id", "editable": true, "editor": owner_id2067, "filter": { "type": "string" }, "header": "Datenobjekt (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByChecker.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "checker", "editable": true, "editor": checker2068, "filter": { "options": [ "Adressen pr\u00fcfen", "Auf Termin\u00fcberschneidungen pr\u00fcfen", "Termine ohne Teilnehmer", "Dauer \u00fcberschreitende Kalendereintr\u00e4ge", "Veraltete generierte Kalendereintr\u00e4ge", "Check data of geographical places.", "Check integrity of ledger vouchers", "Check for previewables needing update", "Check for mismatches between contact details and owner", "Check for missing target files", "Find unbleached html content", "Check metadata of upload files", "Find orphaned files in uploads folder" ], "type": "list" }, "header": "Checker", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByChecker.checker) The Checker that reported this\nproblem.") }, "sortable": false, "tooltip": "The Checker that reported this\nproblem.", "width": Lino.chars2width(11) } ];
    Lino.checkdata.ProblemsByChecker.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.ProblemsByChecker.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByChecker", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.ProblemsByChecker.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByChecker", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.ProblemsByChecker.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByChecker", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.ProblemsByChecker.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByChecker", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.checkdata.ProblemsByChecker.detailPanel = Ext.extend(Lino.checkdata.Problems.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "update_problem", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problem", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problem','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": null, "xtype": "splitbutton" } ],
  ls_url: "/checkdata/ProblemsByChecker",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.ProblemsByChecker.detail;
    Lino.checkdata.ProblemsByChecker.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.ProblemsByChecker.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/ProblemsByChecker" };
  return new Lino.checkdata.ProblemsByChecker.detailPanel(p);
});
Lino.checkdata.ProblemsByChecker.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/ProblemsByChecker" };
  p.params_panel = new Lino.checkdata.Problems.ParamsPanel({});
  return new Lino.checkdata.ProblemsByChecker.GridPanel(p);
});
Lino.checkdata.ProblemsByChecker.update_problem = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByChecker", "GET", pk, "update_problem", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.ProblemsByChecker.fix_problem = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByChecker", "GET", pk, "fix_problem", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.SubscriptionsByUser
Lino.cal.SubscriptionsByUser.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/SubscriptionsByUser",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "calendar" }, 'calendarHidden', { "name": "is_hidden", "type": "boolean" }, { "name": "user" }, 'userHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 20,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/SubscriptionsByUser','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/SubscriptionsByUser','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/SubscriptionsByUser','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/SubscriptionsByUser','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/SubscriptionsByUser','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Abonnements",
  disabled_fields_index : 6,
  initComponent : function() {
    var ww = this.containing_window;
    var id2383 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var calendar2384 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kalender ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Calendars", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/SubscriptionsByUser/calendar" }) }) });
    var is_hidden2385 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var user2386 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/SubscriptionsByUser/user" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id2383, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.SubscriptionsByUser.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "calendar", "editable": true, "editor": calendar2384, "filter": { "type": "string" }, "header": "Kalender", "listeners": { "render": Lino.quicktip_renderer("","(cal.SubscriptionsByUser.calendar) The calendar you want to subscribe to.") }, "renderer": Lino.fk_renderer('calendarHidden','Lino.cal.Calendars.detail'), "sortable": false, "tooltip": "The calendar you want to subscribe to.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "is_hidden", "editable": true, "filter": { "type": "boolean" }, "header": "versteckt", "listeners": { "render": Lino.quicktip_renderer("","(cal.SubscriptionsByUser.is_hidden) Whether this subscription should \"\n        \"initially be displayed as a hidden calendar.") }, "sortable": false, "tooltip": "Whether this subscription should \"\n        \"initially be displayed as a hidden calendar.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 3, "dataIndex": "user", "editable": true, "editor": user2386, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.SubscriptionsByUser.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) } ];
    Lino.cal.SubscriptionsByUser.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.SubscriptionsByUser.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/SubscriptionsByUser", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.SubscriptionsByUser.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/SubscriptionsByUser", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.SubscriptionsByUser.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/SubscriptionsByUser", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.SubscriptionsByUser.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/SubscriptionsByUser", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.SubscriptionsByUser.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/SubscriptionsByUser", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.SubscriptionsByUser.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/SubscriptionsByUser" };
  p.params_panel = new Lino.cal.Subscriptions.ParamsPanel({});
  return new Lino.cal.SubscriptionsByUser.GridPanel(p);
});

// js_render_GridPanel_class cal.SubscriptionsByCalendar
Lino.cal.SubscriptionsByCalendar.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/SubscriptionsByCalendar",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "user" }, 'userHidden', { "name": "is_hidden", "type": "boolean" }, { "name": "calendar" }, 'calendarHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 20,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/SubscriptionsByCalendar','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/SubscriptionsByCalendar','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/SubscriptionsByCalendar','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/SubscriptionsByCalendar','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/SubscriptionsByCalendar','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Abonnements",
  disabled_fields_index : 6,
  initComponent : function() {
    var ww = this.containing_window;
    var id1542 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var user1543 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/SubscriptionsByCalendar/user" }) }) });
    var is_hidden1544 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var calendar1545 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kalender ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Calendars", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/SubscriptionsByCalendar/calendar" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id1542, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.SubscriptionsByCalendar.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user1543, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(cal.SubscriptionsByCalendar.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "is_hidden", "editable": true, "filter": { "type": "boolean" }, "header": "versteckt", "listeners": { "render": Lino.quicktip_renderer("","(cal.SubscriptionsByCalendar.is_hidden) Whether this subscription should \"\n        \"initially be displayed as a hidden calendar.") }, "sortable": false, "tooltip": "Whether this subscription should \"\n        \"initially be displayed as a hidden calendar.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 3, "dataIndex": "calendar", "editable": true, "editor": calendar1545, "filter": { "type": "string" }, "header": "Kalender", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.SubscriptionsByCalendar.calendar) The calendar you want to subscribe to.") }, "renderer": Lino.fk_renderer('calendarHidden','Lino.cal.Calendars.detail'), "sortable": false, "tooltip": "The calendar you want to subscribe to.", "width": Lino.chars2width(21) } ];
    Lino.cal.SubscriptionsByCalendar.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.SubscriptionsByCalendar.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/SubscriptionsByCalendar", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.SubscriptionsByCalendar.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/SubscriptionsByCalendar", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.SubscriptionsByCalendar.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/SubscriptionsByCalendar", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.SubscriptionsByCalendar.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/SubscriptionsByCalendar", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.SubscriptionsByCalendar.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/SubscriptionsByCalendar", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.SubscriptionsByCalendar.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/SubscriptionsByCalendar" };
  p.params_panel = new Lino.cal.Subscriptions.ParamsPanel({});
  return new Lino.cal.SubscriptionsByCalendar.GridPanel(p);
});

// js_render_GridPanel_class cal.TasksByUser
Lino.cal.TasksByUser.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/TasksByUser",
  ls_store_fields : [ { "name": "priority" }, 'priorityHidden', { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "summary" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "name": "start_time" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "due_date", "type": "date" }, { "name": "due_time" }, { "name": "percent", "type": "int", "useNull": true }, { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "user" }, 'userHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 21,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/TasksByUser','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/TasksByUser','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/TasksByUser','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/TasksByUser','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/TasksByUser','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Task) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aufgaben",
  disabled_fields_index : 26,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.TasksByUser.detail;
    this.ls_insert_handler = Lino.cal.TasksByUser.insert;
    var ww = this.containing_window;
    var priority4130 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var start_date4131 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var summary4132 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp4133 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id4134 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified4135 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created4136 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_time4137 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var owner_type4138 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/TasksByUser/owner_type" }) }) });
    var owner_id4139 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/TasksByUser/owner_id" }) }) });
    var description4140 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class4141 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence4142 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type4143 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var due_date4144 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var due_time4145 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var percent4146 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var state4147 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.TaskStates });
    var owner_disp4148 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    var user4149 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/TasksByUser/user" }) }) });
    this.before_row_edit = function(record) {
      owner_id4139.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type4138 !== 'undefined' && owner_type4138.on('change',Lino.chooser_handler(owner_id4139,'owner_type'));
      Lino.cal.TasksByUser.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "priority", "editable": true, "editor": priority4130, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.priority) How urgent this task is.") }, "sortable": false, "tooltip": "How urgent this task is.", "width": Lino.chars2width(12) }, { "colIndex": 1, "dataIndex": "start_date", "editable": true, "editor": start_date4131, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.start_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "summary", "editable": true, "editor": summary4132, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.summary) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id4134, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 7, "dataIndex": "start_time", "editable": true, "editor": start_time4137, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 8, "dataIndex": "owner_type", "editable": true, "editor": owner_type4138, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "owner_id", "editable": true, "editor": owner_id4139, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 10, "dataIndex": "description", "editable": true, "editor": description4140, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 11, "dataIndex": "access_class", "editable": true, "editor": access_class4141, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 12, "dataIndex": "sequence", "editable": true, "editor": sequence4142, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 13, "dataIndex": "auto_type", "editable": true, "editor": auto_type4143, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 14, "dataIndex": "due_date", "editable": true, "editor": due_date4144, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Zahlungsziel", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.due_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 15, "dataIndex": "due_time", "editable": true, "editor": due_time4145, "header": "F\u00e4llig um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.due_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "align": "right", "colIndex": 16, "dataIndex": "percent", "editable": true, "editor": percent4146, "filter": { "type": "numeric" }, "format": "0", "header": "Dauer (Anzahl)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.percent) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 17, "dataIndex": "state", "editable": true, "editor": state4147, "filter": { "options": [ "Zu tun", "Wichtig", "Begonnen", "Erledigt", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.state) The state of this Task. one of TaskStates.") }, "sortable": false, "tooltip": "The state of this Task. one of TaskStates.", "width": Lino.chars2width(13) }, { "colIndex": 18, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.owner) ") }, "sortable": false, "tooltip": "(cal.TasksByUser.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 19, "dataIndex": "user", "editable": true, "editor": user4149, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByUser.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) } ];
    Lino.cal.TasksByUser.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.TasksByUser.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByUser.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByUser.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByUser.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.TasksByUser.insertPanel = Ext.extend(Lino.cal.Tasks.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/TasksByUser",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.TasksByUser.detail;
    this.ls_insert_handler = Lino.cal.TasksByUser.insert;
    Lino.cal.TasksByUser.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.TasksByUser.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/TasksByUser" };
  return new Lino.cal.TasksByUser.insertPanel(p);
});
Lino.cal.TasksByUser.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.TasksByUser.detailPanel = Ext.extend(Lino.cal.Tasks.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Task) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/TasksByUser",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.TasksByUser.detail;
    this.ls_insert_handler = Lino.cal.TasksByUser.insert;
    Lino.cal.TasksByUser.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.TasksByUser.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/TasksByUser" };
  return new Lino.cal.TasksByUser.detailPanel(p);
});
Lino.cal.TasksByUser.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByUser.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByUser.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/TasksByUser" };
  p.params_panel = new Lino.cal.Tasks.ParamsPanel({});
  return new Lino.cal.TasksByUser.GridPanel(p);
});
Lino.cal.TasksByUser.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByUser.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByUser.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByUser.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByUser.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByUser", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.GuestsByEvent
Lino.cal.GuestsByEvent.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/GuestsByEvent",
  ls_store_fields : [ { "name": "partner" }, 'partnerHidden', { "name": "role" }, 'roleHidden', { "name": "remark" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "state" }, 'stateHidden', { "name": "event" }, 'eventHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 25,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByEvent','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByEvent','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByEvent','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByEvent','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByEvent','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Anwesenheiten",
  disabled_fields_index : 11,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestsByEvent.detail;
    this.ls_insert_handler = Lino.cal.GuestsByEvent.insert;
    var ww = this.containing_window;
    var partner1421 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/GuestsByEvent/partner" }) }) });
    var role1422 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Gastrolle ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/GuestsByEvent/role" }) }) });
    var remark1423 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp1424 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id1425 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var state1426 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.GuestStates });
    var event1427 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kalendereintrag ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.OneEvent", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/GuestsByEvent/event" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "partner", "editable": true, "editor": partner1421, "filter": { "type": "string" }, "header": "Person", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByEvent.partner) The partner to which this presence applies.") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The partner to which this presence applies.", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "role", "editable": true, "editor": role1422, "filter": { "type": "string" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByEvent.role) The role of this partner in this presence.") }, "renderer": Lino.fk_renderer('roleHidden','Lino.cal.GuestRoles.detail'), "sortable": false, "tooltip": "The role of this partner in this presence.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "remark", "editable": true, "editor": remark1423, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByEvent.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByEvent.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id1425, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByEvent.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "state", "editable": true, "editor": state1426, "filter": { "options": [ "Eingeladen", "Anwesend", "Fehlt", "Entschuldigt" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByEvent.state) The state of this presence.  See GuestStates.") }, "sortable": false, "tooltip": "The state of this presence.  See GuestStates.", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "event", "editable": true, "editor": event1427, "filter": { "type": "string" }, "header": "Kalendereintrag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByEvent.event) The calendar event to which this presence applies.") }, "renderer": Lino.fk_renderer('eventHidden','Lino.cal.OneEvent.detail'), "sortable": false, "tooltip": "The calendar event to which this presence applies.", "width": Lino.chars2width(21) } ];
    Lino.cal.GuestsByEvent.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestsByEvent.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByEvent.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByEvent.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByEvent.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.GuestsByEvent.insertPanel = Ext.extend(Lino.cal.Guests.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/GuestsByEvent",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestsByEvent.detail;
    this.ls_insert_handler = Lino.cal.GuestsByEvent.insert;
    Lino.cal.GuestsByEvent.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestsByEvent.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/GuestsByEvent" };
  return new Lino.cal.GuestsByEvent.insertPanel(p);
});
Lino.cal.GuestsByEvent.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.GuestsByEvent.detailPanel = Ext.extend(Lino.cal.Guests.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/GuestsByEvent",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestsByEvent.detail;
    this.ls_insert_handler = Lino.cal.GuestsByEvent.insert;
    Lino.cal.GuestsByEvent.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestsByEvent.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/GuestsByEvent" };
  return new Lino.cal.GuestsByEvent.detailPanel(p);
});
Lino.cal.GuestsByEvent.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByEvent.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/GuestsByEvent" };
  p.params_panel = new Lino.cal.Guests.ParamsPanel({});
  return new Lino.cal.GuestsByEvent.GridPanel(p);
});
Lino.cal.GuestsByEvent.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByEvent.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByEvent.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByEvent.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByEvent.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByEvent", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.GuestsByRole
Lino.cal.GuestsByRole.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/GuestsByRole",
  ls_store_fields : [ { "name": "partner" }, 'partnerHidden', { "name": "role" }, 'roleHidden', { "name": "workflow_buttons" }, { "name": "remark" }, { "name": "event" }, 'eventHidden', { "name": "id", "type": "int" }, { "name": "state" }, 'stateHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 8,
  content_type : 25,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByRole','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByRole','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByRole','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByRole','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByRole','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Anwesenheiten",
  disabled_fields_index : 11,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestsByRole.detail;
    this.ls_insert_handler = Lino.cal.GuestsByRole.insert;
    var ww = this.containing_window;
    var partner1744 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/GuestsByRole/partner" }) }) });
    var role1745 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Gastrolle ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/GuestsByRole/role" }) }) });
    var workflow_buttons_disp1746 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var remark1747 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var event1748 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kalendereintrag ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.OneEvent", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/GuestsByRole/event" }) }) });
    var id1749 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var state1750 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.GuestStates });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "partner", "editable": true, "editor": partner1744, "filter": { "type": "string" }, "header": "Person", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByRole.partner) The partner to which this presence applies.") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The partner to which this presence applies.", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "role", "editable": true, "editor": role1745, "filter": { "type": "string" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByRole.role) The role of this partner in this presence.") }, "renderer": Lino.fk_renderer('roleHidden','Lino.cal.GuestRoles.detail'), "sortable": false, "tooltip": "The role of this partner in this presence.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByRole.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "colIndex": 3, "dataIndex": "remark", "editable": true, "editor": remark1747, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByRole.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "event", "editable": true, "editor": event1748, "filter": { "type": "string" }, "header": "Kalendereintrag", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByRole.event) The calendar event to which this presence applies.") }, "renderer": Lino.fk_renderer('eventHidden','Lino.cal.OneEvent.detail'), "sortable": false, "tooltip": "The calendar event to which this presence applies.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id1749, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByRole.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "state", "editable": true, "editor": state1750, "filter": { "options": [ "Eingeladen", "Anwesend", "Fehlt", "Entschuldigt" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByRole.state) The state of this presence.  See GuestStates.") }, "sortable": false, "tooltip": "The state of this presence.  See GuestStates.", "width": Lino.chars2width(11) } ];
    Lino.cal.GuestsByRole.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestsByRole.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByRole.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByRole.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByRole.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.GuestsByRole.insertPanel = Ext.extend(Lino.cal.Guests.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/GuestsByRole",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestsByRole.detail;
    this.ls_insert_handler = Lino.cal.GuestsByRole.insert;
    Lino.cal.GuestsByRole.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestsByRole.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/GuestsByRole" };
  return new Lino.cal.GuestsByRole.insertPanel(p);
});
Lino.cal.GuestsByRole.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.GuestsByRole.detailPanel = Ext.extend(Lino.cal.Guests.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/GuestsByRole",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestsByRole.detail;
    this.ls_insert_handler = Lino.cal.GuestsByRole.insert;
    Lino.cal.GuestsByRole.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestsByRole.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/GuestsByRole" };
  return new Lino.cal.GuestsByRole.detailPanel(p);
});
Lino.cal.GuestsByRole.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByRole.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/GuestsByRole" };
  p.params_panel = new Lino.cal.Guests.ParamsPanel({});
  return new Lino.cal.GuestsByRole.GridPanel(p);
});
Lino.cal.GuestsByRole.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByRole.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByRole.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByRole.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByRole.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByRole", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.GuestsByPartner
Lino.cal.GuestsByPartner.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/GuestsByPartner",
  ls_store_fields : [ { "name": "event__when_text" }, { "name": "event_summary" }, { "name": "event__user" }, 'event__userHidden', { "name": "role" }, 'roleHidden', { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "event" }, 'eventHidden', { "name": "state" }, 'stateHidden', { "name": "remark" }, { "name": "partner" }, 'partnerHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 25,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByPartner','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByPartner','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByPartner','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByPartner','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/GuestsByPartner','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Anwesenheiten",
  disabled_fields_index : 15,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestsByPartner.detail;
    this.ls_insert_handler = Lino.cal.GuestsByPartner.insert;
    var ww = this.containing_window;
    var event__when_text_disp4151 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "sortable": false, "value": null });
    var event_summary_disp4152 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var event__user4153 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "sortable": false, "value": null });
    var role4154 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Gastrolle ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/GuestsByPartner/role" }) }) });
    var workflow_buttons_disp4155 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id4156 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var event4157 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Kalendereintrag ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.OneEvent", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/GuestsByPartner/event" }) }) });
    var state4158 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.GuestStates });
    var remark4159 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var partner4160 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/GuestsByPartner/partner" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "event__when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByPartner.event__when_text) ") }, "sortable": true, "tooltip": "(cal.GuestsByPartner.event__when_text) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "event_summary", "editable": false, "header": "Kalendereintrag", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByPartner.event_summary) ") }, "sortable": false, "tooltip": "(cal.GuestsByPartner.event_summary) ", "width": Lino.chars2width(31) }, { "colIndex": 2, "dataIndex": "event__user", "editable": false, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByPartner.event__user) Der verantwortliche Benutzer.") }, "sortable": true, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "role", "editable": true, "editor": role4154, "filter": { "type": "string" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByPartner.role) The role of this partner in this presence.") }, "renderer": Lino.fk_renderer('roleHidden','Lino.cal.GuestRoles.detail'), "sortable": false, "tooltip": "The role of this partner in this presence.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByPartner.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id4156, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByPartner.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "event", "editable": true, "editor": event4157, "filter": { "type": "string" }, "header": "Kalendereintrag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByPartner.event) The calendar event to which this presence applies.") }, "renderer": Lino.fk_renderer('eventHidden','Lino.cal.OneEvent.detail'), "sortable": false, "tooltip": "The calendar event to which this presence applies.", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "state", "editable": true, "editor": state4158, "filter": { "options": [ "Eingeladen", "Anwesend", "Fehlt", "Entschuldigt" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByPartner.state) The state of this presence.  See GuestStates.") }, "sortable": false, "tooltip": "The state of this presence.  See GuestStates.", "width": Lino.chars2width(11) }, { "colIndex": 8, "dataIndex": "remark", "editable": true, "editor": remark4159, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByPartner.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "partner", "editable": true, "editor": partner4160, "filter": { "type": "string" }, "header": "Person", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestsByPartner.partner) The partner to which this presence applies.") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The partner to which this presence applies.", "width": Lino.chars2width(21) } ];
    Lino.cal.GuestsByPartner.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestsByPartner.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByPartner.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByPartner.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByPartner.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.GuestsByPartner.insertPanel = Ext.extend(Lino.cal.Guests.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/GuestsByPartner",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestsByPartner.detail;
    this.ls_insert_handler = Lino.cal.GuestsByPartner.insert;
    Lino.cal.GuestsByPartner.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestsByPartner.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/GuestsByPartner" };
  return new Lino.cal.GuestsByPartner.insertPanel(p);
});
Lino.cal.GuestsByPartner.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.GuestsByPartner.detailPanel = Ext.extend(Lino.cal.Guests.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Anwesenheit) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/GuestsByPartner",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.GuestsByPartner.detail;
    this.ls_insert_handler = Lino.cal.GuestsByPartner.insert;
    Lino.cal.GuestsByPartner.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestsByPartner.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/GuestsByPartner" };
  return new Lino.cal.GuestsByPartner.detailPanel(p);
});
Lino.cal.GuestsByPartner.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByPartner.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/GuestsByPartner" };
  p.params_panel = new Lino.cal.Guests.ParamsPanel({});
  return new Lino.cal.GuestsByPartner.GridPanel(p);
});
Lino.cal.GuestsByPartner.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByPartner.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByPartner.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByPartner.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestsByPartner.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestsByPartner", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.EntriesByType
Lino.cal.EntriesByType.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/EntriesByType",
  ls_store_fields : [ { "name": "when_text" }, { "name": "user" }, 'userHidden', { "name": "summary" }, { "name": "event_type" }, 'event_typeHidden', { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByType','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByType','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByType','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByType','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByType','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalendereintr\u00e4ge",
  disabled_fields_index : 35,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByType.detail;
    this.ls_insert_handler = Lino.cal.EntriesByType.insert;
    var ww = this.containing_window;
    var when_text_disp1367 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var user1368 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByType/user" }) }) });
    var summary1369 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var event_type1370 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByType/event_type" }) }) });
    var id1371 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified1372 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created1373 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date1374 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time1375 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date1376 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time1377 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time1378 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method1379 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var assigned_to1380 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByType/assigned_to" }) }) });
    var owner_type1381 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByType/owner_type" }) }) });
    var owner_id1382 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByType/owner_id" }) }) });
    var description1383 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class1384 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence1385 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type1386 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority1387 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var transparent1388 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room1389 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByType/room" }) }) });
    var state1390 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp1391 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id1382.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type1381 !== 'undefined' && owner_type1381.on('change',Lino.chooser_handler(owner_id1382,'owner_type'));
      Lino.cal.EntriesByType.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.when_text) ") }, "sortable": true, "tooltip": "(cal.EntriesByType.when_text) ", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user1368, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "summary", "editable": true, "editor": summary1369, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "event_type", "editable": true, "editor": event_type1370, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id1371, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 7, "dataIndex": "start_date", "editable": true, "editor": start_date1374, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "start_time", "editable": true, "editor": start_time1375, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "end_date", "editable": true, "editor": end_date1376, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "end_time", "editable": true, "editor": end_time1377, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 11, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 12, "dataIndex": "build_method", "editable": true, "editor": build_method1379, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 13, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to1380, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "owner_type", "editable": true, "editor": owner_type1381, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 15, "dataIndex": "owner_id", "editable": true, "editor": owner_id1382, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 16, "dataIndex": "description", "editable": true, "editor": description1383, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 17, "dataIndex": "access_class", "editable": true, "editor": access_class1384, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 18, "dataIndex": "sequence", "editable": true, "editor": sequence1385, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 19, "dataIndex": "auto_type", "editable": true, "editor": auto_type1386, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 20, "dataIndex": "priority", "editable": true, "editor": priority1387, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 21, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 22, "dataIndex": "room", "editable": true, "editor": room1389, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "state", "editable": true, "editor": state1390, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 24, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByType.owner) ") }, "sortable": false, "tooltip": "(cal.EntriesByType.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.EntriesByType.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByType.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EntriesByType.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/EntriesByType",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByType.detail;
    this.ls_insert_handler = Lino.cal.EntriesByType.insert;
    Lino.cal.EntriesByType.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByType.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/EntriesByType" };
  return new Lino.cal.EntriesByType.insertPanel(p);
});
Lino.cal.EntriesByType.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EntriesByType.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/EntriesByType",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByType.detail;
    this.ls_insert_handler = Lino.cal.EntriesByType.insert;
    Lino.cal.EntriesByType.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByType.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntriesByType" };
  return new Lino.cal.EntriesByType.detailPanel(p);
});
Lino.cal.EntriesByType.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntriesByType" };
  p.params_panel = new Lino.cal.Events.ParamsPanel({});
  return new Lino.cal.EntriesByType.GridPanel(p);
});
Lino.cal.EntriesByType.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByType.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByType", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.ConflictingEvents
Lino.cal.ConflictingEvents.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/ConflictingEvents",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "name": "end_time" }, { "name": "room" }, 'roomHidden', { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "summary" }, { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "transparent", "type": "boolean" }, { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/ConflictingEvents','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/ConflictingEvents','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/ConflictingEvents','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/ConflictingEvents','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/ConflictingEvents','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "\u00a0\u2694\u00a0",
  disabled_fields_index : 34,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.ConflictingEvents.detail;
    this.ls_insert_handler = Lino.cal.ConflictingEvents.insert;
    var ww = this.containing_window;
    var start_date4162 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var start_time4163 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_time4164 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var room4165 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/ConflictingEvents/room" }) }) });
    var user4166 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/ConflictingEvents/user" }) }) });
    var id4167 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified4168 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created4169 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var end_date4170 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var build_time4171 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method4172 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var assigned_to4173 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/ConflictingEvents/assigned_to" }) }) });
    var owner_type4174 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/ConflictingEvents/owner_type" }) }) });
    var owner_id4175 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/ConflictingEvents/owner_id" }) }) });
    var summary4176 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var description4177 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class4178 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence4179 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type4180 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority4181 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var event_type4182 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/ConflictingEvents/event_type" }) }) });
    var transparent4183 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var state4184 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp4185 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id4175.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type4174 !== 'undefined' && owner_type4174.on('change',Lino.chooser_handler(owner_id4175,'owner_type'));
      Lino.cal.ConflictingEvents.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "start_date", "editable": true, "editor": start_date4162, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "start_time", "editable": true, "editor": start_time4163, "header": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 2, "dataIndex": "end_time", "editable": true, "editor": end_time4164, "header": "Endet um", "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 3, "dataIndex": "room", "editable": true, "editor": room4165, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "user", "editable": true, "editor": user4166, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id4167, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 7, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 8, "dataIndex": "end_date", "editable": true, "editor": end_date4170, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 10, "dataIndex": "build_method", "editable": true, "editor": build_method4172, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 11, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to4173, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "owner_type", "editable": true, "editor": owner_type4174, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "owner_id", "editable": true, "editor": owner_id4175, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 14, "dataIndex": "summary", "editable": true, "editor": summary4176, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "description", "editable": true, "editor": description4177, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 16, "dataIndex": "access_class", "editable": true, "editor": access_class4178, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 17, "dataIndex": "sequence", "editable": true, "editor": sequence4179, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 18, "dataIndex": "auto_type", "editable": true, "editor": auto_type4180, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 19, "dataIndex": "priority", "editable": true, "editor": priority4181, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 20, "dataIndex": "event_type", "editable": true, "editor": event_type4182, "filter": { "type": "string" }, "header": "Kalendereintragsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "colIndex": 21, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 22, "dataIndex": "state", "editable": true, "editor": state4184, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 23, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.ConflictingEvents.owner) ") }, "sortable": false, "tooltip": "(cal.ConflictingEvents.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.ConflictingEvents.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.ConflictingEvents.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.ConflictingEvents.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/ConflictingEvents",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.ConflictingEvents.detail;
    this.ls_insert_handler = Lino.cal.ConflictingEvents.insert;
    Lino.cal.ConflictingEvents.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.ConflictingEvents.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/ConflictingEvents" };
  return new Lino.cal.ConflictingEvents.insertPanel(p);
});
Lino.cal.ConflictingEvents.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.ConflictingEvents.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/ConflictingEvents",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.ConflictingEvents.detail;
    this.ls_insert_handler = Lino.cal.ConflictingEvents.insert;
    Lino.cal.ConflictingEvents.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.ConflictingEvents.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/ConflictingEvents" };
  return new Lino.cal.ConflictingEvents.detailPanel(p);
});
Lino.cal.ConflictingEvents.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/ConflictingEvents" };
  p.params_panel = new Lino.cal.Events.ParamsPanel({});
  return new Lino.cal.ConflictingEvents.GridPanel(p);
});
Lino.cal.ConflictingEvents.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ConflictingEvents.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ConflictingEvents", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.EntriesByRoom
Lino.cal.EntriesByRoom.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/EntriesByRoom",
  ls_store_fields : [ { "name": "when_text" }, { "name": "user" }, 'userHidden', { "name": "summary" }, { "name": "event_type" }, 'event_typeHidden', { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "transparent", "type": "boolean" }, { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "room" }, 'roomHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByRoom','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByRoom','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByRoom','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByRoom','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByRoom','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalendereintr\u00e4ge",
  disabled_fields_index : 35,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByRoom.detail;
    this.ls_insert_handler = Lino.cal.EntriesByRoom.insert;
    var ww = this.containing_window;
    var when_text_disp1486 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var user1487 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByRoom/user" }) }) });
    var summary1488 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var event_type1489 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByRoom/event_type" }) }) });
    var id1490 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified1491 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created1492 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date1493 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time1494 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date1495 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time1496 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time1497 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method1498 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var assigned_to1499 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByRoom/assigned_to" }) }) });
    var owner_type1500 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByRoom/owner_type" }) }) });
    var owner_id1501 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByRoom/owner_id" }) }) });
    var description1502 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class1503 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence1504 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var auto_type1505 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var priority1506 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var transparent1507 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var state1508 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp1509 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    var room1510 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByRoom/room" }) }) });
    this.before_row_edit = function(record) {
      owner_id1501.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type1500 !== 'undefined' && owner_type1500.on('change',Lino.chooser_handler(owner_id1501,'owner_type'));
      Lino.cal.EntriesByRoom.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.when_text) ") }, "sortable": true, "tooltip": "(cal.EntriesByRoom.when_text) ", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user1487, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "summary", "editable": true, "editor": summary1488, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "event_type", "editable": true, "editor": event_type1489, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id1490, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 6, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 7, "dataIndex": "start_date", "editable": true, "editor": start_date1493, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "start_time", "editable": true, "editor": start_time1494, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 9, "dataIndex": "end_date", "editable": true, "editor": end_date1495, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "end_time", "editable": true, "editor": end_time1496, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 11, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 12, "dataIndex": "build_method", "editable": true, "editor": build_method1498, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 13, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to1499, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "owner_type", "editable": true, "editor": owner_type1500, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 15, "dataIndex": "owner_id", "editable": true, "editor": owner_id1501, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 16, "dataIndex": "description", "editable": true, "editor": description1502, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 17, "dataIndex": "access_class", "editable": true, "editor": access_class1503, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 18, "dataIndex": "sequence", "editable": true, "editor": sequence1504, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 19, "dataIndex": "auto_type", "editable": true, "editor": auto_type1505, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 20, "dataIndex": "priority", "editable": true, "editor": priority1506, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 21, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 22, "dataIndex": "state", "editable": true, "editor": state1508, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 23, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.owner) ") }, "sortable": false, "tooltip": "(cal.EntriesByRoom.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 24, "dataIndex": "room", "editable": true, "editor": room1510, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByRoom.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.cal.EntriesByRoom.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByRoom.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EntriesByRoom.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/EntriesByRoom",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByRoom.detail;
    this.ls_insert_handler = Lino.cal.EntriesByRoom.insert;
    Lino.cal.EntriesByRoom.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByRoom.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/EntriesByRoom" };
  return new Lino.cal.EntriesByRoom.insertPanel(p);
});
Lino.cal.EntriesByRoom.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EntriesByRoom.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/EntriesByRoom",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByRoom.detail;
    this.ls_insert_handler = Lino.cal.EntriesByRoom.insert;
    Lino.cal.EntriesByRoom.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByRoom.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntriesByRoom" };
  return new Lino.cal.EntriesByRoom.detailPanel(p);
});
Lino.cal.EntriesByRoom.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntriesByRoom" };
  p.params_panel = new Lino.cal.Events.ParamsPanel({});
  return new Lino.cal.EntriesByRoom.GridPanel(p);
});
Lino.cal.EntriesByRoom.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByRoom.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByRoom", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.EntriesByGuest
Lino.cal.EntriesByGuest.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/EntriesByGuest",
  ls_store_fields : [ { "name": "when_text" }, { "name": "user" }, 'userHidden', { "name": "summary" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByGuest','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByGuest','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByGuest','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByGuest','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByGuest','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalendereintr\u00e4ge",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByGuest.detail;
    this.ls_insert_handler = Lino.cal.EntriesByGuest.insert;
    var ww = this.containing_window;
    var when_text_disp4187 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var user4188 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByGuest/user" }) }) });
    var summary4189 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp4190 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByGuest.when_text) ") }, "sortable": true, "tooltip": "(cal.EntriesByGuest.when_text) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "user", "editable": true, "editor": user4188, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByGuest.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "summary", "editable": true, "editor": summary4189, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByGuest.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByGuest.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) } ];
    Lino.cal.EntriesByGuest.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByGuest.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EntriesByGuest.insertPanel = Ext.extend(Lino.cal.EntriesByGuest.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/EntriesByGuest",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByGuest.detail;
    this.ls_insert_handler = Lino.cal.EntriesByGuest.insert;
    Lino.cal.EntriesByGuest.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByGuest.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/EntriesByGuest" };
  return new Lino.cal.EntriesByGuest.insertPanel(p);
});
Lino.cal.EntriesByGuest.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EntriesByGuest.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/EntriesByGuest",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByGuest.detail;
    this.ls_insert_handler = Lino.cal.EntriesByGuest.insert;
    Lino.cal.EntriesByGuest.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByGuest.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntriesByGuest" };
  return new Lino.cal.EntriesByGuest.detailPanel(p);
});
Lino.cal.EntriesByGuest.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntriesByGuest" };
  p.params_panel = new Lino.cal.Events.ParamsPanel({});
  return new Lino.cal.EntriesByGuest.GridPanel(p);
});
Lino.cal.EntriesByGuest.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByGuest.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByGuest", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class calview.DailyPlanner
Lino.calview.DailyPlanner.GridPanel = Ext.extend(Lino.GridPanel,{
  use_detail_params_value : true,
  ls_url : "/calview/DailyPlanner",
  ls_store_fields : [ { "name": "overview" }, { "name": "vc0" }, { "name": "vc1" }, { "name": "id", "type": "int" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 26,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/calview/DailyPlanner','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/DailyPlanner','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/calview/DailyPlanner','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/DailyPlanner','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/calview/DailyPlanner','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Tagesplaner",
  initComponent : function() {
    var ww = this.containing_window;
    var overview_htmlbox4192 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "overview", "title": "Zeitabschnitt", "value": "<br/>" });
    var vc0_htmlbox4193 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc0", "title": "Extern", "value": "<br/>" });
    var vc1_htmlbox4194 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc1", "title": "Intern", "value": "<br/>" });
    this.before_row_edit = function(record) {
      overview_htmlbox4192.refresh();
      vc0_htmlbox4193.refresh();
      vc1_htmlbox4194.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "overview", "editable": false, "header": "Zeitabschnitt", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyPlanner.overview) ") }, "sortable": false, "tooltip": "(calview.DailyPlanner.overview) ", "width": Lino.chars2width(13) }, { "colIndex": 1, "dataIndex": "vc0", "editable": false, "header": "Extern", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyPlanner.vc0) ") }, "sortable": false, "tooltip": "(calview.DailyPlanner.vc0) ", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "vc1", "editable": false, "header": "Intern", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyPlanner.vc1) ") }, "sortable": false, "tooltip": "(calview.DailyPlanner.vc1) ", "width": Lino.chars2width(21) } ];
    Lino.calview.DailyPlanner.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.calview.DailyPlanner.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlanner", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlanner.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlanner", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlanner.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlanner", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlanner.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlanner", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlanner.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlanner", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlanner.grid = new Lino.WindowAction({  }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/calview/DailyPlanner" };
  p.params_panel = new Lino.calview.DailyPlanner.ParamsPanel({});
  return new Lino.calview.DailyPlanner.GridPanel(p);
});
Lino.calview.DailyPlanner.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlanner", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlanner.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlanner", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailyPlanner.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyPlanner", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class calview.DailySlave
Lino.calview.DailySlave.GridPanel = Ext.extend(Lino.GridPanel,{
  use_detail_params_value : true,
  ls_url : "/calview/DailySlave",
  ls_store_fields : [ { "name": "overview" }, { "name": "vc0" }, { "name": "vc1" }, { "name": "id", "type": "int" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 26,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/calview/DailySlave','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/DailySlave','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/calview/DailySlave','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/DailySlave','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/calview/DailySlave','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : null,
  initComponent : function() {
    var ww = this.containing_window;
    var overview_htmlbox2620 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "overview", "title": "Zeitabschnitt", "value": "<br/>" });
    var vc0_htmlbox2621 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc0", "title": "Extern", "value": "<br/>" });
    var vc1_htmlbox2622 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc1", "title": "Intern", "value": "<br/>" });
    this.before_row_edit = function(record) {
      overview_htmlbox2620.refresh();
      vc0_htmlbox2621.refresh();
      vc1_htmlbox2622.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "overview", "editable": false, "header": "Zeitabschnitt", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailySlave.overview) ") }, "sortable": false, "tooltip": "(calview.DailySlave.overview) ", "width": Lino.chars2width(13) }, { "colIndex": 1, "dataIndex": "vc0", "editable": false, "header": "Extern", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailySlave.vc0) ") }, "sortable": false, "tooltip": "(calview.DailySlave.vc0) ", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "vc1", "editable": false, "header": "Intern", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailySlave.vc1) ") }, "sortable": false, "tooltip": "(calview.DailySlave.vc1) ", "width": Lino.chars2width(21) } ];
    Lino.calview.DailySlave.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.calview.DailySlave.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailySlave", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailySlave.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailySlave", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailySlave.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailySlave", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailySlave.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailySlave", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailySlave.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailySlave", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailySlave.grid = new Lino.WindowAction({  }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/calview/DailySlave" };
  p.params_panel = new Lino.calview.DailySlave.ParamsPanel({});
  return new Lino.calview.DailySlave.GridPanel(p);
});
Lino.calview.DailySlave.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailySlave", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailySlave.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailySlave", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.DailySlave.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailySlave", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class calview.WeeklySlave
Lino.calview.WeeklySlave.GridPanel = Ext.extend(Lino.GridPanel,{
  use_detail_params_value : true,
  ls_url : "/calview/WeeklySlave",
  ls_store_fields : [ { "name": "overview" }, { "name": "vc0" }, { "name": "vc1" }, { "name": "vc2" }, { "name": "vc3" }, { "name": "vc4" }, { "name": "vc5" }, { "name": "vc6" }, { "name": "id", "type": "int" } ],
  ls_id_property : "id",
  pk_index : 8,
  content_type : 26,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/calview/WeeklySlave','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/WeeklySlave','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/calview/WeeklySlave','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/WeeklySlave','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/calview/WeeklySlave','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : null,
  initComponent : function() {
    var ww = this.containing_window;
    var overview_htmlbox1069 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "overview", "title": "Zeitabschnitt", "value": "<br/>" });
    var vc0_htmlbox1070 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc0", "title": "Montag", "value": "<br/>" });
    var vc1_htmlbox1071 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc1", "title": "Dienstag", "value": "<br/>" });
    var vc2_htmlbox1072 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc2", "title": "Mittwoch", "value": "<br/>" });
    var vc3_htmlbox1073 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc3", "title": "Donnerstag", "value": "<br/>" });
    var vc4_htmlbox1074 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc4", "title": "Freitag", "value": "<br/>" });
    var vc5_htmlbox1075 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc5", "title": "Samstag", "value": "<br/>" });
    var vc6_htmlbox1076 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc6", "title": "Sonntag", "value": "<br/>" });
    this.before_row_edit = function(record) {
      overview_htmlbox1069.refresh();
      vc0_htmlbox1070.refresh();
      vc1_htmlbox1071.refresh();
      vc2_htmlbox1072.refresh();
      vc3_htmlbox1073.refresh();
      vc4_htmlbox1074.refresh();
      vc5_htmlbox1075.refresh();
      vc6_htmlbox1076.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "overview", "editable": false, "header": "Zeitabschnitt", "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklySlave.overview) ") }, "sortable": false, "tooltip": "(calview.WeeklySlave.overview) ", "width": Lino.chars2width(13) }, { "colIndex": 1, "dataIndex": "vc0", "editable": false, "header": "Montag", "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklySlave.vc0) ") }, "sortable": false, "tooltip": "(calview.WeeklySlave.vc0) ", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "vc1", "editable": false, "header": "Dienstag", "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklySlave.vc1) ") }, "sortable": false, "tooltip": "(calview.WeeklySlave.vc1) ", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "vc2", "editable": false, "header": "Mittwoch", "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklySlave.vc2) ") }, "sortable": false, "tooltip": "(calview.WeeklySlave.vc2) ", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "vc3", "editable": false, "header": "Donnerstag", "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklySlave.vc3) ") }, "sortable": false, "tooltip": "(calview.WeeklySlave.vc3) ", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "vc4", "editable": false, "header": "Freitag", "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklySlave.vc4) ") }, "sortable": false, "tooltip": "(calview.WeeklySlave.vc4) ", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "vc5", "editable": false, "header": "Samstag", "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklySlave.vc5) ") }, "sortable": false, "tooltip": "(calview.WeeklySlave.vc5) ", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "vc6", "editable": false, "header": "Sonntag", "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklySlave.vc6) ") }, "sortable": false, "tooltip": "(calview.WeeklySlave.vc6) ", "width": Lino.chars2width(21) } ];
    Lino.calview.WeeklySlave.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.calview.WeeklySlave.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/WeeklySlave", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.WeeklySlave.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/WeeklySlave", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.WeeklySlave.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/WeeklySlave", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.WeeklySlave.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/WeeklySlave", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.WeeklySlave.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/WeeklySlave", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.WeeklySlave.grid = new Lino.WindowAction({  }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/calview/WeeklySlave" };
  p.params_panel = new Lino.calview.WeeklySlave.ParamsPanel({});
  return new Lino.calview.WeeklySlave.GridPanel(p);
});
Lino.calview.WeeklySlave.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/WeeklySlave", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.WeeklySlave.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/WeeklySlave", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.WeeklySlave.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/WeeklySlave", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class uploads.UploadsByType
Lino.uploads.UploadsByType.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/uploads/UploadsByType",
  ls_store_fields : [ { "name": "file" }, { "name": "library_file" }, { "name": "description" }, { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "mimetype" }, { "name": "upload_area" }, 'upload_areaHidden', { "name": "volume" }, 'volumeHidden', { "name": "file_size", "type": "int", "useNull": true }, { "name": "owner" }, { "name": "type" }, 'typeHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 29,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadsByType','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadsByType','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadsByType','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadsByType','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadsByType','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Upload-Dateien",
  disabled_fields_index : 19,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.UploadsByType.detail;
    this.ls_insert_handler = Lino.uploads.UploadsByType.insert;
    var ww = this.containing_window;
    var file1864 = Lino.file_field_handler(this,{ "allowBlank": true, "maxLength": 100, "selectOnFocus": true });
    var library_file1865 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByType/library_file" }) }) });
    var description1866 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var user1867 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByType/user" }) }) });
    var id1868 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type1869 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByType/owner_type" }) }) });
    var owner_id1870 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByType/owner_id" }) }) });
    var mimetype1871 = new Ext.form.TextField({ "disabled": true, "hidden": true, "maxLength": 255 });
    var upload_area1872 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.uploads.UploadAreas });
    var volume1873 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Dateibibliothek ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByType/volume" }) }) });
    var file_size1874 = new Ext.form.NumberField({ "disabled": true, "hidden": true });
    var owner_disp1875 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    var type1876 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Upload-Art ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "uploads.UploadTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByType/type" }) }) });
    this.before_row_edit = function(record) {
      library_file1865.setContextValue('volume', record ? record.data['volumeHidden'] : undefined);
      owner_id1870.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      type1876.setContextValue('upload_area', record ? record.data['upload_areaHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof volume1873 !== 'undefined' && volume1873.on('change',Lino.chooser_handler(library_file1865,'volume'));
      typeof owner_type1869 !== 'undefined' && owner_type1869.on('change',Lino.chooser_handler(owner_id1870,'owner_type'));
      typeof upload_area1872 !== 'undefined' && upload_area1872.on('change',Lino.chooser_handler(type1876,'upload_area'));
      Lino.uploads.UploadsByType.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "file", "editable": true, "editor": file1864, "filter": { "type": "string" }, "header": "Datei", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.file) Pointer to the uploaded file itself (a Django FileField).") }, "sortable": true, "tooltip": "Pointer to the uploaded file itself (a Django FileField).", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "library_file", "editable": true, "editor": library_file1865, "filter": { "type": "string" }, "header": "Bibliotheksdatei", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.library_file) The path of this file, relative the volume's root.") }, "sortable": false, "tooltip": "The path of this file, relative the volume's root.", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "description", "editable": true, "editor": description1866, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.description) A short description entered manually by the user.") }, "sortable": true, "tooltip": "A short description entered manually by the user.", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "user", "editable": true, "editor": user1867, "filter": { "type": "string" }, "header": "Hochgeladen durch", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id1868, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type1869, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id1870, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 7, "dataIndex": "mimetype", "editable": false, "filter": { "type": "string" }, "header": "MIME-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.mimetype) The media type of the\nuploaded file.") }, "sortable": true, "tooltip": "The media type of the\nuploaded file.", "width": Lino.chars2width(22) }, { "colIndex": 8, "dataIndex": "upload_area", "editable": true, "editor": upload_area1872, "filter": { "options": [ "Uploads" ], "type": "list" }, "header": "Upload-Bereich", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.upload_area) The upload area this file belongs to.") }, "sortable": false, "tooltip": "The upload area this file belongs to.", "width": Lino.chars2width(11) }, { "colIndex": 9, "dataIndex": "volume", "editable": true, "editor": volume1873, "filter": { "type": "string" }, "header": "Dateibibliothek", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.volume) A pointer to the library volume where this file is stored.") }, "renderer": Lino.fk_renderer('volumeHidden','Lino.uploads.Volumes.detail'), "sortable": false, "tooltip": "A pointer to the library volume where this file is stored.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 10, "dataIndex": "file_size", "editable": false, "filter": { "type": "numeric" }, "format": "0", "header": "File size", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.file_size) The size of the file in bytes. Not yet implemented.") }, "sortable": true, "tooltip": "The size of the file in bytes. Not yet implemented.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 11, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.owner) ") }, "sortable": false, "tooltip": "(uploads.UploadsByType.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 12, "dataIndex": "type", "editable": true, "editor": type1876, "filter": { "type": "string" }, "header": "Upload-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByType.type) The type of this upload.") }, "renderer": Lino.fk_renderer('typeHidden','Lino.uploads.UploadTypes.detail'), "sortable": false, "tooltip": "The type of this upload.", "width": Lino.chars2width(21) } ];
    Lino.uploads.UploadsByType.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.UploadsByType.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByType", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByType.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByType", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByType.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByType", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByType.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByType", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.UploadsByType.insertPanel = Ext.extend(Lino.uploads.Uploads.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/uploads/UploadsByType",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.UploadsByType.detail;
    this.ls_insert_handler = Lino.uploads.UploadsByType.insert;
    Lino.uploads.UploadsByType.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.UploadsByType.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/uploads/UploadsByType" };
  return new Lino.uploads.UploadsByType.insertPanel(p);
});
Lino.uploads.UploadsByType.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByType", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.UploadsByType.detailPanel = Ext.extend(Lino.uploads.Uploads.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/uploads/UploadsByType",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.UploadsByType.detail;
    this.ls_insert_handler = Lino.uploads.UploadsByType.insert;
    Lino.uploads.UploadsByType.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.UploadsByType.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/UploadsByType" };
  return new Lino.uploads.UploadsByType.detailPanel(p);
});
Lino.uploads.UploadsByType.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByType", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByType.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByType", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByType.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByType", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByType.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/UploadsByType" };
  p.params_panel = new Lino.uploads.Uploads.ParamsPanel({});
  return new Lino.uploads.UploadsByType.GridPanel(p);
});
Lino.uploads.UploadsByType.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByType", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class sepa.AccountsByPartner
Lino.sepa.AccountsByPartner.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/sepa/AccountsByPartner",
  ls_store_fields : [ { "name": "iban" }, { "name": "bic" }, { "name": "remark" }, { "name": "primary", "type": "boolean" }, { "name": "id", "type": "int" }, { "name": "partner" }, 'partnerHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 40,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/sepa/AccountsByPartner','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/sepa/AccountsByPartner','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/sepa/AccountsByPartner','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/sepa/AccountsByPartner','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/sepa/AccountsByPartner','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Bankkonto) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Bankkonten",
  disabled_fields_index : 7,
  initComponent : function() {
    this.ls_insert_handler = Lino.sepa.AccountsByPartner.insert;
    var ww = this.containing_window;
    var iban648 = new Lino.UppercaseTextField({ "allowBlank": false, "maxLength": 34, "selectOnFocus": true });
    var bic649 = new Lino.UppercaseTextField({ "allowBlank": true, "maxLength": 11, "selectOnFocus": true });
    var remark650 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var primary651 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var id652 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var partner653 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Partner ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/sepa/AccountsByPartner/partner" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "iban", "editable": true, "editor": iban648, "filter": { "type": "string" }, "header": "IBAN", "listeners": { "render": Lino.quicktip_renderer("","(sepa.AccountsByPartner.iban) ") }, "renderer": Lino.iban_renderer, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "bic", "editable": true, "editor": bic649, "filter": { "type": "string" }, "header": "BIC", "listeners": { "render": Lino.quicktip_renderer("","(sepa.AccountsByPartner.bic) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(13) }, { "colIndex": 2, "dataIndex": "remark", "editable": true, "editor": remark650, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(sepa.AccountsByPartner.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "listeners": { "render": Lino.quicktip_renderer("","(sepa.AccountsByPartner.primary) Enabling this field will automatically disable any previous primary account and update the partner's IBAN and BIC") }, "sortable": false, "tooltip": "Enabling this field will automatically disable any previous primary account and update the partner's IBAN and BIC", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id652, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(sepa.AccountsByPartner.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "partner", "editable": true, "editor": partner653, "filter": { "type": "string" }, "header": "Partner", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(sepa.AccountsByPartner.partner) Partner") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "Partner", "width": Lino.chars2width(21) } ];
    Lino.sepa.AccountsByPartner.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.sepa.AccountsByPartner.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/AccountsByPartner", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.sepa.AccountsByPartner.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/AccountsByPartner", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.sepa.AccountsByPartner.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/AccountsByPartner", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.sepa.AccountsByPartner.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/AccountsByPartner", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.sepa.AccountsByPartner.insertPanel = Ext.extend(Lino.sepa.AccountsByPartner.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/sepa/AccountsByPartner",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_insert_handler = Lino.sepa.AccountsByPartner.insert;
    Lino.sepa.AccountsByPartner.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.sepa.AccountsByPartner.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/sepa/AccountsByPartner" };
  return new Lino.sepa.AccountsByPartner.insertPanel(p);
});
Lino.sepa.AccountsByPartner.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/AccountsByPartner", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.sepa.AccountsByPartner.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/sepa/AccountsByPartner", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.sepa.AccountsByPartner.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/sepa/AccountsByPartner" };
  return new Lino.sepa.AccountsByPartner.GridPanel(p);
});

// js_render_GridPanel_class addresses.AddressesByPartner
Lino.addresses.AddressesByPartner.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/addresses/AddressesByPartner",
  ls_store_fields : [ { "name": "address_type" }, 'address_typeHidden', { "name": "remark" }, { "name": "address_column" }, { "name": "primary", "type": "boolean" }, { "name": "id", "type": "int" }, { "name": "country" }, 'countryHidden', { "name": "city" }, 'cityHidden', { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street" }, { "name": "street_no" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "data_source" }, 'data_sourceHidden', { "name": "partner" }, 'partnerHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 41,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByPartner','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByPartner','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByPartner','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByPartner','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByPartner','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByPartner','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Adresse) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Adressen",
  disabled_fields_index : 23,
  initComponent : function() {
    this.ls_detail_handler = Lino.addresses.AddressesByPartner.detail;
    this.ls_insert_handler = Lino.addresses.AddressesByPartner.insert;
    var ww = this.containing_window;
    var address_type4196 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.addresses.AddressTypes });
    var remark4197 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 50, "selectOnFocus": true });
    var address_column_disp4198 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var primary4199 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var id4200 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var country4201 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/AddressesByPartner/country" }) }) });
    var city4202 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/AddressesByPartner/city" }) }) });
    var zip_code4203 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region4204 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/AddressesByPartner/region" }) }) });
    var addr14205 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix4206 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street4207 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_no4208 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var street_box4209 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr24210 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var data_source4211 = new Lino.ChoicesFieldElement({ "disabled": true, "forceSelection": true, "hidden": true, "store": Lino.addresses.DataSources });
    var partner4212 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partner ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/AddressesByPartner/partner" }) }) });
    this.before_row_edit = function(record) {
      city4202.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city4202.setContextValue('region', record ? record.data['regionHidden'] : undefined);
      region4204.setContextValue('country', record ? record.data['countryHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof country4201 !== 'undefined' && country4201.on('change',Lino.chooser_handler(city4202,'country'));
      typeof region4204 !== 'undefined' && region4204.on('change',Lino.chooser_handler(city4202,'region'));
      typeof country4201 !== 'undefined' && country4201.on('change',Lino.chooser_handler(region4204,'country'));
      Lino.addresses.AddressesByPartner.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "address_type", "editable": true, "editor": address_type4196, "filter": { "options": [ "Offizielle Adresse", "Ungepr\u00fcfte Adresse", "Deklarierte Addresse", "Referenzadresse", "Veraltet", "Sonstige" ], "type": "list" }, "header": "Adressenart", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.address_type) The type of this address record.\nA pointer to AddressTypes.\nThe default value is AddressTypes.official.") }, "sortable": false, "tooltip": "The type of this address record.\nA pointer to AddressTypes.\nThe default value is AddressTypes.official.", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "remark", "editable": true, "editor": remark4197, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "address_column", "editable": false, "header": "Adresse", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.address_column) ") }, "sortable": false, "tooltip": "(addresses.AddressesByPartner.address_column) ", "width": Lino.chars2width(31) }, { "colIndex": 3, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.primary) Whether this address is the primary address of its owner.\nSetting this field will automatically uncheck any previousl\nprimary addresses and update the owner's address fields.") }, "sortable": false, "tooltip": "Whether this address is the primary address of its owner.\nSetting this field will automatically uncheck any previousl\nprimary addresses and update the owner's address fields.", "width": Lino.chars2width(6), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id4200, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "country", "editable": true, "editor": country4201, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "city", "editable": true, "editor": city4202, "filter": { "type": "string" }, "header": "Ortschaft", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "zip_code", "editable": true, "editor": zip_code4203, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 8, "dataIndex": "region", "editable": true, "editor": region4204, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "addr1", "editable": true, "editor": addr14205, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 10, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix4206, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 11, "dataIndex": "street", "editable": true, "editor": street4207, "filter": { "type": "string" }, "header": "Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 12, "dataIndex": "street_no", "editable": true, "editor": street_no4208, "filter": { "type": "string" }, "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 13, "dataIndex": "street_box", "editable": true, "editor": street_box4209, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 14, "dataIndex": "addr2", "editable": true, "editor": addr24210, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "data_source", "editable": false, "filter": { "options": [ "Manuell eingegeben", "Eingelesen von eID-Karte" ], "type": "list" }, "header": "Datenquelle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.data_source) Pointer to DataSources.") }, "sortable": false, "tooltip": "Pointer to DataSources.", "width": Lino.chars2width(20) }, { "colIndex": 16, "dataIndex": "partner", "editable": true, "editor": partner4212, "filter": { "type": "string" }, "header": "Partner", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByPartner.partner) ") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.addresses.AddressesByPartner.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.AddressesByPartner.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByPartner", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressesByPartner.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByPartner", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressesByPartner.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByPartner", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressesByPartner.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByPartner", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressesByPartner.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByPartner", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.addresses.AddressesByPartner.insertPanel = Ext.extend(Lino.addresses.Addresses.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/addresses/AddressesByPartner",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.addresses.AddressesByPartner.detail;
    this.ls_insert_handler = Lino.addresses.AddressesByPartner.insert;
    Lino.addresses.AddressesByPartner.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.AddressesByPartner.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/addresses/AddressesByPartner" };
  return new Lino.addresses.AddressesByPartner.insertPanel(p);
});
Lino.addresses.AddressesByPartner.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByPartner", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.addresses.AddressesByPartner.detailPanel = Ext.extend(Lino.addresses.Addresses.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Adresse) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/addresses/AddressesByPartner",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.addresses.AddressesByPartner.detail;
    this.ls_insert_handler = Lino.addresses.AddressesByPartner.insert;
    Lino.addresses.AddressesByPartner.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.AddressesByPartner.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/addresses/AddressesByPartner" };
  return new Lino.addresses.AddressesByPartner.detailPanel(p);
});
Lino.addresses.AddressesByPartner.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByPartner", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressesByPartner.grid = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(20), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/addresses/AddressesByPartner" };
  p.params_panel = new Lino.addresses.Addresses.ParamsPanel({});
  return new Lino.addresses.AddressesByPartner.GridPanel(p);
});
Lino.addresses.AddressesByPartner.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByPartner", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class addresses.AddressesByCity
Lino.addresses.AddressesByCity.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/addresses/AddressesByCity",
  ls_store_fields : [ { "name": "address_type" }, 'address_typeHidden', { "name": "partner" }, 'partnerHidden', { "name": "remark" }, { "name": "street" }, { "name": "primary", "type": "boolean" }, { "name": "id", "type": "int" }, { "name": "country" }, 'countryHidden', { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street_no" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "data_source" }, 'data_sourceHidden', { "name": "city" }, 'cityHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 41,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByCity','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByCity','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByCity','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByCity','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByCity','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressesByCity','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Adresse) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Adressen",
  disabled_fields_index : 22,
  initComponent : function() {
    this.ls_detail_handler = Lino.addresses.AddressesByCity.detail;
    this.ls_insert_handler = Lino.addresses.AddressesByCity.insert;
    var ww = this.containing_window;
    var address_type1161 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.addresses.AddressTypes });
    var partner1162 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partner ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/AddressesByCity/partner" }) }) });
    var remark1163 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 50, "selectOnFocus": true });
    var street1164 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var primary1165 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var id1166 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var country1167 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/AddressesByCity/country" }) }) });
    var zip_code1168 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region1169 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/AddressesByCity/region" }) }) });
    var addr11170 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix1171 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_no1172 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var street_box1173 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr21174 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var data_source1175 = new Lino.ChoicesFieldElement({ "disabled": true, "forceSelection": true, "hidden": true, "store": Lino.addresses.DataSources });
    var city1176 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/addresses/AddressesByCity/city" }) }) });
    this.before_row_edit = function(record) {
      region1169.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city1176.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city1176.setContextValue('region', record ? record.data['regionHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof country1167 !== 'undefined' && country1167.on('change',Lino.chooser_handler(region1169,'country'));
      typeof country1167 !== 'undefined' && country1167.on('change',Lino.chooser_handler(city1176,'country'));
      typeof region1169 !== 'undefined' && region1169.on('change',Lino.chooser_handler(city1176,'region'));
      Lino.addresses.AddressesByCity.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "address_type", "editable": true, "editor": address_type1161, "filter": { "options": [ "Offizielle Adresse", "Ungepr\u00fcfte Adresse", "Deklarierte Addresse", "Referenzadresse", "Veraltet", "Sonstige" ], "type": "list" }, "header": "Adressenart", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.address_type) The type of this address record.\nA pointer to AddressTypes.\nThe default value is AddressTypes.official.") }, "sortable": false, "tooltip": "The type of this address record.\nA pointer to AddressTypes.\nThe default value is AddressTypes.official.", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "partner", "editable": true, "editor": partner1162, "filter": { "type": "string" }, "header": "Partner", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.partner) ") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "remark", "editable": true, "editor": remark1163, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 3, "dataIndex": "street", "editable": true, "editor": street1164, "filter": { "type": "string" }, "header": "Stra\u00dfe", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.primary) Whether this address is the primary address of its owner.\nSetting this field will automatically uncheck any previousl\nprimary addresses and update the owner's address fields.") }, "sortable": false, "tooltip": "Whether this address is the primary address of its owner.\nSetting this field will automatically uncheck any previousl\nprimary addresses and update the owner's address fields.", "width": Lino.chars2width(6), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id1166, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "country", "editable": true, "editor": country1167, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "zip_code", "editable": true, "editor": zip_code1168, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 8, "dataIndex": "region", "editable": true, "editor": region1169, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "addr1", "editable": true, "editor": addr11170, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 10, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix1171, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 11, "dataIndex": "street_no", "editable": true, "editor": street_no1172, "filter": { "type": "string" }, "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 12, "dataIndex": "street_box", "editable": true, "editor": street_box1173, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 13, "dataIndex": "addr2", "editable": true, "editor": addr21174, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "data_source", "editable": false, "filter": { "options": [ "Manuell eingegeben", "Eingelesen von eID-Karte" ], "type": "list" }, "header": "Datenquelle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.data_source) Pointer to DataSources.") }, "sortable": false, "tooltip": "Pointer to DataSources.", "width": Lino.chars2width(20) }, { "colIndex": 15, "dataIndex": "city", "editable": true, "editor": city1176, "filter": { "type": "string" }, "header": "Ortschaft", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressesByCity.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) } ];
    Lino.addresses.AddressesByCity.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.AddressesByCity.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByCity", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressesByCity.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByCity", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressesByCity.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByCity", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressesByCity.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByCity", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressesByCity.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByCity", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.addresses.AddressesByCity.insertPanel = Ext.extend(Lino.addresses.Addresses.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/addresses/AddressesByCity",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.addresses.AddressesByCity.detail;
    this.ls_insert_handler = Lino.addresses.AddressesByCity.insert;
    Lino.addresses.AddressesByCity.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.AddressesByCity.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/addresses/AddressesByCity" };
  return new Lino.addresses.AddressesByCity.insertPanel(p);
});
Lino.addresses.AddressesByCity.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByCity", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.addresses.AddressesByCity.detailPanel = Ext.extend(Lino.addresses.Addresses.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Adresse) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/addresses/AddressesByCity",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.addresses.AddressesByCity.detail;
    this.ls_insert_handler = Lino.addresses.AddressesByCity.insert;
    Lino.addresses.AddressesByCity.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.AddressesByCity.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/addresses/AddressesByCity" };
  return new Lino.addresses.AddressesByCity.detailPanel(p);
});
Lino.addresses.AddressesByCity.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByCity", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressesByCity.grid = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(20), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/addresses/AddressesByCity" };
  p.params_panel = new Lino.addresses.Addresses.ParamsPanel({});
  return new Lino.addresses.AddressesByCity.GridPanel(p);
});
Lino.addresses.AddressesByCity.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressesByCity", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class phones.ContactDetailsByPartner
Lino.phones.ContactDetailsByPartner.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/phones/ContactDetailsByPartner",
  ls_store_fields : [ { "name": "detail_type" }, 'detail_typeHidden', { "name": "value" }, { "name": "primary", "type": "boolean" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "remark" }, { "name": "id", "type": "int" }, { "name": "partner" }, 'partnerHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 42,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetailsByPartner','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetailsByPartner','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetailsByPartner','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetailsByPartner','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetailsByPartner','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kontaktangabe) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kontaktangaben",
  disabled_fields_index : 9,
  initComponent : function() {
    this.ls_detail_handler = Lino.phones.ContactDetailsByPartner.detail;
    this.ls_insert_handler = Lino.phones.ContactDetailsByPartner.insert;
    var ww = this.containing_window;
    var detail_type4214 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.phones.ContactDetailTypes });
    var value4215 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var primary4216 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var end_date4217 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var remark4218 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id4219 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var partner4220 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partner ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/phones/ContactDetailsByPartner/partner" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_type", "editable": true, "editor": detail_type4214, "filter": { "options": [ "E-Mail", "Handy", "Telefon", "Website", "Fax", "Sonstige" ], "type": "list" }, "header": "Kontaktangabenart", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailsByPartner.detail_type) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "value", "editable": true, "editor": value4215, "filter": { "type": "string" }, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailsByPartner.value) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(31) }, { "colIndex": 2, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailsByPartner.primary) Whether this item is the primary contact detail for this type\nand this owner.  Setting this field will automatically uncheck\nany previously primary items and update the owner's contact\ndetail fields.") }, "sortable": false, "tooltip": "Whether this item is the primary contact detail for this type\nand this owner.  Setting this field will automatically uncheck\nany previously primary items and update the owner's contact\ndetail fields.", "width": Lino.chars2width(6), "xtype": "checkcolumn" }, { "colIndex": 3, "dataIndex": "end_date", "editable": true, "editor": end_date4217, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Bis", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailsByPartner.end_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 4, "dataIndex": "remark", "editable": true, "editor": remark4218, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailsByPartner.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id4219, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailsByPartner.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "partner", "editable": true, "editor": partner4220, "filter": { "type": "string" }, "header": "Partner", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailsByPartner.partner) ") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.phones.ContactDetailsByPartner.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.phones.ContactDetailsByPartner.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailsByPartner", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetailsByPartner.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailsByPartner", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetailsByPartner.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailsByPartner", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetailsByPartner.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailsByPartner", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.phones.ContactDetailsByPartner.insertPanel = Ext.extend(Lino.phones.ContactDetails.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/phones/ContactDetailsByPartner",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.phones.ContactDetailsByPartner.detail;
    this.ls_insert_handler = Lino.phones.ContactDetailsByPartner.insert;
    Lino.phones.ContactDetailsByPartner.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.phones.ContactDetailsByPartner.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/phones/ContactDetailsByPartner" };
  return new Lino.phones.ContactDetailsByPartner.insertPanel(p);
});
Lino.phones.ContactDetailsByPartner.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailsByPartner", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.phones.ContactDetailsByPartner.detailPanel = Ext.extend(Lino.phones.ContactDetails.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kontaktangabe) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/phones/ContactDetailsByPartner",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.phones.ContactDetailsByPartner.detail;
    this.ls_insert_handler = Lino.phones.ContactDetailsByPartner.insert;
    Lino.phones.ContactDetailsByPartner.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.phones.ContactDetailsByPartner.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/phones/ContactDetailsByPartner" };
  return new Lino.phones.ContactDetailsByPartner.detailPanel(p);
});
Lino.phones.ContactDetailsByPartner.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailsByPartner", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetailsByPartner.grid = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(20), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/phones/ContactDetailsByPartner" };
  p.params_panel = new Lino.phones.ContactDetails.ParamsPanel({});
  return new Lino.phones.ContactDetailsByPartner.GridPanel(p);
});
Lino.phones.ContactDetailsByPartner.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailsByPartner", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class households.HouseholdsByType
Lino.households.HouseholdsByType.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/households/HouseholdsByType",
  ls_store_fields : [ { "name": "name" }, { "name": "type" }, 'typeHidden', { "name": "address_column" }, { "name": "id", "type": "int" }, { "name": "email" }, { "name": "language" }, 'languageHidden', { "name": "url" }, { "name": "phone" }, { "name": "gsm" }, { "name": "fax" }, { "name": "country" }, 'countryHidden', { "name": "city" }, 'cityHidden', { "name": "zip_code" }, { "name": "region" }, 'regionHidden', { "name": "addr1" }, { "name": "street_prefix" }, { "name": "street" }, { "name": "street_no" }, { "name": "street_box" }, { "name": "addr2" }, { "name": "prefix" }, { "name": "remarks" }, { "name": "payment_term" }, 'payment_termHidden', { "name": "purchase_account" }, 'purchase_accountHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 6,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/households/HouseholdsByType','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/HouseholdsByType','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/households/HouseholdsByType','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "print_labels", "menu_item_text": "Etiketten", "overflowText": "Etiketten", "panel_btn_handler": Lino.list_action_handler('/households/HouseholdsByType','print_labels','GET',Lino.get_current_grid_config), "text": "Etiketten", "tooltip": "Add this action to your table, which is expected to execute on a\nmodel which implements\nAddressable.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/HouseholdsByType','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/households/HouseholdsByType','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/households/HouseholdsByType','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Haushalt) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.households.Households.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-lightning", "itemId": "populate_members", "menu_item_text": "Populate", "overflowText": "Populate", "panel_btn_handler": Lino.row_action_handler('populate_members','GET',null), "tooltip": "Populate household members from data in human links.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Haushalte",
  disabled_fields_index : 31,
  initComponent : function() {
    this.ls_detail_handler = Lino.households.HouseholdsByType.detail;
    this.ls_insert_handler = Lino.households.HouseholdsByType.insert;
    var ww = this.containing_window;
    var name2470 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var type2471 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Haushaltsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "households.Types", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/HouseholdsByType/type" }) }) });
    var address_column_disp2472 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id2473 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var email2474 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 254, "selectOnFocus": true });
    var language2475 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var url2476 = new Lino.URLField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var phone2477 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var gsm2478 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var fax2479 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var country2480 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Land ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Countries", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/HouseholdsByType/country" }) }) });
    var city2481 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": true, "emptyText": "Ort ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/HouseholdsByType/city" }) }) });
    var zip_code2482 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var region2483 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Ort ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "countries.Places", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/HouseholdsByType/region" }) }) });
    var addr12484 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_prefix2485 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street2486 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var street_no2487 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var street_box2488 = new Ext.form.TextField({ "allowBlank": true, "boxMinWidth": Lino.chars2width(10), "hidden": true, "maxLength": 10, "selectOnFocus": true });
    var addr22489 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var prefix2490 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var remarks2491 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkungen" });
    var payment_term2492 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Zahlungsbedingungen ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.PaymentTerms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/HouseholdsByType/payment_term" }) }) });
    var purchase_account2493 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Konto ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "ledger.Accounts", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/HouseholdsByType/purchase_account" }) }) });
    this.before_row_edit = function(record) {
      city2481.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      city2481.setContextValue('region', record ? record.data['regionHidden'] : undefined);
      region2483.setContextValue('country', record ? record.data['countryHidden'] : undefined);
      remarks2491.refresh();
    };
    this.onRender = function(ct, position) {
      typeof country2480 !== 'undefined' && country2480.on('change',Lino.chooser_handler(city2481,'country'));
      typeof region2483 !== 'undefined' && region2483.on('change',Lino.chooser_handler(city2481,'region'));
      typeof country2480 !== 'undefined' && country2480.on('change',Lino.chooser_handler(region2483,'country'));
      Lino.households.HouseholdsByType.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name", "editable": true, "editor": name2470, "filter": { "type": "string" }, "header": "Name", "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.name) The full name of this partner. Used for alphabetic sorting.") }, "sortable": true, "tooltip": "The full name of this partner. Used for alphabetic sorting.", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "type", "editable": true, "editor": type2471, "filter": { "type": "string" }, "header": "Haushaltsart", "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.type) The type of this household.  See household types") }, "renderer": Lino.fk_renderer('typeHidden','Lino.households.Types.detail'), "sortable": false, "tooltip": "The type of this household.  See household types", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "address_column", "editable": false, "header": "Adresse", "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.address_column) ") }, "sortable": false, "tooltip": "(households.HouseholdsByType.address_column) ", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id2473, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "email", "editable": true, "editor": email2474, "filter": { "type": "string" }, "header": "E-Mail-Adresse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.email) The primary email address.") }, "sortable": true, "tooltip": "The primary email address.", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "language", "editable": true, "editor": language2475, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.language) The language to use when communicating with this partner.") }, "sortable": false, "tooltip": "The language to use when communicating with this partner.", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "url", "editable": true, "editor": url2476, "filter": { "type": "string" }, "header": "Adresse (URL)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.url) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "phone", "editable": true, "editor": phone2477, "filter": { "type": "string" }, "header": "Telefon", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.phone) The primary phone number.") }, "sortable": true, "tooltip": "The primary phone number.", "width": Lino.chars2width(22) }, { "colIndex": 8, "dataIndex": "gsm", "editable": true, "editor": gsm2478, "filter": { "type": "string" }, "header": "GSM", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.gsm) The primary mobile phone number.") }, "sortable": true, "tooltip": "The primary mobile phone number.", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "fax", "editable": true, "editor": fax2479, "filter": { "type": "string" }, "header": "Fax", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.fax) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 10, "dataIndex": "country", "editable": true, "editor": country2480, "filter": { "type": "string" }, "header": "Land", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.country) ") }, "renderer": Lino.fk_renderer('countryHidden','Lino.countries.Countries.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "city", "editable": true, "editor": city2481, "filter": { "type": "string" }, "header": "Ortschaft", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.city) Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.") }, "renderer": Lino.fk_renderer('cityHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "Die Ortschaft, d.h. \u00fcblicherweise das Dorf oder die Stadt.", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "zip_code", "editable": true, "editor": zip_code2482, "filter": { "type": "string" }, "header": "Postleitzahl", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.zip_code) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 13, "dataIndex": "region", "editable": true, "editor": region2483, "filter": { "type": "string" }, "header": "Regierungsbezirk", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.region) ") }, "renderer": Lino.fk_renderer('regionHidden','Lino.countries.Places.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "addr1", "editable": true, "editor": addr12484, "filter": { "type": "string" }, "header": "Adresszeile vor Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.addr1) Adresszeile vor Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile vor Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "street_prefix", "editable": true, "editor": street_prefix2485, "filter": { "type": "string" }, "header": "Pr\u00e4fix Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.street_prefix) Text to print before name of street, but to ignore for sorting.") }, "sortable": true, "tooltip": "Text to print before name of street, but to ignore for sorting.", "width": Lino.chars2width(22) }, { "colIndex": 16, "dataIndex": "street", "editable": true, "editor": street2486, "filter": { "type": "string" }, "header": "Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.street) Name der Stra\u00dfe, ohne Hausnummer") }, "sortable": true, "tooltip": "Name der Stra\u00dfe, ohne Hausnummer", "width": Lino.chars2width(22) }, { "colIndex": 17, "dataIndex": "street_no", "editable": true, "editor": street_no2487, "filter": { "type": "string" }, "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.street_no) Hausnummer") }, "sortable": true, "tooltip": "Hausnummer", "width": Lino.chars2width(12) }, { "colIndex": 18, "dataIndex": "street_box", "editable": true, "editor": street_box2488, "filter": { "type": "string" }, "header": "Box", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.street_box) Text to print after street number on the same line.") }, "sortable": true, "tooltip": "Text to print after street number on the same line.", "width": Lino.chars2width(12) }, { "colIndex": 19, "dataIndex": "addr2", "editable": true, "editor": addr22489, "filter": { "type": "string" }, "header": "Adresszeile nach Stra\u00dfe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.addr2) Adresszeile nach Stra\u00dfe") }, "sortable": true, "tooltip": "Adresszeile nach Stra\u00dfe", "width": Lino.chars2width(22) }, { "colIndex": 20, "dataIndex": "prefix", "editable": true, "editor": prefix2490, "filter": { "type": "string" }, "header": "Name prefix", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.prefix) An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.") }, "sortable": true, "tooltip": "An optional name prefix. For organisations this is inserted\nbefore the name, for persons this is inserted between first\nname and last name.", "width": Lino.chars2width(22) }, { "colIndex": 21, "dataIndex": "remarks", "editable": true, "editor": remarks2491, "filter": { "type": "string" }, "header": "Bemerkungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.remarks) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 22, "dataIndex": "payment_term", "editable": true, "editor": payment_term2492, "filter": { "type": "string" }, "header": "Zahlungsbedingungen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.payment_term) The default payment term for sales invoices to this customer.") }, "sortable": false, "tooltip": "The default payment term for sales invoices to this customer.", "width": Lino.chars2width(21) }, { "colIndex": 23, "dataIndex": "purchase_account", "editable": true, "editor": purchase_account2493, "filter": { "type": "string" }, "header": "Konto Einkauf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.HouseholdsByType.purchase_account) The general account to suggest as default value in purchase\ninvoices from this partner.") }, "sortable": false, "tooltip": "The general account to suggest as default value in purchase\ninvoices from this partner.", "width": Lino.chars2width(21) } ];
    Lino.households.HouseholdsByType.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.households.HouseholdsByType.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.export_vcf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "export_vcf", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.print_labels = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "print_labels", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.households.HouseholdsByType.insertPanel = Ext.extend(Lino.households.HouseholdsByType.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/households/HouseholdsByType",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.households.HouseholdsByType.detail;
    this.ls_insert_handler = Lino.households.HouseholdsByType.insert;
    Lino.households.HouseholdsByType.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.households.HouseholdsByType.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/households/HouseholdsByType" };
  return new Lino.households.HouseholdsByType.insertPanel(p);
});
Lino.households.HouseholdsByType.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.households.HouseholdsByType.detailPanel = Ext.extend(Lino.households.Households.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-vcard", "itemId": "export_vcf", "menu_item_text": "Export as vCard", "overflowText": "Export as vCard", "panel_btn_handler": Lino.list_action_handler('/households/HouseholdsByType','export_vcf','GET',null), "tooltip": "Download all records as a .vcf file which you can import to another\ncontacts application.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Haushalt) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.households.Households.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "create_excerpt2", "menu_item_text": "Payment reminder", "overflowText": "Payment reminder", "panel_btn_handler": Lino.row_action_handler('create_excerpt2','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "show_problems", "menu_item_text": "Datenprobleme", "overflowText": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": "Datenprobleme", "tooltip": "Datenprobleme", "tooltipType": "title" }, { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Datenprobleme", "panel_btn_handler": Lino.row_action_handler('show_problems','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-lightning", "itemId": "populate_members", "menu_item_text": "Populate", "overflowText": "Populate", "panel_btn_handler": Lino.row_action_handler('populate_members','GET',null), "tooltip": "Populate household members from data in human links.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/households/HouseholdsByType",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.households.HouseholdsByType.detail;
    this.ls_insert_handler = Lino.households.HouseholdsByType.insert;
    Lino.households.HouseholdsByType.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.households.HouseholdsByType.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/HouseholdsByType" };
  return new Lino.households.HouseholdsByType.detailPanel(p);
});
Lino.households.HouseholdsByType.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.create_excerpt2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "create_excerpt2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.due = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "due", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.show_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "show_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.del_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "del_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.del_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "del_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.del_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "del_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.del_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "del_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/HouseholdsByType" };
  p.params_panel = new Lino.contacts.Partners.ParamsPanel({});
  return new Lino.households.HouseholdsByType.GridPanel(p);
});
Lino.households.HouseholdsByType.ins_company = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "ins_company", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.ins_household = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "ins_household", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.ins_partner = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "ins_partner", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.ins_person = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "ins_person", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.populate_members = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "GET", pk, "populate_members", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.HouseholdsByType.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/HouseholdsByType", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class households.MembersByHousehold
Lino.households.MembersByHousehold.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/households/MembersByHousehold",
  ls_store_fields : [ { "name": "age" }, { "name": "role" }, 'roleHidden', { "name": "dependency" }, 'dependencyHidden', { "name": "person" }, 'personHidden', { "name": "first_name" }, { "name": "last_name" }, { "name": "birth_date" }, { "name": "gender" }, 'genderHidden', { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "title" }, { "name": "middle_name" }, { "name": "primary", "type": "boolean" }, { "name": "household" }, 'householdHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 12,
  content_type : 44,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/households/MembersByHousehold','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/MembersByHousehold','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/households/MembersByHousehold','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/MembersByHousehold','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/households/MembersByHousehold','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "set_primary", "menu_item_text": "set_primary", "overflowText": "set_primary", "panel_btn_handler": Lino.row_action_handler('set_primary','GET',null), "text": "set_primary", "tooltip": "Diesen Haushalt als prim\u00e4r markieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Mitglieder",
  disabled_fields_index : 20,
  initComponent : function() {
    var ww = this.containing_window;
    var age_disp2510 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var role2511 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.households.MemberRoles) });
    var dependency2512 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.households.MemberDependencies });
    var person2513 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/MembersByHousehold/person" }) }) });
    var first_name2514 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var last_name2515 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var birth_date2516 = new Lino.IncompleteDateField({ "allowBlank": true, "selectOnFocus": true });
    var gender2517 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.Genders) });
    var id2518 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date2519 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date2520 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var title2521 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var middle_name2522 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var primary2523 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var household2524 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Haushalt ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "households.Households", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/MembersByHousehold/household" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "age", "editable": false, "header": "Alter", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.age) Virtual field displaying the age in years.") }, "sortable": false, "tooltip": "Virtual field displaying the age in years.", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "role", "editable": true, "editor": role2511, "filter": { "options": [ "Vorstand", "Ehepartner", "Partner", "Mitbewohner", "Kind", "Verwandt", "Adoptivkind", "Pflegekind", "Sonstige" ], "type": "list" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.role) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "dependency", "editable": true, "editor": dependency2512, "filter": { "options": [ "Zu Lasten", "Nicht zu Lasten", "Lasten geteilt" ], "type": "list" }, "header": "Abh\u00e4ngigkeit", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.dependency) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(20) }, { "colIndex": 3, "dataIndex": "person", "editable": true, "editor": person2513, "filter": { "type": "string" }, "header": "Person", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.person) ") }, "renderer": Lino.fk_renderer('personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "first_name", "editable": true, "editor": first_name2514, "filter": { "type": "string" }, "header": "Vorname", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.first_name) The first name, also known as given name.") }, "sortable": true, "tooltip": "The first name, also known as given name.", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "last_name", "editable": true, "editor": last_name2515, "filter": { "type": "string" }, "header": "Familienname", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.last_name) The last name, also known as family name.") }, "sortable": true, "tooltip": "The last name, also known as family name.", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "birth_date", "editable": true, "editor": birth_date2516, "filter": { "type": "string" }, "header": "Geburtsdatum", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.birth_date) Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".") }, "sortable": true, "tooltip": "Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".", "width": Lino.chars2width(13) }, { "colIndex": 7, "dataIndex": "gender", "editable": true, "editor": gender2517, "filter": { "options": [ "M\u00e4nnlich", "Weiblich" ], "type": "list" }, "header": "Geschlecht", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.gender) The sex of this person (male or female).") }, "sortable": false, "tooltip": "The sex of this person (male or female).", "width": Lino.chars2width(10) }, { "align": "right", "colIndex": 8, "dataIndex": "id", "editable": true, "editor": id2518, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 9, "dataIndex": "start_date", "editable": true, "editor": start_date2519, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.start_date) Since when this membership exists. This is usually empty.") }, "sortable": true, "tooltip": "Since when this membership exists. This is usually empty.", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "end_date", "editable": true, "editor": end_date2520, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.end_date) Until when this membership exists.") }, "sortable": true, "tooltip": "Until when this membership exists.", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 11, "dataIndex": "title", "editable": true, "editor": title2521, "filter": { "type": "string" }, "header": "Titel", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.title) Eventuelle berufliche Position oder akademischer Titel, z.B. \"Dr.\" oder \"Prof.\"") }, "sortable": true, "tooltip": "Eventuelle berufliche Position oder akademischer Titel, z.B. \"Dr.\" oder \"Prof.\"", "width": Lino.chars2width(22) }, { "colIndex": 12, "dataIndex": "middle_name", "editable": true, "editor": middle_name2522, "filter": { "type": "string" }, "header": "Zwischenname", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.middle_name) A space-separated list of all middle names.") }, "sortable": true, "tooltip": "A space-separated list of all middle names.", "width": Lino.chars2width(22) }, { "colIndex": 13, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.primary) Whether this is the primary household of this person.\nChecking this field will automatically disable any other primary memberships.") }, "sortable": false, "tooltip": "Whether this is the primary household of this person.\nChecking this field will automatically disable any other primary memberships.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 14, "dataIndex": "household", "editable": true, "editor": household2524, "filter": { "type": "string" }, "header": "Haushalt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByHousehold.household) ") }, "renderer": Lino.fk_renderer('householdHidden','Lino.households.Households.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.households.MembersByHousehold.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.households.MembersByHousehold.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByHousehold", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MembersByHousehold.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByHousehold", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MembersByHousehold.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByHousehold", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MembersByHousehold.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByHousehold", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MembersByHousehold.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByHousehold", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MembersByHousehold.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/MembersByHousehold" };
  p.params_panel = new Lino.households.Members.ParamsPanel({});
  return new Lino.households.MembersByHousehold.GridPanel(p);
});
Lino.households.MembersByHousehold.set_primary = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByHousehold", "GET", pk, "set_primary", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class households.SiblingsByPerson
Lino.households.SiblingsByPerson.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/households/SiblingsByPerson",
  ls_store_fields : [ { "name": "age" }, { "name": "role" }, 'roleHidden', { "name": "dependency" }, 'dependencyHidden', { "name": "person" }, 'personHidden', { "name": "first_name" }, { "name": "last_name" }, { "name": "birth_date" }, { "name": "gender" }, 'genderHidden', { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "title" }, { "name": "middle_name" }, { "name": "household" }, 'householdHidden', { "name": "primary", "type": "boolean" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 12,
  content_type : 44,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/households/SiblingsByPerson','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/SiblingsByPerson','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/households/SiblingsByPerson','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/SiblingsByPerson','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/households/SiblingsByPerson','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "set_primary", "menu_item_text": "set_primary", "overflowText": "set_primary", "panel_btn_handler": Lino.row_action_handler('set_primary','GET',null), "text": "set_primary", "tooltip": "Diesen Haushalt als prim\u00e4r markieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Haushaltszusammensetzung",
  disabled_fields_index : 20,
  initComponent : function() {
    var ww = this.containing_window;
    var age_disp1669 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var role1670 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.households.MemberRoles) });
    var dependency1671 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.households.MemberDependencies });
    var person1672 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/SiblingsByPerson/person" }) }) });
    var first_name1673 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var last_name1674 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var birth_date1675 = new Lino.IncompleteDateField({ "allowBlank": true, "selectOnFocus": true });
    var gender1676 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.Genders) });
    var id1677 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date1678 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date1679 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var title1680 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var middle_name1681 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var household1682 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Haushalt ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "households.Households", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/SiblingsByPerson/household" }) }) });
    var primary1683 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "age", "editable": false, "header": "Alter", "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.age) Virtual field displaying the age in years.") }, "sortable": false, "tooltip": "Virtual field displaying the age in years.", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "role", "editable": true, "editor": role1670, "filter": { "options": [ "Vorstand", "Ehepartner", "Partner", "Mitbewohner", "Kind", "Verwandt", "Adoptivkind", "Pflegekind", "Sonstige" ], "type": "list" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.role) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "dependency", "editable": true, "editor": dependency1671, "filter": { "options": [ "Zu Lasten", "Nicht zu Lasten", "Lasten geteilt" ], "type": "list" }, "header": "Abh\u00e4ngigkeit", "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.dependency) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(20) }, { "colIndex": 3, "dataIndex": "person", "editable": true, "editor": person1672, "filter": { "type": "string" }, "header": "Person", "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.person) ") }, "renderer": Lino.fk_renderer('personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "first_name", "editable": true, "editor": first_name1673, "filter": { "type": "string" }, "header": "Vorname", "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.first_name) The first name, also known as given name.") }, "sortable": true, "tooltip": "The first name, also known as given name.", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "last_name", "editable": true, "editor": last_name1674, "filter": { "type": "string" }, "header": "Familienname", "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.last_name) The last name, also known as family name.") }, "sortable": true, "tooltip": "The last name, also known as family name.", "width": Lino.chars2width(22) }, { "colIndex": 6, "dataIndex": "birth_date", "editable": true, "editor": birth_date1675, "filter": { "type": "string" }, "header": "Geburtsdatum", "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.birth_date) Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".") }, "sortable": true, "tooltip": "Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".", "width": Lino.chars2width(13) }, { "colIndex": 7, "dataIndex": "gender", "editable": true, "editor": gender1676, "filter": { "options": [ "M\u00e4nnlich", "Weiblich" ], "type": "list" }, "header": "Geschlecht", "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.gender) The sex of this person (male or female).") }, "sortable": false, "tooltip": "The sex of this person (male or female).", "width": Lino.chars2width(10) }, { "align": "right", "colIndex": 8, "dataIndex": "id", "editable": true, "editor": id1677, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 9, "dataIndex": "start_date", "editable": true, "editor": start_date1678, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.start_date) Since when this membership exists. This is usually empty.") }, "sortable": true, "tooltip": "Since when this membership exists. This is usually empty.", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "end_date", "editable": true, "editor": end_date1679, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.end_date) Until when this membership exists.") }, "sortable": true, "tooltip": "Until when this membership exists.", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 11, "dataIndex": "title", "editable": true, "editor": title1680, "filter": { "type": "string" }, "header": "Titel", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.title) Eventuelle berufliche Position oder akademischer Titel, z.B. \"Dr.\" oder \"Prof.\"") }, "sortable": true, "tooltip": "Eventuelle berufliche Position oder akademischer Titel, z.B. \"Dr.\" oder \"Prof.\"", "width": Lino.chars2width(22) }, { "colIndex": 12, "dataIndex": "middle_name", "editable": true, "editor": middle_name1681, "filter": { "type": "string" }, "header": "Zwischenname", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.middle_name) A space-separated list of all middle names.") }, "sortable": true, "tooltip": "A space-separated list of all middle names.", "width": Lino.chars2width(22) }, { "colIndex": 13, "dataIndex": "household", "editable": true, "editor": household1682, "filter": { "type": "string" }, "header": "Haushalt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.household) ") }, "renderer": Lino.fk_renderer('householdHidden','Lino.households.Households.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.SiblingsByPerson.primary) Whether this is the primary household of this person.\nChecking this field will automatically disable any other primary memberships.") }, "sortable": false, "tooltip": "Whether this is the primary household of this person.\nChecking this field will automatically disable any other primary memberships.", "width": Lino.chars2width(11), "xtype": "checkcolumn" } ];
    Lino.households.SiblingsByPerson.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.households.SiblingsByPerson.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/SiblingsByPerson", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.SiblingsByPerson.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/SiblingsByPerson", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.SiblingsByPerson.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/SiblingsByPerson", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.SiblingsByPerson.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/SiblingsByPerson", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.SiblingsByPerson.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/SiblingsByPerson", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.SiblingsByPerson.grid = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(20), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(100) }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/SiblingsByPerson" };
  p.params_panel = new Lino.households.Members.ParamsPanel({});
  return new Lino.households.SiblingsByPerson.GridPanel(p);
});
Lino.households.SiblingsByPerson.set_primary = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/SiblingsByPerson", "GET", pk, "set_primary", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class households.MembersByPerson
Lino.households.MembersByPerson.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/households/MembersByPerson",
  ls_store_fields : [ { "name": "household" }, 'householdHidden', { "name": "role" }, 'roleHidden', { "name": "primary", "type": "boolean" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "id", "type": "int" }, { "name": "title" }, { "name": "first_name" }, { "name": "middle_name" }, { "name": "last_name" }, { "name": "gender" }, 'genderHidden', { "name": "birth_date" }, { "name": "dependency" }, 'dependencyHidden', { "name": "person" }, 'personHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 44,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/households/MembersByPerson','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/MembersByPerson','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/households/MembersByPerson','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/MembersByPerson','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/households/MembersByPerson','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Mitglied) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "set_primary", "menu_item_text": "set_primary", "overflowText": "set_primary", "panel_btn_handler": Lino.row_action_handler('set_primary','GET',null), "text": "set_primary", "tooltip": "Diesen Haushalt als prim\u00e4r markieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Mitgliedschaft in Haushalten",
  disabled_fields_index : 19,
  initComponent : function() {
    this.ls_insert_handler = Lino.households.MembersByPerson.insert;
    var ww = this.containing_window;
    var household4222 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Haushalt ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "households.Households", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/MembersByPerson/household" }) }) });
    var role4223 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.households.MemberRoles) });
    var primary4224 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "selectOnFocus": true });
    var start_date4225 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var end_date4226 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var id4227 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var title4228 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var first_name4229 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var middle_name4230 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var last_name4231 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var gender4232 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.system.Genders) });
    var birth_date4233 = new Lino.IncompleteDateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var dependency4234 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.households.MemberDependencies });
    var person4235 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/households/MembersByPerson/person" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "household", "editable": true, "editor": household4222, "filter": { "type": "string" }, "header": "Haushalt", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.household) ") }, "renderer": Lino.fk_renderer('householdHidden','Lino.households.Households.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "role", "editable": true, "editor": role4223, "filter": { "options": [ "Vorstand", "Ehepartner", "Partner", "Mitbewohner", "Kind", "Verwandt", "Adoptivkind", "Pflegekind", "Sonstige" ], "type": "list" }, "header": "Rolle", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.role) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "primary", "editable": true, "filter": { "type": "boolean" }, "header": "Prim\u00e4r", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.primary) Whether this is the primary household of this person.\nChecking this field will automatically disable any other primary memberships.") }, "sortable": false, "tooltip": "Whether this is the primary household of this person.\nChecking this field will automatically disable any other primary memberships.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 3, "dataIndex": "start_date", "editable": true, "editor": start_date4225, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.start_date) Since when this membership exists. This is usually empty.") }, "sortable": true, "tooltip": "Since when this membership exists. This is usually empty.", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 4, "dataIndex": "end_date", "editable": true, "editor": end_date4226, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.end_date) Until when this membership exists.") }, "sortable": true, "tooltip": "Until when this membership exists.", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id4227, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "title", "editable": true, "editor": title4228, "filter": { "type": "string" }, "header": "Titel", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.title) Eventuelle berufliche Position oder akademischer Titel, z.B. \"Dr.\" oder \"Prof.\"") }, "sortable": true, "tooltip": "Eventuelle berufliche Position oder akademischer Titel, z.B. \"Dr.\" oder \"Prof.\"", "width": Lino.chars2width(22) }, { "colIndex": 7, "dataIndex": "first_name", "editable": true, "editor": first_name4229, "filter": { "type": "string" }, "header": "Vorname", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.first_name) The first name, also known as given name.") }, "sortable": true, "tooltip": "The first name, also known as given name.", "width": Lino.chars2width(22) }, { "colIndex": 8, "dataIndex": "middle_name", "editable": true, "editor": middle_name4230, "filter": { "type": "string" }, "header": "Zwischenname", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.middle_name) A space-separated list of all middle names.") }, "sortable": true, "tooltip": "A space-separated list of all middle names.", "width": Lino.chars2width(22) }, { "colIndex": 9, "dataIndex": "last_name", "editable": true, "editor": last_name4231, "filter": { "type": "string" }, "header": "Familienname", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.last_name) The last name, also known as family name.") }, "sortable": true, "tooltip": "The last name, also known as family name.", "width": Lino.chars2width(22) }, { "colIndex": 10, "dataIndex": "gender", "editable": true, "editor": gender4232, "filter": { "options": [ "M\u00e4nnlich", "Weiblich" ], "type": "list" }, "header": "Geschlecht", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.gender) The sex of this person (male or female).") }, "sortable": false, "tooltip": "The sex of this person (male or female).", "width": Lino.chars2width(10) }, { "colIndex": 11, "dataIndex": "birth_date", "editable": true, "editor": birth_date4233, "filter": { "type": "string" }, "header": "Geburtsdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.birth_date) Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".") }, "sortable": true, "tooltip": "Uncomplete dates are allowed, e.g.\n\"00.00.1980\" means \"some day in 1980\",\n\"00.07.1980\" means \"in July 1980\"\nor \"23.07.0000\" means \"on a 23th of July\".", "width": Lino.chars2width(13) }, { "colIndex": 12, "dataIndex": "dependency", "editable": true, "editor": dependency4234, "filter": { "options": [ "Zu Lasten", "Nicht zu Lasten", "Lasten geteilt" ], "type": "list" }, "header": "Abh\u00e4ngigkeit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.dependency) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(20) }, { "colIndex": 13, "dataIndex": "person", "editable": true, "editor": person4235, "filter": { "type": "string" }, "header": "Person", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MembersByPerson.person) ") }, "renderer": Lino.fk_renderer('personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.households.MembersByPerson.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.households.MembersByPerson.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByPerson", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MembersByPerson.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByPerson", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MembersByPerson.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByPerson", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MembersByPerson.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByPerson", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.households.MembersByPerson.insertPanel = Ext.extend(Lino.households.MembersByPerson.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/households/MembersByPerson",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_insert_handler = Lino.households.MembersByPerson.insert;
    Lino.households.MembersByPerson.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.households.MembersByPerson.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/households/MembersByPerson" };
  return new Lino.households.MembersByPerson.insertPanel(p);
});
Lino.households.MembersByPerson.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByPerson", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MembersByPerson.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByPerson", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MembersByPerson.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/MembersByPerson" };
  p.params_panel = new Lino.households.Members.ParamsPanel({});
  return new Lino.households.MembersByPerson.GridPanel(p);
});
Lino.households.MembersByPerson.set_primary = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MembersByPerson", "GET", pk, "set_primary", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class humanlinks.LinksByHuman
Lino.humanlinks.LinksByHuman.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/humanlinks/LinksByHuman",
  ls_store_fields : [ { "name": "parent" }, 'parentHidden', { "name": "type_as_parent" }, { "name": "child" }, 'childHidden', { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 46,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/humanlinks/LinksByHuman','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/humanlinks/LinksByHuman','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/humanlinks/LinksByHuman','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/humanlinks/LinksByHuman','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/humanlinks/LinksByHuman','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Verwandtschaftsbeziehung) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Beziehungen",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.humanlinks.LinksByHuman.detail;
    this.ls_insert_handler = Lino.humanlinks.LinksByHuman.insert;
    var ww = this.containing_window;
    var parent4237 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/humanlinks/LinksByHuman/parent" }) }) });
    var type_as_parent_disp4238 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var child4239 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/humanlinks/LinksByHuman/child" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "parent", "editable": true, "editor": parent4237, "filter": { "type": "string" }, "header": "Wer ist...", "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.LinksByHuman.parent) Pointer to the person who is \"parent\".") }, "renderer": Lino.fk_renderer('parentHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "Pointer to the person who is \"parent\".", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "type_as_parent", "editable": false, "header": "Art", "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.LinksByHuman.type_as_parent) ") }, "sortable": false, "tooltip": "(humanlinks.LinksByHuman.type_as_parent) ", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "child", "editable": true, "editor": child4239, "filter": { "type": "string" }, "header": "Von wem...", "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.LinksByHuman.child) Pointer to the person who is \"child\".") }, "renderer": Lino.fk_renderer('childHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "Pointer to the person who is \"child\".", "width": Lino.chars2width(21) } ];
    Lino.humanlinks.LinksByHuman.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.humanlinks.LinksByHuman.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinksByHuman", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.LinksByHuman.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinksByHuman", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.LinksByHuman.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinksByHuman", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.LinksByHuman.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinksByHuman", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.humanlinks.LinksByHuman.insertPanel = Ext.extend(Lino.humanlinks.Links.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/humanlinks/LinksByHuman",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.humanlinks.LinksByHuman.detail;
    this.ls_insert_handler = Lino.humanlinks.LinksByHuman.insert;
    Lino.humanlinks.LinksByHuman.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.humanlinks.LinksByHuman.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/humanlinks/LinksByHuman" };
  return new Lino.humanlinks.LinksByHuman.insertPanel(p);
});
Lino.humanlinks.LinksByHuman.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinksByHuman", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.humanlinks.LinksByHuman.detailPanel = Ext.extend(Lino.humanlinks.Links.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Verwandtschaftsbeziehung) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/humanlinks/LinksByHuman",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.humanlinks.LinksByHuman.detail;
    this.ls_insert_handler = Lino.humanlinks.LinksByHuman.insert;
    Lino.humanlinks.LinksByHuman.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.humanlinks.LinksByHuman.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(40) }, function(){
  var p = { "is_main_window": true, "ls_url": "/humanlinks/LinksByHuman" };
  return new Lino.humanlinks.LinksByHuman.detailPanel(p);
});
Lino.humanlinks.LinksByHuman.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinksByHuman", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.LinksByHuman.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/humanlinks/LinksByHuman" };
  return new Lino.humanlinks.LinksByHuman.GridPanel(p);
});
Lino.humanlinks.LinksByHuman.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinksByHuman", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class lists.MembersByList
Lino.lists.MembersByList.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/lists/MembersByList",
  ls_store_fields : [ { "name": "seqno", "type": "int", "useNull": true }, { "name": "partner" }, 'partnerHidden', { "name": "remark" }, { "name": "workflow_buttons" }, { "name": "partner__address_column" }, { "name": "partner__contact_details" }, { "name": "id", "type": "int" }, { "name": "list" }, 'listHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 56,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/lists/MembersByList','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/MembersByList','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/lists/MembersByList','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/MembersByList','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/lists/MembersByList','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Mitglieder",
  disabled_fields_index : 10,
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.MembersByList.detail;
    var ww = this.containing_window;
    var seqno2556 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var partner2557 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partner ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/MembersByList/partner" }) }) });
    var remark2558 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp2559 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var partner__address_column_disp2560 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "sortable": false, "value": null });
    var partner__contact_details_disp2561 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "sortable": false, "value": null });
    var id2562 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var list2563 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partnerliste ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "lists.Lists", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/MembersByList/list" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "seqno", "editable": true, "editor": seqno2556, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByList.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "partner", "editable": true, "editor": partner2557, "filter": { "type": "string" }, "header": "Partner", "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByList.partner) ") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "remark", "editable": true, "editor": remark2558, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByList.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByList.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "partner__address_column", "editable": false, "header": "Adresse", "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByList.partner__address_column) ") }, "sortable": true, "tooltip": "(lists.MembersByList.partner__address_column) ", "width": Lino.chars2width(31) }, { "colIndex": 5, "dataIndex": "partner__contact_details", "editable": false, "header": "Kontaktangaben", "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByList.partner__contact_details) ") }, "sortable": true, "tooltip": "(lists.MembersByList.partner__contact_details) ", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id2562, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByList.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "list", "editable": true, "editor": list2563, "filter": { "type": "string" }, "header": "Partnerliste", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByList.list) ") }, "renderer": Lino.fk_renderer('listHidden','Lino.lists.Lists.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.lists.MembersByList.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.MembersByList.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByList", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByList.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByList", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByList.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByList", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByList.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByList", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByList.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByList", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.lists.MembersByList.detailPanel = Ext.extend(Lino.lists.Members.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/lists/MembersByList",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.MembersByList.detail;
    Lino.lists.MembersByList.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.MembersByList.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/MembersByList" };
  return new Lino.lists.MembersByList.detailPanel(p);
});
Lino.lists.MembersByList.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByList", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByList.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/MembersByList" };
  return new Lino.lists.MembersByList.GridPanel(p);
});
Lino.lists.MembersByList.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByList", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByList.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByList", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByList.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByList", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByList.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByList", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class lists.MembersByPartner
Lino.lists.MembersByPartner.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/lists/MembersByPartner",
  ls_store_fields : [ { "name": "list" }, 'listHidden', { "name": "remark" }, { "name": "id", "type": "int" }, { "name": "seqno", "type": "int", "useNull": true }, { "name": "partner" }, 'partnerHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 56,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/lists/MembersByPartner','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/MembersByPartner','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/lists/MembersByPartner','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/lists/MembersByPartner','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/lists/MembersByPartner','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Listenmitgliedschaft) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Listenmitgliedschaften",
  disabled_fields_index : 7,
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.MembersByPartner.detail;
    this.ls_insert_handler = Lino.lists.MembersByPartner.insert;
    var ww = this.containing_window;
    var list4241 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partnerliste ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "lists.Lists", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/MembersByPartner/list" }) }) });
    var remark4242 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var id4243 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var seqno4244 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var partner4245 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Partner ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Partners", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/lists/MembersByPartner/partner" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "list", "editable": true, "editor": list4241, "filter": { "type": "string" }, "header": "Partnerliste", "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByPartner.list) ") }, "renderer": Lino.fk_renderer('listHidden','Lino.lists.Lists.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "remark", "editable": true, "editor": remark4242, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByPartner.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 2, "dataIndex": "id", "editable": true, "editor": id4243, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByPartner.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 3, "dataIndex": "seqno", "editable": true, "editor": seqno4244, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByPartner.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "partner", "editable": true, "editor": partner4245, "filter": { "type": "string" }, "header": "Partner", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(lists.MembersByPartner.partner) ") }, "renderer": Lino.fk_renderer('partnerHidden','Lino.contacts.Partners.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.lists.MembersByPartner.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.MembersByPartner.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByPartner.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByPartner.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByPartner.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.lists.MembersByPartner.insertPanel = Ext.extend(Lino.lists.MembersByPartner.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/lists/MembersByPartner",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.MembersByPartner.detail;
    this.ls_insert_handler = Lino.lists.MembersByPartner.insert;
    Lino.lists.MembersByPartner.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.MembersByPartner.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/lists/MembersByPartner" };
  return new Lino.lists.MembersByPartner.insertPanel(p);
});
Lino.lists.MembersByPartner.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByPartner.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.lists.MembersByPartner.detailPanel = Ext.extend(Lino.lists.Members.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Listenmitgliedschaft) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/lists/MembersByPartner",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.lists.MembersByPartner.detail;
    this.ls_insert_handler = Lino.lists.MembersByPartner.insert;
    Lino.lists.MembersByPartner.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.lists.MembersByPartner.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/MembersByPartner" };
  return new Lino.lists.MembersByPartner.detailPanel(p);
});
Lino.lists.MembersByPartner.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByPartner.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/lists/MembersByPartner" };
  return new Lino.lists.MembersByPartner.GridPanel(p);
});
Lino.lists.MembersByPartner.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByPartner.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByPartner.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.lists.MembersByPartner.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/lists/MembersByPartner", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class blogs.EntriesByType
Lino.blogs.EntriesByType.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/blogs/EntriesByType",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "pub_date", "type": "date" }, { "name": "title" }, { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "body" }, { "name": "short_preview" }, { "name": "full_preview" }, { "name": "pub_time" }, { "name": "language" }, 'languageHidden', { "name": "owner" }, { "name": "entry_type" }, 'entry_typeHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 58,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/blogs/EntriesByType','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/EntriesByType','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/EntriesByType','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/EntriesByType','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/blogs/EntriesByType','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Blog-Eintr\u00e4ge",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.EntriesByType.detail;
    this.ls_insert_handler = Lino.blogs.EntriesByType.insert;
    var ww = this.containing_window;
    var pub_date2175 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var title2176 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var user2177 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/EntriesByType/user" }) }) });
    var id2178 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type2179 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/EntriesByType/owner_type" }) }) });
    var owner_id2180 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/EntriesByType/owner_id" }) }) });
    var body2181 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Inhalt" });
    var short_preview2182 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau" });
    var full_preview2183 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau (komplett)" });
    var pub_time2184 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var language2185 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var owner_disp2186 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    var entry_type2187 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Blog Entry Type ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "blogs.EntryTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/EntriesByType/entry_type" }) }) });
    this.before_row_edit = function(record) {
      owner_id2180.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      body2181.refresh();
      short_preview2182.refresh();
      full_preview2183.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type2179 !== 'undefined' && owner_type2179.on('change',Lino.chooser_handler(owner_id2180,'owner_type'));
      Lino.blogs.EntriesByType.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "pub_date", "editable": true, "editor": pub_date2175, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Bildungsart", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.pub_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "title", "editable": true, "editor": title2176, "filter": { "type": "string" }, "header": "\u00dcberschrift", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.title) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user2177, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id2178, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "owner_type", "editable": true, "editor": owner_type2179, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_id", "editable": true, "editor": owner_id2180, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "body", "editable": true, "editor": body2181, "filter": { "type": "string" }, "header": "Inhalt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.body) An editable text body.") }, "sortable": false, "tooltip": "An editable text body.", "width": Lino.chars2width(61) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.short_preview) A read-only short preview of body.") }, "sortable": false, "tooltip": "A read-only short preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "pub_time", "editable": true, "editor": pub_time2184, "header": "Bildungsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.pub_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "language", "editable": true, "editor": language2185, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.language) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.owner) ") }, "sortable": false, "tooltip": "(blogs.EntriesByType.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 12, "dataIndex": "entry_type", "editable": true, "editor": entry_type2187, "filter": { "type": "string" }, "header": "Blog Entry Type", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByType.entry_type) ") }, "renderer": Lino.fk_renderer('entry_typeHidden','Lino.blogs.EntryTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.blogs.EntriesByType.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.EntriesByType.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByType", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByType.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByType", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByType.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByType", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByType.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByType", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.EntriesByType.insertPanel = Ext.extend(Lino.blogs.Entries.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/blogs/EntriesByType",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.EntriesByType.detail;
    this.ls_insert_handler = Lino.blogs.EntriesByType.insert;
    Lino.blogs.EntriesByType.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.EntriesByType.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/blogs/EntriesByType" };
  return new Lino.blogs.EntriesByType.insertPanel(p);
});
Lino.blogs.EntriesByType.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByType", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.EntriesByType.detailPanel = Ext.extend(Lino.blogs.Entries.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/blogs/EntriesByType",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.EntriesByType.detail;
    this.ls_insert_handler = Lino.blogs.EntriesByType.insert;
    Lino.blogs.EntriesByType.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.EntriesByType.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/EntriesByType" };
  return new Lino.blogs.EntriesByType.detailPanel(p);
});
Lino.blogs.EntriesByType.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByType", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByType.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByType", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByType.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByType", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByType.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/EntriesByType" };
  p.params_panel = new Lino.blogs.Entries.ParamsPanel({});
  return new Lino.blogs.EntriesByType.GridPanel(p);
});
Lino.blogs.EntriesByType.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByType", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByType.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByType", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class excerpts.ExcerptsByType
Lino.excerpts.ExcerptsByType.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/excerpts/ExcerptsByType",
  ls_store_fields : [ { "name": "build_time" }, { "name": "owner" }, { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "build_method" }, 'build_methodHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "company" }, 'companyHidden', { "name": "contact_person" }, 'contact_personHidden', { "name": "contact_role" }, 'contact_roleHidden', { "name": "language" }, 'languageHidden', { "name": "excerpt_type" }, 'excerpt_typeHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 60,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptsByType','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptsByType','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptsByType','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptsByType','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptsByType','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Ausz\u00fcge",
  disabled_fields_index : 21,
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.ExcerptsByType.detail;
    var ww = this.containing_window;
    var build_time2289 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var owner_disp2290 = new Ext.form.DisplayField({ "disabled": true });
    var user2291 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByType/user" }) }) });
    var id2292 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var build_method2293 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var owner_type2294 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByType/owner_type" }) }) });
    var owner_id2295 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByType/owner_id" }) }) });
    var company2296 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByType/company" }) }) });
    var contact_person2297 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByType/contact_person" }) }) });
    var contact_role2298 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByType/contact_role" }) }) });
    var language2299 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var excerpt_type2300 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "emptyText": "Auszugsart ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "excerpts.ExcerptTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByType/excerpt_type" }) }) });
    this.before_row_edit = function(record) {
      owner_id2295.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      contact_person2297.setContextValue('company', record ? record.data['companyHidden'] : undefined);
      excerpt_type2300.setContextValue('owner', record ? record.data['owner'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type2294 !== 'undefined' && owner_type2294.on('change',Lino.chooser_handler(owner_id2295,'owner_type'));
      typeof company2296 !== 'undefined' && company2296.on('change',Lino.chooser_handler(contact_person2297,'company'));
      typeof owner_disp2290 !== 'undefined' && owner_disp2290.on('change',Lino.chooser_handler(excerpt_type2300,'owner'));
      Lino.excerpts.ExcerptsByType.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 1, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.owner) The object being printed by this excerpt.\nSee Controllable.owner.") }, "sortable": false, "tooltip": "The object being printed by this excerpt.\nSee Controllable.owner.", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user2291, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id2292, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "build_method", "editable": true, "editor": build_method2293, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type2294, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id2295, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 7, "dataIndex": "company", "editable": true, "editor": company2296, "filter": { "type": "string" }, "header": "Empf\u00e4nger (Organisation)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.company) The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "contact_person", "editable": true, "editor": contact_person2297, "filter": { "type": "string" }, "header": "Empf\u00e4nger (Person)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.contact_person) The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.") }, "renderer": Lino.fk_renderer('contact_personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "contact_role", "editable": true, "editor": contact_role2298, "filter": { "type": "string" }, "header": "in seiner Eigenschaft als", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.contact_role) The optional Role\nof the contact_person within company.") }, "sortable": false, "tooltip": "The optional Role\nof the contact_person within company.", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "language", "editable": true, "editor": language2299, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.language) The language used for printing this excerpt.") }, "sortable": false, "tooltip": "The language used for printing this excerpt.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "excerpt_type", "editable": true, "editor": excerpt_type2300, "filter": { "type": "string" }, "header": "Auszugsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByType.excerpt_type) The type of this excerpt (ForeignKey to ExcerptType).") }, "renderer": Lino.fk_renderer('excerpt_typeHidden','Lino.excerpts.ExcerptTypes.detail'), "sortable": false, "tooltip": "The type of this excerpt (ForeignKey to ExcerptType).", "width": Lino.chars2width(21) } ];
    Lino.excerpts.ExcerptsByType.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.ExcerptsByType.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByType.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByType.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByType.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByType.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.excerpts.ExcerptsByType.detailPanel = Ext.extend(Lino.excerpts.Excerpts.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/excerpts/ExcerptsByType",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.ExcerptsByType.detail;
    Lino.excerpts.ExcerptsByType.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.ExcerptsByType.detail = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(13), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/ExcerptsByType" };
  return new Lino.excerpts.ExcerptsByType.detailPanel(p);
});
Lino.excerpts.ExcerptsByType.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByType.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByType.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByType.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByType.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByType.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/ExcerptsByType" };
  p.params_panel = new Lino.excerpts.Excerpts.ParamsPanel({});
  return new Lino.excerpts.ExcerptsByType.GridPanel(p);
});
Lino.excerpts.ExcerptsByType.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByType", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.CommentsByType
Lino.comments.CommentsByType.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/CommentsByType",
  ls_store_fields : [ { "name": "body" }, { "name": "created" }, { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "short_preview" }, { "name": "full_preview" }, { "name": "reply_to" }, 'reply_toHidden', { "name": "private", "type": "boolean" }, { "name": "owner" }, { "name": "comment_type" }, 'comment_typeHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 63,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByType','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByType','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByType','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByType','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByType','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kommentare",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByType.detail;
    this.ls_insert_handler = Lino.comments.CommentsByType.insert;
    var ww = this.containing_window;
    var body4247 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Inhalt" });
    var created4248 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var user4249 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers" });
    var id4250 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified4251 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var owner_type4252 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByType/owner_type" }) }) });
    var owner_id4253 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByType/owner_id" }) }) });
    var short_preview4254 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau" });
    var full_preview4255 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau (komplett)" });
    var reply_to4256 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByType/reply_to" }) }) });
    var private4257 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "hidden": true, "selectOnFocus": true });
    var owner_disp4258 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    var comment_type4259 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar-Art ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "comments.CommentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByType/comment_type" }) }) });
    this.before_row_edit = function(record) {
      body4247.refresh();
      owner_id4253.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      short_preview4254.refresh();
      full_preview4255.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type4252 !== 'undefined' && owner_type4252.on('change',Lino.chooser_handler(owner_id4253,'owner_type'));
      Lino.comments.CommentsByType.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "body", "editable": true, "editor": body4247, "filter": { "type": "string" }, "header": "Inhalt", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.body) The full body text of your comment.") }, "sortable": false, "tooltip": "The full body text of your comment.", "width": Lino.chars2width(61) }, { "colIndex": 1, "dataIndex": "created", "editable": false, "header": "Erstellt", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 2, "dataIndex": "user", "editable": false, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.user) The author of the comment.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of the comment.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id4250, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type4252, "filter": { "type": "string" }, "header": "Thema (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id4253, "filter": { "type": "string" }, "header": "Thema (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.short_preview) The first paragraph of your body.") }, "sortable": false, "tooltip": "The first paragraph of your body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "reply_to", "editable": true, "editor": reply_to4256, "filter": { "type": "string" }, "header": "Antwort auf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.reply_to) ") }, "renderer": Lino.fk_renderer('reply_toHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "private", "editable": true, "filter": { "type": "boolean" }, "header": "Privat", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.private) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 11, "dataIndex": "owner", "editable": false, "header": "Thema", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.owner) The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.") }, "sortable": false, "tooltip": "The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.", "width": Lino.chars2width(11) }, { "colIndex": 12, "dataIndex": "comment_type", "editable": true, "editor": comment_type4259, "filter": { "type": "string" }, "header": "Kommentar-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByType.comment_type) ") }, "renderer": Lino.fk_renderer('comment_typeHidden','Lino.comments.CommentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.comments.CommentsByType.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByType.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByType.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByType.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByType.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.CommentsByType.insertPanel = Ext.extend(Lino.comments.Comments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/comments/CommentsByType",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByType.detail;
    this.ls_insert_handler = Lino.comments.CommentsByType.insert;
    Lino.comments.CommentsByType.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByType.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(15), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/comments/CommentsByType" };
  return new Lino.comments.CommentsByType.insertPanel(p);
});
Lino.comments.CommentsByType.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.CommentsByType.detailPanel = Ext.extend(Lino.comments.Comments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/comments/CommentsByType",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByType.detail;
    this.ls_insert_handler = Lino.comments.CommentsByType.insert;
    Lino.comments.CommentsByType.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByType.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentsByType" };
  return new Lino.comments.CommentsByType.detailPanel(p);
});
Lino.comments.CommentsByType.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByType.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByType.do_pick_my_emotion = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "GET", pk, "do_pick_my_emotion", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByType.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByType.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentsByType" };
  p.params_panel = new Lino.comments.Comments.ParamsPanel({});
  return new Lino.comments.CommentsByType.GridPanel(p);
});
Lino.comments.CommentsByType.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByType.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByType", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.CommentsByMentioned
Lino.comments.CommentsByMentioned.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/CommentsByMentioned",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "body" }, { "name": "short_preview" }, { "name": "full_preview" }, { "name": "reply_to" }, 'reply_toHidden', { "name": "private", "type": "boolean" }, { "name": "comment_type" }, 'comment_typeHidden', { "name": "owner" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 63,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByMentioned','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByMentioned','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByMentioned','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByMentioned','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByMentioned','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Mentioned in",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByMentioned.detail;
    var ww = this.containing_window;
    var id4261 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified4262 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var created4263 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var user4264 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers" });
    var owner_type4265 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByMentioned/owner_type" }) }) });
    var owner_id4266 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByMentioned/owner_id" }) }) });
    var body4267 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Inhalt" });
    var short_preview4268 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau" });
    var full_preview4269 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau (komplett)" });
    var reply_to4270 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByMentioned/reply_to" }) }) });
    var private4271 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "selectOnFocus": true });
    var comment_type4272 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar-Art ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.CommentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByMentioned/comment_type" }) }) });
    var owner_disp4273 = new Ext.form.DisplayField({ "disabled": true });
    this.before_row_edit = function(record) {
      body4267.refresh();
      short_preview4268.refresh();
      full_preview4269.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type4265 !== 'undefined' && owner_type4265.on('change',Lino.chooser_handler(owner_id4266,'owner_type'));
      Lino.comments.CommentsByMentioned.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id4261, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 2, "dataIndex": "created", "editable": false, "header": "Erstellt", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 3, "dataIndex": "user", "editable": false, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.user) The author of the comment.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of the comment.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "owner_type", "editable": true, "editor": owner_type4265, "filter": { "type": "string" }, "header": "Thema (Modell)", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_id", "editable": true, "editor": owner_id4266, "filter": { "type": "string" }, "header": "Thema (Objekt)", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "body", "editable": true, "editor": body4267, "filter": { "type": "string" }, "header": "Inhalt", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.body) The full body text of your comment.") }, "sortable": false, "tooltip": "The full body text of your comment.", "width": Lino.chars2width(61) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.short_preview) The first paragraph of your body.") }, "sortable": false, "tooltip": "The first paragraph of your body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "reply_to", "editable": true, "editor": reply_to4270, "filter": { "type": "string" }, "header": "Antwort auf", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.reply_to) ") }, "renderer": Lino.fk_renderer('reply_toHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "private", "editable": true, "filter": { "type": "boolean" }, "header": "Privat", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.private) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 11, "dataIndex": "comment_type", "editable": true, "editor": comment_type4272, "filter": { "type": "string" }, "header": "Kommentar-Art", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.comment_type) ") }, "renderer": Lino.fk_renderer('comment_typeHidden','Lino.comments.CommentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "owner", "editable": false, "header": "Thema", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByMentioned.owner) The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.") }, "sortable": false, "tooltip": "The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.", "width": Lino.chars2width(11) } ];
    Lino.comments.CommentsByMentioned.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByMentioned.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByMentioned", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByMentioned.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByMentioned", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByMentioned.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByMentioned", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByMentioned.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByMentioned", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.CommentsByMentioned.detailPanel = Ext.extend(Lino.comments.Comments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  ls_url: "/comments/CommentsByMentioned",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByMentioned.detail;
    Lino.comments.CommentsByMentioned.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByMentioned.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentsByMentioned" };
  return new Lino.comments.CommentsByMentioned.detailPanel(p);
});
Lino.comments.CommentsByMentioned.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByMentioned", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByMentioned.do_pick_my_emotion = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByMentioned", "GET", pk, "do_pick_my_emotion", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByMentioned.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByMentioned", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByMentioned.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentsByMentioned" };
  p.params_panel = new Lino.comments.Comments.ParamsPanel({});
  return new Lino.comments.CommentsByMentioned.GridPanel(p);
});
Lino.comments.CommentsByMentioned.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByMentioned", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.RepliesByComment
Lino.comments.RepliesByComment.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/RepliesByComment",
  ls_store_fields : [ { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "body" }, { "name": "short_preview" }, { "name": "full_preview" }, { "name": "private", "type": "boolean" }, { "name": "comment_type" }, 'comment_typeHidden', { "name": "owner" }, { "name": "reply_to" }, 'reply_toHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 0,
  content_type : 63,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/RepliesByComment','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/RepliesByComment','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/RepliesByComment','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/RepliesByComment','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/RepliesByComment','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Antworten",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.RepliesByComment.detail;
    this.ls_insert_handler = Lino.comments.RepliesByComment.insert;
    var ww = this.containing_window;
    var id4275 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var modified4276 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var created4277 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var user4278 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers" });
    var owner_type4279 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/RepliesByComment/owner_type" }) }) });
    var owner_id4280 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/RepliesByComment/owner_id" }) }) });
    var body4281 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Inhalt" });
    var short_preview4282 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau" });
    var full_preview4283 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "title": "Vorschau (komplett)" });
    var private4284 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "selectOnFocus": true });
    var comment_type4285 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar-Art ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.CommentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/RepliesByComment/comment_type" }) }) });
    var owner_disp4286 = new Ext.form.DisplayField({ "disabled": true });
    var reply_to4287 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/RepliesByComment/reply_to" }) }) });
    this.before_row_edit = function(record) {
      owner_id4280.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      body4281.refresh();
      short_preview4282.refresh();
      full_preview4283.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type4279 !== 'undefined' && owner_type4279.on('change',Lino.chooser_handler(owner_id4280,'owner_type'));
      Lino.comments.RepliesByComment.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "id", "editable": true, "editor": id4275, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 2, "dataIndex": "created", "editable": false, "header": "Erstellt", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 3, "dataIndex": "user", "editable": false, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.user) The author of the comment.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of the comment.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "owner_type", "editable": true, "editor": owner_type4279, "filter": { "type": "string" }, "header": "Thema (Modell)", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_id", "editable": true, "editor": owner_id4280, "filter": { "type": "string" }, "header": "Thema (Objekt)", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "body", "editable": true, "editor": body4281, "filter": { "type": "string" }, "header": "Inhalt", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.body) The full body text of your comment.") }, "sortable": false, "tooltip": "The full body text of your comment.", "width": Lino.chars2width(61) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.short_preview) The first paragraph of your body.") }, "sortable": false, "tooltip": "The first paragraph of your body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "private", "editable": true, "filter": { "type": "boolean" }, "header": "Privat", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.private) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 10, "dataIndex": "comment_type", "editable": true, "editor": comment_type4285, "filter": { "type": "string" }, "header": "Kommentar-Art", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.comment_type) ") }, "renderer": Lino.fk_renderer('comment_typeHidden','Lino.comments.CommentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "owner", "editable": false, "header": "Thema", "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.owner) The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.") }, "sortable": false, "tooltip": "The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.", "width": Lino.chars2width(11) }, { "colIndex": 12, "dataIndex": "reply_to", "editable": true, "editor": reply_to4287, "filter": { "type": "string" }, "header": "Antwort auf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.RepliesByComment.reply_to) ") }, "renderer": Lino.fk_renderer('reply_toHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.comments.RepliesByComment.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.RepliesByComment.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RepliesByComment.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RepliesByComment.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RepliesByComment.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.RepliesByComment.insertPanel = Ext.extend(Lino.comments.Comments.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/comments/RepliesByComment",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.RepliesByComment.detail;
    this.ls_insert_handler = Lino.comments.RepliesByComment.insert;
    Lino.comments.RepliesByComment.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.RepliesByComment.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(15), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/comments/RepliesByComment" };
  return new Lino.comments.RepliesByComment.insertPanel(p);
});
Lino.comments.RepliesByComment.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.RepliesByComment.detailPanel = Ext.extend(Lino.comments.Comments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/comments/RepliesByComment",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.RepliesByComment.detail;
    this.ls_insert_handler = Lino.comments.RepliesByComment.insert;
    Lino.comments.RepliesByComment.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.RepliesByComment.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/RepliesByComment" };
  return new Lino.comments.RepliesByComment.detailPanel(p);
});
Lino.comments.RepliesByComment.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RepliesByComment.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RepliesByComment.do_pick_my_emotion = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "GET", pk, "do_pick_my_emotion", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RepliesByComment.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RepliesByComment.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/RepliesByComment" };
  p.params_panel = new Lino.comments.Comments.ParamsPanel({});
  return new Lino.comments.RepliesByComment.GridPanel(p);
});
Lino.comments.RepliesByComment.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.RepliesByComment.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/RepliesByComment", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class dashboard.WidgetsByUser
Lino.dashboard.WidgetsByUser.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/dashboard/WidgetsByUser",
  ls_store_fields : [ { "name": "seqno", "type": "int", "useNull": true }, { "name": "move_buttons" }, { "name": "title" }, { "name": "visible", "type": "boolean" }, { "name": "id", "type": "int" }, { "name": "item_name" }, { "name": "user" }, 'userHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 66,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/dashboard/WidgetsByUser','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/dashboard/WidgetsByUser','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/dashboard/WidgetsByUser','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/dashboard/WidgetsByUser','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/dashboard/WidgetsByUser','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren (verdoppeln).", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_down", "menu_item_text": "\u25bc", "overflowText": "\u25bc", "panel_btn_handler": Lino.row_action_handler('move_down','GET',null), "text": " <font size=\"4\">\u25bc</font>", "tooltip": "Exchange the seqno of this item and the next item.", "tooltipType": "title" }, { "auto_save": true, "itemId": "move_up", "menu_item_text": "\u25b2", "overflowText": "\u25b2", "panel_btn_handler": Lino.row_action_handler('move_up','GET',null), "text": " <font size=\"4\">\u25b2</font>", "tooltip": "Exchange the seqno of this item and the previous item.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Dashboard",
  disabled_fields_index : 8,
  initComponent : function() {
    var ww = this.containing_window;
    var seqno2390 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var move_buttons_disp2391 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var title_disp2392 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var visible2393 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "selectOnFocus": true });
    var id2394 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var item_name2395 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/dashboard/WidgetsByUser/item_name" }) }) });
    var user2396 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/dashboard/WidgetsByUser/user" }) }) });
    this.before_row_edit = function(record) {
      var bp = this.get_base_params();
      item_name2395.setContextValue('mk',bp['mk']);
      item_name2395.setContextValue('mt',bp['mt']);
    };
    this.onRender = function(ct, position) {
      typeof user2396 !== 'undefined' && user2396.on('change',Lino.chooser_handler(item_name2395,'user'));
      Lino.dashboard.WidgetsByUser.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "align": "right", "colIndex": 0, "dataIndex": "seqno", "editable": true, "editor": seqno2390, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.WidgetsByUser.seqno) The sequence number of this item with its parent.") }, "sortable": true, "tooltip": "The sequence number of this item with its parent.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 1, "dataIndex": "move_buttons", "editable": false, "header": "Bearbeiten", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.WidgetsByUser.move_buttons) Displays buttons for certain actions on this row:") }, "sortable": false, "tooltip": "Displays buttons for certain actions on this row:", "width": Lino.chars2width(6) }, { "colIndex": 2, "dataIndex": "title", "editable": false, "header": "Label", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.WidgetsByUser.title) ") }, "sortable": false, "tooltip": "(dashboard.WidgetsByUser.title) ", "width": Lino.chars2width(31) }, { "colIndex": 3, "dataIndex": "visible", "editable": true, "filter": { "type": "boolean" }, "header": "Sichtbar", "listeners": { "render": Lino.quicktip_renderer("","(dashboard.WidgetsByUser.visible) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id2394, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(dashboard.WidgetsByUser.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 5, "dataIndex": "item_name", "editable": true, "editor": item_name2395, "filter": { "type": "string" }, "header": "Resource", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(dashboard.WidgetsByUser.item_name) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "user", "editable": true, "editor": user2396, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(dashboard.WidgetsByUser.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) } ];
    Lino.dashboard.WidgetsByUser.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.dashboard.WidgetsByUser.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/WidgetsByUser", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.WidgetsByUser.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/WidgetsByUser", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.WidgetsByUser.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/WidgetsByUser", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.WidgetsByUser.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/WidgetsByUser", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.WidgetsByUser.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/WidgetsByUser", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.WidgetsByUser.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/WidgetsByUser", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.WidgetsByUser.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/dashboard/WidgetsByUser" };
  p.params_panel = new Lino.dashboard.Widgets.ParamsPanel({});
  return new Lino.dashboard.WidgetsByUser.GridPanel(p);
});
Lino.dashboard.WidgetsByUser.move_by_n = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/WidgetsByUser", "GET", pk, "move_by_n", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.WidgetsByUser.move_down = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/WidgetsByUser", "GET", pk, "move_down", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.dashboard.WidgetsByUser.move_up = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/dashboard/WidgetsByUser", "GET", pk, "move_up", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class users.AuthoritiesGiven
Lino.users.AuthoritiesGiven.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/users/AuthoritiesGiven",
  ls_store_fields : [ { "name": "authorized" }, 'authorizedHidden', { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 2,
  content_type : 3,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/users/AuthoritiesGiven','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/AuthoritiesGiven','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/users/AuthoritiesGiven','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/AuthoritiesGiven','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/users/AuthoritiesGiven','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Erteilte Vollmachten",
  disabled_fields_index : 3,
  initComponent : function() {
    var ww = this.containing_window;
    var authorized2373 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/AuthoritiesGiven/authorized" }) }) });
    this.before_row_edit = function(record) {
      var bp = this.get_base_params();
      authorized2373.setContextValue('mk',bp['mk']);
      authorized2373.setContextValue('mt',bp['mt']);
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "authorized", "editable": true, "editor": authorized2373, "filter": { "type": "string" }, "header": "Benutzer", "listeners": { "render": Lino.quicktip_renderer("","(users.AuthoritiesGiven.authorized) The user who gets the right to represent the author") }, "renderer": Lino.fk_renderer('authorizedHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The user who gets the right to represent the author", "width": Lino.chars2width(21) } ];
    Lino.users.AuthoritiesGiven.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.users.AuthoritiesGiven.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AuthoritiesGiven", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AuthoritiesGiven.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AuthoritiesGiven", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AuthoritiesGiven.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AuthoritiesGiven", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AuthoritiesGiven.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AuthoritiesGiven", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AuthoritiesGiven.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AuthoritiesGiven", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AuthoritiesGiven.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/AuthoritiesGiven" };
  p.params_panel = new Lino.users.Authorities.ParamsPanel({});
  return new Lino.users.AuthoritiesGiven.GridPanel(p);
});

// js_render_GridPanel_class users.AuthoritiesTaken
Lino.users.AuthoritiesTaken.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/users/AuthoritiesTaken",
  ls_store_fields : [ { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 2,
  content_type : 3,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/users/AuthoritiesTaken','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/AuthoritiesTaken','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/users/AuthoritiesTaken','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/AuthoritiesTaken','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/users/AuthoritiesTaken','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Erhaltene Vollmachten",
  disabled_fields_index : 3,
  initComponent : function() {
    var ww = this.containing_window;
    var user4289 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/users/AuthoritiesTaken/user" }) }) });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "user", "editable": true, "editor": user4289, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(users.AuthoritiesTaken.user) The user who gives the right of representation. author of this\nauthority") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The user who gives the right of representation. author of this\nauthority", "width": Lino.chars2width(21) } ];
    Lino.users.AuthoritiesTaken.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.users.AuthoritiesTaken.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AuthoritiesTaken", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AuthoritiesTaken.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AuthoritiesTaken", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AuthoritiesTaken.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AuthoritiesTaken", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AuthoritiesTaken.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AuthoritiesTaken", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AuthoritiesTaken.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/AuthoritiesTaken", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.AuthoritiesTaken.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/AuthoritiesTaken" };
  p.params_panel = new Lino.users.Authorities.ParamsPanel({});
  return new Lino.users.AuthoritiesTaken.GridPanel(p);
});

// js_render_GridPanel_class courses.LinesByTopic
Lino.courses.LinesByTopic.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/LinesByTopic",
  ls_store_fields : [ { "name": "ref" }, { "name": "name" }, { "name": "name_de" }, { "name": "name_fr" }, { "name": "topic" }, 'topicHidden', { "name": "course_area" }, 'course_areaHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "guest_role" }, 'guest_roleHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "id", "type": "int" }, { "name": "company" }, 'companyHidden', { "name": "contact_person" }, 'contact_personHidden', { "name": "contact_role" }, 'contact_roleHidden', { "name": "excerpt_title" }, { "name": "excerpt_title_de" }, { "name": "excerpt_title_fr" }, { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "body_template" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 15,
  content_type : 49,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/LinesByTopic','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/LinesByTopic','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/LinesByTopic','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/LinesByTopic','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/LinesByTopic','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4tenreihe) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.courses.Lines.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aktivit\u00e4tenreihen",
  disabled_fields_index : 29,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.LinesByTopic.detail;
    this.ls_insert_handler = Lino.courses.LinesByTopic.insert;
    var ww = this.containing_window;
    var ref914 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name915 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 200, "selectOnFocus": true });
    var name_de916 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var name_fr917 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var topic918 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Thema ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Topics", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/LinesByTopic/topic" }) }) });
    var course_area919 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.courses.ActivityLayouts });
    var event_type920 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/LinesByTopic/event_type" }) }) });
    var guest_role921 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Gastrolle ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.GuestRoles", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/LinesByTopic/guest_role" }) }) });
    var every_unit922 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every923 = new Ext.form.NumberField({ "allowBlank": false, "selectOnFocus": true, "value": 1 });
    var id924 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var company925 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/LinesByTopic/company" }) }) });
    var contact_person926 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/LinesByTopic/contact_person" }) }) });
    var contact_role927 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/LinesByTopic/contact_role" }) }) });
    var excerpt_title928 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var excerpt_title_de929 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var excerpt_title_fr930 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 200, "selectOnFocus": true });
    var description931 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de932 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr933 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var body_template934 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/LinesByTopic/body_template" }) }) });
    this.before_row_edit = function(record) {
      contact_person926.setContextValue('company', record ? record.data['companyHidden'] : undefined);
      description931.refresh();
      description_de932.refresh();
      description_fr933.refresh();
    };
    this.onRender = function(ct, position) {
      typeof company925 !== 'undefined' && company925.on('change',Lino.chooser_handler(contact_person926,'company'));
      Lino.courses.LinesByTopic.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "ref", "editable": true, "editor": ref914, "filter": { "type": "string" }, "header": "Referenz", "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.ref) Die Referenz. Muss entweder leer oder einzig sein.") }, "sortable": true, "tooltip": "Die Referenz. Muss entweder leer oder einzig sein.", "width": Lino.chars2width(41) }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name915, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.name) The designation of this activity line as seen by the user\ne.g. when selecting the line.") }, "sortable": true, "tooltip": "The designation of this activity line as seen by the user\ne.g. when selecting the line.", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "name_de", "editable": true, "editor": name_de916, "filter": { "type": "string" }, "header": "Bezeichnung (de)", "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.name_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "name_fr", "editable": true, "editor": name_fr917, "filter": { "type": "string" }, "header": "Bezeichnung (fr)", "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.name_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "topic", "editable": true, "editor": topic918, "filter": { "type": "string" }, "header": "Thema", "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.topic) ") }, "renderer": Lino.fk_renderer('topicHidden','Lino.courses.Topics.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "course_area", "editable": true, "editor": course_area919, "filter": { "options": [ "Aktivit\u00e4ten" ], "type": "list" }, "header": "Layout", "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.course_area) Pointer to ActivityLayouts.  This is used only when an\napplication defines several variants of\nEnrolmentsByPupil.") }, "sortable": false, "tooltip": "Pointer to ActivityLayouts.  This is used only when an\napplication defines several variants of\nEnrolmentsByPupil.", "width": Lino.chars2width(14) }, { "colIndex": 6, "dataIndex": "event_type", "editable": true, "editor": event_type920, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.event_type) The type of calendar entries to be generated. If this is empty, no calendar entries will be generated.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of calendar entries to be generated. If this is empty, no calendar entries will be generated.", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "guest_role", "editable": true, "editor": guest_role921, "filter": { "type": "string" }, "header": "Anwesenheiten erfassen als", "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.guest_role) The default guest role for particpants of calendar entries for activities in this series. Leave empty if you don't want any presences management.") }, "renderer": Lino.fk_renderer('guest_roleHidden','Lino.cal.GuestRoles.detail'), "sortable": false, "tooltip": "The default guest role for particpants of calendar entries for activities in this series. Leave empty if you don't want any presences management.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "every_unit", "editable": true, "editor": every_unit922, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.every_unit) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 9, "dataIndex": "every", "editable": true, "editor": every923, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.every) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 10, "dataIndex": "id", "editable": true, "editor": id924, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 11, "dataIndex": "company", "editable": true, "editor": company925, "filter": { "type": "string" }, "header": "Organisation", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.company) Pointer to Company.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "Pointer to Company.", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "contact_person", "editable": true, "editor": contact_person926, "filter": { "type": "string" }, "header": "Vertreten durch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.contact_person) Pointer to Person.") }, "renderer": Lino.fk_renderer('contact_personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "Pointer to Person.", "width": Lino.chars2width(21) }, { "colIndex": 13, "dataIndex": "contact_role", "editable": true, "editor": contact_role927, "filter": { "type": "string" }, "header": "in seiner Eigenschaft als", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.contact_role) The optional Role\nof the contact_person within company.") }, "sortable": false, "tooltip": "The optional Role\nof the contact_person within company.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "excerpt_title", "editable": true, "editor": excerpt_title928, "filter": { "type": "string" }, "header": "Excerpt title", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.excerpt_title) The text to print as title in enrolments.") }, "sortable": true, "tooltip": "The text to print as title in enrolments.", "width": Lino.chars2width(22) }, { "colIndex": 15, "dataIndex": "excerpt_title_de", "editable": true, "editor": excerpt_title_de929, "filter": { "type": "string" }, "header": "Excerpt title (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.excerpt_title_de) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 16, "dataIndex": "excerpt_title_fr", "editable": true, "editor": excerpt_title_fr930, "filter": { "type": "string" }, "header": "Excerpt title (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.excerpt_title_fr) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 17, "dataIndex": "description", "editable": true, "editor": description931, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 18, "dataIndex": "description_de", "editable": true, "editor": description_de932, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 19, "dataIndex": "description_fr", "editable": true, "editor": description_fr933, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 20, "dataIndex": "body_template", "editable": true, "editor": body_template934, "filter": { "type": "string" }, "header": "Textk\u00f6rper-Vorlage", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.LinesByTopic.body_template) The body template to use when printing an activity of this\nline.  Leave empty to use the site's default (defined by\nbody_template on the\nlino_xl.lib.excerpts.models.ExcerptType for\nCourse)") }, "sortable": false, "tooltip": "The body template to use when printing an activity of this\nline.  Leave empty to use the site's default (defined by\nbody_template on the\nlino_xl.lib.excerpts.models.ExcerptType for\nCourse)", "width": Lino.chars2width(11) } ];
    Lino.courses.LinesByTopic.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.LinesByTopic.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/LinesByTopic", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.LinesByTopic.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/LinesByTopic", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.LinesByTopic.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/LinesByTopic", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.LinesByTopic.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/LinesByTopic", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.LinesByTopic.insertPanel = Ext.extend(Lino.courses.Lines.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/LinesByTopic",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.LinesByTopic.detail;
    this.ls_insert_handler = Lino.courses.LinesByTopic.insert;
    Lino.courses.LinesByTopic.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.LinesByTopic.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(16), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/LinesByTopic" };
  return new Lino.courses.LinesByTopic.insertPanel(p);
});
Lino.courses.LinesByTopic.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/LinesByTopic", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.LinesByTopic.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/LinesByTopic", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.LinesByTopic.detailPanel = Ext.extend(Lino.courses.Lines.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4tenreihe) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-arrow_join", "itemId": "merge_row", "menu_item_text": "Fusionieren", "overflowText": "Fusionieren", "panel_btn_handler": Lino.param_action_handler(Lino.courses.Lines.merge_row), "tooltip": "Fusionieren", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/LinesByTopic",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.LinesByTopic.detail;
    this.ls_insert_handler = Lino.courses.LinesByTopic.insert;
    Lino.courses.LinesByTopic.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.LinesByTopic.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/LinesByTopic" };
  return new Lino.courses.LinesByTopic.detailPanel(p);
});
Lino.courses.LinesByTopic.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/LinesByTopic", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.LinesByTopic.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/LinesByTopic" };
  return new Lino.courses.LinesByTopic.GridPanel(p);
});
Lino.courses.LinesByTopic.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/LinesByTopic", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.EntriesByTeacher
Lino.courses.EntriesByTeacher.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/EntriesByTeacher",
  ls_store_fields : [ { "name": "when_text" }, { "name": "owner" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/EntriesByTeacher','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EntriesByTeacher','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EntriesByTeacher','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EntriesByTeacher','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/EntriesByTeacher','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalendereintr\u00e4ge",
  disabled_fields_index : 7,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.EntriesByTeacher.detail;
    this.ls_insert_handler = Lino.courses.EntriesByTeacher.insert;
    var ww = this.containing_window;
    var when_text_disp4291 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var owner_disp4292 = new Ext.form.DisplayField({ "disabled": true });
    var room4293 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EntriesByTeacher/room" }) }) });
    var state4294 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(courses.EntriesByTeacher.when_text) ") }, "sortable": true, "tooltip": "(courses.EntriesByTeacher.when_text) ", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(courses.EntriesByTeacher.owner) ") }, "sortable": false, "tooltip": "(courses.EntriesByTeacher.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "room", "editable": true, "editor": room4293, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.EntriesByTeacher.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "state", "editable": true, "editor": state4294, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "listeners": { "render": Lino.quicktip_renderer("","(courses.EntriesByTeacher.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) } ];
    Lino.courses.EntriesByTeacher.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.EntriesByTeacher.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.EntriesByTeacher.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/EntriesByTeacher",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.EntriesByTeacher.detail;
    this.ls_insert_handler = Lino.courses.EntriesByTeacher.insert;
    Lino.courses.EntriesByTeacher.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.EntriesByTeacher.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/EntriesByTeacher" };
  return new Lino.courses.EntriesByTeacher.insertPanel(p);
});
Lino.courses.EntriesByTeacher.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.EntriesByTeacher.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/EntriesByTeacher",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.EntriesByTeacher.detail;
    this.ls_insert_handler = Lino.courses.EntriesByTeacher.insert;
    Lino.courses.EntriesByTeacher.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.EntriesByTeacher.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/EntriesByTeacher" };
  return new Lino.courses.EntriesByTeacher.detailPanel(p);
});
Lino.courses.EntriesByTeacher.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/EntriesByTeacher" };
  p.params_panel = new Lino.cal.Events.ParamsPanel({});
  return new Lino.courses.EntriesByTeacher.GridPanel(p);
});
Lino.courses.EntriesByTeacher.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EntriesByTeacher.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EntriesByTeacher", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.ActivitiesByTeacher
Lino.courses.ActivitiesByTeacher.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/ActivitiesByTeacher",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "name": "end_time" }, { "name": "line" }, 'lineHidden', { "name": "room" }, 'roomHidden', { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "name": "name" }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "teacher" }, 'teacherHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByTeacher','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByTeacher','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByTeacher','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByTeacher','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByTeacher','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aktivit\u00e4ten",
  disabled_fields_index : 37,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByTeacher.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesByTeacher.insert;
    var ww = this.containing_window;
    var start_date4296 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var start_time4297 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_time4298 = new Lino.TimeField({ "allowBlank": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var line4299 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTeacher/line" }) }) });
    var room4300 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTeacher/room" }) }) });
    var id4301 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date4302 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var user4303 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTeacher/user" }) }) });
    var every_unit4304 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every4305 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions4306 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday4307 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday4308 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday4309 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday4310 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday4311 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday4312 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday4313 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events4314 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var max_date4315 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var slot4316 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTeacher/slot" }) }) });
    var description4317 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de4318 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr4319 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark4320 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state4321 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places4322 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var name4323 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 100, "selectOnFocus": true });
    var enrolments_until4324 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var teacher4325 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTeacher/teacher" }) }) });
    this.before_row_edit = function(record) {
      description4317.refresh();
      description_de4318.refresh();
      description_fr4319.refresh();
      remark4320.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "start_date", "editable": true, "editor": start_date4296, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "start_time", "editable": true, "editor": start_time4297, "header": "Beginnt um", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 2, "dataIndex": "end_time", "editable": true, "editor": end_time4298, "header": "Endet um", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 3, "dataIndex": "line", "editable": true, "editor": line4299, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "room", "editable": true, "editor": room4300, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id4301, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "end_date", "editable": true, "editor": end_date4302, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 7, "dataIndex": "user", "editable": true, "editor": user4303, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "every_unit", "editable": true, "editor": every_unit4304, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 9, "dataIndex": "every", "editable": true, "editor": every4305, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 10, "dataIndex": "positions", "editable": true, "editor": positions4306, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 11, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 12, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 13, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 14, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 18, "dataIndex": "max_events", "editable": true, "editor": max_events4314, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 19, "dataIndex": "max_date", "editable": true, "editor": max_date4315, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 20, "dataIndex": "slot", "editable": true, "editor": slot4316, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 21, "dataIndex": "description", "editable": true, "editor": description4317, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 22, "dataIndex": "description_de", "editable": true, "editor": description_de4318, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 23, "dataIndex": "description_fr", "editable": true, "editor": description_fr4319, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 24, "dataIndex": "remark", "editable": true, "editor": remark4320, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 25, "dataIndex": "state", "editable": true, "editor": state4321, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 26, "dataIndex": "max_places", "editable": true, "editor": max_places4322, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 27, "dataIndex": "name", "editable": true, "editor": name4323, "filter": { "type": "string" }, "header": "Bezeichnung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 28, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until4324, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 29, "dataIndex": "teacher", "editable": true, "editor": teacher4325, "filter": { "type": "string" }, "header": "Kursleiter", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTeacher.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.courses.ActivitiesByTeacher.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByTeacher.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTeacher.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTeacher.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTeacher.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActivitiesByTeacher.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/ActivitiesByTeacher",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByTeacher.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesByTeacher.insert;
    Lino.courses.ActivitiesByTeacher.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByTeacher.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/ActivitiesByTeacher" };
  return new Lino.courses.ActivitiesByTeacher.insertPanel(p);
});
Lino.courses.ActivitiesByTeacher.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTeacher.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActivitiesByTeacher.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/ActivitiesByTeacher",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByTeacher.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesByTeacher.insert;
    Lino.courses.ActivitiesByTeacher.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByTeacher.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivitiesByTeacher" };
  return new Lino.courses.ActivitiesByTeacher.detailPanel(p);
});
Lino.courses.ActivitiesByTeacher.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTeacher.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTeacher.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTeacher.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivitiesByTeacher" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.ActivitiesByTeacher.GridPanel(p);
});
Lino.courses.ActivitiesByTeacher.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTeacher.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTeacher", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.ActivitiesByLine
Lino.courses.ActivitiesByLine.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/ActivitiesByLine",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "weekdays_text" }, { "name": "room" }, 'roomHidden', { "name": "times_text" }, { "name": "teacher" }, 'teacherHidden', { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "name": "name" }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "line" }, 'lineHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByLine','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByLine','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByLine','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByLine','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByLine','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aktivit\u00e4ten",
  disabled_fields_index : 40,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByLine.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesByLine.insert;
    var ww = this.containing_window;
    var detail_link_disp4327 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var weekdays_text_disp4328 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var room4329 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByLine/room" }) }) });
    var times_text_disp4330 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var teacher4331 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByLine/teacher" }) }) });
    var id4332 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date4333 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time4334 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date4335 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time4336 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user4337 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByLine/user" }) }) });
    var every_unit4338 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every4339 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions4340 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday4341 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday4342 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday4343 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday4344 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday4345 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday4346 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday4347 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events4348 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var max_date4349 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var slot4350 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByLine/slot" }) }) });
    var description4351 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de4352 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr4353 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark4354 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state4355 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places4356 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var name4357 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 100, "selectOnFocus": true });
    var enrolments_until4358 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var line4359 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByLine/line" }) }) });
    this.before_row_edit = function(record) {
      description4351.refresh();
      description_de4352.refresh();
      description_fr4353.refresh();
      remark4354.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.detail_link) ") }, "sortable": false, "tooltip": "(courses.ActivitiesByLine.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "weekdays_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.weekdays_text) A virtual field returning the textual formulation of the\nweekdays where the recurrence occurs.") }, "sortable": false, "tooltip": "A virtual field returning the textual formulation of the\nweekdays where the recurrence occurs.", "width": Lino.chars2width(31) }, { "colIndex": 2, "dataIndex": "room", "editable": true, "editor": room4329, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "times_text", "editable": false, "header": "Uhrzeiten", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.times_text) ") }, "sortable": false, "tooltip": "(courses.ActivitiesByLine.times_text) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "teacher", "editable": true, "editor": teacher4331, "filter": { "type": "string" }, "header": "Kursleiter", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id4332, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "start_date", "editable": true, "editor": start_date4333, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 7, "dataIndex": "start_time", "editable": true, "editor": start_time4334, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 8, "dataIndex": "end_date", "editable": true, "editor": end_date4335, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "end_time", "editable": true, "editor": end_time4336, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "user", "editable": true, "editor": user4337, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "every_unit", "editable": true, "editor": every_unit4338, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 12, "dataIndex": "every", "editable": true, "editor": every4339, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 13, "dataIndex": "positions", "editable": true, "editor": positions4340, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 19, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 20, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 21, "dataIndex": "max_events", "editable": true, "editor": max_events4348, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 22, "dataIndex": "max_date", "editable": true, "editor": max_date4349, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 23, "dataIndex": "slot", "editable": true, "editor": slot4350, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "description", "editable": true, "editor": description4351, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 25, "dataIndex": "description_de", "editable": true, "editor": description_de4352, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 26, "dataIndex": "description_fr", "editable": true, "editor": description_fr4353, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 27, "dataIndex": "remark", "editable": true, "editor": remark4354, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 28, "dataIndex": "state", "editable": true, "editor": state4355, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 29, "dataIndex": "max_places", "editable": true, "editor": max_places4356, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 30, "dataIndex": "name", "editable": true, "editor": name4357, "filter": { "type": "string" }, "header": "Bezeichnung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 31, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until4358, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 32, "dataIndex": "line", "editable": true, "editor": line4359, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByLine.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.courses.ActivitiesByLine.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByLine.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLine.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLine.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLine.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActivitiesByLine.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/ActivitiesByLine",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByLine.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesByLine.insert;
    Lino.courses.ActivitiesByLine.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByLine.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/ActivitiesByLine" };
  return new Lino.courses.ActivitiesByLine.insertPanel(p);
});
Lino.courses.ActivitiesByLine.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLine.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActivitiesByLine.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/ActivitiesByLine",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByLine.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesByLine.insert;
    Lino.courses.ActivitiesByLine.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByLine.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivitiesByLine" };
  return new Lino.courses.ActivitiesByLine.detailPanel(p);
});
Lino.courses.ActivitiesByLine.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLine.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLine.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLine.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivitiesByLine" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.ActivitiesByLine.GridPanel(p);
});
Lino.courses.ActivitiesByLine.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByLine.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByLine", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.ActivitiesByTopic
Lino.courses.ActivitiesByTopic.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/ActivitiesByTopic",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "weekdays_text" }, { "name": "times_text" }, { "name": "max_places", "type": "int", "useNull": true }, { "name": "confirmed", "type": "int", "useNull": true }, { "name": "free_places", "type": "int", "useNull": true }, { "name": "requested", "type": "int", "useNull": true }, { "name": "trying", "type": "int", "useNull": true }, { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "name": "room" }, 'roomHidden', { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "line" }, 'lineHidden', { "name": "teacher" }, 'teacherHidden', { "name": "slot" }, 'slotHidden', { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "name" }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "line__topic" }, 'line__topicHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 8,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByTopic','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByTopic','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByTopic','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByTopic','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesByTopic','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aktivit\u00e4ten",
  disabled_fields_index : 46,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByTopic.detail;
    var ww = this.containing_window;
    var detail_link_disp1005 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var weekdays_text_disp1006 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var times_text_disp1007 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var max_places1008 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var confirmed1009 = new Ext.form.NumberField({ "disabled": true });
    var free_places1010 = new Ext.form.NumberField({ "disabled": true });
    var requested1011 = new Ext.form.NumberField({ "disabled": true });
    var trying1012 = new Ext.form.NumberField({ "disabled": true });
    var id1013 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date1014 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time1015 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date1016 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time1017 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user1018 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTopic/user" }) }) });
    var every_unit1019 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every1020 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions1021 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday1022 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday1023 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday1024 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday1025 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday1026 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday1027 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday1028 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events1029 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var room1030 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTopic/room" }) }) });
    var max_date1031 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var line1032 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTopic/line" }) }) });
    var teacher1033 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTopic/teacher" }) }) });
    var slot1034 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesByTopic/slot" }) }) });
    var description1035 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de1036 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr1037 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark1038 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state1039 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var name1040 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 100, "selectOnFocus": true });
    var enrolments_until1041 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var line__topic1042 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Thema ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Topics", "sortable": false, "value": null });
    this.before_row_edit = function(record) {
      description1035.refresh();
      description_de1036.refresh();
      description_fr1037.refresh();
      remark1038.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.detail_link) ") }, "sortable": false, "tooltip": "(courses.ActivitiesByTopic.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "weekdays_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.weekdays_text) A virtual field returning the textual formulation of the\nweekdays where the recurrence occurs.") }, "sortable": false, "tooltip": "A virtual field returning the textual formulation of the\nweekdays where the recurrence occurs.", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "times_text", "editable": false, "header": "Uhrzeiten", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.times_text) ") }, "sortable": false, "tooltip": "(courses.ActivitiesByTopic.times_text) ", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 3, "dataIndex": "max_places", "editable": true, "editor": max_places1008, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(9), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 4, "dataIndex": "confirmed", "editable": false, "format": "0", "header": "Best\u00e4tigt", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.confirmed) Number of confirmed places.") }, "sortable": true, "tooltip": "Number of confirmed places.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 5, "dataIndex": "free_places", "editable": false, "format": "0", "header": "Freie Pl\u00e4tze", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.free_places) Number of free places.") }, "sortable": true, "tooltip": "Number of free places.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 6, "dataIndex": "requested", "editable": false, "format": "0", "header": "Angefragt", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.requested) Number of requested places.") }, "sortable": true, "tooltip": "Number of requested places.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 7, "dataIndex": "trying", "editable": false, "format": "0", "header": "Test", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.trying) Number of trying places.") }, "sortable": true, "tooltip": "Number of trying places.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "align": "right", "colIndex": 8, "dataIndex": "id", "editable": true, "editor": id1013, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 9, "dataIndex": "start_date", "editable": true, "editor": start_date1014, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "start_time", "editable": true, "editor": start_time1015, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 11, "dataIndex": "end_date", "editable": true, "editor": end_date1016, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 12, "dataIndex": "end_time", "editable": true, "editor": end_time1017, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 13, "dataIndex": "user", "editable": true, "editor": user1018, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 14, "dataIndex": "every_unit", "editable": true, "editor": every_unit1019, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 15, "dataIndex": "every", "editable": true, "editor": every1020, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 16, "dataIndex": "positions", "editable": true, "editor": positions1021, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 17, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 19, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 20, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 21, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 22, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 23, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 24, "dataIndex": "max_events", "editable": true, "editor": max_events1029, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 25, "dataIndex": "room", "editable": true, "editor": room1030, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 26, "dataIndex": "max_date", "editable": true, "editor": max_date1031, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 27, "dataIndex": "line", "editable": true, "editor": line1032, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 28, "dataIndex": "teacher", "editable": true, "editor": teacher1033, "filter": { "type": "string" }, "header": "Kursleiter", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 29, "dataIndex": "slot", "editable": true, "editor": slot1034, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 30, "dataIndex": "description", "editable": true, "editor": description1035, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 31, "dataIndex": "description_de", "editable": true, "editor": description_de1036, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 32, "dataIndex": "description_fr", "editable": true, "editor": description_fr1037, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 33, "dataIndex": "remark", "editable": true, "editor": remark1038, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 34, "dataIndex": "state", "editable": true, "editor": state1039, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "colIndex": 35, "dataIndex": "name", "editable": true, "editor": name1040, "filter": { "type": "string" }, "header": "Bezeichnung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 36, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until1041, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 37, "dataIndex": "line__topic", "editable": false, "filter": { "type": "string" }, "header": "Thema", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesByTopic.line__topic) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.courses.ActivitiesByTopic.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByTopic.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTopic", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTopic.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTopic", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTopic.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTopic", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTopic.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTopic", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTopic.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTopic", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActivitiesByTopic.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/ActivitiesByTopic",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesByTopic.detail;
    Lino.courses.ActivitiesByTopic.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesByTopic.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivitiesByTopic" };
  return new Lino.courses.ActivitiesByTopic.detailPanel(p);
});
Lino.courses.ActivitiesByTopic.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTopic", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTopic.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTopic", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTopic.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTopic", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTopic.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivitiesByTopic" };
  p.params_panel = new Lino.courses.ActivitiesByTopic.ParamsPanel({});
  return new Lino.courses.ActivitiesByTopic.GridPanel(p);
});
Lino.courses.ActivitiesByTopic.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTopic", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesByTopic.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesByTopic", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.ActivitiesBySlot
Lino.courses.ActivitiesBySlot.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/ActivitiesBySlot",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "name" }, { "name": "line" }, 'lineHidden', { "name": "teacher" }, 'teacherHidden', { "name": "room" }, 'roomHidden', { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "user" }, 'userHidden', { "name": "every_unit" }, 'every_unitHidden', { "name": "every", "type": "int", "useNull": true }, { "name": "positions" }, { "name": "monday", "type": "boolean" }, { "name": "tuesday", "type": "boolean" }, { "name": "wednesday", "type": "boolean" }, { "name": "thursday", "type": "boolean" }, { "name": "friday", "type": "boolean" }, { "name": "saturday", "type": "boolean" }, { "name": "sunday", "type": "boolean" }, { "name": "max_events", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "max_date", "type": "date" }, { "name": "description" }, { "name": "description_de" }, { "name": "description_fr" }, { "name": "remark" }, { "name": "state" }, 'stateHidden', { "name": "max_places", "type": "int", "useNull": true }, { "dateFormat": "d.m.Y", "name": "enrolments_until", "type": "date" }, { "name": "slot" }, 'slotHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 9,
  content_type : 50,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesBySlot','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesBySlot','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesBySlot','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesBySlot','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/ActivitiesBySlot','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aktivit\u00e4ten",
  disabled_fields_index : 38,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesBySlot.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesBySlot.insert;
    var ww = this.containing_window;
    var start_date774 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var name775 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 100, "selectOnFocus": true });
    var line776 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Aktivit\u00e4tenreihe ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Lines", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesBySlot/line" }) }) });
    var teacher777 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Person ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesBySlot/teacher" }) }) });
    var room778 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesBySlot/room" }) }) });
    var workflow_buttons_disp779 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id780 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time781 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date782 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time783 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var user784 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesBySlot/user" }) }) });
    var every_unit785 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.Recurrencies) });
    var every786 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true });
    var positions787 = new Ext.form.TextField({ "allowBlank": true, "hidden": true, "maxLength": 50, "selectOnFocus": true });
    var monday788 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var tuesday789 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var wednesday790 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var thursday791 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var friday792 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var saturday793 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var sunday794 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var max_events795 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var max_date796 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var description797 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung" });
    var description_de798 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (de)" });
    var description_fr799 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Beschreibung (fr)" });
    var remark800 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Bemerkung" });
    var state801 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.CourseStates });
    var max_places802 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var enrolments_until803 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var slot804 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Timetable Slot ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Slots", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/ActivitiesBySlot/slot" }) }) });
    this.before_row_edit = function(record) {
      description797.refresh();
      description_de798.refresh();
      description_fr799.refresh();
      remark800.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "start_date", "editable": true, "editor": start_date774, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.start_date) Das Beginndatum der ersten Veranstaltung.") }, "sortable": true, "tooltip": "Das Beginndatum der ersten Veranstaltung.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "name", "editable": true, "editor": name775, "filter": { "type": "string" }, "header": "Bezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.name) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "line", "editable": true, "editor": line776, "filter": { "type": "string" }, "header": "Aktivit\u00e4tenreihe", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.line) ") }, "renderer": Lino.fk_renderer('lineHidden','Lino.courses.Lines.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "teacher", "editable": true, "editor": teacher777, "filter": { "type": "string" }, "header": "Kursleiter", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.teacher) ") }, "renderer": Lino.fk_renderer('teacherHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "room", "editable": true, "editor": room778, "filter": { "type": "string" }, "header": "Raum", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id780, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "start_time", "editable": true, "editor": start_time781, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.start_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 8, "dataIndex": "end_date", "editable": true, "editor": end_date782, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.end_date) Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.") }, "sortable": true, "tooltip": "Das Enddatum der ersten Veranstaltung. Dieses Feld leer lassen, wenn die Veranstaltungen weniger als einen Tag dauern.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 9, "dataIndex": "end_time", "editable": true, "editor": end_time783, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.end_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "user", "editable": true, "editor": user784, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "every_unit", "editable": true, "editor": every_unit785, "filter": { "options": [ "einmalig", "t\u00e4glich", "w\u00f6chentlich", "monatlich", "j\u00e4hrlich", "pro Wochentag", "Beweglich mit Ostern" ], "type": "list" }, "header": "Wiederholung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.every_unit) The interval between each periodic iteration.") }, "sortable": false, "tooltip": "The interval between each periodic iteration.", "width": Lino.chars2width(22) }, { "align": "right", "colIndex": 12, "dataIndex": "every", "editable": true, "editor": every786, "filter": { "type": "numeric" }, "format": "0", "header": "... alle", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.every) The frequency of periodic iteration: daily, weekly, monthly or yearly.") }, "sortable": true, "tooltip": "The frequency of periodic iteration: daily, weekly, monthly or yearly.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 13, "dataIndex": "positions", "editable": true, "editor": positions787, "filter": { "type": "string" }, "header": "Positionen", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.positions) Space-separated list of one or several positions within the recurrency\ncycle.") }, "sortable": true, "tooltip": "Space-separated list of one or several positions within the recurrency\ncycle.", "width": Lino.chars2width(22) }, { "colIndex": 14, "dataIndex": "monday", "editable": true, "filter": { "type": "boolean" }, "header": "Montag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.monday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 15, "dataIndex": "tuesday", "editable": true, "filter": { "type": "boolean" }, "header": "Dienstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.tuesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 16, "dataIndex": "wednesday", "editable": true, "filter": { "type": "boolean" }, "header": "Mittwoch", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.wednesday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 17, "dataIndex": "thursday", "editable": true, "filter": { "type": "boolean" }, "header": "Donnerstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.thursday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 18, "dataIndex": "friday", "editable": true, "filter": { "type": "boolean" }, "header": "Freitag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.friday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 19, "dataIndex": "saturday", "editable": true, "filter": { "type": "boolean" }, "header": "Samstag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.saturday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 20, "dataIndex": "sunday", "editable": true, "filter": { "type": "boolean" }, "header": "Sonntag", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.sunday) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "align": "right", "colIndex": 21, "dataIndex": "max_events", "editable": true, "editor": max_events795, "filter": { "type": "numeric" }, "format": "0", "header": "Anzahl Termine", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.max_events) Maximum number of calendar entries to generate.") }, "sortable": true, "tooltip": "Maximum number of calendar entries to generate.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 22, "dataIndex": "max_date", "editable": true, "editor": max_date796, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Termine generieren bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.max_date) Don't generate meeting having their start date beyond this\ndate.") }, "sortable": true, "tooltip": "Don't generate meeting having their start date beyond this\ndate.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 23, "dataIndex": "description", "editable": true, "editor": description797, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.description) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 24, "dataIndex": "description_de", "editable": true, "editor": description_de798, "filter": { "type": "string" }, "header": "Beschreibung (de)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.description_de) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 25, "dataIndex": "description_fr", "editable": true, "editor": description_fr799, "filter": { "type": "string" }, "header": "Beschreibung (fr)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.description_fr) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 26, "dataIndex": "remark", "editable": true, "editor": remark800, "filter": { "type": "string" }, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.remark) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 27, "dataIndex": "state", "editable": true, "editor": state801, "filter": { "options": [ "Entwurf", "Gestartet", "Inaktiv", "Abgeschlossen" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.state) The workflow state field.") }, "sortable": false, "tooltip": "The workflow state field.", "width": Lino.chars2width(12) }, { "align": "right", "colIndex": 28, "dataIndex": "max_places", "editable": true, "editor": max_places802, "filter": { "type": "numeric" }, "format": "0", "header": "Verf\u00fcgbare Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.max_places) Available places. The maximum number of participants to allow\nin this activity.") }, "sortable": true, "tooltip": "Available places. The maximum number of participants to allow\nin this activity.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 29, "dataIndex": "enrolments_until", "editable": true, "editor": enrolments_until803, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Einschreibung m\u00f6glich bis", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.enrolments_until) Until when new enrolments are accepted.") }, "sortable": true, "tooltip": "Until when new enrolments are accepted.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 30, "dataIndex": "slot", "editable": true, "editor": slot804, "filter": { "type": "string" }, "header": "Timetable Slot", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivitiesBySlot.slot) ") }, "renderer": Lino.fk_renderer('slotHidden','Lino.courses.Slots.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.courses.ActivitiesBySlot.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesBySlot.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesBySlot.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesBySlot.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesBySlot.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActivitiesBySlot.insertPanel = Ext.extend(Lino.courses.Activities.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/ActivitiesBySlot",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesBySlot.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesBySlot.insert;
    Lino.courses.ActivitiesBySlot.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesBySlot.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/ActivitiesBySlot" };
  return new Lino.courses.ActivitiesBySlot.insertPanel(p);
});
Lino.courses.ActivitiesBySlot.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesBySlot.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.ActivitiesBySlot.detailPanel = Ext.extend(Lino.courses.Activities.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Aktivit\u00e4t) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "do_update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('do_update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update the automatic calendar entries controlled by\nthis generator.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_all_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_all_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerlisten aller offenen Kalendereintr\u00e4ge aktualisieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/ActivitiesBySlot",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.ActivitiesBySlot.detail;
    this.ls_insert_handler = Lino.courses.ActivitiesBySlot.insert;
    Lino.courses.ActivitiesBySlot.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivitiesBySlot.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivitiesBySlot" };
  return new Lino.courses.ActivitiesBySlot.detailPanel(p);
});
Lino.courses.ActivitiesBySlot.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesBySlot.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesBySlot.do_update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "GET", pk, "do_update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesBySlot.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivitiesBySlot" };
  p.params_panel = new Lino.courses.Activities.ParamsPanel({});
  return new Lino.courses.ActivitiesBySlot.GridPanel(p);
});
Lino.courses.ActivitiesBySlot.update_all_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "GET", pk, "update_all_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivitiesBySlot.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivitiesBySlot", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.EnrolmentsByPupil
Lino.courses.EnrolmentsByPupil.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/EnrolmentsByPupil",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "request_date", "type": "date" }, { "name": "course" }, 'courseHidden', { "name": "user" }, 'userHidden', { "name": "remark" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "printed_by" }, 'printed_byHidden', { "name": "course_area" }, 'course_areaHidden', { "name": "state" }, 'stateHidden', { "name": "places", "type": "int", "useNull": true }, { "name": "confirmation_details" }, { "name": "pupil" }, 'pupilHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 7,
  content_type : 51,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentsByPupil','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentsByPupil','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentsByPupil','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentsByPupil','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentsByPupil','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Einschreibungen in Aktivit\u00e4ten",
  disabled_fields_index : 20,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.EnrolmentsByPupil.detail;
    this.ls_insert_handler = Lino.courses.EnrolmentsByPupil.insert;
    var ww = this.containing_window;
    var request_date4361 = new Lino.DateField({ "allowBlank": false, "selectOnFocus": true });
    var course4362 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Aktivit\u00e4t ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "courses.Activities", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EnrolmentsByPupil/course" }) }) });
    var user4363 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EnrolmentsByPupil/user" }) }) });
    var remark4364 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp4365 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id4366 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date4367 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date4368 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var printed_by4369 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Auszug ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "excerpts.Excerpts" });
    var course_area4370 = new Lino.ChoicesFieldElement({ "disabled": true, "forceSelection": true, "hidden": true, "store": [['','<br>']].concat(Lino.courses.ActivityLayouts) });
    var state4371 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.EnrolmentStates });
    var places4372 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 1 });
    var confirmation_details4373 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Details Best\u00e4tigung" });
    var pupil4374 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EnrolmentsByPupil/pupil" }) }) });
    this.before_row_edit = function(record) {
      course4362.setContextValue('course_area', record ? record.data['course_areaHidden'] : undefined);
      course4362.setContextValue('request_date', record ? record.data['request_date'] : undefined);
      confirmation_details4373.refresh();
      pupil4374.setContextValue('course', record ? record.data['courseHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof course_area4370 !== 'undefined' && course_area4370.on('change',Lino.chooser_handler(course4362,'course_area'));
      typeof request_date4361 !== 'undefined' && request_date4361.on('change',Lino.chooser_handler(course4362,'request_date'));
      typeof course4362 !== 'undefined' && course4362.on('change',Lino.chooser_handler(pupil4374,'course'));
      Lino.courses.EnrolmentsByPupil.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "request_date", "editable": true, "editor": request_date4361, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Datum der Anfrage", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.request_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "course", "editable": true, "editor": course4362, "filter": { "type": "string" }, "header": "Aktivit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.course) ") }, "renderer": Lino.fk_renderer('courseHidden','Lino.courses.Activities.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user4363, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(11) }, { "colIndex": 3, "dataIndex": "remark", "editable": true, "editor": remark4364, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id4366, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "start_date", "editable": true, "editor": start_date4367, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.start_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 7, "dataIndex": "end_date", "editable": true, "editor": end_date4368, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.end_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "printed_by", "editable": false, "filter": { "type": "string" }, "header": "Ausgedruckt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.printed_by) ForeignKey to the Excerpt which certifies this instance.") }, "renderer": Lino.fk_renderer('printed_byHidden','Lino.excerpts.Excerpts.detail'), "sortable": false, "tooltip": "ForeignKey to the Excerpt which certifies this instance.", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "course_area", "editable": false, "filter": { "options": [ "Aktivit\u00e4ten" ], "type": "list" }, "header": "Layout", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.course_area) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(14) }, { "colIndex": 10, "dataIndex": "state", "editable": true, "editor": state4371, "filter": { "options": [ "Angefragt", "Test", "Best\u00e4tigt", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.state) One of lino_xl.lib.courses.EnrolmentStates.") }, "sortable": false, "tooltip": "One of lino_xl.lib.courses.EnrolmentStates.", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 11, "dataIndex": "places", "editable": true, "editor": places4372, "filter": { "type": "numeric" }, "format": "0", "header": "Anz. Pl\u00e4tze", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.places) The number of participants in this enrolment.") }, "sortable": true, "tooltip": "The number of participants in this enrolment.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 12, "dataIndex": "confirmation_details", "editable": true, "editor": confirmation_details4373, "filter": { "type": "string" }, "header": "Details Best\u00e4tigung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.confirmation_details) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 13, "dataIndex": "pupil", "editable": true, "editor": pupil4374, "filter": { "type": "string" }, "header": "Teilnehmer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByPupil.pupil) ") }, "renderer": Lino.fk_renderer('pupilHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.courses.EnrolmentsByPupil.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.EnrolmentsByPupil.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByPupil", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByPupil.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByPupil", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByPupil.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByPupil", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByPupil.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByPupil", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.EnrolmentsByPupil.insertPanel = Ext.extend(Lino.courses.EnrolmentsByPupil.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/EnrolmentsByPupil",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.EnrolmentsByPupil.detail;
    this.ls_insert_handler = Lino.courses.EnrolmentsByPupil.insert;
    Lino.courses.EnrolmentsByPupil.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.EnrolmentsByPupil.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/EnrolmentsByPupil" };
  return new Lino.courses.EnrolmentsByPupil.insertPanel(p);
});
Lino.courses.EnrolmentsByPupil.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByPupil", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.EnrolmentsByPupil.detailPanel = Ext.extend(Lino.courses.Enrolments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/EnrolmentsByPupil",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.EnrolmentsByPupil.detail;
    this.ls_insert_handler = Lino.courses.EnrolmentsByPupil.insert;
    Lino.courses.EnrolmentsByPupil.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.EnrolmentsByPupil.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/EnrolmentsByPupil" };
  return new Lino.courses.EnrolmentsByPupil.detailPanel(p);
});
Lino.courses.EnrolmentsByPupil.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByPupil", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByPupil.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByPupil", "GET", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByPupil.clear_printed = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByPupil", "GET", pk, "clear_printed", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByPupil.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/EnrolmentsByPupil" };
  p.params_panel = new Lino.courses.Enrolments.ParamsPanel({});
  return new Lino.courses.EnrolmentsByPupil.GridPanel(p);
});
Lino.courses.EnrolmentsByPupil.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByPupil", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class courses.EnrolmentsByCourse
Lino.courses.EnrolmentsByCourse.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/EnrolmentsByCourse",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "request_date", "type": "date" }, { "name": "pupil" }, 'pupilHidden', { "name": "places", "type": "int", "useNull": true }, { "name": "remark" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "user" }, 'userHidden', { "name": "printed_by" }, 'printed_byHidden', { "name": "course_area" }, 'course_areaHidden', { "name": "state" }, 'stateHidden', { "name": "confirmation_details" }, { "name": "course" }, 'courseHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 6,
  content_type : 51,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentsByCourse','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentsByCourse','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentsByCourse','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentsByCourse','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentsByCourse','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Einschreibungen",
  disabled_fields_index : 20,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.EnrolmentsByCourse.detail;
    this.ls_insert_handler = Lino.courses.EnrolmentsByCourse.insert;
    var ww = this.containing_window;
    var request_date4376 = new Lino.DateField({ "allowBlank": false, "selectOnFocus": true });
    var pupil4377 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": true, "emptyText": "Person ausw\u00e4hlen...", "forceSelection": false, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EnrolmentsByCourse/pupil" }) }) });
    var places4378 = new Ext.form.NumberField({ "allowBlank": false, "selectOnFocus": true, "value": 1 });
    var remark4379 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp4380 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id4381 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_date4382 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_date4383 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var user4384 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EnrolmentsByCourse/user" }) }) });
    var printed_by4385 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Auszug ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "excerpts.Excerpts" });
    var course_area4386 = new Lino.ChoicesFieldElement({ "disabled": true, "forceSelection": true, "hidden": true, "store": [['','<br>']].concat(Lino.courses.ActivityLayouts) });
    var state4387 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.courses.EnrolmentStates });
    var confirmation_details4388 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Details Best\u00e4tigung" });
    var course4389 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Aktivit\u00e4t ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "courses.Activities", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/courses/EnrolmentsByCourse/course" }) }) });
    this.before_row_edit = function(record) {
      var bp = this.get_base_params();
      pupil4377.setContextValue('mk',bp['mk']);
      pupil4377.setContextValue('mt',bp['mt']);
      confirmation_details4388.refresh();
      course4389.setContextValue('course_area', record ? record.data['course_areaHidden'] : undefined);
      course4389.setContextValue('request_date', record ? record.data['request_date'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof course4389 !== 'undefined' && course4389.on('change',Lino.chooser_handler(pupil4377,'course'));
      typeof course_area4386 !== 'undefined' && course_area4386.on('change',Lino.chooser_handler(course4389,'course_area'));
      typeof request_date4376 !== 'undefined' && request_date4376.on('change',Lino.chooser_handler(course4389,'request_date'));
      Lino.courses.EnrolmentsByCourse.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "request_date", "editable": true, "editor": request_date4376, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Datum der Anfrage", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.request_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "pupil", "editable": true, "editor": pupil4377, "filter": { "type": "string" }, "header": "Teilnehmer", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.pupil) ") }, "renderer": Lino.fk_renderer('pupilHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 2, "dataIndex": "places", "editable": true, "editor": places4378, "filter": { "type": "numeric" }, "format": "0", "header": "Anz. Pl\u00e4tze", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.places) The number of participants in this enrolment.") }, "sortable": true, "tooltip": "The number of participants in this enrolment.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 3, "dataIndex": "remark", "editable": true, "editor": remark4379, "filter": { "type": "string" }, "header": "Bemerkung", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.remark) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 5, "dataIndex": "id", "editable": true, "editor": id4381, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 6, "dataIndex": "start_date", "editable": true, "editor": start_date4382, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.start_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 7, "dataIndex": "end_date", "editable": true, "editor": end_date4383, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.end_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(11), "xtype": "datecolumn" }, { "colIndex": 8, "dataIndex": "user", "editable": true, "editor": user4384, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "printed_by", "editable": false, "filter": { "type": "string" }, "header": "Ausgedruckt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.printed_by) ForeignKey to the Excerpt which certifies this instance.") }, "renderer": Lino.fk_renderer('printed_byHidden','Lino.excerpts.Excerpts.detail'), "sortable": false, "tooltip": "ForeignKey to the Excerpt which certifies this instance.", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "course_area", "editable": false, "filter": { "options": [ "Aktivit\u00e4ten" ], "type": "list" }, "header": "Layout", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.course_area) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(14) }, { "colIndex": 11, "dataIndex": "state", "editable": true, "editor": state4387, "filter": { "options": [ "Angefragt", "Test", "Best\u00e4tigt", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.state) One of lino_xl.lib.courses.EnrolmentStates.") }, "sortable": false, "tooltip": "One of lino_xl.lib.courses.EnrolmentStates.", "width": Lino.chars2width(13) }, { "colIndex": 12, "dataIndex": "confirmation_details", "editable": true, "editor": confirmation_details4388, "filter": { "type": "string" }, "header": "Details Best\u00e4tigung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.confirmation_details) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "colIndex": 13, "dataIndex": "course", "editable": true, "editor": course4389, "filter": { "type": "string" }, "header": "Aktivit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentsByCourse.course) ") }, "renderer": Lino.fk_renderer('courseHidden','Lino.courses.Activities.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.courses.EnrolmentsByCourse.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.EnrolmentsByCourse.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByCourse", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByCourse.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByCourse", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByCourse.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByCourse", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByCourse.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByCourse", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.EnrolmentsByCourse.insertPanel = Ext.extend(Lino.courses.EnrolmentsByCourse.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/courses/EnrolmentsByCourse",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.EnrolmentsByCourse.detail;
    this.ls_insert_handler = Lino.courses.EnrolmentsByCourse.insert;
    Lino.courses.EnrolmentsByCourse.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.EnrolmentsByCourse.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/courses/EnrolmentsByCourse" };
  return new Lino.courses.EnrolmentsByCourse.insertPanel(p);
});
Lino.courses.EnrolmentsByCourse.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByCourse", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.courses.EnrolmentsByCourse.detailPanel = Ext.extend(Lino.courses.Enrolments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Einschreibung) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Enrolment", "overflowText": "Enrolment", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Auszug von diesem Datensatz erstellen zwecks Ausdruck.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "clear_printed", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('clear_printed','GET',null), "tooltip": "Clear any previously generated printable document.  Mark this\nobject as not printed. A subsequent call to print will generate a\nnew cache file.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/courses/EnrolmentsByCourse",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.EnrolmentsByCourse.detail;
    this.ls_insert_handler = Lino.courses.EnrolmentsByCourse.insert;
    Lino.courses.EnrolmentsByCourse.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.EnrolmentsByCourse.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/EnrolmentsByCourse" };
  return new Lino.courses.EnrolmentsByCourse.detailPanel(p);
});
Lino.courses.EnrolmentsByCourse.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByCourse", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByCourse.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByCourse", "GET", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByCourse.clear_printed = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByCourse", "GET", pk, "clear_printed", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentsByCourse.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/EnrolmentsByCourse" };
  p.params_panel = new Lino.courses.Enrolments.ParamsPanel({});
  return new Lino.courses.EnrolmentsByCourse.GridPanel(p);
});
Lino.courses.EnrolmentsByCourse.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentsByCourse", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class gfks.HelpTextsByModel
Lino.gfks.HelpTextsByModel.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/gfks/HelpTextsByModel",
  ls_store_fields : [ { "name": "field" }, { "name": "verbose_name" }, { "name": "help_text" }, { "name": "id", "type": "int" }, { "name": "content_type" }, 'content_typeHidden', { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 13,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/gfks/HelpTextsByModel','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/HelpTextsByModel','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/HelpTextsByModel','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/HelpTextsByModel','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/gfks/HelpTextsByModel','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Hilfetexte",
  disabled_fields_index : 6,
  initComponent : function() {
    var ww = this.containing_window;
    var field1055 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/gfks/HelpTextsByModel/field" }) }) });
    var verbose_name1056 = new Ext.form.TextField({ "disabled": true, "maxLength": 200 });
    var help_text1057 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "selectOnFocus": true });
    var id1058 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var content_type1059 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/gfks/HelpTextsByModel/content_type" }) }) });
    this.before_row_edit = function(record) {
      var bp = this.get_base_params();
      field1055.setContextValue('mk',bp['mk']);
      field1055.setContextValue('mt',bp['mt']);
    };
    this.onRender = function(ct, position) {
      typeof content_type1059 !== 'undefined' && content_type1059.on('change',Lino.chooser_handler(field1055,'content_type'));
      Lino.gfks.HelpTextsByModel.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "field", "editable": true, "editor": field1055, "filter": { "type": "string" }, "header": "Feld", "listeners": { "render": Lino.quicktip_renderer("","(gfks.HelpTextsByModel.field) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 1, "dataIndex": "verbose_name", "editable": false, "header": "Feldbezeichnung", "listeners": { "render": Lino.quicktip_renderer("","(gfks.HelpTextsByModel.verbose_name) ") }, "sortable": true, "tooltip": "(gfks.HelpTextsByModel.verbose_name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "help_text", "editable": true, "editor": help_text1057, "filter": { "type": "string" }, "header": "Hilfetext", "listeners": { "render": Lino.quicktip_renderer("","(gfks.HelpTextsByModel.help_text) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(61) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id1058, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(gfks.HelpTextsByModel.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "content_type", "editable": true, "editor": content_type1059, "filter": { "type": "string" }, "header": "Modell", "listeners": { "render": Lino.quicktip_renderer("","(gfks.HelpTextsByModel.content_type) ") }, "renderer": Lino.fk_renderer('content_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) } ];
    Lino.gfks.HelpTextsByModel.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.gfks.HelpTextsByModel.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/HelpTextsByModel", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.HelpTextsByModel.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/HelpTextsByModel", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.HelpTextsByModel.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/HelpTextsByModel", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.HelpTextsByModel.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/HelpTextsByModel", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.HelpTextsByModel.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/HelpTextsByModel", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.HelpTextsByModel.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/gfks/HelpTextsByModel" };
  return new Lino.gfks.HelpTextsByModel.GridPanel(p);
});

// js_render_GridPanel_class checkdata.ProblemsByOwner
Lino.checkdata.ProblemsByOwner.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/checkdata/ProblemsByOwner",
  ls_store_fields : [ { "name": "message" }, { "name": "checker" }, 'checkerHidden', { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "owner" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 14,
  cell_edit : false,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/checkdata/ProblemsByOwner','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/ProblemsByOwner','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/ProblemsByOwner','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/ProblemsByOwner','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/checkdata/ProblemsByOwner','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "update_problem", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problem", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problem','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Datenprobleme",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.ProblemsByOwner.detail;
    var ww = this.containing_window;
    var message4391 = new Ext.form.TextField({ "allowBlank": false, "maxLength": 250, "selectOnFocus": true });
    var checker4392 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.checkdata.Checkers });
    var user4393 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/ProblemsByOwner/user" }) }) });
    var id4394 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type4395 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/ProblemsByOwner/owner_type" }) }) });
    var owner_id4396 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/checkdata/ProblemsByOwner/owner_id" }) }) });
    var owner_disp4397 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
    };
    this.onRender = function(ct, position) {
      typeof owner_type4395 !== 'undefined' && owner_type4395.on('change',Lino.chooser_handler(owner_id4396,'owner_type'));
      Lino.checkdata.ProblemsByOwner.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "message", "editable": true, "editor": message4391, "filter": { "type": "string" }, "header": "Meldung", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByOwner.message) The message text. This is a concatenation of all messages that\nwere yielded by the checker.") }, "sortable": true, "tooltip": "The message text. This is a concatenation of all messages that\nwere yielded by the checker.", "width": Lino.chars2width(51) }, { "colIndex": 1, "dataIndex": "checker", "editable": true, "editor": checker4392, "filter": { "options": [ "Adressen pr\u00fcfen", "Auf Termin\u00fcberschneidungen pr\u00fcfen", "Termine ohne Teilnehmer", "Dauer \u00fcberschreitende Kalendereintr\u00e4ge", "Veraltete generierte Kalendereintr\u00e4ge", "Check data of geographical places.", "Check integrity of ledger vouchers", "Check for previewables needing update", "Check for mismatches between contact details and owner", "Check for missing target files", "Find unbleached html content", "Check metadata of upload files", "Find orphaned files in uploads folder" ], "type": "list" }, "header": "Checker", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByOwner.checker) The Checker that reported this\nproblem.") }, "sortable": false, "tooltip": "The Checker that reported this\nproblem.", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user4393, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByOwner.user) The user responsible for fixing this\nproblem.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The user responsible for fixing this\nproblem.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id4394, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByOwner.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "owner_type", "editable": true, "editor": owner_type4395, "filter": { "type": "string" }, "header": "Datenobjekt (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByOwner.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_id", "editable": true, "editor": owner_id4396, "filter": { "type": "string" }, "header": "Datenobjekt (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByOwner.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "owner", "editable": false, "header": "Datenobjekt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(checkdata.ProblemsByOwner.owner) ") }, "sortable": false, "tooltip": "(checkdata.ProblemsByOwner.owner) ", "width": Lino.chars2width(11) } ];
    Lino.checkdata.ProblemsByOwner.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.ProblemsByOwner.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByOwner", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.ProblemsByOwner.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByOwner", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.ProblemsByOwner.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByOwner", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.ProblemsByOwner.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByOwner", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.checkdata.ProblemsByOwner.detailPanel = Ext.extend(Lino.checkdata.Problems.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "update_problem", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problem", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problem','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('update_problem','GET',null), "text": null, "xtype": "splitbutton" } ],
  ls_url: "/checkdata/ProblemsByOwner",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.ProblemsByOwner.detail;
    Lino.checkdata.ProblemsByOwner.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.ProblemsByOwner.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(70) }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/ProblemsByOwner" };
  return new Lino.checkdata.ProblemsByOwner.detailPanel(p);
});
Lino.checkdata.ProblemsByOwner.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/ProblemsByOwner" };
  p.params_panel = new Lino.checkdata.Problems.ParamsPanel({});
  return new Lino.checkdata.ProblemsByOwner.GridPanel(p);
});
Lino.checkdata.ProblemsByOwner.update_problem = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByOwner", "GET", pk, "update_problem", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.ProblemsByOwner.fix_problem = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/ProblemsByOwner", "GET", pk, "fix_problem", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.TasksByController
Lino.cal.TasksByController.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/TasksByController",
  ls_store_fields : [ { "name": "priority" }, 'priorityHidden', { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "summary" }, { "name": "workflow_buttons" }, { "name": "id", "type": "int" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 21,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/TasksByController','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/TasksByController','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/TasksByController','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/TasksByController','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/TasksByController','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Task) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aufgaben",
  disabled_fields_index : 6,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.TasksByController.detail;
    this.ls_insert_handler = Lino.cal.TasksByController.insert;
    var ww = this.containing_window;
    var priority4399 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var start_date4400 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var summary4401 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp4402 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var id4403 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "priority", "editable": true, "editor": priority4399, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByController.priority) How urgent this task is.") }, "sortable": false, "tooltip": "How urgent this task is.", "width": Lino.chars2width(12) }, { "colIndex": 1, "dataIndex": "start_date", "editable": true, "editor": start_date4400, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByController.start_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 2, "dataIndex": "summary", "editable": true, "editor": summary4401, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByController.summary) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByController.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 4, "dataIndex": "id", "editable": true, "editor": id4403, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "listeners": { "render": Lino.quicktip_renderer("","(cal.TasksByController.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" } ];
    Lino.cal.TasksByController.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.TasksByController.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByController.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByController.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByController.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.TasksByController.insertPanel = Ext.extend(Lino.cal.Tasks.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/TasksByController",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.TasksByController.detail;
    this.ls_insert_handler = Lino.cal.TasksByController.insert;
    Lino.cal.TasksByController.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.TasksByController.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(50) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/TasksByController" };
  return new Lino.cal.TasksByController.insertPanel(p);
});
Lino.cal.TasksByController.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.TasksByController.detailPanel = Ext.extend(Lino.cal.Tasks.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Task) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/TasksByController",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.TasksByController.detail;
    this.ls_insert_handler = Lino.cal.TasksByController.insert;
    Lino.cal.TasksByController.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.TasksByController.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/TasksByController" };
  return new Lino.cal.TasksByController.detailPanel(p);
});
Lino.cal.TasksByController.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByController.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByController.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/TasksByController" };
  p.params_panel = new Lino.cal.Tasks.ParamsPanel({});
  return new Lino.cal.TasksByController.GridPanel(p);
});
Lino.cal.TasksByController.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByController.wf1 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "GET", pk, "wf1", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByController.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByController.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TasksByController.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TasksByController", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class cal.EntriesByController
Lino.cal.EntriesByController.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/EntriesByController",
  ls_store_fields : [ { "name": "when_text" }, { "name": "summary" }, { "name": "workflow_buttons" }, { "name": "auto_type", "type": "int", "useNull": true }, { "name": "user" }, 'userHidden', { "name": "event_type" }, 'event_typeHidden', { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "created" }, { "dateFormat": "d.m.Y", "name": "start_date", "type": "date" }, { "name": "start_time" }, { "dateFormat": "d.m.Y", "name": "end_date", "type": "date" }, { "name": "end_time" }, { "name": "build_time" }, { "name": "build_method" }, 'build_methodHidden', { "name": "assigned_to" }, 'assigned_toHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "description" }, { "name": "access_class" }, 'access_classHidden', { "name": "sequence", "type": "int", "useNull": true }, { "name": "priority" }, 'priorityHidden', { "name": "transparent", "type": "boolean" }, { "name": "room" }, 'roomHidden', { "name": "state" }, 'stateHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 8,
  content_type : 24,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByController','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByController','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByController','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByController','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/EntriesByController','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalendereintr\u00e4ge",
  disabled_fields_index : 36,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByController.detail;
    this.ls_insert_handler = Lino.cal.EntriesByController.insert;
    var ww = this.containing_window;
    var when_text_disp4405 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var summary4406 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var workflow_buttons_disp4407 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var auto_type4408 = new Ext.form.NumberField({ "allowBlank": true, "selectOnFocus": true });
    var user4409 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByController/user" }) }) });
    var event_type4410 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kalendereintragsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "cal.EventTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByController/event_type" }) }) });
    var id4411 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified4412 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var created4413 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var start_date4414 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var start_time4415 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var end_date4416 = new Lino.DateField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var end_time4417 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var build_time4418 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var build_method4419 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var assigned_to4420 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByController/assigned_to" }) }) });
    var owner_type4421 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByController/owner_type" }) }) });
    var owner_id4422 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByController/owner_id" }) }) });
    var description4423 = new Ext.form.TextArea({ "allowBlank": true, "growMax": 2000, "hidden": true, "selectOnFocus": true });
    var access_class4424 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.cal.AccessClasses) });
    var sequence4425 = new Ext.form.NumberField({ "allowBlank": false, "hidden": true, "selectOnFocus": true, "value": 0 });
    var priority4426 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.xl.Priorities });
    var transparent4427 = new Ext.form.Checkbox({ "allowBlank": false, "checked": false, "hidden": true, "selectOnFocus": true });
    var room4428 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Raum ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "cal.Rooms", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/cal/EntriesByController/room" }) }) });
    var state4429 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.cal.EntryStates });
    var owner_disp4430 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id4422.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_type4421 !== 'undefined' && owner_type4421.on('change',Lino.chooser_handler(owner_id4422,'owner_type'));
      Lino.cal.EntriesByController.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "when_text", "editable": false, "header": "Wann", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.when_text) ") }, "sortable": true, "tooltip": "(cal.EntriesByController.when_text) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "summary", "editable": true, "editor": summary4406, "filter": { "type": "string" }, "header": "Kurzbeschreibung", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.summary) A one-line descriptive text.") }, "sortable": true, "tooltip": "A one-line descriptive text.", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "workflow_buttons", "editable": false, "header": "Workflow", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.workflow_buttons) List of actions that change the workflow state of this object.") }, "sortable": false, "tooltip": "List of actions that change the workflow state of this object.", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 3, "dataIndex": "auto_type", "editable": true, "editor": auto_type4408, "filter": { "type": "numeric" }, "format": "0", "header": "Nr.", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.auto_type) Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.") }, "sortable": true, "tooltip": "Contains the sequence number if this is an automatically\ngenerated component. Otherwise this field is empty.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "user", "editable": true, "editor": user4409, "filter": { "type": "string" }, "header": "Verantwortlicher", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.user) Der verantwortliche Benutzer.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Der verantwortliche Benutzer.", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "event_type", "editable": true, "editor": event_type4410, "filter": { "type": "string" }, "header": "Kalendereintragsart", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.event_type) The type of this calendar entry.") }, "renderer": Lino.fk_renderer('event_typeHidden','Lino.cal.EventTypes.detail'), "sortable": false, "tooltip": "The type of this calendar entry.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id4411, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 8, "dataIndex": "created", "editable": false, "header": "Erstellt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 9, "dataIndex": "start_date", "editable": true, "editor": start_date4414, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Beginnt am", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.start_date) The starting date of this entry.  May not be empty.") }, "sortable": true, "tooltip": "The starting date of this entry.  May not be empty.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 10, "dataIndex": "start_time", "editable": true, "editor": start_time4415, "header": "Beginnt um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.start_time) The starting time.  If this is empty, the entry is considered a\nall-day entry.") }, "sortable": true, "tooltip": "The starting time.  If this is empty, the entry is considered a\nall-day entry.", "width": Lino.chars2width(9) }, { "colIndex": 11, "dataIndex": "end_date", "editable": true, "editor": end_date4416, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Enddatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.end_date) The ending date of this entry. Leave empty for same-day entries.") }, "sortable": true, "tooltip": "The ending date of this entry. Leave empty for same-day entries.", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 12, "dataIndex": "end_time", "editable": true, "editor": end_time4417, "header": "Endet um", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.end_time) The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.") }, "sortable": true, "tooltip": "The ending time.  If this is before the starting time, and no ending date\nis given, the entry ends the day after.", "width": Lino.chars2width(9) }, { "colIndex": 13, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 14, "dataIndex": "build_method", "editable": true, "editor": build_method4419, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 15, "dataIndex": "assigned_to", "editable": true, "editor": assigned_to4420, "filter": { "type": "string" }, "header": "Zugewiesen zu", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.assigned_to) Another user who is expected to take responsibility for this\nentry.") }, "renderer": Lino.fk_renderer('assigned_toHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "Another user who is expected to take responsibility for this\nentry.", "width": Lino.chars2width(21) }, { "colIndex": 16, "dataIndex": "owner_type", "editable": true, "editor": owner_type4421, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 17, "dataIndex": "owner_id", "editable": true, "editor": owner_id4422, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 18, "dataIndex": "description", "editable": true, "editor": description4423, "filter": { "type": "string" }, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.description) A longer descriptive text.") }, "sortable": false, "tooltip": "A longer descriptive text.", "width": Lino.chars2width(61) }, { "colIndex": 19, "dataIndex": "access_class", "editable": true, "editor": access_class4424, "filter": { "options": [ "Privat", "halb \u00f6ffentlich (\"Besch\u00e4ftigt\")", "\u00d6ffentlich" ], "type": "list" }, "header": "Zugriffsklasse", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.access_class) Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist") }, "sortable": false, "tooltip": "Ob dieser Termin  privat, \u00f6ffentlich oder halb \u00f6ffentlich ist", "width": Lino.chars2width(13) }, { "align": "right", "colIndex": 20, "dataIndex": "sequence", "editable": true, "editor": sequence4425, "filter": { "type": "numeric" }, "format": "0", "header": "Revisionsnummer", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.sequence) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 21, "dataIndex": "priority", "editable": true, "editor": priority4426, "filter": { "options": [ "Kritisch", "Hoch", "Normal", "Niedrig", "Very Low" ], "type": "list" }, "header": "Priorit\u00e4t", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.priority) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(12) }, { "colIndex": 22, "dataIndex": "transparent", "editable": true, "filter": { "type": "boolean" }, "header": "nicht blockierend", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.transparent) Whether this entry should allow other entries at the same time.") }, "sortable": false, "tooltip": "Whether this entry should allow other entries at the same time.", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 23, "dataIndex": "room", "editable": true, "editor": room4428, "filter": { "type": "string" }, "header": "Raum", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.room) ") }, "renderer": Lino.fk_renderer('roomHidden','Lino.cal.Rooms.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 24, "dataIndex": "state", "editable": true, "editor": state4429, "filter": { "options": [ "Vorschlag", "Entwurf", "Stattgefunden", "Storniert" ], "type": "list" }, "header": "Zustand", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.state) The state of this entry. The state can change according to\nrules defined by the workflow.") }, "sortable": false, "tooltip": "The state of this entry. The state can change according to\nrules defined by the workflow.", "width": Lino.chars2width(14) }, { "colIndex": 25, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EntriesByController.owner) ") }, "sortable": false, "tooltip": "(cal.EntriesByController.owner) ", "width": Lino.chars2width(11) } ];
    Lino.cal.EntriesByController.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByController.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EntriesByController.insertPanel = Ext.extend(Lino.cal.Events.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/cal/EntriesByController",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByController.detail;
    this.ls_insert_handler = Lino.cal.EntriesByController.insert;
    Lino.cal.EntriesByController.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByController.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/cal/EntriesByController" };
  return new Lino.cal.EntriesByController.insertPanel(p);
});
Lino.cal.EntriesByController.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.cal.EntriesByController.detailPanel = Ext.extend(Lino.cal.Events.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kalendereintrag) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_conflicting", "menu_item_text": "\u00a0\u2694\u00a0", "overflowText": "\u00a0\u2694\u00a0", "panel_btn_handler": Lino.row_action_handler('show_conflicting','GET',null), "text": "\u00a0\u2694\u00a0", "tooltip": "A ShowSlaveTable\nbutton which opens the ConflictingEvents table for this event.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-calendar", "itemId": "show_today", "menu_item_text": "Heute", "overflowText": "Heute", "panel_btn_handler": Lino.row_action_handler('show_today','GET',null), "tooltip": "Alle Termine am gleichen Tag zeigen", "tooltipType": "title" }, { "auto_save": true, "itemId": "show_uploads", "menu_item_text": "Upload-Dateien", "overflowText": "Upload-Dateien", "panel_btn_handler": Lino.row_action_handler('show_uploads','GET',null), "text": " <font size=\"4\">\ud83d\uddbf</font>", "tooltip": "Show uploads in a grid table.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "itemId": "update_events", "menu_item_text": "Termine aktualisieren", "overflowText": "Termine aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_events','GET',null), "text": "\u00a0\u26a1\u00a0", "tooltip": "Create or update all other automatic calendar entries of this\nseries.", "tooltipType": "title" }, { "auto_save": true, "itemId": "update_guests", "menu_item_text": "Anwesenheiten aktualisieren", "overflowText": "Anwesenheiten aktualisieren", "panel_btn_handler": Lino.row_action_handler('update_guests','GET',null), "text": "\u00a0\u2637\u00a0", "tooltip": "Teilnehmerliste f\u00fcr diesen Kalendereintrag f\u00fcllen entsprechend der Vorschl\u00e4ge.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/cal/EntriesByController",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.cal.EntriesByController.detail;
    this.ls_insert_handler = Lino.cal.EntriesByController.insert;
    Lino.cal.EntriesByController.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntriesByController.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntriesByController" };
  return new Lino.cal.EntriesByController.detailPanel(p);
});
Lino.cal.EntriesByController.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.show_conflicting = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "show_conflicting", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.show_today = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "show_today", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.show_uploads = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "show_uploads", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.assign_to_me = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "assign_to_me", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntriesByController" };
  p.params_panel = new Lino.cal.Events.ParamsPanel({});
  return new Lino.cal.EntriesByController.GridPanel(p);
});
Lino.cal.EntriesByController.move_next = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "move_next", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.take = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "take", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.update_events = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "update_events", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.update_guests = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "update_guests", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.reset_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "reset_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.wf2 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "wf2", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.wf3 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "wf3", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntriesByController.wf4 = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntriesByController", "GET", pk, "wf4", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class uploads.UploadsByController
Lino.uploads.UploadsByController.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/uploads/UploadsByController",
  ls_store_fields : [ { "name": "file" }, { "name": "volume" }, 'volumeHidden', { "name": "library_file" }, { "name": "type" }, 'typeHidden', { "name": "description" }, { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "mimetype" }, { "name": "upload_area" }, 'upload_areaHidden', { "name": "file_size", "type": "int", "useNull": true }, { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 9,
  content_type : 29,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadsByController','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadsByController','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadsByController','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadsByController','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadsByController','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Upload-Dateien",
  disabled_fields_index : 19,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.UploadsByController.detail;
    this.ls_insert_handler = Lino.uploads.UploadsByController.insert;
    var ww = this.containing_window;
    var file4432 = Lino.file_field_handler(this,{ "allowBlank": true, "maxLength": 100, "selectOnFocus": true });
    var volume4433 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Dateibibliothek ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 5, "related_actor_id": "uploads.Volumes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByController/volume" }) }) });
    var library_file4434 = new Lino.SimpleRemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByController/library_file" }) }) });
    var type4435 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Upload-Art ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "uploads.UploadTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByController/type" }) }) });
    var description4436 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var user4437 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByController/user" }) }) });
    var id4438 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type4439 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByController/owner_type" }) }) });
    var owner_id4440 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/uploads/UploadsByController/owner_id" }) }) });
    var mimetype4441 = new Ext.form.TextField({ "disabled": true, "hidden": true, "maxLength": 255 });
    var upload_area4442 = new Lino.ChoicesFieldElement({ "allowBlank": false, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": Lino.uploads.UploadAreas });
    var file_size4443 = new Ext.form.NumberField({ "disabled": true, "hidden": true });
    var owner_disp4444 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      library_file4434.setContextValue('volume', record ? record.data['volumeHidden'] : undefined);
      type4435.setContextValue('upload_area', record ? record.data['upload_areaHidden'] : undefined);
      owner_id4440.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof volume4433 !== 'undefined' && volume4433.on('change',Lino.chooser_handler(library_file4434,'volume'));
      typeof upload_area4442 !== 'undefined' && upload_area4442.on('change',Lino.chooser_handler(type4435,'upload_area'));
      typeof owner_type4439 !== 'undefined' && owner_type4439.on('change',Lino.chooser_handler(owner_id4440,'owner_type'));
      Lino.uploads.UploadsByController.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "file", "editable": true, "editor": file4432, "filter": { "type": "string" }, "header": "Datei", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.file) Pointer to the uploaded file itself (a Django FileField).") }, "sortable": true, "tooltip": "Pointer to the uploaded file itself (a Django FileField).", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "volume", "editable": true, "editor": volume4433, "filter": { "type": "string" }, "header": "Dateibibliothek", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.volume) A pointer to the library volume where this file is stored.") }, "renderer": Lino.fk_renderer('volumeHidden','Lino.uploads.Volumes.detail'), "sortable": false, "tooltip": "A pointer to the library volume where this file is stored.", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "library_file", "editable": true, "editor": library_file4434, "filter": { "type": "string" }, "header": "Bibliotheksdatei", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.library_file) The path of this file, relative the volume's root.") }, "sortable": false, "tooltip": "The path of this file, relative the volume's root.", "width": Lino.chars2width(11) }, { "colIndex": 3, "dataIndex": "type", "editable": true, "editor": type4435, "filter": { "type": "string" }, "header": "Upload-Art", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.type) The type of this upload.") }, "renderer": Lino.fk_renderer('typeHidden','Lino.uploads.UploadTypes.detail'), "sortable": false, "tooltip": "The type of this upload.", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "description", "editable": true, "editor": description4436, "filter": { "type": "string" }, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.description) A short description entered manually by the user.") }, "sortable": true, "tooltip": "A short description entered manually by the user.", "width": Lino.chars2width(22) }, { "colIndex": 5, "dataIndex": "user", "editable": true, "editor": user4437, "filter": { "type": "string" }, "header": "Hochgeladen durch", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 6, "dataIndex": "id", "editable": true, "editor": id4438, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 7, "dataIndex": "owner_type", "editable": true, "editor": owner_type4439, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "owner_id", "editable": true, "editor": owner_id4440, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 9, "dataIndex": "mimetype", "editable": false, "filter": { "type": "string" }, "header": "MIME-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.mimetype) The media type of the\nuploaded file.") }, "sortable": true, "tooltip": "The media type of the\nuploaded file.", "width": Lino.chars2width(22) }, { "colIndex": 10, "dataIndex": "upload_area", "editable": true, "editor": upload_area4442, "filter": { "options": [ "Uploads" ], "type": "list" }, "header": "Upload-Bereich", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.upload_area) The upload area this file belongs to.") }, "sortable": false, "tooltip": "The upload area this file belongs to.", "width": Lino.chars2width(11) }, { "align": "right", "colIndex": 11, "dataIndex": "file_size", "editable": false, "filter": { "type": "numeric" }, "format": "0", "header": "File size", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.file_size) The size of the file in bytes. Not yet implemented.") }, "sortable": true, "tooltip": "The size of the file in bytes. Not yet implemented.", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 12, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadsByController.owner) ") }, "sortable": false, "tooltip": "(uploads.UploadsByController.owner) ", "width": Lino.chars2width(11) } ];
    Lino.uploads.UploadsByController.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.UploadsByController.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByController", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByController.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByController", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByController.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByController", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByController.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByController", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.UploadsByController.insertPanel = Ext.extend(Lino.uploads.UploadsByController.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/uploads/UploadsByController",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.UploadsByController.detail;
    this.ls_insert_handler = Lino.uploads.UploadsByController.insert;
    Lino.uploads.UploadsByController.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.UploadsByController.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/uploads/UploadsByController" };
  return new Lino.uploads.UploadsByController.insertPanel(p);
});
Lino.uploads.UploadsByController.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByController", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.uploads.UploadsByController.detailPanel = Ext.extend(Lino.uploads.Uploads.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Upload-Datei) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/uploads/UploadsByController",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.uploads.UploadsByController.detail;
    this.ls_insert_handler = Lino.uploads.UploadsByController.insert;
    Lino.uploads.UploadsByController.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.UploadsByController.detail = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/UploadsByController" };
  return new Lino.uploads.UploadsByController.detailPanel(p);
});
Lino.uploads.UploadsByController.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByController", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByController.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByController", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByController.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByController", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadsByController.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/UploadsByController" };
  p.params_panel = new Lino.uploads.Uploads.ParamsPanel({});
  return new Lino.uploads.UploadsByController.GridPanel(p);
});
Lino.uploads.UploadsByController.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadsByController", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class blogs.EntriesByController
Lino.blogs.EntriesByController.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/blogs/EntriesByController",
  ls_store_fields : [ { "dateFormat": "d.m.Y", "name": "pub_date", "type": "date" }, { "name": "title" }, { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "body" }, { "name": "short_preview" }, { "name": "full_preview" }, { "name": "pub_time" }, { "name": "entry_type" }, 'entry_typeHidden', { "name": "language" }, 'languageHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 58,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/blogs/EntriesByController','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/EntriesByController','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/EntriesByController','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/blogs/EntriesByController','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/blogs/EntriesByController','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Blog-Eintr\u00e4ge",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.EntriesByController.detail;
    this.ls_insert_handler = Lino.blogs.EntriesByController.insert;
    var ww = this.containing_window;
    var pub_date4446 = new Lino.DateField({ "allowBlank": true, "selectOnFocus": true });
    var title4447 = new Ext.form.TextField({ "allowBlank": true, "maxLength": 200, "selectOnFocus": true });
    var user4448 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/EntriesByController/user" }) }) });
    var id4449 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var owner_type4450 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/EntriesByController/owner_type" }) }) });
    var owner_id4451 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/EntriesByController/owner_id" }) }) });
    var body4452 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "hidden": true, "selectOnFocus": true, "title": "Inhalt" });
    var short_preview4453 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau" });
    var full_preview4454 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau (komplett)" });
    var pub_time4455 = new Lino.TimeField({ "allowBlank": true, "hidden": true, "maxValue": "9:00 PM", "minValue": "7:00", "selectOnFocus": true });
    var entry_type4456 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Blog Entry Type ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "blogs.EntryTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/blogs/EntriesByController/entry_type" }) }) });
    var language4457 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var owner_disp4458 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      owner_id4451.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      body4452.refresh();
      short_preview4453.refresh();
      full_preview4454.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type4450 !== 'undefined' && owner_type4450.on('change',Lino.chooser_handler(owner_id4451,'owner_type'));
      Lino.blogs.EntriesByController.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "pub_date", "editable": true, "editor": pub_date4446, "filter": { "dateFormat": "d.m.Y", "type": "date" }, "format": "d.m.Y", "header": "Bildungsart", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.pub_date) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(14), "xtype": "datecolumn" }, { "colIndex": 1, "dataIndex": "title", "editable": true, "editor": title4447, "filter": { "type": "string" }, "header": "\u00dcberschrift", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.title) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user4448, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id4449, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "owner_type", "editable": true, "editor": owner_type4450, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "owner_id", "editable": true, "editor": owner_id4451, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 6, "dataIndex": "body", "editable": true, "editor": body4452, "filter": { "type": "string" }, "header": "Inhalt", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.body) An editable text body.") }, "sortable": false, "tooltip": "An editable text body.", "width": Lino.chars2width(61) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.short_preview) A read-only short preview of body.") }, "sortable": false, "tooltip": "A read-only short preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "pub_time", "editable": true, "editor": pub_time4455, "header": "Bildungsart", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.pub_time) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(9) }, { "colIndex": 10, "dataIndex": "entry_type", "editable": true, "editor": entry_type4456, "filter": { "type": "string" }, "header": "Blog Entry Type", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.entry_type) ") }, "renderer": Lino.fk_renderer('entry_typeHidden','Lino.blogs.EntryTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "language", "editable": true, "editor": language4457, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.language) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(blogs.EntriesByController.owner) ") }, "sortable": false, "tooltip": "(blogs.EntriesByController.owner) ", "width": Lino.chars2width(11) } ];
    Lino.blogs.EntriesByController.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.EntriesByController.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByController", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByController.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByController", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByController.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByController", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByController.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByController", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.EntriesByController.insertPanel = Ext.extend(Lino.blogs.Entries.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/blogs/EntriesByController",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.EntriesByController.detail;
    this.ls_insert_handler = Lino.blogs.EntriesByController.insert;
    Lino.blogs.EntriesByController.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.EntriesByController.insert = new Lino.WindowAction({ "autoHeight": true, "draggable": true, "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/blogs/EntriesByController" };
  return new Lino.blogs.EntriesByController.insertPanel(p);
});
Lino.blogs.EntriesByController.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByController", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.blogs.EntriesByController.detailPanel = Ext.extend(Lino.blogs.Entries.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Blog Entry) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/blogs/EntriesByController",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.blogs.EntriesByController.detail;
    this.ls_insert_handler = Lino.blogs.EntriesByController.insert;
    Lino.blogs.EntriesByController.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.blogs.EntriesByController.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/EntriesByController" };
  return new Lino.blogs.EntriesByController.detailPanel(p);
});
Lino.blogs.EntriesByController.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByController", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByController.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByController", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByController.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByController", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByController.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/blogs/EntriesByController" };
  p.params_panel = new Lino.blogs.Entries.ParamsPanel({});
  return new Lino.blogs.EntriesByController.GridPanel(p);
});
Lino.blogs.EntriesByController.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByController", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.blogs.EntriesByController.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/blogs/EntriesByController", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class excerpts.ExcerptsByOwner
Lino.excerpts.ExcerptsByOwner.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/excerpts/ExcerptsByOwner",
  ls_store_fields : [ { "name": "build_time" }, { "name": "excerpt_type" }, 'excerpt_typeHidden', { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "build_method" }, 'build_methodHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "company" }, 'companyHidden', { "name": "contact_person" }, 'contact_personHidden', { "name": "contact_role" }, 'contact_roleHidden', { "name": "language" }, 'languageHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 5,
  content_type : 60,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptsByOwner','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptsByOwner','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptsByOwner','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptsByOwner','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/excerpts/ExcerptsByOwner','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Bestehende Ausz\u00fcge",
  disabled_fields_index : 21,
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.ExcerptsByOwner.detail;
    var ww = this.containing_window;
    var build_time4460 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var excerpt_type4461 = new Lino.RemoteComboFieldElement({ "allowBlank": false, "can_create_choice": false, "emptyText": "Auszugsart ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "excerpts.ExcerptTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByOwner/excerpt_type" }) }) });
    var user4462 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByOwner/user" }) }) });
    var id4463 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var build_method4464 = new Lino.ChoicesFieldElement({ "allowBlank": true, "forceSelection": true, "hidden": true, "selectOnFocus": true, "store": [['','<br>']].concat(Lino.printing.BuildMethods) });
    var owner_type4465 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByOwner/owner_type" }) }) });
    var owner_id4466 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByOwner/owner_id" }) }) });
    var company4467 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Organisation ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Companies", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByOwner/company" }) }) });
    var contact_person4468 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "emptyText": "Person ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 20, "related_actor_id": "contacts.Persons", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByOwner/contact_person" }) }) });
    var contact_role4469 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Funktion ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "contacts.RoleTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/excerpts/ExcerptsByOwner/contact_role" }) }) });
    var language4470 = new Lino.ChoicesFieldElement({ "allowBlank": true, "hidden": true, "selectOnFocus": true, "store": [ [ "en", "Englisch" ], [ "de", "Deutsch" ], [ "fr", "Franz\u00f6sisch" ] ] });
    var owner_disp4471 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      var bp = this.get_base_params();
      excerpt_type4461.setContextValue('mk',bp['mk']);
      excerpt_type4461.setContextValue('mt',bp['mt']);
      owner_id4466.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      contact_person4468.setContextValue('company', record ? record.data['companyHidden'] : undefined);
    };
    this.onRender = function(ct, position) {
      typeof owner_disp4471 !== 'undefined' && owner_disp4471.on('change',Lino.chooser_handler(excerpt_type4461,'owner'));
      typeof owner_type4465 !== 'undefined' && owner_type4465.on('change',Lino.chooser_handler(owner_id4466,'owner_type'));
      typeof company4467 !== 'undefined' && company4467.on('change',Lino.chooser_handler(contact_person4468,'company'));
      Lino.excerpts.ExcerptsByOwner.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "build_time", "editable": false, "header": "Druckdatum", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.build_time) Timestamp of the built target file. Contains None\nif no build hasn't been called yet.") }, "sortable": true, "tooltip": "Timestamp of the built target file. Contains None\nif no build hasn't been called yet.", "width": Lino.chars2width(17) }, { "colIndex": 1, "dataIndex": "excerpt_type", "editable": true, "editor": excerpt_type4461, "filter": { "type": "string" }, "header": "Auszugsart", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.excerpt_type) The type of this excerpt (ForeignKey to ExcerptType).") }, "renderer": Lino.fk_renderer('excerpt_typeHidden','Lino.excerpts.ExcerptTypes.detail'), "sortable": false, "tooltip": "The type of this excerpt (ForeignKey to ExcerptType).", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "user", "editable": true, "editor": user4462, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id4463, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "build_method", "editable": true, "editor": build_method4464, "filter": { "options": [ "AppyDocBuildMethod", "AppyOdtBuildMethod", "AppyPdfBuildMethod", "AppyRtfBuildMethod", "LatexBuildMethod", "RtfBuildMethod", "WeasyHtmlBuildMethod", "WeasyPdfBuildMethod", "XmlBuildMethod" ], "type": "list" }, "header": "Druckmethode", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.build_method) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(24) }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type4465, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id4466, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 7, "dataIndex": "company", "editable": true, "editor": company4467, "filter": { "type": "string" }, "header": "Empf\u00e4nger (Organisation)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.company) The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.") }, "renderer": Lino.fk_renderer('companyHidden','Lino.contacts.Companies.detail'), "sortable": false, "tooltip": "The optional company of the recipient of this\nexcerpt.  See ContactRelated.company.", "width": Lino.chars2width(21) }, { "colIndex": 8, "dataIndex": "contact_person", "editable": true, "editor": contact_person4468, "filter": { "type": "string" }, "header": "Empf\u00e4nger (Person)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.contact_person) The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.") }, "renderer": Lino.fk_renderer('contact_personHidden','Lino.contacts.Persons.detail'), "sortable": false, "tooltip": "The optional contact person of the recipient of this\nexcerpt.  See ContactRelated.contact_person.", "width": Lino.chars2width(21) }, { "colIndex": 9, "dataIndex": "contact_role", "editable": true, "editor": contact_role4469, "filter": { "type": "string" }, "header": "in seiner Eigenschaft als", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.contact_role) The optional Role\nof the contact_person within company.") }, "sortable": false, "tooltip": "The optional Role\nof the contact_person within company.", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "language", "editable": true, "editor": language4470, "filter": { "type": "string" }, "header": "Sprache", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.language) The language used for printing this excerpt.") }, "sortable": false, "tooltip": "The language used for printing this excerpt.", "width": Lino.chars2width(21) }, { "colIndex": 11, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.ExcerptsByOwner.owner) The object being printed by this excerpt.\nSee Controllable.owner.") }, "sortable": false, "tooltip": "The object being printed by this excerpt.\nSee Controllable.owner.", "width": Lino.chars2width(11) } ];
    Lino.excerpts.ExcerptsByOwner.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.ExcerptsByOwner.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByOwner.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByOwner.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByOwner.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByOwner.duplicate = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "GET", pk, "duplicate", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.excerpts.ExcerptsByOwner.detailPanel = Ext.extend(Lino.excerpts.Excerpts.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "itemId": "duplicate", "menu_item_text": "\u2687", "overflowText": "\u2687", "panel_btn_handler": Lino.row_action_handler('duplicate','GET',null), "text": " <font size=\"4\">\u2687</font>", "tooltip": "Diese Zeile duplizieren.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','POST',null), "tooltip": "The action used to print this object.\nThis is an instance of\nDirectPrintAction or CachedPrintAction by\ndefault.  And if lino_xl.lib.excerpts is installed,\nthen set_excerpts_actions possibly replaces\ndo_print by a\nlino_xl.lib.excerpts.CreateExcerpt instance.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-printer_delete", "itemId": "do_clear_cache", "menu_item_text": "Cache l\u00f6schen", "overflowText": "Cache l\u00f6schen", "panel_btn_handler": Lino.row_action_handler('do_clear_cache','GET',null), "tooltip": "Defines the Clear cache button on a Printable record.", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/excerpts/ExcerptsByOwner",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.excerpts.ExcerptsByOwner.detail;
    Lino.excerpts.ExcerptsByOwner.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.ExcerptsByOwner.detail = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(13), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(80) }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/ExcerptsByOwner" };
  return new Lino.excerpts.ExcerptsByOwner.detailPanel(p);
});
Lino.excerpts.ExcerptsByOwner.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByOwner.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "POST", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByOwner.do_clear_cache = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "GET", pk, "do_clear_cache", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByOwner.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByOwner.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.ExcerptsByOwner.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/ExcerptsByOwner" };
  p.params_panel = new Lino.excerpts.Excerpts.ParamsPanel({});
  return new Lino.excerpts.ExcerptsByOwner.GridPanel(p);
});
Lino.excerpts.ExcerptsByOwner.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/ExcerptsByOwner", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.CommentsByRFC
Lino.comments.CommentsByRFC.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/CommentsByRFC",
  ls_store_fields : [ { "name": "body" }, { "name": "created" }, { "name": "user" }, 'userHidden', { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden', { "name": "short_preview" }, { "name": "full_preview" }, { "name": "reply_to" }, 'reply_toHidden', { "name": "private", "type": "boolean" }, { "name": "comment_type" }, 'comment_typeHidden', { "name": "owner" }, { "name": "disabled_fields" }, { "name": "disable_editing" } ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 63,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByRFC','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByRFC','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByRFC','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByRFC','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/CommentsByRFC','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true, "getRowClass": Lino.getRowClass },
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kommentare",
  disabled_fields_index : 18,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByRFC.detail;
    this.ls_insert_handler = Lino.comments.CommentsByRFC.insert;
    var ww = this.containing_window;
    var body4473 = new Lino.RichTextPanel({ "allowBlank": true, "containing_panel": this, "selectOnFocus": true, "title": "Inhalt" });
    var created4474 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var user4475 = new Lino.RemoteComboFieldElement({ "disabled": true, "emptyText": "Benutzer ausw\u00e4hlen...", "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers" });
    var id4476 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified4477 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var owner_type4478 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByRFC/owner_type" }) }) });
    var owner_id4479 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByRFC/owner_id" }) }) });
    var short_preview4480 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau" });
    var full_preview4481 = new Lino.RichTextPanel({ "containing_panel": this, "disabled": true, "hidden": true, "title": "Vorschau (komplett)" });
    var reply_to4482 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByRFC/reply_to" }) }) });
    var private4483 = new Ext.form.Checkbox({ "allowBlank": false, "checked": true, "hidden": true, "selectOnFocus": true });
    var comment_type4484 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar-Art ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "comments.CommentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/CommentsByRFC/comment_type" }) }) });
    var owner_disp4485 = new Ext.form.DisplayField({ "disabled": true, "hidden": true });
    this.before_row_edit = function(record) {
      body4473.refresh();
      owner_id4479.setContextValue('owner_type', record ? record.data['owner_typeHidden'] : undefined);
      short_preview4480.refresh();
      full_preview4481.refresh();
    };
    this.onRender = function(ct, position) {
      typeof owner_type4478 !== 'undefined' && owner_type4478.on('change',Lino.chooser_handler(owner_id4479,'owner_type'));
      Lino.comments.CommentsByRFC.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "body", "editable": true, "editor": body4473, "filter": { "type": "string" }, "header": "Inhalt", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.body) The full body text of your comment.") }, "sortable": false, "tooltip": "The full body text of your comment.", "width": Lino.chars2width(61) }, { "colIndex": 1, "dataIndex": "created", "editable": false, "header": "Erstellt", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "colIndex": 2, "dataIndex": "user", "editable": false, "filter": { "type": "string" }, "header": "Autor", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.user) The author of the comment.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of the comment.", "width": Lino.chars2width(21) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id4476, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 5, "dataIndex": "owner_type", "editable": true, "editor": owner_type4478, "filter": { "type": "string" }, "header": "Thema (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_id", "editable": true, "editor": owner_id4479, "filter": { "type": "string" }, "header": "Thema (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) }, { "colIndex": 7, "dataIndex": "short_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.short_preview) The first paragraph of your body.") }, "sortable": false, "tooltip": "The first paragraph of your body.", "width": Lino.chars2width(61) }, { "colIndex": 8, "dataIndex": "full_preview", "editable": false, "filter": { "type": "string" }, "header": "Vorschau (komplett)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.full_preview) A read-only full preview of body.") }, "sortable": false, "tooltip": "A read-only full preview of body.", "width": Lino.chars2width(61) }, { "colIndex": 9, "dataIndex": "reply_to", "editable": true, "editor": reply_to4482, "filter": { "type": "string" }, "header": "Antwort auf", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.reply_to) ") }, "renderer": Lino.fk_renderer('reply_toHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 10, "dataIndex": "private", "editable": true, "filter": { "type": "boolean" }, "header": "Privat", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.private) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11), "xtype": "checkcolumn" }, { "colIndex": 11, "dataIndex": "comment_type", "editable": true, "editor": comment_type4484, "filter": { "type": "string" }, "header": "Kommentar-Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.comment_type) ") }, "renderer": Lino.fk_renderer('comment_typeHidden','Lino.comments.CommentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 12, "dataIndex": "owner", "editable": false, "header": "Thema", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentsByRFC.owner) The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.") }, "sortable": false, "tooltip": "The topic this comment is about. This field is a Generic Foreign Key,\ni.e. users can basically comment on any database object.  It is however\nthe application developer who decides where comments can be\ncreated and how they are being displayed.", "width": Lino.chars2width(11) } ];
    Lino.comments.CommentsByRFC.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByRFC.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByRFC.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByRFC.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByRFC.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.CommentsByRFC.insertPanel = Ext.extend(Lino.comments.CommentsByRFC.InsertFormPanel,{
  empty_title: "Neu",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_insert",
  ls_bbar_actions: [ { "auto_save": false, "itemId": "submit_insert", "menu_item_text": "Erstellen", "overflowText": "Erstellen", "panel_btn_handler": function(panel){panel.save()}, "text": "Erstellen", "tooltip": "Datensatz erstellen und dann im Detail-Fenster \u00f6ffnen", "tooltipType": "title" } ],
  ls_url: "/comments/CommentsByRFC",
  action_name: "insert",
  default_record_id: -99999,
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByRFC.detail;
    this.ls_insert_handler = Lino.comments.CommentsByRFC.insert;
    Lino.comments.CommentsByRFC.insertPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByRFC.insert = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(13), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/comments/CommentsByRFC" };
  return new Lino.comments.CommentsByRFC.insertPanel(p);
});
Lino.comments.CommentsByRFC.submit_insert = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "POST", pk, "submit_insert", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.comments.CommentsByRFC.detailPanel = Ext.extend(Lino.comments.Comments.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert", "keycode": 44, "menu_item_text": "Neu", "overflowText": "Neu", "panel_btn_handler": Lino.show_insert, "tooltip": "\u00d6ffnet ein Dialogfenster, um einen neuen Datensatz (Kommentar) zu erstellen.", "tooltipType": "title" }, { "auto_save": false, "iconCls": "x-tbar-delete", "itemId": "delete_selected", "keycode": 46, "menu_item_text": "L\u00f6schen", "overflowText": "L\u00f6schen", "panel_btn_handler": Lino.row_action_handler('delete_selected','GET',null), "tooltip": "Diesen Datensatz l\u00f6schen", "tooltipType": "title" }, { "iconCls": "x-tbar-bell", "menu": [ { "auto_save": true, "itemId": "check_data", "menu_item_text": "Check data", "overflowText": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": "Check data", "tooltip": "Check data", "tooltipType": "title" }, { "auto_save": true, "itemId": "fix_problems", "menu_item_text": "Datenprobleme reparieren", "overflowText": "Datenprobleme reparieren", "panel_btn_handler": Lino.row_action_handler('fix_problems','GET',null), "text": "Datenprobleme reparieren", "tooltip": "Datenprobleme reparieren", "tooltipType": "title" } ], "menu_item_text": "Check data", "panel_btn_handler": Lino.row_action_handler('check_data','GET',null), "text": null, "xtype": "splitbutton" }, { "auto_save": false, "iconCls": "x-tbar-disk", "itemId": "submit_detail", "menu_item_text": "Speichern", "overflowText": "Speichern", "panel_btn_handler": function(panel){panel.save()}, "tooltip": "\u00c4nderungen in diesem Formular speichern", "tooltipType": "title" } ],
  ls_url: "/comments/CommentsByRFC",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.comments.CommentsByRFC.detail;
    this.ls_insert_handler = Lino.comments.CommentsByRFC.insert;
    Lino.comments.CommentsByRFC.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentsByRFC.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentsByRFC" };
  return new Lino.comments.CommentsByRFC.detailPanel(p);
});
Lino.comments.CommentsByRFC.delete_selected = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "GET", pk, "delete_selected", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByRFC.check_data = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "GET", pk, "check_data", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByRFC.do_pick_my_emotion = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "GET", pk, "do_pick_my_emotion", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByRFC.fix_problems = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "GET", pk, "fix_problems", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByRFC.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentsByRFC" };
  p.params_panel = new Lino.comments.Comments.ParamsPanel({});
  return new Lino.comments.CommentsByRFC.GridPanel(p);
});
Lino.comments.CommentsByRFC.preview_publication = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "GET", pk, "preview_publication", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentsByRFC.submit_detail = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentsByRFC", "PUT", pk, "submit_detail", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class comments.MentionsByOwner
Lino.comments.MentionsByOwner.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/MentionsByOwner",
  ls_store_fields : [ { "name": "comment" }, 'commentHidden', { "name": "owner" }, { "name": "created" }, { "name": "id", "type": "int" }, { "name": "modified" }, { "name": "user" }, 'userHidden', { "name": "owner_type" }, 'owner_typeHidden', { "name": "owner_id" }, 'owner_idHidden' ],
  ls_id_property : "id",
  pk_index : 4,
  content_type : 64,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/MentionsByOwner','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/MentionsByOwner','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/MentionsByOwner','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/MentionsByOwner','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/MentionsByOwner','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Erw\u00e4hnungen",
  initComponent : function() {
    var ww = this.containing_window;
    var comment4487 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Kommentar ausw\u00e4hlen...", "pageSize": 20, "related_actor_id": "comments.Comments", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/MentionsByOwner/comment" }) }) });
    var owner_disp4488 = new Ext.form.DisplayField({ "disabled": true });
    var created4489 = new Ext.form.DisplayField({ "disabled": true, "value": "<br>" });
    var id4490 = new Ext.form.NumberField({ "allowBlank": true, "hidden": true, "selectOnFocus": true });
    var modified4491 = new Ext.form.DisplayField({ "disabled": true, "hidden": true, "value": "<br>" });
    var user4492 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Benutzer ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "preferred_width": 15, "related_actor_id": "users.AllUsers", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/MentionsByOwner/user" }) }) });
    var owner_type4493 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "emptyText": "Datenbankmodell ausw\u00e4hlen...", "hidden": true, "pageSize": 20, "related_actor_id": "gfks.ContentTypes", "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/MentionsByOwner/owner_type" }) }) });
    var owner_id4494 = new Lino.RemoteComboFieldElement({ "allowBlank": true, "can_create_choice": false, "hidden": true, "selectOnFocus": true, "store": new Lino.ComplexRemoteComboStore({ "proxy": new Ext.data.HttpProxy({ "method": "GET", "url": "/choices/comments/MentionsByOwner/owner_id" }) }) });
    this.before_row_edit = function(record) {
    };
    this.onRender = function(ct, position) {
      typeof owner_type4493 !== 'undefined' && owner_type4493.on('change',Lino.chooser_handler(owner_id4494,'owner_type'));
      Lino.comments.MentionsByOwner.GridPanel.superclass.onRender.call(this, ct, position);
    }
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "comment", "editable": true, "editor": comment4487, "filter": { "type": "string" }, "header": "Kommentar", "listeners": { "render": Lino.quicktip_renderer("","(comments.MentionsByOwner.comment) ") }, "renderer": Lino.fk_renderer('commentHidden','Lino.comments.Comments.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "owner", "editable": false, "header": "Verkn\u00fcpft mit", "listeners": { "render": Lino.quicktip_renderer("","(comments.MentionsByOwner.owner) ") }, "sortable": false, "tooltip": "(comments.MentionsByOwner.owner) ", "width": Lino.chars2width(11) }, { "colIndex": 2, "dataIndex": "created", "editable": false, "header": "Erstellt", "listeners": { "render": Lino.quicktip_renderer("","(comments.MentionsByOwner.created) The time when this object was created.") }, "sortable": true, "tooltip": "The time when this object was created.", "width": Lino.chars2width(17) }, { "align": "right", "colIndex": 3, "dataIndex": "id", "editable": true, "editor": id4490, "filter": { "type": "numeric" }, "format": "0", "header": "ID", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MentionsByOwner.id) ") }, "sortable": true, "tooltip": "", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 4, "dataIndex": "modified", "editable": false, "header": "Bearbeitet", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MentionsByOwner.modified) The time when this database object was last modified.") }, "sortable": true, "tooltip": "The time when this database object was last modified.", "width": Lino.chars2width(17) }, { "colIndex": 5, "dataIndex": "user", "editable": true, "editor": user4492, "filter": { "type": "string" }, "header": "Autor", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MentionsByOwner.user) The author of this object.\nA pointer to lino.modlib.users.models.User.") }, "renderer": Lino.fk_renderer('userHidden','Lino.users.AllUsers.detail'), "sortable": false, "tooltip": "The author of this object.\nA pointer to lino.modlib.users.models.User.", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "owner_type", "editable": true, "editor": owner_type4493, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Modell)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MentionsByOwner.owner_type) ") }, "renderer": Lino.fk_renderer('owner_typeHidden','Lino.gfks.ContentTypes.detail'), "sortable": false, "tooltip": "", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "owner_id", "editable": true, "editor": owner_id4494, "filter": { "type": "string" }, "header": "Verkn\u00fcpft mit (Objekt)", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.MentionsByOwner.owner_id) ") }, "sortable": false, "tooltip": "", "width": Lino.chars2width(11) } ];
    Lino.comments.MentionsByOwner.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.MentionsByOwner.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MentionsByOwner", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MentionsByOwner.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MentionsByOwner", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MentionsByOwner.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MentionsByOwner", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MentionsByOwner.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/MentionsByOwner", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.MentionsByOwner.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/MentionsByOwner" };
  p.params_panel = new Lino.comments.Mentions.ParamsPanel({});
  return new Lino.comments.MentionsByOwner.GridPanel(p);
});

// js_render_GridPanel_class about.SiteSearch
Lino.about.SiteSearch.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/about/SiteSearch",
  ls_store_fields : [ { "name": "description" }, { "name": "matches" } ],
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/about/SiteSearch','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/about/SiteSearch','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/about/SiteSearch','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/about/SiteSearch','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/about/SiteSearch','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Suchen",
  initComponent : function() {
    var ww = this.containing_window;
    var description_disp4496 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var matches_disp4497 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "description", "editable": false, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(about.SiteSearch.description) ") }, "sortable": false, "tooltip": "(about.SiteSearch.description) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "matches", "editable": false, "header": "Matches", "listeners": { "render": Lino.quicktip_renderer("","(about.SiteSearch.matches) ") }, "sortable": false, "tooltip": "(about.SiteSearch.matches) ", "width": Lino.chars2width(31) } ];
    Lino.about.SiteSearch.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.about.SiteSearch.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/about/SiteSearch", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.about.SiteSearch.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/about/SiteSearch", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.about.SiteSearch.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/about/SiteSearch", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.about.SiteSearch.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/about/SiteSearch", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.about.SiteSearch.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/about/SiteSearch" };
  return new Lino.about.SiteSearch.GridPanel(p);
});

// js_render_GridPanel_class gfks.BrokenGFKs
Lino.gfks.BrokenGFKs.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/gfks/BrokenGFKs",
  ls_store_fields : [ { "name": "database_model" }, { "name": "database_object" }, { "name": "message" }, { "name": "todo" } ],
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/gfks/BrokenGFKs','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/BrokenGFKs','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/BrokenGFKs','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/BrokenGFKs','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/gfks/BrokenGFKs','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Broken GFKs",
  initComponent : function() {
    var ww = this.containing_window;
    var database_model_disp4499 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var database_object_disp4500 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var message_disp4501 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var todo_disp4502 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "database_model", "editable": false, "header": "Datenbankmodell", "listeners": { "render": Lino.quicktip_renderer("","(gfks.BrokenGFKs.database_model) ") }, "sortable": false, "tooltip": "(gfks.BrokenGFKs.database_model) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "database_object", "editable": false, "header": "Datenobjekt", "listeners": { "render": Lino.quicktip_renderer("","(gfks.BrokenGFKs.database_object) ") }, "sortable": false, "tooltip": "(gfks.BrokenGFKs.database_object) ", "width": Lino.chars2width(31) }, { "colIndex": 2, "dataIndex": "message", "editable": false, "header": "Meldung", "listeners": { "render": Lino.quicktip_renderer("","(gfks.BrokenGFKs.message) ") }, "sortable": false, "tooltip": "(gfks.BrokenGFKs.message) ", "width": Lino.chars2width(31) }, { "colIndex": 3, "dataIndex": "todo", "editable": false, "header": "Action", "listeners": { "render": Lino.quicktip_renderer("","(gfks.BrokenGFKs.todo) ") }, "sortable": false, "tooltip": "(gfks.BrokenGFKs.todo) ", "width": Lino.chars2width(31) } ];
    Lino.gfks.BrokenGFKs.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.gfks.BrokenGFKs.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/BrokenGFKs", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.BrokenGFKs.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/BrokenGFKs", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.BrokenGFKs.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/BrokenGFKs", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.BrokenGFKs.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/BrokenGFKs", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.BrokenGFKs.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/gfks/BrokenGFKs" };
  return new Lino.gfks.BrokenGFKs.GridPanel(p);
});

// js_render_GridPanel_class gfks.BrokenGFKsByModel
Lino.gfks.BrokenGFKsByModel.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/gfks/BrokenGFKsByModel",
  ls_store_fields : [ { "name": "database_object" }, { "name": "message" }, { "name": "todo" }, { "name": "id", "type": "int" } ],
  ls_id_property : "id",
  pk_index : 3,
  content_type : 1,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/gfks/BrokenGFKsByModel','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/BrokenGFKsByModel','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/BrokenGFKsByModel','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/gfks/BrokenGFKsByModel','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/gfks/BrokenGFKsByModel','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Broken GFKs",
  initComponent : function() {
    var ww = this.containing_window;
    var database_object_disp1062 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var message_disp1063 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var todo_disp1064 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "database_object", "editable": false, "header": "Datenobjekt", "listeners": { "render": Lino.quicktip_renderer("","(gfks.BrokenGFKsByModel.database_object) ") }, "sortable": false, "tooltip": "(gfks.BrokenGFKsByModel.database_object) ", "width": Lino.chars2width(31) }, { "colIndex": 1, "dataIndex": "message", "editable": false, "header": "Meldung", "listeners": { "render": Lino.quicktip_renderer("","(gfks.BrokenGFKsByModel.message) ") }, "sortable": false, "tooltip": "(gfks.BrokenGFKsByModel.message) ", "width": Lino.chars2width(31) }, { "colIndex": 2, "dataIndex": "todo", "editable": false, "header": "Action", "listeners": { "render": Lino.quicktip_renderer("","(gfks.BrokenGFKsByModel.todo) ") }, "sortable": false, "tooltip": "(gfks.BrokenGFKsByModel.todo) ", "width": Lino.chars2width(31) } ];
    Lino.gfks.BrokenGFKsByModel.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.gfks.BrokenGFKsByModel.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/BrokenGFKsByModel", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.BrokenGFKsByModel.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/BrokenGFKsByModel", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.BrokenGFKsByModel.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/BrokenGFKsByModel", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.BrokenGFKsByModel.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/gfks/BrokenGFKsByModel", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.gfks.BrokenGFKsByModel.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/gfks/BrokenGFKsByModel" };
  return new Lino.gfks.BrokenGFKsByModel.GridPanel(p);
});

// js_render_GridPanel_class calview.MonthlySlave
Lino.calview.MonthlySlave.GridPanel = Ext.extend(Lino.GridPanel,{
  use_detail_params_value : true,
  ls_url : "/calview/MonthlySlave",
  ls_store_fields : [ { "name": "week_number" }, { "name": "vc0" }, { "name": "vc1" }, { "name": "vc2" }, { "name": "vc3" }, { "name": "vc4" }, { "name": "vc5" }, { "name": "vc6" } ],
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/calview/MonthlySlave','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/MonthlySlave','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/calview/MonthlySlave','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/MonthlySlave','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/calview/MonthlySlave','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : null,
  initComponent : function() {
    var ww = this.containing_window;
    var week_number_disp1620 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var vc0_htmlbox1621 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc0", "title": "Montag", "value": "<br/>" });
    var vc1_htmlbox1622 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc1", "title": "Dienstag", "value": "<br/>" });
    var vc2_htmlbox1623 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc2", "title": "Mittwoch", "value": "<br/>" });
    var vc3_htmlbox1624 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc3", "title": "Donnerstag", "value": "<br/>" });
    var vc4_htmlbox1625 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc4", "title": "Freitag", "value": "<br/>" });
    var vc5_htmlbox1626 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc5", "title": "Samstag", "value": "<br/>" });
    var vc6_htmlbox1627 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "vc6", "title": "Sonntag", "value": "<br/>" });
    this.before_row_edit = function(record) {
      vc0_htmlbox1621.refresh();
      vc1_htmlbox1622.refresh();
      vc2_htmlbox1623.refresh();
      vc3_htmlbox1624.refresh();
      vc4_htmlbox1625.refresh();
      vc5_htmlbox1626.refresh();
      vc6_htmlbox1627.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "week_number", "editable": false, "header": "Week", "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlySlave.week_number) ") }, "sortable": false, "tooltip": "(calview.MonthlySlave.week_number) ", "width": Lino.chars2width(3) }, { "colIndex": 1, "dataIndex": "vc0", "editable": false, "header": "Montag", "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlySlave.vc0) ") }, "sortable": false, "tooltip": "(calview.MonthlySlave.vc0) ", "width": Lino.chars2width(21) }, { "colIndex": 2, "dataIndex": "vc1", "editable": false, "header": "Dienstag", "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlySlave.vc1) ") }, "sortable": false, "tooltip": "(calview.MonthlySlave.vc1) ", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "vc2", "editable": false, "header": "Mittwoch", "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlySlave.vc2) ") }, "sortable": false, "tooltip": "(calview.MonthlySlave.vc2) ", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "vc3", "editable": false, "header": "Donnerstag", "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlySlave.vc3) ") }, "sortable": false, "tooltip": "(calview.MonthlySlave.vc3) ", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "vc4", "editable": false, "header": "Freitag", "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlySlave.vc4) ") }, "sortable": false, "tooltip": "(calview.MonthlySlave.vc4) ", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "vc5", "editable": false, "header": "Samstag", "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlySlave.vc5) ") }, "sortable": false, "tooltip": "(calview.MonthlySlave.vc5) ", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "vc6", "editable": false, "header": "Sonntag", "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlySlave.vc6) ") }, "sortable": false, "tooltip": "(calview.MonthlySlave.vc6) ", "width": Lino.chars2width(21) } ];
    Lino.calview.MonthlySlave.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.calview.MonthlySlave.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/MonthlySlave", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.MonthlySlave.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/MonthlySlave", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.MonthlySlave.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/MonthlySlave", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.MonthlySlave.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/MonthlySlave", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.MonthlySlave.grid = new Lino.WindowAction({  }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/calview/MonthlySlave" };
  p.params_panel = new Lino.calview.MonthlySlave.ParamsPanel({});
  return new Lino.calview.MonthlySlave.GridPanel(p);
});

// js_render_GridPanel_class calview.DailyView
Lino.calview.DailyView.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/calview/DailyView",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "day_number", "type": "int", "useNull": true }, { "name": "navigation_panel" } ],
  ls_id_property : null,
  pk_index : 1,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert_event", "menu_item_text": "Create new Event", "overflowText": "Create new Event", "panel_btn_handler": Lino.row_action_handler('insert_event','GET',null), "tooltip": "Create a new Event", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  page_length : 20,
  stripeRows : true,
  title : "Tagesansicht",
  initComponent : function() {
    this.ls_detail_handler = Lino.calview.DailyView.detail;
    var ww = this.containing_window;
    var detail_link_disp4504 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var day_number4505 = new Ext.form.NumberField({ "disabled": true, "hidden": true });
    var navigation_panel_htmlbox4506 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "hidden": true, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "navigation_panel", "value": "<br/>" });
    this.before_row_edit = function(record) {
      navigation_panel_htmlbox4506.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyView.detail_link) ") }, "sortable": false, "tooltip": "(calview.DailyView.detail_link) ", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 1, "dataIndex": "day_number", "editable": false, "format": "0", "header": "Tag Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyView.day_number) ") }, "sortable": true, "tooltip": "(calview.DailyView.day_number) ", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 2, "dataIndex": "navigation_panel", "editable": false, "header": "navigation_panel", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(calview.DailyView.navigation_panel) ") }, "sortable": false, "tooltip": "(calview.DailyView.navigation_panel) ", "width": Lino.chars2width(31) } ];
    Lino.calview.DailyView.GridPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.DailyView.detailPanel = Ext.extend(Lino.calview.DailyView.DetailFormPanel,{
  empty_title: "Tagesansicht",
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-add", "itemId": "insert_event", "menu_item_text": "Create new Event", "overflowText": "Create new Event", "panel_btn_handler": Lino.row_action_handler('insert_event','GET',null), "tooltip": "Create a new Event", "tooltipType": "title" } ],
  ls_url: "/calview/DailyView",
  initComponent : function() {
    this.ls_detail_handler = Lino.calview.DailyView.detail;
    Lino.calview.DailyView.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.calview.DailyView.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/calview/DailyView" };
  p.params_panel = new Lino.calview.DailyView.ParamsPanel({});
  return new Lino.calview.DailyView.detailPanel(p);
});
Lino.calview.DailyView.insert_event = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/DailyView", "GET", pk, "insert_event", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class calview.WeeklyView
Lino.calview.WeeklyView.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/calview/WeeklyView",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "day_number", "type": "int", "useNull": true }, { "name": "navigation_panel" } ],
  ls_id_property : null,
  pk_index : 1,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [  ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  page_length : 20,
  stripeRows : true,
  title : "Wochenansicht",
  initComponent : function() {
    this.ls_detail_handler = Lino.calview.WeeklyView.detail;
    var ww = this.containing_window;
    var detail_link_disp4508 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var day_number4509 = new Ext.form.NumberField({ "disabled": true, "hidden": true });
    var navigation_panel_htmlbox4510 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "hidden": true, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "navigation_panel", "value": "<br/>" });
    this.before_row_edit = function(record) {
      navigation_panel_htmlbox4510.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklyView.detail_link) ") }, "sortable": false, "tooltip": "(calview.WeeklyView.detail_link) ", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 1, "dataIndex": "day_number", "editable": false, "format": "0", "header": "Tag Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklyView.day_number) ") }, "sortable": true, "tooltip": "(calview.WeeklyView.day_number) ", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 2, "dataIndex": "navigation_panel", "editable": false, "header": "navigation_panel", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(calview.WeeklyView.navigation_panel) ") }, "sortable": false, "tooltip": "(calview.WeeklyView.navigation_panel) ", "width": Lino.chars2width(31) } ];
    Lino.calview.WeeklyView.GridPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.WeeklyView.detailPanel = Ext.extend(Lino.calview.WeeklyView.DetailFormPanel,{
  empty_title: "Wochenansicht",
  save_action_name: "submit_detail",
  ls_bbar_actions: [  ],
  ls_url: "/calview/WeeklyView",
  initComponent : function() {
    this.ls_detail_handler = Lino.calview.WeeklyView.detail;
    Lino.calview.WeeklyView.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.calview.WeeklyView.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/calview/WeeklyView" };
  p.params_panel = new Lino.calview.WeeklyView.ParamsPanel({});
  return new Lino.calview.WeeklyView.detailPanel(p);
});

// js_render_GridPanel_class calview.MonthlyView
Lino.calview.MonthlyView.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/calview/MonthlyView",
  ls_store_fields : [ { "name": "detail_link" }, { "name": "day_number", "type": "int", "useNull": true }, { "name": "navigation_panel" } ],
  ls_id_property : null,
  pk_index : 1,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [  ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  page_length : 20,
  stripeRows : true,
  title : "Monatsansicht",
  initComponent : function() {
    this.ls_detail_handler = Lino.calview.MonthlyView.detail;
    var ww = this.containing_window;
    var detail_link_disp4512 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var day_number4513 = new Ext.form.NumberField({ "disabled": true, "hidden": true });
    var navigation_panel_htmlbox4514 = new Lino.HtmlBoxPanel({ "always_enabled": true, "bodyStyle": "overflow-x:hidden;", "containing_panel": this, "hidden": true, "items": new Ext.BoxComponent({autoScroll:true}), "layout": "fit", "name": "navigation_panel", "value": "<br/>" });
    this.before_row_edit = function(record) {
      navigation_panel_htmlbox4514.refresh();
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlyView.detail_link) ") }, "sortable": false, "tooltip": "(calview.MonthlyView.detail_link) ", "width": Lino.chars2width(31) }, { "align": "right", "colIndex": 1, "dataIndex": "day_number", "editable": false, "format": "0", "header": "Tag Nr.", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlyView.day_number) ") }, "sortable": true, "tooltip": "(calview.MonthlyView.day_number) ", "width": Lino.chars2width(6), "xtype": "numbercolumn" }, { "colIndex": 2, "dataIndex": "navigation_panel", "editable": false, "header": "navigation_panel", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(calview.MonthlyView.navigation_panel) ") }, "sortable": false, "tooltip": "(calview.MonthlyView.navigation_panel) ", "width": Lino.chars2width(31) } ];
    Lino.calview.MonthlyView.GridPanel.superclass.initComponent.call(this);
  }
});


Lino.calview.MonthlyView.detailPanel = Ext.extend(Lino.calview.MonthlyView.DetailFormPanel,{
  empty_title: "Monatsansicht",
  save_action_name: "submit_detail",
  ls_bbar_actions: [  ],
  ls_url: "/calview/MonthlyView",
  initComponent : function() {
    this.ls_detail_handler = Lino.calview.MonthlyView.detail;
    Lino.calview.MonthlyView.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.calview.MonthlyView.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/calview/MonthlyView" };
  p.params_panel = new Lino.calview.MonthlyView.ParamsPanel({});
  return new Lino.calview.MonthlyView.detailPanel(p);
});

// js_render_GridPanel_class users.UserRoles
Lino.users.UserRoles.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/users/UserRoles",
  ls_store_fields : [ { "name": "name" }, { "name": "ut000" }, { "name": "ut100" }, { "name": "ut200" }, { "name": "ut300" }, { "name": "ut800" }, { "name": "ut900" } ],
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/users/UserRoles','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/UserRoles','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/users/UserRoles','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/UserRoles','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/users/UserRoles','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Benutzerrollen",
  initComponent : function() {
    var ww = this.containing_window;
    var name_disp4516 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var ut000_disp4517 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var ut100_disp4518 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var ut200_disp4519 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var ut300_disp4520 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var ut800_disp4521 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    var ut900_disp4522 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "name", "editable": false, "header": "Name", "listeners": { "render": Lino.quicktip_renderer("","(users.UserRoles.name) ") }, "sortable": false, "tooltip": "(users.UserRoles.name) ", "width": Lino.chars2width(21) }, { "colIndex": 1, "dataIndex": "ut000", "editable": false, "header": "000", "listeners": { "render": Lino.quicktip_renderer("","(users.UserRoles.ut000) ") }, "sortable": false, "tooltip": "(users.UserRoles.ut000) ", "width": Lino.chars2width(4) }, { "colIndex": 2, "dataIndex": "ut100", "editable": false, "header": "100", "listeners": { "render": Lino.quicktip_renderer("","(users.UserRoles.ut100) ") }, "sortable": false, "tooltip": "(users.UserRoles.ut100) ", "width": Lino.chars2width(4) }, { "colIndex": 3, "dataIndex": "ut200", "editable": false, "header": "200", "listeners": { "render": Lino.quicktip_renderer("","(users.UserRoles.ut200) ") }, "sortable": false, "tooltip": "(users.UserRoles.ut200) ", "width": Lino.chars2width(4) }, { "colIndex": 4, "dataIndex": "ut300", "editable": false, "header": "300", "listeners": { "render": Lino.quicktip_renderer("","(users.UserRoles.ut300) ") }, "sortable": false, "tooltip": "(users.UserRoles.ut300) ", "width": Lino.chars2width(4) }, { "colIndex": 5, "dataIndex": "ut800", "editable": false, "header": "800", "listeners": { "render": Lino.quicktip_renderer("","(users.UserRoles.ut800) ") }, "sortable": false, "tooltip": "(users.UserRoles.ut800) ", "width": Lino.chars2width(4) }, { "colIndex": 6, "dataIndex": "ut900", "editable": false, "header": "900", "listeners": { "render": Lino.quicktip_renderer("","(users.UserRoles.ut900) ") }, "sortable": false, "tooltip": "(users.UserRoles.ut900) ", "width": Lino.chars2width(4) } ];
    Lino.users.UserRoles.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.users.UserRoles.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UserRoles", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UserRoles.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UserRoles", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UserRoles.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UserRoles", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UserRoles.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UserRoles", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UserRoles.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/UserRoles" };
  return new Lino.users.UserRoles.GridPanel(p);
});

Lino.about.About.showPanel = Ext.extend(Lino.about.About.DetailFormPanel,{
  empty_title: "Info",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [  ],
  ls_url: "/about/About",
  initComponent : function() {
    this.ls_detail_handler = Lino.about.About.show;
    Lino.about.About.showPanel.superclass.initComponent.call(this);
  }
});

Lino.about.About.show = new Lino.WindowAction({ "draggable": true, "height": Lino.rows2height(20), "maximizable": true, "maximized": false, "modal": true, "width": Lino.chars2width(60) }, function(){
  var p = { "hide_top_toolbar": true, "is_main_window": true, "ls_url": "/about/About" };
  return new Lino.about.About.showPanel(p);
});

Lino.courses.StatusReport.showPanel = Ext.extend(Lino.ledger.Situation.DetailFormPanel,{
  empty_title: "Statusbericht",
  hide_navigator: true,
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [ { "auto_save": true, "iconCls": "x-tbar-printer", "itemId": "do_print", "menu_item_text": "Drucken", "overflowText": "Drucken", "panel_btn_handler": Lino.row_action_handler('do_print','GET',null), "tooltip": "Print using a hard-coded template and without cache.", "tooltipType": "title" } ],
  ls_url: "/courses/StatusReport",
  initComponent : function() {
    this.ls_detail_handler = Lino.courses.StatusReport.show;
    Lino.courses.StatusReport.showPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.StatusReport.show = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/StatusReport" };
  return new Lino.courses.StatusReport.showPanel(p);
});
Lino.courses.StatusReport.do_print = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/StatusReport", "GET", pk, "do_print", params, null);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

// js_render_GridPanel_class system.YesNo
Lino.system.YesNo.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/system/YesNo",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/system/YesNo','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/system/YesNo','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/system/YesNo','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/system/YesNo','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/system/YesNo','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Ja oder Nein",
  initComponent : function() {
    var ww = this.containing_window;
    var value4524 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4525 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4526 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4527 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4528 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4529 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4530 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(system.YesNo.value) ") }, "sortable": true, "tooltip": "(system.YesNo.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(system.YesNo.name) ") }, "sortable": true, "tooltip": "(system.YesNo.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(system.YesNo.text) ") }, "sortable": true, "tooltip": "(system.YesNo.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.YesNo.detail_link) ") }, "sortable": false, "tooltip": "(system.YesNo.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.YesNo.button_text) ") }, "sortable": true, "tooltip": "(system.YesNo.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.YesNo.remark) ") }, "sortable": false, "tooltip": "(system.YesNo.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.YesNo.type) ") }, "sortable": false, "tooltip": "(system.YesNo.type) ", "width": Lino.chars2width(31) } ];
    Lino.system.YesNo.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.system.YesNo.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/YesNo", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.YesNo.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/YesNo", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.YesNo.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/YesNo", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.YesNo.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/YesNo", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.YesNo.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/system/YesNo" };
  return new Lino.system.YesNo.GridPanel(p);
});

// js_render_GridPanel_class system.Genders
Lino.system.Genders.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/system/Genders",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/system/Genders','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/system/Genders','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/system/Genders','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/system/Genders','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/system/Genders','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Genders",
  initComponent : function() {
    var ww = this.containing_window;
    var value4532 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4533 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4534 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4535 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4536 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4537 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4538 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(system.Genders.value) ") }, "sortable": true, "tooltip": "(system.Genders.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(system.Genders.name) ") }, "sortable": true, "tooltip": "(system.Genders.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(system.Genders.text) ") }, "sortable": true, "tooltip": "(system.Genders.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.Genders.detail_link) ") }, "sortable": false, "tooltip": "(system.Genders.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.Genders.button_text) ") }, "sortable": true, "tooltip": "(system.Genders.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.Genders.remark) ") }, "sortable": false, "tooltip": "(system.Genders.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.Genders.type) ") }, "sortable": false, "tooltip": "(system.Genders.type) ", "width": Lino.chars2width(31) } ];
    Lino.system.Genders.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.system.Genders.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/Genders", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.Genders.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/Genders", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.Genders.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/Genders", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.Genders.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/Genders", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.Genders.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/system/Genders" };
  return new Lino.system.Genders.GridPanel(p);
});

// js_render_GridPanel_class system.PeriodEvents
Lino.system.PeriodEvents.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/system/PeriodEvents",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/system/PeriodEvents','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/system/PeriodEvents','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/system/PeriodEvents','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/system/PeriodEvents','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/system/PeriodEvents','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Beobachtungskriterien",
  initComponent : function() {
    var ww = this.containing_window;
    var value4540 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4541 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4542 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4543 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4544 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4545 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4546 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(system.PeriodEvents.value) ") }, "sortable": true, "tooltip": "(system.PeriodEvents.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(system.PeriodEvents.name) ") }, "sortable": true, "tooltip": "(system.PeriodEvents.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(system.PeriodEvents.text) ") }, "sortable": true, "tooltip": "(system.PeriodEvents.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.PeriodEvents.detail_link) ") }, "sortable": false, "tooltip": "(system.PeriodEvents.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.PeriodEvents.button_text) ") }, "sortable": true, "tooltip": "(system.PeriodEvents.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.PeriodEvents.remark) ") }, "sortable": false, "tooltip": "(system.PeriodEvents.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(system.PeriodEvents.type) ") }, "sortable": false, "tooltip": "(system.PeriodEvents.type) ", "width": Lino.chars2width(31) } ];
    Lino.system.PeriodEvents.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.system.PeriodEvents.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/PeriodEvents", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.PeriodEvents.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/PeriodEvents", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.PeriodEvents.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/PeriodEvents", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.PeriodEvents.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/system/PeriodEvents", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.system.PeriodEvents.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/system/PeriodEvents" };
  return new Lino.system.PeriodEvents.GridPanel(p);
});

// js_render_GridPanel_class checkdata.Checkers
Lino.checkdata.Checkers.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/checkdata/Checkers",
  ls_store_fields : [ { "name": "value" }, { "name": "text" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/checkdata/Checkers','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/Checkers','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/Checkers','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/checkdata/Checkers','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/checkdata/Checkers','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" }, { "auto_save": true, "iconCls": "x-tbar-application_form", "itemId": "detail", "menu_item_text": "Detail", "overflowText": "Detail", "panel_btn_handler": Lino.show_detail, "tooltip": "Open a detail window on this record.", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Datentests",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.Checkers.detail;
    var ww = this.containing_window;
    var value4548 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4549 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.Checkers.value) ") }, "sortable": true, "tooltip": "(checkdata.Checkers.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(checkdata.Checkers.text) ") }, "sortable": true, "tooltip": "(checkdata.Checkers.text) ", "width": Lino.chars2width(22) } ];
    Lino.checkdata.Checkers.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.Checkers.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/Checkers", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.Checkers.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/Checkers", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.Checkers.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/Checkers", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.checkdata.Checkers.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/checkdata/Checkers", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};

Lino.checkdata.Checkers.detailPanel = Ext.extend(Lino.checkdata.Checkers.DetailFormPanel,{
  empty_title: "Detail",
  params_panel_hidden: true,
  save_action_name: "submit_detail",
  ls_bbar_actions: [  ],
  ls_url: "/checkdata/Checkers",
  action_name: "detail",
  initComponent : function() {
    this.ls_detail_handler = Lino.checkdata.Checkers.detail;
    Lino.checkdata.Checkers.detailPanel.superclass.initComponent.call(this);
  }
});

Lino.checkdata.Checkers.detail = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/Checkers" };
  return new Lino.checkdata.Checkers.detailPanel(p);
});
Lino.checkdata.Checkers.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/checkdata/Checkers" };
  return new Lino.checkdata.Checkers.GridPanel(p);
});

// js_render_GridPanel_class printing.BuildMethods
Lino.printing.BuildMethods.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/printing/BuildMethods",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/printing/BuildMethods','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/printing/BuildMethods','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/printing/BuildMethods','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/printing/BuildMethods','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/printing/BuildMethods','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "BuildMethods",
  initComponent : function() {
    var ww = this.containing_window;
    var value4551 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4552 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4553 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4554 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4555 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4556 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4557 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(printing.BuildMethods.value) ") }, "sortable": true, "tooltip": "(printing.BuildMethods.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(printing.BuildMethods.name) ") }, "sortable": true, "tooltip": "(printing.BuildMethods.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(printing.BuildMethods.text) ") }, "sortable": true, "tooltip": "(printing.BuildMethods.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(printing.BuildMethods.detail_link) ") }, "sortable": false, "tooltip": "(printing.BuildMethods.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(printing.BuildMethods.button_text) ") }, "sortable": true, "tooltip": "(printing.BuildMethods.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(printing.BuildMethods.remark) ") }, "sortable": false, "tooltip": "(printing.BuildMethods.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(printing.BuildMethods.type) ") }, "sortable": false, "tooltip": "(printing.BuildMethods.type) ", "width": Lino.chars2width(31) } ];
    Lino.printing.BuildMethods.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.printing.BuildMethods.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/printing/BuildMethods", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.printing.BuildMethods.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/printing/BuildMethods", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.printing.BuildMethods.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/printing/BuildMethods", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.printing.BuildMethods.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/printing/BuildMethods", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.printing.BuildMethods.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/printing/BuildMethods" };
  return new Lino.printing.BuildMethods.GridPanel(p);
});

// js_render_GridPanel_class users.UserTypes
Lino.users.UserTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/users/UserTypes",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/users/UserTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/UserTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/users/UserTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/users/UserTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/users/UserTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Benutzerarten",
  initComponent : function() {
    var ww = this.containing_window;
    var value4559 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4560 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4561 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(users.UserTypes.value) ") }, "sortable": true, "tooltip": "(users.UserTypes.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(users.UserTypes.name) ") }, "sortable": true, "tooltip": "(users.UserTypes.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(users.UserTypes.text) ") }, "sortable": true, "tooltip": "(users.UserTypes.text) ", "width": Lino.chars2width(22) } ];
    Lino.users.UserTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.users.UserTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UserTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UserTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UserTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UserTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UserTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UserTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/users/UserTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.users.UserTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/users/UserTypes" };
  return new Lino.users.UserTypes.GridPanel(p);
});

// js_render_GridPanel_class about.TimeZones
Lino.about.TimeZones.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/about/TimeZones",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/about/TimeZones','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/about/TimeZones','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/about/TimeZones','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/about/TimeZones','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/about/TimeZones','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Zeitzonen",
  initComponent : function() {
    var ww = this.containing_window;
    var value4563 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4564 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4565 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4566 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4567 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4568 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4569 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(about.TimeZones.value) ") }, "sortable": true, "tooltip": "(about.TimeZones.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(about.TimeZones.name) ") }, "sortable": true, "tooltip": "(about.TimeZones.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(about.TimeZones.text) ") }, "sortable": true, "tooltip": "(about.TimeZones.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(about.TimeZones.detail_link) ") }, "sortable": false, "tooltip": "(about.TimeZones.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(about.TimeZones.button_text) ") }, "sortable": true, "tooltip": "(about.TimeZones.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(about.TimeZones.remark) ") }, "sortable": false, "tooltip": "(about.TimeZones.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(about.TimeZones.type) ") }, "sortable": false, "tooltip": "(about.TimeZones.type) ", "width": Lino.chars2width(31) } ];
    Lino.about.TimeZones.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.about.TimeZones.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/about/TimeZones", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.about.TimeZones.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/about/TimeZones", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.about.TimeZones.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/about/TimeZones", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.about.TimeZones.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/about/TimeZones", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.about.TimeZones.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/about/TimeZones" };
  return new Lino.about.TimeZones.GridPanel(p);
});

// js_render_GridPanel_class xl.Priorities
Lino.xl.Priorities.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/xl/Priorities",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/xl/Priorities','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/xl/Priorities','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/xl/Priorities','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/xl/Priorities','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/xl/Priorities','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Priorit\u00e4ten",
  initComponent : function() {
    var ww = this.containing_window;
    var value4571 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4572 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4573 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4574 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4575 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4576 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4577 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(xl.Priorities.value) ") }, "sortable": true, "tooltip": "(xl.Priorities.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(xl.Priorities.name) ") }, "sortable": true, "tooltip": "(xl.Priorities.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(xl.Priorities.text) ") }, "sortable": true, "tooltip": "(xl.Priorities.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(xl.Priorities.detail_link) ") }, "sortable": false, "tooltip": "(xl.Priorities.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(xl.Priorities.button_text) ") }, "sortable": true, "tooltip": "(xl.Priorities.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(xl.Priorities.remark) ") }, "sortable": false, "tooltip": "(xl.Priorities.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(xl.Priorities.type) ") }, "sortable": false, "tooltip": "(xl.Priorities.type) ", "width": Lino.chars2width(31) } ];
    Lino.xl.Priorities.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.xl.Priorities.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/xl/Priorities", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.xl.Priorities.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/xl/Priorities", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.xl.Priorities.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/xl/Priorities", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.xl.Priorities.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/xl/Priorities", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.xl.Priorities.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/xl/Priorities" };
  return new Lino.xl.Priorities.GridPanel(p);
});

// js_render_GridPanel_class countries.PlaceTypes
Lino.countries.PlaceTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/countries/PlaceTypes",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/countries/PlaceTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/countries/PlaceTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/countries/PlaceTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/countries/PlaceTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/countries/PlaceTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "PlaceTypes",
  initComponent : function() {
    var ww = this.containing_window;
    var value4579 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4580 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4581 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4582 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4583 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4584 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4585 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlaceTypes.value) ") }, "sortable": true, "tooltip": "(countries.PlaceTypes.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlaceTypes.name) ") }, "sortable": true, "tooltip": "(countries.PlaceTypes.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(countries.PlaceTypes.text) ") }, "sortable": true, "tooltip": "(countries.PlaceTypes.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlaceTypes.detail_link) ") }, "sortable": false, "tooltip": "(countries.PlaceTypes.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlaceTypes.button_text) ") }, "sortable": true, "tooltip": "(countries.PlaceTypes.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlaceTypes.remark) ") }, "sortable": false, "tooltip": "(countries.PlaceTypes.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(countries.PlaceTypes.type) ") }, "sortable": false, "tooltip": "(countries.PlaceTypes.type) ", "width": Lino.chars2width(31) } ];
    Lino.countries.PlaceTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.countries.PlaceTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlaceTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlaceTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlaceTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlaceTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlaceTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlaceTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/countries/PlaceTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.countries.PlaceTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/countries/PlaceTypes" };
  return new Lino.countries.PlaceTypes.GridPanel(p);
});

// js_render_GridPanel_class uploads.Shortcuts
Lino.uploads.Shortcuts.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/uploads/Shortcuts",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/uploads/Shortcuts','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/Shortcuts','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/Shortcuts','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/Shortcuts','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/uploads/Shortcuts','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Upload shortcuts",
  initComponent : function() {
    var ww = this.containing_window;
    var value4587 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4588 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4589 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4590 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4591 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4592 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4593 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Shortcuts.value) ") }, "sortable": true, "tooltip": "(uploads.Shortcuts.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Shortcuts.name) ") }, "sortable": true, "tooltip": "(uploads.Shortcuts.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(uploads.Shortcuts.text) ") }, "sortable": true, "tooltip": "(uploads.Shortcuts.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Shortcuts.detail_link) ") }, "sortable": false, "tooltip": "(uploads.Shortcuts.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Shortcuts.button_text) ") }, "sortable": true, "tooltip": "(uploads.Shortcuts.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Shortcuts.remark) ") }, "sortable": false, "tooltip": "(uploads.Shortcuts.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.Shortcuts.type) ") }, "sortable": false, "tooltip": "(uploads.Shortcuts.type) ", "width": Lino.chars2width(31) } ];
    Lino.uploads.Shortcuts.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.Shortcuts.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Shortcuts", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Shortcuts.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Shortcuts", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Shortcuts.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Shortcuts", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Shortcuts.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/Shortcuts", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.Shortcuts.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/Shortcuts" };
  return new Lino.uploads.Shortcuts.GridPanel(p);
});

// js_render_GridPanel_class uploads.UploadAreas
Lino.uploads.UploadAreas.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/uploads/UploadAreas",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadAreas','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadAreas','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadAreas','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadAreas','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/uploads/UploadAreas','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Upload-Bereiche",
  initComponent : function() {
    var ww = this.containing_window;
    var value4595 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4596 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4597 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4598 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4599 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4600 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4601 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadAreas.value) ") }, "sortable": true, "tooltip": "(uploads.UploadAreas.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadAreas.name) ") }, "sortable": true, "tooltip": "(uploads.UploadAreas.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadAreas.text) ") }, "sortable": true, "tooltip": "(uploads.UploadAreas.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadAreas.detail_link) ") }, "sortable": false, "tooltip": "(uploads.UploadAreas.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadAreas.button_text) ") }, "sortable": true, "tooltip": "(uploads.UploadAreas.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadAreas.remark) ") }, "sortable": false, "tooltip": "(uploads.UploadAreas.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(uploads.UploadAreas.type) ") }, "sortable": false, "tooltip": "(uploads.UploadAreas.type) ", "width": Lino.chars2width(31) } ];
    Lino.uploads.UploadAreas.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.uploads.UploadAreas.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadAreas", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadAreas.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadAreas", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadAreas.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadAreas", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadAreas.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/uploads/UploadAreas", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.uploads.UploadAreas.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/uploads/UploadAreas" };
  return new Lino.uploads.UploadAreas.GridPanel(p);
});

// js_render_GridPanel_class phones.ContactDetailTypes
Lino.phones.ContactDetailTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/phones/ContactDetailTypes",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetailTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetailTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetailTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetailTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/phones/ContactDetailTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kontaktangabenarten",
  initComponent : function() {
    var ww = this.containing_window;
    var value4603 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4604 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4605 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4606 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4607 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4608 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4609 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailTypes.value) ") }, "sortable": true, "tooltip": "(phones.ContactDetailTypes.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailTypes.name) ") }, "sortable": true, "tooltip": "(phones.ContactDetailTypes.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailTypes.text) ") }, "sortable": true, "tooltip": "(phones.ContactDetailTypes.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailTypes.detail_link) ") }, "sortable": false, "tooltip": "(phones.ContactDetailTypes.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailTypes.button_text) ") }, "sortable": true, "tooltip": "(phones.ContactDetailTypes.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailTypes.remark) ") }, "sortable": false, "tooltip": "(phones.ContactDetailTypes.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(phones.ContactDetailTypes.type) ") }, "sortable": false, "tooltip": "(phones.ContactDetailTypes.type) ", "width": Lino.chars2width(31) } ];
    Lino.phones.ContactDetailTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.phones.ContactDetailTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetailTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetailTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetailTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/phones/ContactDetailTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.phones.ContactDetailTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/phones/ContactDetailTypes" };
  return new Lino.phones.ContactDetailTypes.GridPanel(p);
});

// js_render_GridPanel_class contacts.PartnerEvents
Lino.contacts.PartnerEvents.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/PartnerEvents",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnerEvents','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnerEvents','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnerEvents','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnerEvents','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/PartnerEvents','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Beobachtungskriterien",
  initComponent : function() {
    var ww = this.containing_window;
    var value4611 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4612 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4613 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4614 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4615 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4616 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4617 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnerEvents.value) ") }, "sortable": true, "tooltip": "(contacts.PartnerEvents.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnerEvents.name) ") }, "sortable": true, "tooltip": "(contacts.PartnerEvents.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnerEvents.text) ") }, "sortable": true, "tooltip": "(contacts.PartnerEvents.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnerEvents.detail_link) ") }, "sortable": false, "tooltip": "(contacts.PartnerEvents.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnerEvents.button_text) ") }, "sortable": true, "tooltip": "(contacts.PartnerEvents.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnerEvents.remark) ") }, "sortable": false, "tooltip": "(contacts.PartnerEvents.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.PartnerEvents.type) ") }, "sortable": false, "tooltip": "(contacts.PartnerEvents.type) ", "width": Lino.chars2width(31) } ];
    Lino.contacts.PartnerEvents.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.PartnerEvents.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnerEvents", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnerEvents.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnerEvents", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnerEvents.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnerEvents", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnerEvents.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/PartnerEvents", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.PartnerEvents.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/PartnerEvents" };
  return new Lino.contacts.PartnerEvents.GridPanel(p);
});

// js_render_GridPanel_class contacts.CivilStates
Lino.contacts.CivilStates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/contacts/CivilStates",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/contacts/CivilStates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/CivilStates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/CivilStates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/contacts/CivilStates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/contacts/CivilStates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Zivilst\u00e4nde",
  initComponent : function() {
    var ww = this.containing_window;
    var value4619 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4620 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4621 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4622 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4623 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4624 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4625 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(contacts.CivilStates.value) ") }, "sortable": true, "tooltip": "(contacts.CivilStates.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(contacts.CivilStates.name) ") }, "sortable": true, "tooltip": "(contacts.CivilStates.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(contacts.CivilStates.text) ") }, "sortable": true, "tooltip": "(contacts.CivilStates.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CivilStates.detail_link) ") }, "sortable": false, "tooltip": "(contacts.CivilStates.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CivilStates.button_text) ") }, "sortable": true, "tooltip": "(contacts.CivilStates.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CivilStates.remark) ") }, "sortable": false, "tooltip": "(contacts.CivilStates.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(contacts.CivilStates.type) ") }, "sortable": false, "tooltip": "(contacts.CivilStates.type) ", "width": Lino.chars2width(31) } ];
    Lino.contacts.CivilStates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.contacts.CivilStates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CivilStates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CivilStates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CivilStates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CivilStates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CivilStates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CivilStates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/contacts/CivilStates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.contacts.CivilStates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/contacts/CivilStates" };
  return new Lino.contacts.CivilStates.GridPanel(p);
});

// js_render_GridPanel_class cal.DisplayColors
Lino.cal.DisplayColors.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/DisplayColors",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/DisplayColors','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/DisplayColors','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/DisplayColors','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/DisplayColors','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/DisplayColors','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Display colors",
  initComponent : function() {
    var ww = this.containing_window;
    var value4627 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4628 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4629 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4630 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4631 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4632 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4633 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.DisplayColors.value) ") }, "sortable": true, "tooltip": "(cal.DisplayColors.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.DisplayColors.name) ") }, "sortable": true, "tooltip": "(cal.DisplayColors.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.DisplayColors.text) ") }, "sortable": true, "tooltip": "(cal.DisplayColors.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.DisplayColors.detail_link) ") }, "sortable": false, "tooltip": "(cal.DisplayColors.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.DisplayColors.button_text) ") }, "sortable": true, "tooltip": "(cal.DisplayColors.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.DisplayColors.remark) ") }, "sortable": false, "tooltip": "(cal.DisplayColors.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.DisplayColors.type) ") }, "sortable": false, "tooltip": "(cal.DisplayColors.type) ", "width": Lino.chars2width(31) } ];
    Lino.cal.DisplayColors.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.DisplayColors.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/DisplayColors", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.DisplayColors.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/DisplayColors", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.DisplayColors.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/DisplayColors", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.DisplayColors.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/DisplayColors", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.DisplayColors.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/DisplayColors" };
  return new Lino.cal.DisplayColors.GridPanel(p);
});

// js_render_GridPanel_class cal.Weekdays
Lino.cal.Weekdays.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/Weekdays",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/Weekdays','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Weekdays','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Weekdays','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Weekdays','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/Weekdays','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Weekdays",
  initComponent : function() {
    var ww = this.containing_window;
    var value4635 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4636 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4637 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4638 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4639 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4640 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4641 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.Weekdays.value) ") }, "sortable": true, "tooltip": "(cal.Weekdays.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.Weekdays.name) ") }, "sortable": true, "tooltip": "(cal.Weekdays.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.Weekdays.text) ") }, "sortable": true, "tooltip": "(cal.Weekdays.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Weekdays.detail_link) ") }, "sortable": false, "tooltip": "(cal.Weekdays.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Weekdays.button_text) ") }, "sortable": true, "tooltip": "(cal.Weekdays.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Weekdays.remark) ") }, "sortable": false, "tooltip": "(cal.Weekdays.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Weekdays.type) ") }, "sortable": false, "tooltip": "(cal.Weekdays.type) ", "width": Lino.chars2width(31) } ];
    Lino.cal.Weekdays.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Weekdays.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Weekdays", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Weekdays.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Weekdays", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Weekdays.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Weekdays", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Weekdays.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Weekdays", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Weekdays.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Weekdays" };
  return new Lino.cal.Weekdays.GridPanel(p);
});

// js_render_GridPanel_class cal.YearMonths
Lino.cal.YearMonths.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/YearMonths",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/YearMonths','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/YearMonths','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/YearMonths','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/YearMonths','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/YearMonths','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "YearMonths",
  initComponent : function() {
    var ww = this.containing_window;
    var value4643 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4644 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4645 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4646 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4647 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4648 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4649 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.YearMonths.value) ") }, "sortable": true, "tooltip": "(cal.YearMonths.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.YearMonths.name) ") }, "sortable": true, "tooltip": "(cal.YearMonths.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.YearMonths.text) ") }, "sortable": true, "tooltip": "(cal.YearMonths.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.YearMonths.detail_link) ") }, "sortable": false, "tooltip": "(cal.YearMonths.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.YearMonths.button_text) ") }, "sortable": true, "tooltip": "(cal.YearMonths.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.YearMonths.remark) ") }, "sortable": false, "tooltip": "(cal.YearMonths.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.YearMonths.type) ") }, "sortable": false, "tooltip": "(cal.YearMonths.type) ", "width": Lino.chars2width(31) } ];
    Lino.cal.YearMonths.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.YearMonths.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/YearMonths", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.YearMonths.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/YearMonths", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.YearMonths.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/YearMonths", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.YearMonths.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/YearMonths", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.YearMonths.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/YearMonths" };
  return new Lino.cal.YearMonths.GridPanel(p);
});

// js_render_GridPanel_class cal.DurationUnits
Lino.cal.DurationUnits.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/DurationUnits",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/DurationUnits','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/DurationUnits','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/DurationUnits','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/DurationUnits','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/DurationUnits','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "DurationUnits",
  initComponent : function() {
    var ww = this.containing_window;
    var value4651 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4652 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4653 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4654 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4655 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4656 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4657 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.DurationUnits.value) ") }, "sortable": true, "tooltip": "(cal.DurationUnits.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.DurationUnits.name) ") }, "sortable": true, "tooltip": "(cal.DurationUnits.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.DurationUnits.text) ") }, "sortable": true, "tooltip": "(cal.DurationUnits.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.DurationUnits.detail_link) ") }, "sortable": false, "tooltip": "(cal.DurationUnits.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.DurationUnits.button_text) ") }, "sortable": true, "tooltip": "(cal.DurationUnits.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.DurationUnits.remark) ") }, "sortable": false, "tooltip": "(cal.DurationUnits.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.DurationUnits.type) ") }, "sortable": false, "tooltip": "(cal.DurationUnits.type) ", "width": Lino.chars2width(31) } ];
    Lino.cal.DurationUnits.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.DurationUnits.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/DurationUnits", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.DurationUnits.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/DurationUnits", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.DurationUnits.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/DurationUnits", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.DurationUnits.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/DurationUnits", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.DurationUnits.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/DurationUnits" };
  return new Lino.cal.DurationUnits.GridPanel(p);
});

// js_render_GridPanel_class cal.Recurrencies
Lino.cal.Recurrencies.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/Recurrencies",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/Recurrencies','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Recurrencies','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Recurrencies','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/Recurrencies','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/Recurrencies','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Recurrencies",
  initComponent : function() {
    var ww = this.containing_window;
    var value4659 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4660 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4661 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4662 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4663 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4664 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4665 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.Recurrencies.value) ") }, "sortable": true, "tooltip": "(cal.Recurrencies.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.Recurrencies.name) ") }, "sortable": true, "tooltip": "(cal.Recurrencies.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.Recurrencies.text) ") }, "sortable": true, "tooltip": "(cal.Recurrencies.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Recurrencies.detail_link) ") }, "sortable": false, "tooltip": "(cal.Recurrencies.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Recurrencies.button_text) ") }, "sortable": true, "tooltip": "(cal.Recurrencies.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Recurrencies.remark) ") }, "sortable": false, "tooltip": "(cal.Recurrencies.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.Recurrencies.type) ") }, "sortable": false, "tooltip": "(cal.Recurrencies.type) ", "width": Lino.chars2width(31) } ];
    Lino.cal.Recurrencies.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.Recurrencies.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Recurrencies", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Recurrencies.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Recurrencies", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Recurrencies.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Recurrencies", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Recurrencies.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/Recurrencies", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.Recurrencies.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/Recurrencies" };
  return new Lino.cal.Recurrencies.GridPanel(p);
});

// js_render_GridPanel_class cal.AccessClasses
Lino.cal.AccessClasses.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/AccessClasses",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/AccessClasses','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AccessClasses','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AccessClasses','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/AccessClasses','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/AccessClasses','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Zugriffsklassen",
  initComponent : function() {
    var ww = this.containing_window;
    var value4667 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4668 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4669 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4670 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4671 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4672 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4673 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.AccessClasses.value) ") }, "sortable": true, "tooltip": "(cal.AccessClasses.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.AccessClasses.name) ") }, "sortable": true, "tooltip": "(cal.AccessClasses.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.AccessClasses.text) ") }, "sortable": true, "tooltip": "(cal.AccessClasses.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AccessClasses.detail_link) ") }, "sortable": false, "tooltip": "(cal.AccessClasses.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AccessClasses.button_text) ") }, "sortable": true, "tooltip": "(cal.AccessClasses.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AccessClasses.remark) ") }, "sortable": false, "tooltip": "(cal.AccessClasses.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.AccessClasses.type) ") }, "sortable": false, "tooltip": "(cal.AccessClasses.type) ", "width": Lino.chars2width(31) } ];
    Lino.cal.AccessClasses.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.AccessClasses.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AccessClasses", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AccessClasses.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AccessClasses", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AccessClasses.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AccessClasses", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AccessClasses.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/AccessClasses", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.AccessClasses.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/AccessClasses" };
  return new Lino.cal.AccessClasses.GridPanel(p);
});

// js_render_GridPanel_class cal.PlannerColumns
Lino.cal.PlannerColumns.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/PlannerColumns",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/PlannerColumns','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/PlannerColumns','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/PlannerColumns','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/PlannerColumns','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/PlannerColumns','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Tagesplanerkolonnen",
  initComponent : function() {
    var ww = this.containing_window;
    var value4675 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4676 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4677 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4678 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4679 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4680 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4681 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.PlannerColumns.value) ") }, "sortable": true, "tooltip": "(cal.PlannerColumns.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.PlannerColumns.name) ") }, "sortable": true, "tooltip": "(cal.PlannerColumns.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.PlannerColumns.text) ") }, "sortable": true, "tooltip": "(cal.PlannerColumns.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.PlannerColumns.detail_link) ") }, "sortable": false, "tooltip": "(cal.PlannerColumns.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.PlannerColumns.button_text) ") }, "sortable": true, "tooltip": "(cal.PlannerColumns.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.PlannerColumns.remark) ") }, "sortable": false, "tooltip": "(cal.PlannerColumns.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.PlannerColumns.type) ") }, "sortable": false, "tooltip": "(cal.PlannerColumns.type) ", "width": Lino.chars2width(31) } ];
    Lino.cal.PlannerColumns.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.PlannerColumns.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/PlannerColumns", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.PlannerColumns.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/PlannerColumns", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.PlannerColumns.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/PlannerColumns", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.PlannerColumns.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/PlannerColumns", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.PlannerColumns.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/PlannerColumns" };
  return new Lino.cal.PlannerColumns.GridPanel(p);
});

// js_render_GridPanel_class cal.TaskStates
Lino.cal.TaskStates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/TaskStates",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "button_text" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/TaskStates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/TaskStates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/TaskStates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/TaskStates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/TaskStates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aufgaben-Zust\u00e4nde",
  initComponent : function() {
    var ww = this.containing_window;
    var value4683 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4684 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4685 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var button_text4686 = new Ext.form.TextField({ "disabled": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.TaskStates.value) ") }, "sortable": true, "tooltip": "(cal.TaskStates.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.TaskStates.name) ") }, "sortable": true, "tooltip": "(cal.TaskStates.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.TaskStates.text) ") }, "sortable": true, "tooltip": "(cal.TaskStates.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "button_text", "editable": false, "header": "Button text", "listeners": { "render": Lino.quicktip_renderer("","(cal.TaskStates.button_text) ") }, "sortable": true, "tooltip": "(cal.TaskStates.button_text) ", "width": Lino.chars2width(5) } ];
    Lino.cal.TaskStates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.TaskStates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TaskStates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TaskStates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TaskStates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TaskStates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TaskStates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TaskStates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/TaskStates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.TaskStates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/TaskStates" };
  return new Lino.cal.TaskStates.GridPanel(p);
});

// js_render_GridPanel_class cal.GuestStates
Lino.cal.GuestStates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/GuestStates",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "afterwards", "type": "boolean" }, { "name": "text" }, { "name": "button_text" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/GuestStates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestStates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestStates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/GuestStates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/GuestStates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Anwesenheits-Zust\u00e4nde",
  initComponent : function() {
    var ww = this.containing_window;
    var value4688 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4689 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var afterwards_disp4690 = new Ext.form.DisplayField({ "disabled": true });
    var text4691 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var button_text4692 = new Ext.form.TextField({ "disabled": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestStates.value) ") }, "sortable": true, "tooltip": "(cal.GuestStates.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestStates.name) ") }, "sortable": true, "tooltip": "(cal.GuestStates.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "afterwards", "editable": false, "header": "Nachtr\u00e4glich", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestStates.afterwards) ") }, "sortable": false, "tooltip": "(cal.GuestStates.afterwards) ", "width": Lino.chars2width(21) }, { "colIndex": 3, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestStates.text) ") }, "sortable": true, "tooltip": "(cal.GuestStates.text) ", "width": Lino.chars2width(22) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "listeners": { "render": Lino.quicktip_renderer("","(cal.GuestStates.button_text) ") }, "sortable": true, "tooltip": "(cal.GuestStates.button_text) ", "width": Lino.chars2width(5) } ];
    Lino.cal.GuestStates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.GuestStates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestStates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestStates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestStates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestStates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestStates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestStates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/GuestStates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.GuestStates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/GuestStates" };
  return new Lino.cal.GuestStates.GridPanel(p);
});

// js_render_GridPanel_class cal.EventEvents
Lino.cal.EventEvents.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/EventEvents",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/EventEvents','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EventEvents','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EventEvents','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EventEvents','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/EventEvents','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Beobachtungskriterien",
  initComponent : function() {
    var ww = this.containing_window;
    var value4694 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4695 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4696 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4697 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4698 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4699 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4700 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventEvents.value) ") }, "sortable": true, "tooltip": "(cal.EventEvents.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventEvents.name) ") }, "sortable": true, "tooltip": "(cal.EventEvents.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.EventEvents.text) ") }, "sortable": true, "tooltip": "(cal.EventEvents.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventEvents.detail_link) ") }, "sortable": false, "tooltip": "(cal.EventEvents.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventEvents.button_text) ") }, "sortable": true, "tooltip": "(cal.EventEvents.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventEvents.remark) ") }, "sortable": false, "tooltip": "(cal.EventEvents.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(cal.EventEvents.type) ") }, "sortable": false, "tooltip": "(cal.EventEvents.type) ", "width": Lino.chars2width(31) } ];
    Lino.cal.EventEvents.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EventEvents.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventEvents", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventEvents.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventEvents", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventEvents.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventEvents", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventEvents.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EventEvents", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EventEvents.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EventEvents" };
  return new Lino.cal.EventEvents.GridPanel(p);
});

// js_render_GridPanel_class cal.EntryStates
Lino.cal.EntryStates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/EntryStates",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "button_text" }, { "name": "fill_guests", "type": "boolean" }, { "name": "fixed", "type": "boolean" }, { "name": "transparent", "type": "boolean" }, { "name": "noauto", "type": "boolean" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/EntryStates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntryStates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntryStates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/EntryStates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/EntryStates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Kalendereintrag-Zust\u00e4nde",
  initComponent : function() {
    var ww = this.containing_window;
    var value4702 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4703 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4704 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var button_text4705 = new Ext.form.TextField({ "disabled": true });
    var fill_guests_disp4706 = new Ext.form.DisplayField({ "disabled": true });
    var fixed_disp4707 = new Ext.form.DisplayField({ "disabled": true });
    var transparent_disp4708 = new Ext.form.DisplayField({ "disabled": true });
    var noauto_disp4709 = new Ext.form.DisplayField({ "disabled": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntryStates.value) ") }, "sortable": true, "tooltip": "(cal.EntryStates.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntryStates.name) ") }, "sortable": true, "tooltip": "(cal.EntryStates.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntryStates.text) ") }, "sortable": true, "tooltip": "(cal.EntryStates.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "button_text", "editable": false, "header": "Button text", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntryStates.button_text) ") }, "sortable": true, "tooltip": "(cal.EntryStates.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 4, "dataIndex": "fill_guests", "editable": false, "header": "G\u00e4ste ausf\u00fcllen", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntryStates.fill_guests) ") }, "sortable": false, "tooltip": "(cal.EntryStates.fill_guests) ", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "fixed", "editable": false, "header": "Stabil", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntryStates.fixed) ") }, "sortable": false, "tooltip": "(cal.EntryStates.fixed) ", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "transparent", "editable": false, "header": "nicht blockierend", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntryStates.transparent) ") }, "sortable": false, "tooltip": "(cal.EntryStates.transparent) ", "width": Lino.chars2width(21) }, { "colIndex": 7, "dataIndex": "noauto", "editable": false, "header": "No auto", "listeners": { "render": Lino.quicktip_renderer("","(cal.EntryStates.noauto) ") }, "sortable": false, "tooltip": "(cal.EntryStates.noauto) ", "width": Lino.chars2width(21) } ];
    Lino.cal.EntryStates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.EntryStates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntryStates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntryStates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntryStates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntryStates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntryStates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntryStates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/EntryStates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.EntryStates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/EntryStates" };
  return new Lino.cal.EntryStates.GridPanel(p);
});

// js_render_GridPanel_class cal.ReservationStates
Lino.cal.ReservationStates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/cal/ReservationStates",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "button_text" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/cal/ReservationStates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/ReservationStates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/cal/ReservationStates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/cal/ReservationStates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/cal/ReservationStates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Zust\u00e4nde",
  initComponent : function() {
    var ww = this.containing_window;
    var value4711 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4712 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4713 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var button_text4714 = new Ext.form.TextField({ "disabled": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(cal.ReservationStates.value) ") }, "sortable": true, "tooltip": "(cal.ReservationStates.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(cal.ReservationStates.name) ") }, "sortable": true, "tooltip": "(cal.ReservationStates.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(cal.ReservationStates.text) ") }, "sortable": true, "tooltip": "(cal.ReservationStates.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "button_text", "editable": false, "header": "Button text", "listeners": { "render": Lino.quicktip_renderer("","(cal.ReservationStates.button_text) ") }, "sortable": true, "tooltip": "(cal.ReservationStates.button_text) ", "width": Lino.chars2width(5) } ];
    Lino.cal.ReservationStates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.cal.ReservationStates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ReservationStates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ReservationStates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ReservationStates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ReservationStates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ReservationStates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ReservationStates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/cal/ReservationStates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.cal.ReservationStates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/cal/ReservationStates" };
  return new Lino.cal.ReservationStates.GridPanel(p);
});

// js_render_GridPanel_class calview.Planners
Lino.calview.Planners.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/calview/Planners",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/calview/Planners','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/Planners','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/calview/Planners','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/calview/Planners','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/calview/Planners','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Planners",
  initComponent : function() {
    var ww = this.containing_window;
    var value4716 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4717 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4718 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4719 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4720 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4721 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4722 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(calview.Planners.value) ") }, "sortable": true, "tooltip": "(calview.Planners.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(calview.Planners.name) ") }, "sortable": true, "tooltip": "(calview.Planners.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(calview.Planners.text) ") }, "sortable": true, "tooltip": "(calview.Planners.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(calview.Planners.detail_link) ") }, "sortable": false, "tooltip": "(calview.Planners.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(calview.Planners.button_text) ") }, "sortable": true, "tooltip": "(calview.Planners.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(calview.Planners.remark) ") }, "sortable": false, "tooltip": "(calview.Planners.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(calview.Planners.type) ") }, "sortable": false, "tooltip": "(calview.Planners.type) ", "width": Lino.chars2width(31) } ];
    Lino.calview.Planners.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.calview.Planners.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/Planners", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.Planners.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/Planners", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.Planners.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/Planners", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.Planners.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/calview/Planners", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.calview.Planners.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/calview/Planners" };
  return new Lino.calview.Planners.GridPanel(p);
});

// js_render_GridPanel_class ledger.PeriodStates
Lino.ledger.PeriodStates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/ledger/PeriodStates",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "button_text" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/ledger/PeriodStates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/ledger/PeriodStates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/ledger/PeriodStates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/ledger/PeriodStates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/ledger/PeriodStates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Zust\u00e4nde",
  initComponent : function() {
    var ww = this.containing_window;
    var value4724 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4725 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4726 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var button_text4727 = new Ext.form.TextField({ "disabled": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(ledger.PeriodStates.value) ") }, "sortable": true, "tooltip": "(ledger.PeriodStates.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(ledger.PeriodStates.name) ") }, "sortable": true, "tooltip": "(ledger.PeriodStates.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(ledger.PeriodStates.text) ") }, "sortable": true, "tooltip": "(ledger.PeriodStates.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "button_text", "editable": false, "header": "Button text", "listeners": { "render": Lino.quicktip_renderer("","(ledger.PeriodStates.button_text) ") }, "sortable": true, "tooltip": "(ledger.PeriodStates.button_text) ", "width": Lino.chars2width(5) } ];
    Lino.ledger.PeriodStates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.ledger.PeriodStates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/PeriodStates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.PeriodStates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/PeriodStates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.PeriodStates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/PeriodStates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.PeriodStates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/PeriodStates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.PeriodStates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/ledger/PeriodStates" };
  return new Lino.ledger.PeriodStates.GridPanel(p);
});

// js_render_GridPanel_class ledger.VoucherStates
Lino.ledger.VoucherStates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/ledger/VoucherStates",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "is_editable", "type": "boolean" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/ledger/VoucherStates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/ledger/VoucherStates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/ledger/VoucherStates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/ledger/VoucherStates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/ledger/VoucherStates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Belegzust\u00e4nde",
  initComponent : function() {
    var ww = this.containing_window;
    var value4729 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4730 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4731 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var is_editable_disp4732 = new Ext.form.DisplayField({ "disabled": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(ledger.VoucherStates.value) ") }, "sortable": true, "tooltip": "(ledger.VoucherStates.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(ledger.VoucherStates.name) ") }, "sortable": true, "tooltip": "(ledger.VoucherStates.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(ledger.VoucherStates.text) ") }, "sortable": true, "tooltip": "(ledger.VoucherStates.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "is_editable", "editable": false, "header": "Editierbar", "listeners": { "render": Lino.quicktip_renderer("","(ledger.VoucherStates.is_editable) ") }, "sortable": false, "tooltip": "(ledger.VoucherStates.is_editable) ", "width": Lino.chars2width(21) } ];
    Lino.ledger.VoucherStates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.ledger.VoucherStates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/VoucherStates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.VoucherStates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/VoucherStates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.VoucherStates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/VoucherStates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.VoucherStates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/ledger/VoucherStates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.ledger.VoucherStates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/ledger/VoucherStates" };
  return new Lino.ledger.VoucherStates.GridPanel(p);
});

// js_render_GridPanel_class addresses.AddressTypes
Lino.addresses.AddressTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/addresses/AddressTypes",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/addresses/AddressTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Adressenarten",
  initComponent : function() {
    var ww = this.containing_window;
    var value4734 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4735 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4736 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4737 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4738 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4739 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4740 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressTypes.value) ") }, "sortable": true, "tooltip": "(addresses.AddressTypes.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressTypes.name) ") }, "sortable": true, "tooltip": "(addresses.AddressTypes.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressTypes.text) ") }, "sortable": true, "tooltip": "(addresses.AddressTypes.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressTypes.detail_link) ") }, "sortable": false, "tooltip": "(addresses.AddressTypes.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressTypes.button_text) ") }, "sortable": true, "tooltip": "(addresses.AddressTypes.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressTypes.remark) ") }, "sortable": false, "tooltip": "(addresses.AddressTypes.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.AddressTypes.type) ") }, "sortable": false, "tooltip": "(addresses.AddressTypes.type) ", "width": Lino.chars2width(31) } ];
    Lino.addresses.AddressTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.AddressTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/AddressTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.AddressTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/addresses/AddressTypes" };
  return new Lino.addresses.AddressTypes.GridPanel(p);
});

// js_render_GridPanel_class addresses.DataSources
Lino.addresses.DataSources.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/addresses/DataSources",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/addresses/DataSources','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/DataSources','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/DataSources','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/addresses/DataSources','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/addresses/DataSources','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Datenquellen",
  initComponent : function() {
    var ww = this.containing_window;
    var value4742 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4743 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4744 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4745 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4746 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4747 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4748 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(addresses.DataSources.value) ") }, "sortable": true, "tooltip": "(addresses.DataSources.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(addresses.DataSources.name) ") }, "sortable": true, "tooltip": "(addresses.DataSources.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(addresses.DataSources.text) ") }, "sortable": true, "tooltip": "(addresses.DataSources.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.DataSources.detail_link) ") }, "sortable": false, "tooltip": "(addresses.DataSources.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.DataSources.button_text) ") }, "sortable": true, "tooltip": "(addresses.DataSources.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.DataSources.remark) ") }, "sortable": false, "tooltip": "(addresses.DataSources.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(addresses.DataSources.type) ") }, "sortable": false, "tooltip": "(addresses.DataSources.type) ", "width": Lino.chars2width(31) } ];
    Lino.addresses.DataSources.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.addresses.DataSources.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/DataSources", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.DataSources.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/DataSources", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.DataSources.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/DataSources", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.DataSources.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/addresses/DataSources", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.addresses.DataSources.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/addresses/DataSources" };
  return new Lino.addresses.DataSources.GridPanel(p);
});

// js_render_GridPanel_class households.MemberDependencies
Lino.households.MemberDependencies.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/households/MemberDependencies",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/households/MemberDependencies','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/MemberDependencies','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/households/MemberDependencies','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/MemberDependencies','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/households/MemberDependencies','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Haushaltsmitgliedsabh\u00e4ngigkeiten",
  initComponent : function() {
    var ww = this.containing_window;
    var value4750 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4751 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4752 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4753 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4754 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4755 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4756 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(households.MemberDependencies.value) ") }, "sortable": true, "tooltip": "(households.MemberDependencies.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(households.MemberDependencies.name) ") }, "sortable": true, "tooltip": "(households.MemberDependencies.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(households.MemberDependencies.text) ") }, "sortable": true, "tooltip": "(households.MemberDependencies.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MemberDependencies.detail_link) ") }, "sortable": false, "tooltip": "(households.MemberDependencies.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MemberDependencies.button_text) ") }, "sortable": true, "tooltip": "(households.MemberDependencies.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MemberDependencies.remark) ") }, "sortable": false, "tooltip": "(households.MemberDependencies.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MemberDependencies.type) ") }, "sortable": false, "tooltip": "(households.MemberDependencies.type) ", "width": Lino.chars2width(31) } ];
    Lino.households.MemberDependencies.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.households.MemberDependencies.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MemberDependencies", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MemberDependencies.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MemberDependencies", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MemberDependencies.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MemberDependencies", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MemberDependencies.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MemberDependencies", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MemberDependencies.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/MemberDependencies" };
  return new Lino.households.MemberDependencies.GridPanel(p);
});

// js_render_GridPanel_class households.MemberRoles
Lino.households.MemberRoles.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/households/MemberRoles",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/households/MemberRoles','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/MemberRoles','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/households/MemberRoles','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/households/MemberRoles','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/households/MemberRoles','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Haushaltsmitgliedsrollen",
  initComponent : function() {
    var ww = this.containing_window;
    var value4758 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4759 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4760 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4761 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4762 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4763 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4764 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(households.MemberRoles.value) ") }, "sortable": true, "tooltip": "(households.MemberRoles.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(households.MemberRoles.name) ") }, "sortable": true, "tooltip": "(households.MemberRoles.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(households.MemberRoles.text) ") }, "sortable": true, "tooltip": "(households.MemberRoles.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MemberRoles.detail_link) ") }, "sortable": false, "tooltip": "(households.MemberRoles.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MemberRoles.button_text) ") }, "sortable": true, "tooltip": "(households.MemberRoles.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MemberRoles.remark) ") }, "sortable": false, "tooltip": "(households.MemberRoles.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(households.MemberRoles.type) ") }, "sortable": false, "tooltip": "(households.MemberRoles.type) ", "width": Lino.chars2width(31) } ];
    Lino.households.MemberRoles.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.households.MemberRoles.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MemberRoles", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MemberRoles.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MemberRoles", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MemberRoles.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MemberRoles", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MemberRoles.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/households/MemberRoles", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.households.MemberRoles.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/households/MemberRoles" };
  return new Lino.households.MemberRoles.GridPanel(p);
});

// js_render_GridPanel_class humanlinks.LinkTypes
Lino.humanlinks.LinkTypes.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/humanlinks/LinkTypes",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/humanlinks/LinkTypes','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/humanlinks/LinkTypes','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/humanlinks/LinkTypes','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/humanlinks/LinkTypes','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/humanlinks/LinkTypes','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Verwandschaftsarten",
  initComponent : function() {
    var ww = this.containing_window;
    var value4766 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4767 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4768 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4769 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4770 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4771 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4772 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.LinkTypes.value) ") }, "sortable": true, "tooltip": "(humanlinks.LinkTypes.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.LinkTypes.name) ") }, "sortable": true, "tooltip": "(humanlinks.LinkTypes.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.LinkTypes.text) ") }, "sortable": true, "tooltip": "(humanlinks.LinkTypes.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.LinkTypes.detail_link) ") }, "sortable": false, "tooltip": "(humanlinks.LinkTypes.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.LinkTypes.button_text) ") }, "sortable": true, "tooltip": "(humanlinks.LinkTypes.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.LinkTypes.remark) ") }, "sortable": false, "tooltip": "(humanlinks.LinkTypes.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(humanlinks.LinkTypes.type) ") }, "sortable": false, "tooltip": "(humanlinks.LinkTypes.type) ", "width": Lino.chars2width(31) } ];
    Lino.humanlinks.LinkTypes.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.humanlinks.LinkTypes.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinkTypes", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.LinkTypes.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinkTypes", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.LinkTypes.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinkTypes", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.LinkTypes.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/humanlinks/LinkTypes", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.humanlinks.LinkTypes.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/humanlinks/LinkTypes" };
  return new Lino.humanlinks.LinkTypes.GridPanel(p);
});

// js_render_GridPanel_class courses.CourseStates
Lino.courses.CourseStates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/CourseStates",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "is_exposed", "type": "boolean" }, { "name": "is_editable", "type": "boolean" }, { "name": "is_invoiceable", "type": "boolean" }, { "name": "auto_update_calendar", "type": "boolean" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/CourseStates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/CourseStates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/CourseStates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/CourseStates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/CourseStates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Zust\u00e4nde Aktivit\u00e4t",
  initComponent : function() {
    var ww = this.containing_window;
    var value4774 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4775 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4776 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var is_exposed_disp4777 = new Ext.form.DisplayField({ "disabled": true });
    var is_editable_disp4778 = new Ext.form.DisplayField({ "disabled": true });
    var is_invoiceable_disp4779 = new Ext.form.DisplayField({ "disabled": true });
    var auto_update_calendar_disp4780 = new Ext.form.DisplayField({ "disabled": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(courses.CourseStates.value) ") }, "sortable": true, "tooltip": "(courses.CourseStates.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(courses.CourseStates.name) ") }, "sortable": true, "tooltip": "(courses.CourseStates.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(courses.CourseStates.text) ") }, "sortable": true, "tooltip": "(courses.CourseStates.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "is_exposed", "editable": false, "header": "Exponiert", "listeners": { "render": Lino.quicktip_renderer("","(courses.CourseStates.is_exposed) ") }, "sortable": false, "tooltip": "(courses.CourseStates.is_exposed) ", "width": Lino.chars2width(21) }, { "colIndex": 4, "dataIndex": "is_editable", "editable": false, "header": "Editierbar", "listeners": { "render": Lino.quicktip_renderer("","(courses.CourseStates.is_editable) ") }, "sortable": false, "tooltip": "(courses.CourseStates.is_editable) ", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "is_invoiceable", "editable": false, "header": "Invoiceable", "listeners": { "render": Lino.quicktip_renderer("","(courses.CourseStates.is_invoiceable) ") }, "sortable": false, "tooltip": "(courses.CourseStates.is_invoiceable) ", "width": Lino.chars2width(21) }, { "colIndex": 6, "dataIndex": "auto_update_calendar", "editable": false, "header": "Update calendar", "listeners": { "render": Lino.quicktip_renderer("","(courses.CourseStates.auto_update_calendar) ") }, "sortable": false, "tooltip": "(courses.CourseStates.auto_update_calendar) ", "width": Lino.chars2width(21) } ];
    Lino.courses.CourseStates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.CourseStates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/CourseStates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.CourseStates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/CourseStates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.CourseStates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/CourseStates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.CourseStates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/CourseStates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.CourseStates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/CourseStates" };
  return new Lino.courses.CourseStates.GridPanel(p);
});

// js_render_GridPanel_class courses.EnrolmentStates
Lino.courses.EnrolmentStates.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/EnrolmentStates",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "button_text" }, { "name": "invoiceable", "type": "boolean" }, { "name": "uses_a_place", "type": "boolean" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentStates','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentStates','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentStates','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentStates','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/EnrolmentStates','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Zust\u00e4nde Einschreibung",
  initComponent : function() {
    var ww = this.containing_window;
    var value4782 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4783 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4784 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var button_text4785 = new Ext.form.TextField({ "disabled": true });
    var invoiceable_disp4786 = new Ext.form.DisplayField({ "disabled": true });
    var uses_a_place_disp4787 = new Ext.form.DisplayField({ "disabled": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentStates.value) ") }, "sortable": true, "tooltip": "(courses.EnrolmentStates.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentStates.name) ") }, "sortable": true, "tooltip": "(courses.EnrolmentStates.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentStates.text) ") }, "sortable": true, "tooltip": "(courses.EnrolmentStates.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "button_text", "editable": false, "header": "Button text", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentStates.button_text) ") }, "sortable": true, "tooltip": "(courses.EnrolmentStates.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 4, "dataIndex": "invoiceable", "editable": false, "header": "Fakturierbar", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentStates.invoiceable) ") }, "sortable": false, "tooltip": "(courses.EnrolmentStates.invoiceable) ", "width": Lino.chars2width(21) }, { "colIndex": 5, "dataIndex": "uses_a_place", "editable": false, "header": "Besetzt einen Platz", "listeners": { "render": Lino.quicktip_renderer("","(courses.EnrolmentStates.uses_a_place) ") }, "sortable": false, "tooltip": "(courses.EnrolmentStates.uses_a_place) ", "width": Lino.chars2width(21) } ];
    Lino.courses.EnrolmentStates.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.EnrolmentStates.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentStates", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentStates.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentStates", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentStates.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentStates", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentStates.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/EnrolmentStates", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.EnrolmentStates.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/EnrolmentStates" };
  return new Lino.courses.EnrolmentStates.GridPanel(p);
});

// js_render_GridPanel_class courses.ActivityLayouts
Lino.courses.ActivityLayouts.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/courses/ActivityLayouts",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "courses_table" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/courses/ActivityLayouts','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivityLayouts','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivityLayouts','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/courses/ActivityLayouts','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/courses/ActivityLayouts','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Aktivit\u00e4tenlayouts",
  initComponent : function() {
    var ww = this.containing_window;
    var value4789 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4790 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4791 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var courses_table4792 = new Ext.form.TextField({ "disabled": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivityLayouts.value) ") }, "sortable": true, "tooltip": "(courses.ActivityLayouts.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivityLayouts.name) ") }, "sortable": true, "tooltip": "(courses.ActivityLayouts.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivityLayouts.text) ") }, "sortable": true, "tooltip": "(courses.ActivityLayouts.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "courses_table", "editable": false, "header": "Table", "listeners": { "render": Lino.quicktip_renderer("","(courses.ActivityLayouts.courses_table) ") }, "sortable": true, "tooltip": "(courses.ActivityLayouts.courses_table) ", "width": Lino.chars2width(5) } ];
    Lino.courses.ActivityLayouts.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.courses.ActivityLayouts.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivityLayouts", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivityLayouts.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivityLayouts", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivityLayouts.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivityLayouts", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivityLayouts.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/courses/ActivityLayouts", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.courses.ActivityLayouts.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/courses/ActivityLayouts" };
  return new Lino.courses.ActivityLayouts.GridPanel(p);
});

// js_render_GridPanel_class excerpts.Shortcuts
Lino.excerpts.Shortcuts.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/excerpts/Shortcuts",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/excerpts/Shortcuts','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/Shortcuts','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/Shortcuts','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/excerpts/Shortcuts','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/excerpts/Shortcuts','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Excerpt shortcuts",
  initComponent : function() {
    var ww = this.containing_window;
    var value4794 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4795 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4796 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4797 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4798 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4799 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4800 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Shortcuts.value) ") }, "sortable": true, "tooltip": "(excerpts.Shortcuts.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Shortcuts.name) ") }, "sortable": true, "tooltip": "(excerpts.Shortcuts.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Shortcuts.text) ") }, "sortable": true, "tooltip": "(excerpts.Shortcuts.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Shortcuts.detail_link) ") }, "sortable": false, "tooltip": "(excerpts.Shortcuts.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Shortcuts.button_text) ") }, "sortable": true, "tooltip": "(excerpts.Shortcuts.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Shortcuts.remark) ") }, "sortable": false, "tooltip": "(excerpts.Shortcuts.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(excerpts.Shortcuts.type) ") }, "sortable": false, "tooltip": "(excerpts.Shortcuts.type) ", "width": Lino.chars2width(31) } ];
    Lino.excerpts.Shortcuts.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.excerpts.Shortcuts.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Shortcuts", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Shortcuts.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Shortcuts", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Shortcuts.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Shortcuts", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Shortcuts.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/excerpts/Shortcuts", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.excerpts.Shortcuts.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/excerpts/Shortcuts" };
  return new Lino.excerpts.Shortcuts.GridPanel(p);
});

// js_render_GridPanel_class comments.Emotions
Lino.comments.Emotions.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/Emotions",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "button_text" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/Emotions','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Emotions','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Emotions','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/Emotions','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/Emotions','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Emotionen",
  initComponent : function() {
    var ww = this.containing_window;
    var value4802 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4803 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4804 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var button_text4805 = new Ext.form.TextField({ "disabled": true });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(comments.Emotions.value) ") }, "sortable": true, "tooltip": "(comments.Emotions.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(comments.Emotions.name) ") }, "sortable": true, "tooltip": "(comments.Emotions.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(comments.Emotions.text) ") }, "sortable": true, "tooltip": "(comments.Emotions.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "button_text", "editable": false, "header": "Button text", "listeners": { "render": Lino.quicktip_renderer("","(comments.Emotions.button_text) ") }, "sortable": true, "tooltip": "(comments.Emotions.button_text) ", "width": Lino.chars2width(5) } ];
    Lino.comments.Emotions.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.Emotions.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Emotions", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Emotions.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Emotions", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Emotions.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Emotions", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Emotions.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/Emotions", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.Emotions.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/Emotions" };
  return new Lino.comments.Emotions.GridPanel(p);
});

// js_render_GridPanel_class comments.CommentEvents
Lino.comments.CommentEvents.GridPanel = Ext.extend(Lino.GridPanel,{
  ls_url : "/comments/CommentEvents",
  ls_store_fields : [ { "name": "value" }, { "name": "name" }, { "name": "text" }, { "name": "detail_link" }, { "name": "button_text" }, { "name": "remark" }, { "name": "type" } ],
  ls_id_property : null,
  pk_index : 0,
  cell_edit : true,
  focus_on_quick_search : false,
  ls_bbar_actions : [ { "auto_save": true, "iconCls": "x-tbar-html", "itemId": "show_as_html", "menu_item_text": "HTML", "overflowText": "HTML", "panel_btn_handler": Lino.list_action_handler('/comments/CommentEvents','show_as_html','GET',Lino.get_current_grid_config), "tooltip": "Show this table in Bootstrap3 interface", "tooltipType": "title" }, { "iconCls": "x-tbar-page_white_acrobat", "menu": [ { "auto_save": true, "itemId": "as_pdf", "menu_item_text": "Tabelle (Querformat)", "overflowText": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentEvents','as_pdf','GET',Lino.get_current_grid_config), "text": "Tabelle (Querformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" }, { "auto_save": true, "itemId": "as_pdf_p", "menu_item_text": "Tabelle (Hochformat)", "overflowText": "Tabelle (Hochformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentEvents','as_pdf_p','GET',Lino.get_current_grid_config), "text": "Tabelle (Hochformat)", "tooltip": "Show this table as a pdf document.", "tooltipType": "title" } ], "menu_item_text": "Tabelle (Querformat)", "panel_btn_handler": Lino.list_action_handler('/comments/CommentEvents','as_pdf','GET',Lino.get_current_grid_config), "text": null, "xtype": "splitbutton" }, { "auto_save": true, "iconCls": "x-tbar-page_excel", "itemId": "export_excel", "menu_item_text": "Export to .xls", "overflowText": "Export to .xls", "panel_btn_handler": Lino.list_action_handler('/comments/CommentEvents','export_excel','GET',Lino.get_current_grid_config), "tooltip": "Export this table as an .xls document", "tooltipType": "title" } ],
  viewConfig : { "emptyText": "Keine Daten anzuzeigen.", "forceFit": true },
  disable_editing : true,
  params_panel_hidden : true,
  page_length : 20,
  stripeRows : true,
  title : "Beobachtungskriterien",
  initComponent : function() {
    var ww = this.containing_window;
    var value4807 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var name4808 = new Ext.form.TextField({ "disabled": true, "maxLength": 20 });
    var text4809 = new Ext.form.TextField({ "disabled": true, "maxLength": 50 });
    var detail_link_disp4810 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var button_text4811 = new Ext.form.TextField({ "disabled": true, "hidden": true });
    var remark_disp4812 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    var type_disp4813 = new Ext.form.DisplayField({ "always_enabled": true, "disabled": true, "hidden": true, "value": "<br/>" });
    this.before_row_edit = function(record) {
    };
    this.ls_columns = [ { "colIndex": 0, "dataIndex": "value", "editable": false, "header": "Wert", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentEvents.value) ") }, "sortable": true, "tooltip": "(comments.CommentEvents.value) ", "width": Lino.chars2width(22) }, { "colIndex": 1, "dataIndex": "name", "editable": false, "header": "name", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentEvents.name) ") }, "sortable": true, "tooltip": "(comments.CommentEvents.name) ", "width": Lino.chars2width(22) }, { "colIndex": 2, "dataIndex": "text", "editable": false, "header": "Text", "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentEvents.text) ") }, "sortable": true, "tooltip": "(comments.CommentEvents.text) ", "width": Lino.chars2width(22) }, { "colIndex": 3, "dataIndex": "detail_link", "editable": false, "header": "Beschreibung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentEvents.detail_link) ") }, "sortable": false, "tooltip": "(comments.CommentEvents.detail_link) ", "width": Lino.chars2width(31) }, { "colIndex": 4, "dataIndex": "button_text", "editable": false, "header": "Button text", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentEvents.button_text) ") }, "sortable": true, "tooltip": "(comments.CommentEvents.button_text) ", "width": Lino.chars2width(5) }, { "colIndex": 5, "dataIndex": "remark", "editable": false, "header": "Bemerkung", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentEvents.remark) ") }, "sortable": false, "tooltip": "(comments.CommentEvents.remark) ", "width": Lino.chars2width(31) }, { "colIndex": 6, "dataIndex": "type", "editable": false, "header": "Art", "hidden": true, "listeners": { "render": Lino.quicktip_renderer("","(comments.CommentEvents.type) ") }, "sortable": false, "tooltip": "(comments.CommentEvents.type) ", "width": Lino.chars2width(31) } ];
    Lino.comments.CommentEvents.GridPanel.superclass.initComponent.call(this);
  }
});

Lino.comments.CommentEvents.show_as_html = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentEvents", "GET", pk, "show_as_html", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentEvents.as_pdf = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentEvents", "GET", pk, "as_pdf", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentEvents.as_pdf_p = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentEvents", "GET", pk, "as_pdf_p", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentEvents.export_excel = function(rp, is_main, pk, params) { 
  var h = function() { 
    Lino.run_row_action(rp, is_main, "/comments/CommentEvents", "GET", pk, "export_excel", params, Lino.get_current_grid_config);
  };
  var panel = Ext.getCmp(rp);
  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();
};
Lino.comments.CommentEvents.grid = new Lino.WindowAction({  }, function(){
  var p = { "is_main_window": true, "ls_url": "/comments/CommentEvents" };
  return new Lino.comments.CommentEvents.GridPanel(p);
});
